diff --git a/Makefile b/Makefile
index 1e4ea38..3746d3b 100644
--- a/Makefile
+++ b/Makefile
@@ -1,4 +1,4 @@
-VERSION:="Axiom (May 2012)"
+VERSION:="Axiom (August 2014)"
 
 ##### special paths
 SPD:=$(shell pwd)
diff --git a/Makefile.pamphlet b/Makefile.pamphlet
index a8ac5ea..ae6eeba 100644
--- a/Makefile.pamphlet
+++ b/Makefile.pamphlet
@@ -446,7 +446,7 @@ to the document command. This will allow it to be
 changed on the command line.
 \section{The Environment}
 \begin{chunk}{ENVDEFAULTS}
-VERSION:="Axiom (May 2012)"
+VERSION:="Axiom (August 2014)"
 
 ##### special paths
 SPD:=$(shell pwd)
diff --git a/books/bookvol13.pamphlet b/books/bookvol13.pamphlet
index 3ef8ad5..e3d0681 100644
--- a/books/bookvol13.pamphlet
+++ b/books/bookvol13.pamphlet
@@ -4,6 +4,20 @@
 \input{bookheader.tex}
 \mainmatter
 \setcounter{chapter}{0} % Chapter 1
+\begin{quote}
+{\bf Our basic premise is that the ability to construct and modify programs
+will not improve without a new and comprehensive look at the entire
+programming process. Past theoretical research, say, in the logic of
+programs, has tended to focus on methods for reasoning about
+individual programs; little has been done, it seems to us, to develop
+a sound understanding of the process of programming -- the process by
+which programs evolve in concept and in practice. At present, we lack
+the means to describe the techniques of program construction and
+improvement in ways that properly link verification, documentation and
+adaptability.}
+
+-- Scherlis and Scott (1983) in \cite{Mason86}
+\end{quote}
 \chapter{Here is a problem}
 The goal is to prove that Axiom's implementation of 
 the Euclidean GCD algorithm is correct.
@@ -173,6 +187,13 @@ Install OCAML
 \begin{verbatim}
 sudo apt-get install ocaml
 \end{verbatim}
+
+An OCAML version of gcd would be written 
+\begin{verbatim}
+let rec gcd a b = if b = 0 then a else gcd b (a mod b)
+val gcd : int -> int -> int = <fun>
+\end{verbatim}
+
 \begin{thebibliography}{99}
 \section{Coq Spad proofs}
 
@@ -193,8 +214,7 @@ The OCAML website\\
 
 \bibitem[Daly 10]{Daly10} Daly, Timothy\\
 ``Intel Instruction Semantics Generator''\\
-\verb|daly.axiom-developer.org/TimothyDaly_files/publications/sei/|
-\verb|intel/intel.pdf|
+\verb|daly.axiom-developer.org/TimothyDaly_files/publications/sei/intel/intel.pdf|
 
 \bibitem[Hardin 13]{Hard13} Hardin, David S.; McClurg, Jedidiah R.; 
 Davis, Jennifer A.\\
diff --git a/books/bookvol7.1.pamphlet b/books/bookvol7.1.pamphlet
index 536b1a4..04c5c59 100644
--- a/books/bookvol7.1.pamphlet
+++ b/books/bookvol7.1.pamphlet
@@ -9,6 +9,7 @@
 \pagepic{ps/v71releasenotes.eps}{releasenotes}{0.65}
 \pagefrom{Root Page}{RootPage}
 \pageto{Online information}{onlineInformation}
+\pageto{August 2014}{aug2014}
 \pageto{May 2012}{may2012}
 \pageto{March 2012}{mar2012}
 \pageto{January 2012}{jan2012}
@@ -43,6 +44,7 @@
 \beginscroll
 \beginmenu
     \menudownlink{Online information}{onlineInformation}
+    \menudownlink{August 2014}{aug2014}
     \menudownlink{May 2012}{may2012}
     \menudownlink{March 2012}{mar2012}
     \menudownlink{January 2012}{jan2012}
@@ -94,6 +96,486 @@ Axiom information can be found online at
 
 \end{chunk}
 
+\pagetitle{aug2014}{releasenotes.ht}{August 2014 Release Notes}
+\pagepic{ps/v71aug2014.eps}{aug2014}{0.40}
+\pagefrom{What's New in Axiom}{releaseNotes}
+\begin{chunk}{releasenotes.ht}
+\begin{page}{aug2014}{August 2014 Release Notes}
+\beginscroll
+\begin{verbatim}
+August 2014 release notes
+
+This release moves Axiom to the latest GCL version.
+All unused prior versions were removed.
+
+Most of the work involved in this release has involved CATS,
+working with Albert Rich to develop Axiom tests.
+
+Noweb was removed. Axiom now uses its own literate tools.
+
+The databases are no longer compressed.
+
+Volume 13: Proving Axiom Correct was started
+
+Makefile.pamphlet
+   VERSION = August 2014
+   TESTSET defaults to regresstests
+   fix missing dvipdfm
+   remove noweb
+
+book/
+   new directory containing axiom-developer emails
+   reduce and categorize emails for history
+   create timeline of people joining/leaving
+
+books/
+   axiom.sty
+      document
+      remove all other sources
+      add additional macros
+   axbook.tgz
+      fix sinCosExpandRules
+   dvipdfm.def
+      added
+   tanglec.c
+      new C function to handle chunks
+   tangle.lisp
+      add fastxhtml extraction from bookvol11
+   extract (rename from document)
+      support new chunk syntax
+   ps/
+      move .ps to .eps 
+      add new images
+
+books/Makefile
+   handle bookheader.tex
+   fix broken sed regular expression
+   add bookvol13 (Proving Axiom Correct)
+
+books/bookheader.tex
+   user underline, colored links
+   standardize headers, table of contents
+
+books/bookvol0 (Jenks)
+   add condata for MAGCDOC
+   add graphics, fix typos, add text
+
+books/bookvol1 (tutorial)
+   use bookheader.tex
+   fix typos
+
+books/bookvol2 (users guide)
+   use bookheader.tex
+   add category theory chapter
+   remove noweb
+
+books/bookvol3 (programmers guide)
+   use bookheader.tex
+   remove noweb
+
+books/bookvol4 (developers guide)
+   use bookheader.tex
+   section on changing GCL versions
+   document makeHelpFiles
+   remove autoload files
+   remove noweb
+   add HACKPI section
+
+books/bookvol5 (interpreter)
+   use bookheader.tex
+   fix GETL for GCL
+   add Attributes as Categories
+   add Comparable
+   add LeftOreRing
+   add U32Matrix support macros
+   add bc-matrix code
+   add support code for U8Vector
+   add support code for U32Vector
+   add support code for U8Matrix
+   add support code for U16Matrix
+   add U32VectorPolyunomialOperations
+   expose FiniteFieldFactorization
+   expose MAGCDOC
+   expose MatrixManipulation
+   rename functionp to canFuncall?
+   incremental rewrite of br-con.lisp
+   merge ht-util.lisp
+
+books/bookvol6 (commands)
+   use bookheader.tex
+
+books/bookvol7 (hyperdoc)
+   apply Camm's patches
+   remove bibliography
+   standardize the table of contents
+   update credits
+   use bookheader.tex
+
+books/bookvol7.1 (hyperdoc pages)
+   standardize the table of contents
+   update What's New Page
+   update credits
+   use bookheader.tex
+
+books/bookvol8 (graphics)
+   apply Camm's patches
+   convert bookvol8 from noweb to chunks
+   remove crc test cases
+   standardize the table of contents
+   update credits
+   use bookheader.tex
+   remove noweb
+
+books/bookvol8.1 (graphics gallery)
+   add CRC standard test cases, section 2.3-2.9
+
+books/bookvol9 (compiler)
+   use bookheader.tex
+   functionp -> canFuncall?
+
+books/bookvol10 (algebra implementation)
+   absorb src/algebra/Makefile
+   use bookheader.tex
+
+books/bookvol10.1 (algebra theory)
+   add interval arithmetic
+   add section on interpolation formulas
+   use bookheader.tex
+
+books/bookvol10.2 (categories)
+   AGG bug fixed 40355
+   CLAGG bug fixed 40021
+   MONAD bug fix 40350, add 7236
+   ORDSET bug fix 40346
+   PTRANFN bug fixed 40357
+   REAL bug fix 40345
+   add Attributes as Categories
+   add Comparable
+   add LeftOreRing
+   add MAGCDOC
+   add enumerate to FINITE
+   add matrix initializer function
+   fix failing test cases
+   fix help documentation and regression tests
+   use bookheader.tex
+   write help documentation for all categories
+   FiniteSetAggregate subset? fixed
+   BinaryTreeCategory remove finiteAggregate, bug fix 7255
+
+books/bookvol10.3 (domains)
+   AFFSP bug fix 30230, 20495; introduce 60076
+   BLAS1 bug fixed 40304
+   CHAR bug fix 40022
+   DFLOAT bug fix 20073, add 20570
+   DFLOAT bug fixed 40019
+   FPS bug fixed 40013
+   INBFF bug fixed 20465, add 20571
+   INTRVL bug fix 20480, 30143
+   ITAYLOR bug fix 20542 pretend
+   LIST bug fix 20063, add, add 20569
+   MLIFT bug fix 20001, add 20568
+   OPTPROB bug fix 40347
+   RNUMP removed bug fix 30047
+   SINT bug fix 20057 pretend
+   SMTS bug fix 20383, 50005, add 20567
+   SYMBOL bug fix 20056 pretend
+   add U16Matrix
+   add U16Vector
+   add U32Matrix
+   add U8Matrix
+   add U8Vector
+   add information to SingleInteger
+   SEXOF bug fix 20501
+   fix failing test cases
+   fix help documentation and regression tests
+   move EFULS EFUPXS from package to domain
+   update U32Vector domain
+   use bookheader.tex
+   write help documentation for all domains
+
+books/bookvol10.4 (packages)
+   ATTREG bug fix 40362
+   ELTAB bug fix 40360
+   FSPECF bug fix 7235, 40077
+   GRAY bug fixed 20467
+   MAPPKG1 bug fix 40351
+   MSYSCMD bug fix 40359
+   SOLVERAD bug fix 40043
+   SREGSET bug fix 50001
+   add FiniteFieldFactorization
+   add MatrixManipulation, add Raoul Bourquin
+   add U32VectorPolynomialOperations
+   apply Waldek's changes to imposelc in PGCD
+   comment out bad code in GUESS
+   document htrigs function in TRMANIP
+   expand hyperbolic identities
+   bug fix "bad reduction" in multivariate poly gcd
+   bug fix ++X function example in gcd
+   bug fix OUT.spad warning (bug 329)
+   bug fix failing test cases
+   bug fix help documentation and regression tests
+   move EFULS EFUPXS from package to domain
+   use bookheader.tex
+   write help documentation
+   add reportInstantiations to API package
+
+books/bookvol10.5 (numerics)
+   add netlib cephes function covers
+   use bookheader.tex
+
+books/bookvol11 (browser)
+   use bookheader.tex
+   remove noweb
+
+books/bookvol12 (crystal)
+   remove noweb
+
+books/bookvol13 (proving axiom correct)
+   created
+
+books/bookvolbib (bibliography)
+   add references and abstracts
+   add subsection Ore Rings 
+   add subsection Partial Fraction Decomposition
+   add subsection Integration
+   add subsection Expression Simplification
+   add subsection Differential Equations
+   add subsection Advanced Documentation
+   add subsection Numerics
+   add subsection Interval Arithmetic
+   add subsection Proving Axiom Correct
+   add subsection Category Theory
+   add subsection Polynomial GCD
+   add subsection Exponenetial Integral
+   add subsection Special Functions
+   add subsection Numerical Algorithms
+   add subsection Solving Systems of Equations
+
+buglist
+   MLIFT fix 20001, add 20568
+   AGG fixed 40355
+   ATTREG fix 40362
+   BLAS1 fixed 40304
+   CHAR fix 40022
+   CLAGG fixed 40021
+   DFLOAT fix 20073, add 20570
+   DFLOAT fixed 40019
+   ELTAB fix 40360
+   FPS fixed 40013
+   FSPECF fix 7235, 40077
+   GRAY fixed 20467
+   INBFF fixed 20465, add 20571
+   INTRVL fix 20480, 30143
+   ITAYLOR fix 20542 pretend
+   LIST fix 20063, add, add 20569
+   MAPPKG1 fix 40351
+   MONAD fix 40350, add 7236
+   MSYSCMD fix 40359
+   OPTPROB fix 40347
+   ORDSET fix 40346
+   PTRANFN fixed 40357
+   REAL fix 40345
+   SINT fix 20057 pretend
+   SMTS fix 20383, 50005, add 20567
+   SOLVERAD fix 40043
+   SREGSET fix 50001
+   SYMBOL fix 20056 pretend
+   fix bug 7072/19 D(0^z, z) closed
+   fix bug 7248: differentiation fix bug in D(1,z)
+   fix bug 7249: radicalSolve(z^7=1, z)
+   fix bug 7249: radicalSolve(z^7=1, z) update
+   fix bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float
+   fix bug 7252: argument(-%i)
+   fix bug 7253: There are no library operations named 'when'
+   fix bug 7254: f==n+->sum(sum(1/i,i=1..j),j=1..n) complains
+   fix bug 7256: acot(-1) values differ
+   fix bug 7257: normalize(subst(asin(z),z=-1)) division by zero
+   fix bug 7258: acosh(0.0) invalid argument to acosh
+   fix bug 20501, SEXOF pretend, 30047 RNUMP
+   fix bug 30230, 20495; introduce 60076
+   fix bug 7236
+   fix bug 329, add todo 330
+   remove dead items
+   remove error message for deleted files
+   add 7142 exp^log(x) Cannot take first of an empty list update
+   add 7233: fill! operation from U8Vector does not show up
+   add 7242/7243
+   add 7244, 7245
+   add bug 7241, fix the integration routines
+   add bugs found in tests
+   add kamke4, kamke6 missing bug
+   add todo 335: add packages to )d op gcd
+   add 7232
+   wish 1011: sum(1/(k+a), k=1..n) by Gosper's method
+
+Wikipedia
+   en.wikipedia.org/wiki/Axiom_(computer_algebra_system) update date
+   en.wikipedia.org/wiki/List_of_computer_algebra_systems update date
+
+faq
+   remove noweb
+   fix mailing list links
+
+readme
+   add Edi Meier
+   add Edi Meier
+   add Jia Zhao Cong
+   add Raoul Bourquin
+   update credits
+
+src/Makefile
+   clean up src/algebra properly
+   convert bookvol8 from noweb to chunks
+   fix {OUT} bug
+   handle special case files for bookvol11
+   rename tangle.c to tanglec.c
+   pamphlet extract src using chunk syntax
+   pamphlet modified, noweb removed
+
+src/algebra/Makefile
+   add Comparable
+   add FINITE-
+   add LeftOreRing
+   add MatrixManipulation
+   add U16Matrix
+   add U32Matrix
+   add U32VectorPolynomialOperations
+   add U8Matrix
+   add fastxhtml extraction call
+   add machinearithmetic.input
+   compile FiniteFieldFactorization
+   compile MAGCDOC
+   fix failing test cases
+   set up regression tests
+   update graph info for OUT
+   modified, noweb removed
+
+src/algebra/libdb.text
+   add Attributes as Categories
+
+src/axiom-website/
+   AxiomConference.pdf added
+   axiom.sty
+   CATS/
+      charlwood.input added
+      rich* added
+      kamke*.txt added
+   books/
+      add 8.1, 10.5, bibliography
+      add bookvol13
+   community/
+      fix mailing list links
+   documentation.html
+      add AxiomConference.pdf
+      add Bottorff quote
+      add Knuth quote, cleanup
+      add Lamport quote
+      add McNamara quote
+      add Stroustrop quote
+      add W.T. Gowers quote
+   download.html
+      add binaries
+      add texlive-fonts-extra
+   patches.html
+      add patches
+   releasenotes.html
+       update for August 2014
+
+src/booklets
+   Makefile cleanup
+
+src/clef
+   Makefile rename tangle to tanglec
+   edible.c modified, noweb removed
+
+src/doc
+   export endpaper as pdf
+   remove axiom.bib
+   rename tangle to tanglec
+   use books/axiom.sty
+   remove noweb
+   booklet.c fix mailing list, remove noweb
+   msgs/
+      s2-us.msgs remove .as extension from compiler msg
+
+src/etc
+   Makefile remove noweb
+   asq.c remove noweb
+
+src/input/
+   Makefile add input tests for 
+      charlwood, cherry, functioncode, machinarithmetic,
+      pgcd, polygamma, rich*, romanpolynomials, rsa, segletes
+      exptest, subset, tree, trigtests
+   Makefile remove noweb
+   add many tests
+
+src/interp
+   Makefile
+      remove noweb
+      remove autoload of ht-util
+      remove bc-matrix
+    bc-matrix.lisp removed
+    br-con.lisp move to bookvol5
+    debugsys cleanup
+    g-timer.lisp RNUMP removed
+    g-util.lisp functionp -> canFuncall?
+    g-util.lisp remove functions
+    ht-util.lisp deleted, merged with bookvol5
+    i-coerce.lisp functionp -> canFuncall?
+    i-funsel.lisp remove functions
+    i-spec2.lisp. functionp -> canFuncall?
+    interp-proclaims.lisp functionp -> canFuncall?
+    regress.lisp improve diff output
+    sys-pkg.lisp RNUMP removed
+    temp.text deleted
+    util.lisp functionp -> canFuncall?
+    util.lisp remove autoload of ht-util
+    util.lisp remove autoload trigger functions
+    util.lisp remove bc-matrix autoload triggers
+    util.lisp remove compression
+    vmlisp.lisp RNUMP removed
+
+src/scripts
+   Makefile remove noweb
+   boxhead removed
+   boxtail removed
+   boxup removed
+   document -> books/extract
+   showdvi removed
+   tex/
+      axiom.sty removed
+
+src/share
+   Makefile remove noweb
+   algebra/compress removed
+   algebra/browse, category, dependents, interp, operations, users
+      add Attributes as Categories
+      add LeftOreRing
+      enumerate to FINITE
+      no compression
+      updated
+   doc/
+      hypertex/pages/util.ht deleted, unused
+
+src/sman
+   Makefile cleanup
+
+zips/
+   axiom.vim.tgz vim syntax file added
+   gcl-cgywin.tgz added
+   noweb-2.10a.tgz deleted, noweb removed
+   noweb.* deleted, noweb removed
+   all unused patches and versions of gcl deleted
+
+\end{verbatim}
+\endscroll
+\autobuttons
+\end{page}
+
+\end{chunk}
+
+
 \pagetitle{may2012}{releasenotes.ht}{May 2012 Release Notes}
 \pagepic{ps/v71may2012.eps}{may2012}{0.40}
 \pagefrom{What's New in Axiom}{releaseNotes}
diff --git a/books/ps/v71aug2014.eps b/books/ps/v71aug2014.eps
new file mode 100644
index 0000000..5991c4e
--- /dev/null
+++ b/books/ps/v71aug2014.eps
@@ -0,0 +1,2732 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: GIMP PostScript file plugin V 1.17 by Peter Kirchgessner
+%%Title: v71aug2014.eps
+%%CreationDate: Mon Jul 28 02:06:27 2014
+%%DocumentData: Clean7Bit
+%%LanguageLevel: 2
+%%Pages: 1
+%%BoundingBox: 14 14 715 487
+%%EndComments
+%%BeginProlog
+% Use own dictionary to avoid conflicts
+10 dict begin
+%%EndProlog
+%%Page: 1 1
+% Translate for offset
+14.173228346456694 14.173228346456694 translate
+% Translate to begin of first scanline
+0 471.93416422947126 translate
+699.90236220472445 -471.93416422947126 scale
+% Image geometry
+700 472 8
+% Transformation matrix
+[ 700 0 0 472 0 0 ]
+% Strings to hold RGB-samples per scanline
+/rstr 700 string def
+/gstr 700 string def
+/bstr 700 string def
+{currentfile /ASCII85Decode filter /RunLengthDecode filter rstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter gstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter bstr readstring pop}
+true 3
+%%BeginData:       149429 ASCII Bytes
+colorimage
+!rr2kJb4NcJb4NcJb7.X!qlKkJ,~>
+!rr2kJb4NcJb4NcJb7.X!qlKkJ,~>
+!rr2kJb4NcJb4NcJb7.X!qlKkJ,~>
+!rVZYJaJ$UJaJ$UJaLYJ!q5aYJ,~>
+!rVZYJaJ$UJaJ$UJaLYJ!q5aYJ,~>
+!rVZYJaJ$UJaJ$UJaLYJ!q5aYJ,~>
+!VPi2m"+MSm"+MSm)eSpmIbu~>
+!VPi2m"+MSm"+MSm)eSpmIbu~>
+!VPi2m"+MSm"+MSm)eSpmIbu~>
+!:PL)Ja:SH!TVr4f`Bg[rn7G,j6D3]Ja83Z!:PF~>
+!:PL)Ja:SH!TVr4f`Bg[rn7G,j6D3]Ja83Z!:PF~>
+!:PL)Ja:SH!TVr4f`Bg[rn7G,j6D3]Ja83Z!:PF~>
+q<AFQjP%D&DfTi8KYZ=&kkaQRkiCI5Jo>XKDh>dYjQQI*%Hum,^k?WGEGU<Dg>qIKlAY!0_U?g1
+cN2D?rQkVp_rQC6Ja/*WJ,~>
+q<AFQjP%D&DfTi8KYZ=&kkaQRkiCI5Jo>XKDh>dYjQQI*%Hum,^k?WHEGU<Dg>qIKlAY!0_U?g1
+cN2D?rQkVp_rQC6Ja/*WJ,~>
+q<AFQjP%D&DfTi8KYZ=&kkaQRkiCI5Jo,LIDh>dYjQQI*%Hum,^k?WGE,:3Cg>qIKlAY!0_U?g1
+cN2D?rQkVp_rQC6Ja/*WJ,~>
+q<8@KespQ*O.Dc#I;GG)j8/!Lj49`9I>jV`NdY]5f&QVk%HH$0D17P:RZ)W0SCZ_Ol&=j3XO>PN
+g=tE=rnRP-!NP(/l%/)Ul$r~>
+q<8@KespQ*O.Dc#I;GG)j8/!Lj49`9I?'eeNdY]5f&QVk%HH$0D17P:RuD`1SCZ_Ol&=j3XO>PN
+g=tE=rnRP-!NP(/l%/)Ul$r~>
+q<8@KespQ*O.Dc#I;GG)j8/!Lj49`9I>jS_N.#K3f&QVk%HH$0D17M8RYuQ/SCZ_Ol&=j3XO>PN
+g=tE=rnRP-!NP(/l%/)Ul$r~>
+q</:>TQcBsbMhC%XGqFsfD=\?f:dDKXNKJ[bH6hLU"B/)%G.:tNipRahoMjXGG*Q=k`"^/Z/3Ws
+V;M7>"OGNWZJYNB!O@FXkQ-^*jQHWjE;k+`P.uS3J`sc1J,~>
+q</:>TQcBsbMhC%XGqFsfD=\?f:dDKXNTS]bH?nMU"B/)%G.:tO06^dhoMjXGG*Q=k`"^/Z/3Ws
+V;M7>"OGNWZJYNB!J[]TkQ9a_[H-NOYPi_IR*pQLJ`sc1J,~>
+q</:>TQcBsbMhC%XGqFsfD=\?f:dDJXNBAWb,gVIU"B/)%G.:tNigI]hSlLSGG*Q=k`"^/Z/3Ws
+V;M7>"OGNWZJYQC!oS1AroaF.C!Yl(!1!P/!e7*(J`q[K]]ak~>
+q<&4(KU]HhcIgdn`4)4h_YWF)_Le8e`6R&icG[5^K#7BI%Dmdg\AZ\Ff#kn?S:nb1kD\R6ZL?Y$
+A$GS$qWbKBpU/lSk5h2HrT=2r=le`Na=V"_E\/l.J`hUI^#sn~>
+q<&4(KU]HhcIgdn`4)4h_YWF)_Le8e`6R)jcG[5^K#7BI%Dmdg\AZ\Ff#kn?S:nb1kD\R6ZL?Y$
+A$GS$qWbKBpU/lSk5e>FroX@>/XYV^#Fd;pL0Q;^^k(["kIp&/~>
+q<&4(KU]HhcIgdn`4)4h_YWF)_Le8e`6HrecG[5^K#7BI%Dmdg\AQSBe]Pe>S:nb1kD\R6ZL?Y$
+A$GS$qWbKBpU/lTk5sNs^]*Bt`\,$ek6GoWKmtp2/_,F8J`j`0J,~>
+q;r-YS\;qZaNi)P`5B9ZTDI[ZS=R@3`QHQSb/M<4SXfQ=%A03)_o9aCcH4&C]q(dHk)AF4ZL@Y1
+D/RPjoXi9>qR,/UjoM&VrT4,p=le]Na"G9lk0tt8bCSf,k.]u.~>
+q;r-YS\;qZaNi)P`5B9ZTDI[ZS=R@3`QHQSb/M<4SXfQ=%A03)_o9aCcH4&C]q(dHk)AF4ZL@Y1
+D/RPjoXi9>qR,/UjoJ_SroO:?/XYV]#b*L-k2s3+0]R`HJ`a]/J,~>
+q;r-YS\;qZaNi)P`5B9ZTDI[ZS=R@3`QHNQb/M<4SXfQ=%A03)_o9aCc,mrB]q(dHk)AF4ZL@Y1
+D/RPjoXi9>qR,/VjoXBs^Ad6r`@emcjoK@0roO9S/UE!1J`aZ.J,~>
+q;`!OYf+W)bKS2RaiME)QhobPPH`!Hb08,Tbf\#FYa#"F%@FE>aND]Nbfe/M`Nbe]jG`.0Z0qG\
+WF1;5`P(g;q6\rRj8kcPrT")p=PmDOro=rIPK@"@/M1M_jQ+`p/LnNrjJm?q/\8qS^Ad1*_C_,8
+jd%JM9?-&RjdRhR0#N8$J`P):J,~>
+q;`!OYf+W)bKS2RaiME)QhobPPH`!Hb08,Tbf\#FYa#"F%@FE>aND]Nbfe/M`Nbe]jG`.0Z0qG\
+WF1;5`P(g;q6\rRj8iJSro=XL/XFO3^#\829td<OYq7P]ro=R$/M18\jQ(`XI4j9B0AHKe&X4ld
+jP+i0/U,t1jP,)7/MGt3jFQC:jF@~>
+q;`!OYf+W)bKS2RaiME)QhobPPH`!Hb08,Tbf\#FYa#"F%@FE>aND]Nbfe/M`Nbe]jG`.0Z0qG\
+WF1;5`P(g;q6\rSj9"*o_#EC+a"G$+9\&4ba%k*9Tp%&[V>fNcU+S$Ji8i[$W`2XOD.;Q)j:Q2[
+g#U7^/M3.GjQ+Es/M2#'J`MCCc/aB~>
+q;`!P]?&4@cd:%bc-48@R/5kQQFt>acd:+gd*KtY]U&ET%@OlNbg+Vada?@bah4$mjG`.+Z0qG`
+l&8rJZ0M>a!OUYYj8kbsrNRMAA)r@lhW2p6]#H<SUTuIRjPMP:eWME:jIn.O[FE2K^Ad1*j\K^R
+N@qH\GV78%L+SV7[EsKcJ`P):J,~>
+q;`!P]?&4@cd:%bc-48@R/5kQQFt>acd:+gd*KtY]U&ET%@OlNbg+Vada?@bah4$mjG`.+Z0qG`
+l&8rJZ0M>a!OUYYj<n/V[B[!8/XGHKE9-)X0%cRD0=@6#QK6%;V9rLQjQ'l(Ge)e$0AHKe&^W,&
+j=Dt&a%\8Hi@HUdcEZ>ZjFQC:jF@~>
+q;`!P]?&4@cd:%bc-48@R/5kQQFt>acd:+gd*KtY]U&ET%@OlNbg+Vada?@bah4$mjG`.+Z0qG`
+l&8rJZ0M>a!OUYZj=&e@P-qR&QS,qt0;.CeI9>NO/ShtQ/\0r@/\8nYQ/p^Z/X!m0D.;Q)j:J^O
+_9aiUc*K0YjNoPQ^<!^5jFQC9jF@~>
+q;MOJ^<P!OrRD%ud*9:qqVhsQ^s19Ve_&O)eBuOVRel"QT"iRueCWF.f@83n^Rg#9N8alBmf*"b
+[sW:rnc&=bZeG98!h1`Er`^Ns@cGH[Xl>9`il!Fiio6U[e\*N>bd]47igV4Hio7m-]`$guE*(aE
+OlGBV/<SX;J:Z^2ilU21~>
+q;MOJ^<P!OrRD%ud*9:qqVhsQ^s19Ve_&O)eBuOVRel"QT"iRueCWF.f@83n^Rg#9N8alBmf*"b
+[sW:rnc&=bZeG98!b<lor`^<mQ/\Jgd,HR/ig;CVio4KRifc":d%)cAi`^R*iW>K"g&Bt?gan`(
+/AL3(_(<@7/?j]bJ`=f2J,~>
+q;MOJ^<P!OrRD%ud*9:qqVhsQ^s19Ve_&O)eBuOVRel"QT"iRueCWF.f@83n^Rg#9N8alBmf*"b
+[sW:rnc&=bZeG<9,2+qJ>[(E./@shf/E"r/YMsACio8cPOQ'bYbfkE9iS$,[ro*uq@H%4F%E0p1
+SLi@Oigq^NR4QU6idp+2id_~>
+q;DdX][50[gYUfAf@A6\U\`pYTY/\&g"kNBh:^?+]V,,[%A^\bf%T!<hqm)<d_2K.iJc_*YjV>_
+m&@L.EmaUVq6ScNi;oBJrS\B%=5i.D@G*3)iPR.tiShEufW>$&">.=GRTBFH!lHS&ro"=A/<&@8
+XPr-q/<JO9Mh0i<iQ:&/~>
+q;DdX][50[gYUfAf@A6\U\`pYTY/\&g"kNBh:^?+]V,,[%A^\bf%T!<hqm)<d_2K.iJc_*YjV>_
+m&@L.EmaUVq6ScNi;m,Mro":B/<o,D/=FF-aPiI]ro!s7>iC&//-RUXf\p#%ro!pF0%g0^%E'g,
+`%B<oiQ<^d^b!*KiITt0iIC~>
+q;DdX][50[gYUfAf@A6\U\`pYTY/\&g"kNBh:^?+]V,,[%A^\bf%T!<hqm)<d_2K.iJc_*YjV>_
+m&@L.EmaUVq6ScOi<%[h^&Ht!`%ARZ]e-pg/D8ulPQ'MC<Kl3:r[\4FE8]D+^&HslCgl9$i=2J3
+c_3tdiSgpje"J>@J`21=al.a~>
+q;2XeYL2"Xhr<YQh:U,YZMNGfXK^1,h;RGUiSE2:YcR]Y%C<:eg>:iMjPo%Md]p-0hi-G&YO2,W
+[^t[l>_qG8pp/NJhZ9-GrSJ<$<o;f</7^3Xhn^eqhqt"Sd^h$Lr8.OC<rUtX_(<1sh[QG6YLb=j
+hr!-=O4Pq9J_u%9akqU~>
+q;2XeYL2"Xhr<YQh:U,YZMNGfXK^1,h;RGUiSE2:YcR]Y%C<:eg>:iMjPo%Md]p-0hi-G&YO2,W
+[^t[l>_qG8pp/NJhZ6lDrne.8/<euKJ1Xo.hqs_qrndig>MkAlqqhEWPQ'G@Q7gkih[OWYd(:jE
+hqu:%]t5i$J_u%9akqU~>
+q;2XeYL2"Xhr<YQh:U,YZMNGfXK^1,h;RGUiSE2:YcR]Y%C<:eg>:iMjPo%Md]p-0hi-G&YO2,W
+[^t[l>_qG8pp/NKhZDCd\GkA"^FctQgf.?2P2G/+P2G0N2Nls+DuAJof/1#:h\0a4hV[5B3EP((
+/D&e:S1N'S/Brb'J`"T,J,~>
+q;2A&WlNlOir8!Ai7uAQd/)W/cDek?iT0.`jPeq9WQt@t%FD/sgu7>Vk2bLWaK*[=hi-G&Y3l#(
+Yj2#@J6\u?pp&HIhZ9-GrSJQ+<o;fg/1cJ3hn^jhd)R\OhqBVR`n%fKhjIOEh\X*[R`<*o/9p(0
+Fsk#TO"J6+K.NYD\B0<ZJ`"`0J,~>
+q;2A&WlNlOir8!Ai7uAQd/)W/cDek?iT0.`jPeq9WQt@t%FD/sgu7>Vk2bLWaK*[=hi-G&Y3l#(
+Yj2#@J6\u?pp&HIhZ6lDrne^K/<euK_CR7Dhqs_NSCY%uU#3^<I*g?Mgtu7urneNX/\&g5@k=J6
+fdgX\csn]]gab"ed';8Thgs\0hgb~>
+q;2A&WlNlOir8!Ai7uAQd/)W/cDek?iT0.`jPeq9WQt@t%FD/sgu7>Vk2bLWaK*[=hi-G&Y3l#(
+Yj2#@J6\u?pp&HJhZDCd\GkA*^FctQhk2MOb2;)s/@4#u/AU/=/=G&6\DPmp\GkA%C.c@_Xu.cG
+ho.1-e\O+]hTRT[`Qb[EJ_u%9c/4$~>
+q:uM2_QqMGjQG^eiR"pKf)"23f"JE:iT01bjl+Rm^"3&9%G&D%cf!mIkN(RJZbk:Eh2L/"XmOiB
+i:m$A`bT5(oWcsCh#WmCrS7KlC&Zp(M(HR#h7tO_.k>&Xh;-:Y.k<0\h3_4Ah#P7h.fi8BrnRn5
+F=SjjY2.pjJc7/"\UiRfh9Fc+~>
+q:uM2_QqMGjQG^eiR"pKf)"23f"JE:iT01bjl+Rm^"3&9%G&D%cf!mIkN(RJZbk:Eh2L/"XmOiB
+i:m$A`bT5(oWcsCh#UW@rnRY-/"?Oo$7[[^h;+>J@OisarnRR_r[S+'fA0PlrnRRBr@7nb^Acpt
+a@e$69uu/Hc<)SI/_#@-J_eT,J,~>
+q:uM2_QqMGjQG^eiR"pKf)"23f"JE:iT01bjl+Rm^"3&9%G&D%cf!mIkN(RJZbk:Eh2L/"XmOiB
+i:m$A`bT5(oWcsDh#c+_[f5(f]e$eOh9[`rrnR`l?Sj8`W;bTYSLc9AB\_,o[f5(_Er@KhIa.lJ%
+CIl?.sBM"h7PKn.pq(_h1=D,h1,~>
+q:lG1f>Y/@g"tZ?bI5CAf)"/2f%7[Eak5J,fZLV:f@KfR%G'.M[)gkThUflW`Ri[lgl1"uV9H3L
+bKeGZbE@FOc(rkXg];7lrnIXk.+ZtrqqM5!e*Yoke'S!I!n5NLJ_Yh3bhR^~>
+q:lG1f>Y/@g"tZ?bI5CAf)"/2f%7[Eak5J,fZLV:f@KfR%G'.M[)gkThUflW`Ri[lgl1"uV9H3L
+bKeGZbE@FOc(rkYg]H%WOoF,=PZlkhe,.o$d*qC;s3UYu!RT;Hgk"8(gjf~>
+q:lG1f>Y/@g"tZ?bI5CAf)"/2f%7[Eak5J,fZLV:f@KfR%G'.M[)gkThUflW`Ri[lgl1"uV9H3L
+bKeGZbE@FOc(rkYg]G8B[Jnqa@?fQof)4;)g!J=<g]H0Ue,.o$d+3d'J_\H(J,~>
+q:cA3f@e]h]>24o^X_#hg%sG4g"4p-\$ir^[^Xf?f@g#T%GB@de\AZ.]t(o.g"4o.gPjkj\%K;a
+]=IpP"hVFZ]X-2YgB,)>XT$rU].D6YgO\+SgOK~>
+q:cA3f@e]h]>24o^X_#hg%sG4g"4p-\$ir^[^Xf?f@g#T%GB@de\AZ.]t(o.g"4o.gPjkj\%K;a
+]=IpP"hVFZ]X-2YgB*Qhbl6>tN\5n;J_QpRJ,~>
+q:cA3f@e]h]>24o^X_#hg%sG4g"4p-\$ir^[^Xf?f@g#T%GB@de\AZ.]t(o.g"4o.gPjkj\%K;a
+]=IpP"hVFZ]X-2YgB)%=gA]h-<J5qXJ_QpRJ,~>
+pt>i&f%AdVhZMZdf%BcO"5)2Wh#6+4gt:31pt>i&f%AdVhZMZdf%>Q-MqS6^e("BG#h7>QeC2pr
+eCj?F!lL_`rn7G%U""YIJ_HmQJ,~>
+pt>i&f%AdVhZMZdf%BcO"5)2Wh#6+4gt:31pt>i&f%AdVhZMZdf%>Q-MqS6^e("BG#h7>QeC2pr
+eCj?F!O/R%g&]'iJ_G\/U=t+~>
+pt>i&f%AdVhZMZdf%BcO"5)2Wh#6+4gt:31pt>i&f%AdVhZMZdf%>Q-MqS6^e("BG#h7>QeC2pr
+eCjBG!nX<[rRq:X\UiIcg7m;O~>
+p=fQ!rRV#$o\0>trRV#$o\0>trRV#$J_G\/J_G\/K%b_~>
+p=fQ!rRV#$o\0>trRV#$o\0>trRV#$J_G\/J_G\/K%b_~>
+p=fQ!rRV#$o\0>trRV#$o\0>trRV#$J_G\/J_G\/K%b_~>
+J_>V-J_>V-J_A#qJ,~>
+J_>V-J_>V-J_A#qJ,~>
+J_>V-J_>V-J_A#qJ,~>
+J_5P+J_5P+J_7roJ,~>
+J_5P+J_5P+J_7roJ,~>
+J_5P+J_5P+J_7roJ,~>
+49#<\!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3!Z!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3%Ms+13$s1&(i!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3&us#L/[!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!.Y~>
+49#<\!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3!Z!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3%Ms+13$s1&(i!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3&us#L/[!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!.Y~>
+49#<\!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3!Z!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3%Ms+13$s1&(i!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3&us#L/[!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!.Y~>
+3WT0[rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#L/[!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3![!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!J,~>
+3WT0[rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#L/[!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3![!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!J,~>
+3WT0[rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#L/[!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3![!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!J,~>
+a8c/>rr2ruaoDA@JcC<$JcE7[!!(.@rrE&u!!(.@rr@Q~>
+a8c/>rr2ruaoDA@JcC<$JcE7[!!(.@rrE&u!!(.@rr@Q~>
+a8c/>rr2ruaoDA@JcC<$JcE7[!!(.@rrE&u!!(.@rr@Q~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+JcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#u!<7Q~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+JcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#u!<7Q~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+JcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#u!<7Q~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+JcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#u!<7Q~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+JcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#u!<7Q~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+JcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#u!<7Q~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+!!*#u!<E/n!"f/1rrE'!rrE'!rrE'!rrE)u!##;3rrE'!rrE'!rrE'!rrE'!s8E#trr<&urrE-"
+qu?`squ@6,!<3'!!<3'!!<3'!!<;rs')qt3!<3'!!<3'!!<3'!!<3'!rW%NLdJs1Gq>^Eoq>^Hp
+pAb-miW&iVJcE"T!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/n!"f/1rrE'!rrE'!rrE'!rrE)u!##;3rrE'!rrE'!rrE'!rrE'!s8E#trr<&urrE-"
+qu?`squ@6,!<3'!!<3'!!<3'!!<;rs')qt3!<3'!!<3'!!<3'!!<3'!rW%NLdJs1Gq>^Eoq>^Hp
+pAb-miW&iVJcE"T!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/n!"f/1rrE'!rrE'!rrE'!rrE)u!##;3rrE'!rrE'!rrE'!rrE'!s8E#trr<&urrE-"
+qu?`squ@6,!<3'!!<3'!!<3'!!<;rs')qt3!<3'!!<3'!!<3'!!<3'!rW%NLdJs1Gq>^Eoq>^Hp
+pAb-miW&iVJcE"T!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!p](m*!<3'!!<3'!!<3'!!<3'!qu@B0!<3'!!<3'!!<3'!!<3'!!<<#urr3-%rrE'!
+s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"fs8;rArr<&j
+rr<&urr<&rrr<&urr<&ss8N'"rrDfn!W`6#q#C0jmf*7eb5_G@s8W#tnc&RhJc@Y/rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<3!W!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW%H~>
+#6+]'!<3'!p](m*!<3'!!<3'!!<3'!!<3'!qu@B0!<3'!!<3'!!<3'!!<3'!!<<#urr3-%rrE'!
+s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"fs8;rArr<&j
+rr<&urr<&rrr<&urr<&ss8N'"rrDfn!W`6#q#C0jmf*7eb5_G@s8W#tnc&RhJc@Y/rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<3!W!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW%H~>
+#6+]'!<3'!p](m*!<3'!!<3'!!<3'!!<3'!qu@B0!<3'!!<3'!!<3'!!<3'!!<<#urr3-%rrE'!
+s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"fs8;rArr<&j
+rr<&urr<&rrr<&urr<&ss8N'"rrDfn!W`6#q#C0jmf*7eb5_G@s8W#tnc&RhJc@Y/rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<3!W!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW%H~>
+!!*#u!<E/t!!<0#s8E!.rrE'!rrE'!rrE'!rrE)s!!rT)rrE'!rrE)u!!`H'rrE'!s8E#trr<&u
+rrE-"qu?`squ@<.!<3'!!<3'!!<3'!!<3'!rW!T2!<3'!!<3'!!<3'!!<3'!!<<#uQi@$cbl7YC
+o`"mkr;Q`srVlitr;Q`sqYpNqp\t9prrDfn!!)rs!!)Kf!!(.@rrE#t!!)Ng!!%WN!!*#u1B@FT
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&us"aZT
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!<0#s8E!.rrE'!rrE'!rrE'!rrE)s!!rT)rrE'!rrE)u!!`H'rrE'!s8E#trr<&u
+rrE-"qu?`squ@<.!<3'!!<3'!!<3'!!<3'!rW!T2!<3'!!<3'!!<3'!!<3'!!<<#uQi@$cbl7YC
+o`"mkr;Q`srVlitr;Q`sqYpNqp\t9prrDfn!!)rs!!)Kf!!(.@rrE#t!!)Ng!!%WN!!*#u1B@FT
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&us"aZT
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!<0#s8E!.rrE'!rrE'!rrE'!rrE)s!!rT)rrE'!rrE)u!!`H'rrE'!s8E#trr<&u
+rrE-"qu?`squ@<.!<3'!!<3'!!<3'!!<3'!rW!T2!<3'!!<3'!!<3'!!<3'!!<<#uQi@$cbl7YC
+o`"mkr;Q`srVlitr;Q`sqYpNqp\t9prrDfn!!)rs!!)Kf!!(.@rrE#t!!)Ng!!%WN!!*#u1B@FT
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&us"aZT
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!rW!`6!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u#lao)!<3'!!<<#u#lao)!<3'!!<<#u
+rr3-%rrE'!s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"d
+rrN3#!6tND!;-9k!;uis!<)ot!;uis!;c]q!;QQr!<<'!p\t3nr;Q`sn,E@fao;DBrrE&u!!)Ng
+!!%TM2ZWjXrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+s8E#trtth:!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!q>_<2!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+J,~>
+#6+]'!<3'!rW!`6!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u#lao)!<3'!!<<#u#lao)!<3'!!<<#u
+rr3-%rrE'!s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"d
+rrN3#!6tND!;-9k!;uis!<)ot!;uis!;c]q!;QQr!<<'!p\t3nr;Q`sn,E@fao;DBrrE&u!!)Ng
+!!%TM2ZWjXrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+s8E#trtth:!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!q>_<2!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+J,~>
+#6+]'!<3'!rW!`6!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u#lao)!<3'!!<<#u#lao)!<3'!!<<#u
+rr3-%rrE'!s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"d
+rrN3#!6tND!;-9k!;uis!<)ot!;uis!;c]q!;QQr!<<'!p\t3nr;Q`sn,E@fao;DBrrE&u!!)Ng
+!!%TM2ZWjXrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+s8E#trtth:!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!q>_<2!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+J,~>
+!!*#u!<E/t!$M:ArrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)s!!`H'rrE'!s8E#trr<&u
+rrE-"qu?`squ@<.!<3'!!<3'!!<3'!!<3'!rW!T2!<3'!!<3'!!<3'!!<3'!!<<#uR/[3frrDus
+rrE#trrDusr;['%!!*'!!!)utrrDusr;Zlu!<)ro!:p-i!<)ot!;uis!;c]q!;QQr!<<'!p\t3n
+r;Q`sr;Z]qq#:<oq>^BnqZ$KoqZ$Ko!WN/ts8;rkrrN3#!<2uu!;ulq!;lfm!;ulq!;c`o!!3*"
+SGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!<2uu!<3!5!<3'!!<3'!!<3'!!<3'!!<3'!!<;fo'`S15!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!$M:ArrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)s!!`H'rrE'!s8E#trr<&u
+rrE-"qu?`squ@<.!<3'!!<3'!!<3'!!<3'!rW!T2!<3'!!<3'!!<3'!!<3'!!<<#uR/[3frrDus
+rrE#trrDusr;['%!!*'!!!)utrrDusr;Zlu!<)ro!:p-i!<)ot!;uis!;c]q!;QQr!<<'!p\t3n
+r;Q`sr;Z]qq#:<oq>^BnqZ$KoqZ$Ko!WN/ts8;rkrrN3#!<2uu!;ulq!;lfm!;ulq!;c`o!!3*"
+SGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!<2uu!<3!5!<3'!!<3'!!<3'!!<3'!!<3'!!<;fo'`S15!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!$M:ArrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)s!!`H'rrE'!s8E#trr<&u
+rrE-"qu?`squ@<.!<3'!!<3'!!<3'!!<3'!rW!T2!<3'!!<3'!!<3'!!<3'!!<<#uR/[3frrDus
+rrE#trrDusr;['%!!*'!!!)utrrDusr;Zlu!<)ro!:p-i!<)ot!;uis!;c]q!;QQr!<<'!p\t3n
+r;Q`sr;Z]qq#:<oq>^BnqZ$KoqZ$Ko!WN/ts8;rkrrN3#!<2uu!;ulq!;lfm!;ulq!;c`o!!3*"
+SGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u
+!<2uu!<3!5!<3'!!<3'!!<3'!!<3'!!<3'!!<;fo'`S15!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!rW"/B!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u#lao)!<3'!!<<#u
+rr3-%rrE'!s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"e
+rr<&urr<&srr<&srr<&trr<&ts8N)trr<&srr<&trr<&ts8N)rrr<&frr<&srr<&srr<&qrr<&p
+rr<&urr<&nrr<&trr<&srr<&trr<&prr<&qrr<&trr<&srr<&trr<&srr<&ts8N)trr<&trr<&n
+rrrK'rrE*!!<)ot!<)ot!;c]q!;ZWp!<)ot!;uis!<)rt!1X!I!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt'`e76rrE'!rrE'!rrE'!rrE'!
+rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!rW"/B!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u#lao)!<3'!!<<#u
+rr3-%rrE'!s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"e
+rr<&urr<&srr<&srr<&trr<&ts8N)trr<&srr<&trr<&ts8N)rrr<&frr<&srr<&srr<&qrr<&p
+rr<&urr<&nrr<&trr<&srr<&trr<&prr<&qrr<&trr<&srr<&trr<&srr<&ts8N)trr<&trr<&n
+rrrK'rrE*!!<)ot!<)ot!;c]q!;ZWp!<)ot!;uis!<)rt!1X!I!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt'`e76rrE'!rrE'!rrE'!rrE'!
+rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!rW"/B!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u#lao)!<3'!!<<#u
+rr3-%rrE'!s8E!"rrE)u!"f/1rrE'!rrE'!rrE'!rrE)s!##;3rrE'!rrE'!rrE'!rrE'!s8E"e
+rr<&urr<&srr<&srr<&trr<&ts8N)trr<&srr<&trr<&ts8N)rrr<&frr<&srr<&srr<&qrr<&p
+rr<&urr<&nrr<&trr<&srr<&trr<&prr<&qrr<&trr<&srr<&trr<&srr<&ts8N)trr<&trr<&n
+rrrK'rrE*!!<)ot!<)ot!;c]q!;ZWp!<)ot!;uis!<)rt!1X!I!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt'`e76rrE'!rrE'!rrE'!rrE'!
+rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+!!*#u!<E/t!!*&u!!<0#s82iss82iurrE)s!!N<%rrE)m!!<0#s8E#trr<&urrE-"qu?`squ?fu
+!<;lq#6+]'!<3'!rW!*$!<3'!rVuruqu?m"!<3'!rW&Ad!!*#u!!)rs!!)rs!!*#u!!)or!!)ut
+!!)rs!!)ut!!)rs!!)or!!)Ng!!)or!!)rs!!)lq!!)ip!!*#u!!)cnquHZp!!)or!!)lq!!)or
+!!)or!!)fo!!)rs!!)rs!!*#u!!)or!!)fo"p"]'!<<'!rr2ruqu6Wrqu6WrqYpNqqu6WrrVlit
+r;Q`sSGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE)u!<2uu!<3!1!<3'!!<3'!!<3'!!<3'!!<;Ng&H;b1!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!*&u!!<0#s82iss82iurrE)s!!N<%rrE)m!!<0#s8E#trr<&urrE-"qu?`squ?fu
+!<;lq#6+]'!<3'!rW!*$!<3'!rVuruqu?m"!<3'!rW&Ad!!*#u!!)rs!!)rs!!*#u!!)or!!)ut
+!!)rs!!)ut!!)rs!!)or!!)Ng!!)or!!)rs!!)lq!!)ip!!*#u!!)cnquHZp!!)or!!)lq!!)or
+!!)or!!)fo!!)rs!!)rs!!*#u!!)or!!)fo"p"]'!<<'!rr2ruqu6Wrqu6WrqYpNqqu6WrrVlit
+r;Q`sSGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE)u!<2uu!<3!1!<3'!!<3'!!<3'!!<3'!!<;Ng&H;b1!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!*&u!!<0#s82iss82iurrE)s!!N<%rrE)m!!<0#s8E#trr<&urrE-"qu?`squ?fu
+!<;lq#6+]'!<3'!rW!*$!<3'!rVuruqu?m"!<3'!rW&Ad!!*#u!!)rs!!)rs!!*#u!!)or!!)ut
+!!)rs!!)ut!!)rs!!)or!!)Ng!!)or!!)rs!!)lq!!)ip!!*#u!!)cnquHZp!!)or!!)lq!!)or
+!!)or!!)fo!!)rs!!)rs!!*#u!!)or!!)fo"p"]'!<<'!rr2ruqu6Wrqu6WrqYpNqqu6WrrVlit
+r;Q`sSGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE)u!<2uu!<3!1!<3'!!<3'!!<3'!!<3'!!<;Ng&H;b1!<3'!!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!q>^Ts!<;rs!ri9#rW!*$!<3'!qu?m"!<3'!p](Hs!<3'!rW)rt"T\Q&rrE)o!!<0#
+s7cQsrrE'!s82j"rrE'!s7cQsrrE'!s8E"frr<&srr<&trr<&srr<&urr<&rrr<&trr<&srr<&s
+s8E#nrr<&hrr<&qrr<&srr<&qrr<&qrr<&trr<&nrr<&trr<&ts7lZkrr<&rs7lZns8)fns8E#q
+s7lZirr<&urrN3#!<2uu!;lcr!;lcr!;c`k!;ulr!1<dF!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt&HMh2rrE'!rrE'!rrE'!rrE)a!"T#/
+rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!q>^Ts!<;rs!ri9#rW!*$!<3'!qu?m"!<3'!p](Hs!<3'!rW)rt"T\Q&rrE)o!!<0#
+s7cQsrrE'!s82j"rrE'!s7cQsrrE'!s8E"frr<&srr<&trr<&srr<&urr<&rrr<&trr<&srr<&s
+s8E#nrr<&hrr<&qrr<&srr<&qrr<&qrr<&trr<&nrr<&trr<&ts7lZkrr<&rs7lZns8)fns8E#q
+s7lZirr<&urrN3#!<2uu!;lcr!;lcr!;c`k!;ulr!1<dF!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt&HMh2rrE'!rrE'!rrE'!rrE)a!"T#/
+rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!q>^Ts!<;rs!ri9#rW!*$!<3'!qu?m"!<3'!p](Hs!<3'!rW)rt"T\Q&rrE)o!!<0#
+s7cQsrrE'!s82j"rrE'!s7cQsrrE'!s8E"frr<&srr<&trr<&srr<&urr<&rrr<&trr<&srr<&s
+s8E#nrr<&hrr<&qrr<&srr<&qrr<&qrr<&trr<&nrr<&trr<&ts7lZkrr<&rs7lZns8)fns8E#q
+s7lZirr<&urrN3#!<2uu!;lcr!;lcr!;c`k!;ulr!1<dF!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt&HMh2rrE'!rrE'!rrE'!rrE)a!"T#/
+rrE'!rrE'!rrE'!s8E"K~>
+!!*#u!<E/p!!<0#s82iss8E!&rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!!<;`m
+!<;rs!<;rs"TJK%!<<#u"TJK%!<;rs!<;rs!ri9#rW&Deq>gKo!!)rs!!*#u!!)or!!)ut!!)rs
+!!)iprrDoq!!)Ti!!)ip!!)rs!!)lq!!)lqq>g<j!!)ut!!)ut!!)Wj!!)or!!)cn!!)rs!!)fo
+rrE#t!!)Qh!!*#u!W`6#rr2ruqu6Wrqu6WrqYpNqo)J^iS,WHgrr4bSrrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<2uu!<3!-!<3'!!<3'!!<3'!!<;6_%
+0$>-!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/p!!<0#s82iss8E!&rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!!<;`m
+!<;rs!<;rs"TJK%!<<#u"TJK%!<;rs!<;rs!ri9#rW&Deq>gKo!!)rs!!*#u!!)or!!)ut!!)rs
+!!)iprrDoq!!)Ti!!)ip!!)rs!!)lq!!)lqq>g<j!!)ut!!)ut!!)Wj!!)or!!)cn!!)rs!!)fo
+rrE#t!!)Qh!!*#u!W`6#rr2ruqu6Wrqu6WrqYpNqo)J^iS,WHgrr4bSrrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<2uu!<3!-!<3'!!<3'!!<3'!!<;6_%
+0$>-!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/p!!<0#s82iss8E!&rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!!<;`m
+!<;rs!<;rs"TJK%!<<#u"TJK%!<;rs!<;rs!ri9#rW&Deq>gKo!!)rs!!*#u!!)or!!)ut!!)rs
+!!)iprrDoq!!)Ti!!)ip!!)rs!!)lq!!)lqq>g<j!!)ut!!)ut!!)Wj!!)or!!)cn!!)rs!!)fo
+rrE#t!!)Qh!!*#u!W`6#rr2ruqu6Wrqu6WrqYpNqo)J^iS,WHgrr4bSrrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<2uu!<3!-!<3'!!<3'!!<3'!!<;6_%
+0$>-!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!rW!6(!<3'!!<3'!q>^a"!<3'!!<;rs#6+]'!<3'!rW!6(!<3'!!<3'!rW)rt"T\Q&
+rrE)u!!<0#s8Duus82iurrE)u!!N<%rrE)s!!N<%rrE)u!!<0#s82iurrE)u!1a&h!;c]q!<2uu
+!;uis!<2uu!;lcr!<)ot!;uis!<)ot!;uis!;lcr!;$3j!;QQo!;uis!;c]q!;6?l!;HKn!;uis
+!<2uu!;$3j!;lcr!;HKn!;uis!;uis!;uis!<2uu!:g'h!<)rt!<2uu!;lcr!;lcr!;c]q!;?Em
+!;uis!1X!I!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!rW)rt'`e76rrE'!rrE'!rrE'!rrE'!rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!rW!6(!<3'!!<3'!q>^a"!<3'!!<;rs#6+]'!<3'!rW!6(!<3'!!<3'!rW)rt"T\Q&
+rrE)u!!<0#s8Duus82iurrE)u!!N<%rrE)s!!N<%rrE)u!!<0#s82iurrE)u!1a&h!;c]q!<2uu
+!;uis!<2uu!;lcr!<)ot!;uis!<)ot!;uis!;lcr!;$3j!;QQo!;uis!;c]q!;6?l!;HKn!;uis
+!<2uu!;$3j!;lcr!;HKn!;uis!;uis!;uis!<2uu!:g'h!<)rt!<2uu!;lcr!;lcr!;c]q!;?Em
+!;uis!1X!I!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!rW)rt'`e76rrE'!rrE'!rrE'!rrE'!rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!rW!6(!<3'!!<3'!q>^a"!<3'!!<;rs#6+]'!<3'!rW!6(!<3'!!<3'!rW)rt"T\Q&
+rrE)u!!<0#s8Duus82iurrE)u!!N<%rrE)s!!N<%rrE)u!!<0#s82iurrE)u!1a&h!;c]q!<2uu
+!;uis!<2uu!;lcr!<)ot!;uis!<)ot!;uis!;lcr!;$3j!;QQo!;uis!;c]q!;6?l!;HKn!;uis
+!<2uu!;$3j!;lcr!;HKn!;uis!;uis!;uis!<2uu!:g'h!<)rt!<2uu!;lcr!;lcr!;c]q!;?Em
+!;uis!1X!I!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!rW)rt'`e76rrE'!rrE'!rrE'!rrE'!rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+!!*#u!<E/t!!rT)rrE'!rrE)s!!rT)rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<;`m"TJK%!<<#u"TJK%!<;rs!ri9#rW!$"!<<#uS,WHgqYpNqrr2rurVultrVlit
+rVultrVlitrVultrVultrVlitqu6WrrVlitq>UEpr;Q`sr;Q`srr2ruq>UEpp&>!lp\t3nr;Q`s
+rVlitrVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVultq#:<orVultrVlitrVlit
+qYpNqrVlitrr2rurVultrVultrVlitSGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<2uu!<3!1!<3'!!<3'!!<3'!!<3'!!<;Ng&H;b1!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!rT)rrE'!rrE)s!!rT)rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<;`m"TJK%!<<#u"TJK%!<;rs!ri9#rW!$"!<<#uS,WHgqYpNqrr2rurVultrVlit
+rVultrVlitrVultrVultrVlitqu6WrrVlitq>UEpr;Q`sr;Q`srr2ruq>UEpp&>!lp\t3nr;Q`s
+rVlitrVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVultq#:<orVultrVlitrVlit
+qYpNqrVlitrr2rurVultrVultrVlitSGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<2uu!<3!1!<3'!!<3'!!<3'!!<3'!!<;Ng&H;b1!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!rT)rrE'!rrE)s!!rT)rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<;`m"TJK%!<<#u"TJK%!<;rs!ri9#rW!$"!<<#uS,WHgqYpNqrr2rurVultrVlit
+rVultrVlitrVultrVultrVlitqu6WrrVlitq>UEpr;Q`sr;Q`srr2ruq>UEpp&>!lp\t3nr;Q`s
+rVlitrVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVultq#:<orVultrVlitrVlit
+qYpNqrVlitrr2rurVultrVultrVlitSGrQhrr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE)u!<2uu!<3!1!<3'!!<3'!!<3'!!<3'!!<;Ng&H;b1!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!rW!<*!<3'!!<3'!!<;rs#6+]'!<3'!qu?s$!<3'!!<<#u#lao)!<3'!!<<#urr3-%
+rrE'!s8E!"rrE)u!!*&m!!N<%rrE)s!!N<%rrE)u!!<0#s82iurrE)u!1j/g!<3#s!<3#s!!<0#
+!<)rr!!3*"r;Z]q!ri6#rr3!!s8;rns8;rns7lZls8E#qs7u`ls8;rns8;rrs8N)us8;rps7u`n
+s8;rps8;ots8E#trrE-"r;c`pr;cTlr;cis!!)rsr;cWmr;ccqr;c`p!<E/u!1NpH!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt'`e76rrE'!
+rrE'!rrE'!rrE'!rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!rW!<*!<3'!!<3'!!<;rs#6+]'!<3'!qu?s$!<3'!!<<#u#lao)!<3'!!<<#urr3-%
+rrE'!s8E!"rrE)u!!*&m!!N<%rrE)s!!N<%rrE)u!!<0#s82iurrE)u!1j/g!<3#s!<3#s!!<0#
+!<)rr!!3*"r;Z]q!ri6#rr3!!s8;rns8;rns7lZls8E#qs7u`ls8;rns8;rrs8N)us8;rps7u`n
+s8;rps8;ots8E#trrE-"r;c`pr;cTlr;cis!!)rsr;cWmr;ccqr;c`p!<E/u!1NpH!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt'`e76rrE'!
+rrE'!rrE'!rrE'!rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!rW!<*!<3'!!<3'!!<;rs#6+]'!<3'!qu?s$!<3'!!<<#u#lao)!<3'!!<<#urr3-%
+rrE'!s8E!"rrE)u!!*&m!!N<%rrE)s!!N<%rrE)u!!<0#s82iurrE)u!1j/g!<3#s!<3#s!!<0#
+!<)rr!!3*"r;Z]q!ri6#rr3!!s8;rns8;rns7lZls8E#qs7u`ls8;rns8;rrs8N)us8;rps7u`n
+s8;rps8;ots8E#trrE-"r;c`pr;cTlr;cis!!)rsr;cWmr;ccqr;c`p!<E/u!1NpH!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt'`e76rrE'!
+rrE'!rrE'!rrE'!rrE)i!##;3rrE'!rrE'!rrE'!rrE'!s8E"K~>
+!!*#u!<E/t!"/`+rrE'!rrE'!s82j$rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<<#u%0$>-!<3'!!<3'!!<<#u"TJK%!<;rs!ri9#rW!$"!<<#uJcG`L!!%TMJcEC_
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&urt,82!<3'!!<3'!!<3'!!<3'!n,O%"!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+!!*#u!<E/t!"/`+rrE'!rrE'!s82j$rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<<#u%0$>-!<3'!!<3'!!<<#u"TJK%!<;rs!ri9#rW!$"!<<#uJcG`L!!%TMJcEC_
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&urt,82!<3'!!<3'!!<3'!!<3'!n,O%"!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+!!*#u!<E/t!"/`+rrE'!rrE'!s82j$rrE'!rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<<#u%0$>-!<3'!!<3'!!<<#u"TJK%!<;rs!ri9#rW!$"!<<#uJcG`L!!%TMJcEC_
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&urt,82!<3'!!<3'!!<3'!!<3'!n,O%"!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+#6+]'!<3'!rW!<*!<3'!!<3'!!<;lq"TJK%!<;rs#6+]'!<3'!rW!6(!<3'!!<3'!rW)rt"T\Q&
+rrE)u!!<0#s8Duus82j(rrE'!rrE'!rrE)s!!N<%rrE)u!!<0#s82iurrE)u!.k1Mrr<%Ms+13^
+s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr3]5rrE'!rrE'!rrE'!rrE'!rrE'!s7-.&rrE'!rrE'!rrE'!rrE'!rrE)u!.Y~>
+#6+]'!<3'!rW!<*!<3'!!<3'!!<;lq"TJK%!<;rs#6+]'!<3'!rW!6(!<3'!!<3'!rW)rt"T\Q&
+rrE)u!!<0#s8Duus82j(rrE'!rrE'!rrE)s!!N<%rrE)u!!<0#s82iurrE)u!.k1Mrr<%Ms+13^
+s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr3]5rrE'!rrE'!rrE'!rrE'!rrE'!s7-.&rrE'!rrE'!rrE'!rrE'!rrE)u!.Y~>
+#6+]'!<3'!rW!<*!<3'!!<3'!!<;lq"TJK%!<;rs#6+]'!<3'!rW!6(!<3'!!<3'!rW)rt"T\Q&
+rrE)u!!<0#s8Duus82j(rrE'!rrE'!rrE)s!!N<%rrE)u!!<0#s82iurrE)u!.k1Mrr<%Ms+13^
+s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr3]5rrE'!rrE'!rrE'!rrE'!rrE'!s7-.&rrE'!rrE'!rrE'!rrE'!rrE)u!.Y~>
+!!*#u!<E/t!!<0#s8E!"rrE)u!!*&s!!N<%rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<;rs!ri9#rW!*$!<3'!rW!*$!<3'!qu?`squ?fu!<<#uJcGcM!!%TMJcE@^!!*#u
+1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&u
+s"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!<0#s8E!"rrE)u!!*&s!!N<%rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<;rs!ri9#rW!*$!<3'!rW!*$!<3'!qu?`squ?fu!<<#uJcGcM!!%TMJcE@^!!*#u
+1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&u
+s"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/t!!<0#s8E!"rrE)u!!*&s!!N<%rrE)u!!`H'rrE'!s82j$rrE'!rrE)u!<2uu!<3!!
+!<;rs!<;rs!<;rs!ri9#rW!*$!<3'!rW!*$!<3'!qu?`squ?fu!<<#uJcGcM!!%TMJcE@^!!*#u
+1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&u
+s"aZT!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+#6+]'!<3'!p](Bq!<<#u!ri9#qu?fu!<;rs#6+]'!<3'!q>^Zu!<3'!rW)rt"T\Q&rrE)u!!<0#
+s8E!"rrE)o!!N<%rrE)s!!N<%rrE)o!!N<%rrE)u!/:IN!.k0$s1/.g!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt2ZWjXrrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!p](Bq!<<#u!ri9#qu?fu!<;rs#6+]'!<3'!q>^Zu!<3'!rW)rt"T\Q&rrE)u!!<0#
+s8E!"rrE)o!!N<%rrE)s!!N<%rrE)o!!N<%rrE)u!/:IN!.k0$s1/.g!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt2ZWjXrrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E"K~>
+#6+]'!<3'!p](Bq!<<#u!ri9#qu?fu!<;rs#6+]'!<3'!q>^Zu!<3'!rW)rt"T\Q&rrE)u!!<0#
+s8E!"rrE)o!!N<%rrE)s!!N<%rrE)o!!N<%rrE)u!/:IN!.k0$s1/.g!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!rW)rt2ZWjXrrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E"K~>
+!!*#u!<E/n!!*&s!!*&s!!<0#s7u^"rrE'!rrE)s!!N<%rrE)u!<2uu!<3!!!<;rs!<;rs!ri9#
+q>^Zu!<3'!q>^Ts!<;fo"TJK%!<<#uJcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/n!!*&s!!*&s!!<0#s7u^"rrE'!rrE)s!!N<%rrE)u!<2uu!<3!!!<;rs!<;rs!ri9#
+q>^Zu!<3'!q>^Ts!<;fo"TJK%!<<#uJcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+!!*#u!<E/n!!*&s!!*&s!!<0#s7u^"rrE'!rrE)s!!N<%rrE)u!<2uu!<3!!!<;rs!<;rs!ri9#
+q>^Zu!<3'!q>^Ts!<;fo"TJK%!<<#uJcC<$JcE7[!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#trr<&us"aZT!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u!<7Q~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4DIrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E!*rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4DIrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E!*rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4DIrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E!*rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us!7[F!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!qu@$&!<3'!!<3'!rW%NL
+JcC<$\GlO/rr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE)u!<2uu!<3!S!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!rVuruJ,~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us!7[F!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!qu@$&!<3'!!<3'!rW%NL
+JcC<$\GlO/rr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE)u!<2uu!<3!S!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!rVuruJ,~>
+!!*#u1B@FTrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E#t
+rr<&us!7[F!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!qu@$&!<3'!!<3'!rW%NL
+JcC<$\GlO/rr4bSrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE)u!<2uu!<3!S!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!rVuruJ,~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4DIrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E!*rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4DIrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E!*rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+3<'!Y!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<<#u
+rr4DIrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!s8E!*rrE'!rrE'!rrE)u
+!.k0$s+13[s#0rX!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!!<3'!
+!<3'!!<<#urr4nWrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE)u!.Y~>
+!<E/@!<3!"!<<)@!.k0$s+13[rrN3#s2b9?rrN3#s2b6@s*t~>
+!<E/@!<3!"!<<)@!.k0$s+13[rrN3#s2b9?rrN3#s2b6@s*t~>
+!<E/@!<3!"!<<)@!.k0$s+13[rrN3#s2b9?rrN3#s2b6@s*t~>
+!<:%=s8U%<JcC<$JcE7[`W6#<`W1M~>
+!<:%=s8U%<JcC<$JcE7[`W6#<`W1M~>
+!<:%=s8U%<JcC<$JcE7[`W6#<`W1M~>
+3WT0[rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr5"ZrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr@WMJcC<$\GnSirrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE&u3ro9\rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!s*t~>
+3WT0[rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr5"ZrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr@WMJcC<$\GnSirrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE&u3ro9\rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!s*t~>
+3WT0[rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr5"ZrrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rr@WMJcC<$\GnSirrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE&u3ro9\rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!rrE'!
+rrE'!rrE'!rrE'!s*t~>
+JH16$JH16$JH3XhJ,~>
+JH16$JH16$JH3XhJ,~>
+JH16$JH16$JH3XhJ,~>
+JH16$JH16$JH3XhJ,~>
+JH16$JH16$JH3XhJ,~>
+JH16$JH16$JH3XhJ,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rr<*"!:g*h!!*%L~>
+JcC<$JcC<$JcFO*rr<*"!:g*h!!*%L~>
+JcC<$JcC<$JcFO*rr<*"!:g*h!!*%L~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rr<9'!<3'!!<;lq!ri9#rVuruJ,~>
+JcC<$JcC<$JcFO*rr<9'!<3'!!<;lq!ri9#rVuruJ,~>
+JcC<$JcC<$JcFO*rr<9'!<3'!!<;lq!ri9#rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt!<E/p!!WB&rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!<E/p!!WB&rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!<E/p!!WB&rrE'!J,~>
+JcC<$JcC<$JcFO*rr<3%!<3'!p&G*mrVuruJ,~>
+JcC<$JcC<$JcFO*rr<3%!<3'!p&G*mrVuruJ,~>
+JcC<$JcC<$JcFO*rr<3%!<3'!p&G*mrVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<?)!<3'!!<3'!rW!*$!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<-#!<;Ng!<7Q~>
+JcC<$JcC<$JcFO*rr<-#!<;Ng!<7Q~>
+JcC<$JcC<$JcFO*rr<-#!<;Ng!<7Q~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*l2Z>~>
+JcC<$JcC<$JcFO*l2Z>~>
+JcC<$JcC<$JcFO*l2Z>~>
+JcC<$JcC<$JcFO*l2Z>~>
+JcC<$JcC<$JcFO*l2Z>~>
+JcC<$JcC<$JcFO*l2Z>~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rW!W3!<3'!!<3'!!<3'!!<3'!!<3%L~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rr<c5!<3'!!<3'!!<3'!!<3'!!<3'!J,~>
+JcC<$JcC<$JcFO*rW)Bd!!%N~>
+JcC<$JcC<$JcFO*rW)Bd!!%N~>
+JcC<$JcC<$JcFO*rW)Bd!!%N~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+JcC<$JcC<$JcFO*rW)rt&-2_1rrE'!rrE'!rrE'!rr@Q~>
+SH&Qgq>^Eoq>^HppAb-mg].3PJcC<$JcCi3rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+SH&Qgq>^Eoq>^HppAb-mg].3PJcC<$JcCi3rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+SH&Qgq>^Eoq>^HppAb-mg].3PJcC<$JcCi3rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+li6n`bl7YCmJd.drr2ruqu6Wrrr2rur;Zcs!WN/orrN3#!8.;O!3?,"!.k0$s+145s8E#trt#21
+!<3'!!<3'!!<3'!!<3%L~>
+li6n`bl7YCmJd.drr2ruqu6Wrrr2rur;Zcs!WN/orrN3#!8.;O!3?,"!.k0$s+145s8E#trt#21
+!<3'!!<3'!!<3'!!<3%L~>
+li6n`bl7YCmJd.drr2ruqu6Wrrr2rur;Zcs!WN/orrN3#!8.;O!3?,"!.k0$s+145s8E#trt#21
+!<3'!!<3'!!<3'!!<3%L~>
+kl1V_bl7YCmf*7er;Q`srVlitr;Q`sqYpNqp\t9prrC^O!!')"!!%TMJcC<$kPtP^&H;b1!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+kl1V_bl7YCmf*7er;Q`srVlitr;Q`sqYpNqp\t9prrC^O!!')"!!%TMJcC<$kPtP^&H;b1!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+kl1V_bl7YCmf*7er;Q`srVlitr;Q`sqYpNqp\t9prrC^O!!')"!!%TMJcC<$kPtP^&H;b1!<3'!
+!<3'!!<3'!!<<#u!<7Q~>
+l2LebrrC=D!!)He!!)rs!!)ut!!)rs!!)lq!!)fo!s&B$!8.;O!3?,"!.k0$s+145s8E#trt#21
+!<3'!!<3'!!<3'!!<3%L~>
+l2LebrrC=D!!)He!!)rs!!)ut!!)rs!!)lq!!)fo!s&B$!8.;O!3?,"!.k0$s+145s8E#trt#21
+!<3'!!<3'!!<3'!!<3%L~>
+l2LebrrC=D!!)He!!)rs!!)ut!!)rs!!)lq!!)fo!s&B$!8.;O!3?,"!.k0$s+145s8E#trt#21
+!<3'!!<3'!!<3'!!<3%L~>
+l2LebrrDusrrE#trrDusr;['%!!*'!!!)utrrDusr;Zlu!<)ro!:9^c!<)ot!;uis!;c]q!;QQr
+!<<'!o)J[h!<<#uqu?Tpq#:<oq>^BnqZ$KoqZ$Ko!WN/ts8;rfs8N'!s8;rps8;rps7u`ns8;ro
+s8;ourr@WMJcC<$rr<-#!<;Ng!<7Q~>
+l2LebrrDusrrE#trrDusr;['%!!*'!!!)utrrDusr;Zlu!<)ro!:9^c!<)ot!;uis!;c]q!;QQr
+!<<'!o)J[h!<<#uqu?Tpq#:<oq>^BnqZ$KoqZ$Ko!WN/ts8;rfs8N'!s8;rps8;rps7u`ns8;ro
+s8;ourr@WMJcC<$rr<-#!<;Ng!<7Q~>
+l2LebrrDusrrE#trrDusr;['%!!*'!!!)utrrDusr;Zlu!<)ro!:9^c!<)ot!;uis!;c]q!;QQr
+!<<'!o)J[h!<<#uqu?Tpq#:<oq>^BnqZ$KoqZ$Ko!WN/ts8;rfs8N'!s8;rps8;rps7u`ns8;ro
+s8;ourr@WMJcC<$rr<-#!<;Ng!<7Q~>
+lMgharr2rur;Q`sr;Q`srVlitrVultrVlitr;Q`srVlitrVultqu6Wrl2L_`r;Q`sr;Q`sqYpNq
+q>UEprr2runGiLgrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlitr;Q`srVultrVlitrVlit
+nc/UhrVlitrVlitrVlitqYpNqq>UEprVlitr;Q`srVultJcC<$JcG]L'E8(4!<3'!!<3'!!<3'!
+!<3'!!.Y~>
+lMgharr2rur;Q`sr;Q`srVlitrVultrVlitr;Q`srVlitrVultqu6Wrl2L_`r;Q`sr;Q`sqYpNq
+q>UEprr2runGiLgrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlitr;Q`srVultrVlitrVlit
+nc/UhrVlitrVlitrVlitqYpNqq>UEprVlitr;Q`srVultJcC<$JcG]L'E8(4!<3'!!<3'!!<3'!
+!<3'!!.Y~>
+lMgharr2rur;Q`sr;Q`srVlitrVultrVlitr;Q`srVlitrVultqu6Wrl2L_`r;Q`sr;Q`sqYpNq
+q>UEprr2runGiLgrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlitr;Q`srVultrVlitrVlit
+nc/UhrVlitrVlitrVlitqYpNqq>UEprVlitr;Q`srVultJcC<$JcG]L'E8(4!<3'!!<3'!!<3'!
+!<3'!!.Y~>
+lMgharr2rur;Q`sr;Q`srr2ruqu6WrrVlitr;Q`srVlitr;Q`squ6WrlMghaqu6Wrr;Q`sqYpNq
+q>UEprr2runG`Igq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`srr2ruqu6Wro)A[ir;Q`s
+rr2ruqu6Wrqu6WrqYpNqqu6WrrVlitr;Q`sJcC<$JcG`M'`S15!<3'!!<3'!!<3'!!<3'!!<7Q~>
+lMgharr2rur;Q`sr;Q`srr2ruqu6WrrVlitr;Q`srVlitr;Q`squ6WrlMghaqu6Wrr;Q`sqYpNq
+q>UEprr2runG`Igq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`srr2ruqu6Wro)A[ir;Q`s
+rr2ruqu6Wrqu6WrqYpNqqu6WrrVlitr;Q`sJcC<$JcG`M'`S15!<3'!!<3'!!<3'!!<3'!!<7Q~>
+lMgharr2rur;Q`sr;Q`srr2ruqu6WrrVlitr;Q`srVlitr;Q`squ6WrlMghaqu6Wrr;Q`sqYpNq
+q>UEprr2runG`Igq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`srr2ruqu6Wro)A[ir;Q`s
+rr2ruqu6Wrqu6WrqYpNqqu6WrrVlitr;Q`sJcC<$JcG`M'`S15!<3'!!<3'!!<3'!!<3'!!<7Q~>
+li-qbr;Q`srVlitr;Q`srr2ruqu6WrrVlitr;Q`sr;Z`rq#:<oli-qbqYpNqr;Q`sqYpNqqYpNq
+rVlitnG`Igq>^6jqYpNqqu?HlrVu`pqu?Wqqu?Hlo)A[ir;Q`srr2ruqu6Wrqu6WrqZ$?kr;Z`r
+JcC<$JcG`LrrDEcJ,~>
+li-qbr;Q`srVlitr;Q`srr2ruqu6WrrVlitr;Q`sr;Z`rq#:<oli-qbqYpNqr;Q`sqYpNqqYpNq
+rVlitnG`Igq>^6jqYpNqqu?HlrVu`pqu?Wqqu?Hlo)A[ir;Q`srr2ruqu6Wrqu6WrqZ$?kr;Z`r
+JcC<$JcG`LrrDEcJ,~>
+li-qbr;Q`srVlitr;Q`srr2ruqu6WrrVlitr;Q`sr;Z`rq#:<oli-qbqYpNqr;Q`sqYpNqqYpNq
+rVlitnG`Igq>^6jqYpNqqu?HlrVu`pqu?Wqqu?Hlo)A[ir;Q`srr2ruqu6Wrqu6WrqZ$?kr;Z`r
+JcC<$JcG`LrrDEcJ,~>
+li6e]rVlitr;Q`srr2ruqu6WrrVlitr;Q`sq>^HpqYpNqm/I%cq>UEpr;Q`sqYpNqqZ$Blnc&Rh
+q>UEpoD\djqu6Wrp\t3nr;Q`sq#C?orVlitli-qbr;Q`srr2ruqu6Wrqu6WrqYpNqo)J^iJcC<$
+Jc>`Mr;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li6e]rVlitr;Q`srr2ruqu6WrrVlitr;Q`sq>^HpqYpNqm/I%cq>UEpr;Q`sqYpNqqZ$Blnc&Rh
+q>UEpoD\djqu6Wrp\t3nr;Q`sq#C?orVlitli-qbr;Q`srr2ruqu6Wrqu6WrqYpNqo)J^iJcC<$
+Jc>`Mr;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li6e]rVlitr;Q`srr2ruqu6WrrVlitr;Q`sq>^HpqYpNqm/I%cq>UEpr;Q`sqYpNqqZ$Blnc&Rh
+q>UEpoD\djqu6Wrp\t3nr;Q`sq#C?orVlitli-qbr;Q`srr2ruqu6Wrqu6WrqYpNqo)J^iJcC<$
+Jc>`Mr;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+m/I%cqYpNqrr2rur;Q`srr2ruqu6WrrVlitr;Q`srVlitr;Q`squ6WrmJd.dq#:<or;Q`sqYpNq
+p&>!lnG`Igq>UEpoD\djqu6Wrp\t3nr;Q`sr;Q`sr;Q`srr2ruli-qbr;Q`srr2ruqu6Wrqu6Wr
+qYpNqpAY*mr;Q`sJcC<$JcG`Mm/MS~>
+m/I%cqYpNqrr2rur;Q`srr2ruqu6WrrVlitr;Q`srVlitr;Q`squ6WrmJd.dq#:<or;Q`sqYpNq
+p&>!lnG`Igq>UEpoD\djqu6Wrp\t3nr;Q`sr;Q`sr;Q`srr2ruli-qbr;Q`srr2ruqu6Wrqu6Wr
+qYpNqpAY*mr;Q`sJcC<$JcG`Mm/MS~>
+m/I%cqYpNqrr2rur;Q`srr2ruqu6WrrVlitr;Q`srVlitr;Q`squ6WrmJd.dq#:<or;Q`sqYpNq
+p&>!lnG`Igq>UEpoD\djqu6Wrp\t3nr;Q`sr;Q`sr;Q`srr2ruli-qbr;Q`srr2ruqu6Wrqu6Wr
+qYpNqpAY*mr;Q`sJcC<$JcG`Mm/MS~>
+m/I%cqYpNqrr2rurVultrVlitrVultrVlitrVultrVultrVlitqu6WrrVlitoD\djr;Q`sr;Q`s
+rr2ruq>UEpp&>!lnG`Igq#:<orVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVult
+o)A[ir;Q`srVlitrVlitqYpNqrVlitrr2rurVultrVultrVlitJcC<$JcG`Mm/MS~>
+m/I%cqYpNqrr2rurVultrVlitrVultrVlitrVultrVultrVlitqu6WrrVlitoD\djr;Q`sr;Q`s
+rr2ruq>UEpp&>!lnG`Igq#:<orVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVult
+o)A[ir;Q`srVlitrVlitqYpNqrVlitrr2rurVultrVultrVlitJcC<$JcG`Mm/MS~>
+m/I%cqYpNqrr2rurVultrVlitrVultrVlitrVultrVultrVlitqu6WrrVlitoD\djr;Q`sr;Q`s
+rr2ruq>UEpp&>!lnG`Igq#:<orVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVult
+o)A[ir;Q`srVlitrVlitqYpNqrVlitrr2rurVultrVultrVlitJcC<$JcG`Mm/MS~>
+mJm+brr;osrr;os!ri6#rVufr!WN/ts8;p!rr<&urrE-"r;cZnr;cHhq#L<lrW)iqq>gBlr;cHh
+q>gEmr;c`pq>gHnr;c`pr;ZitrW)rt!<E/u!;lfp!:g*g!<3#t!<)rr!;QTm!;ulq!;lcs!<;ut
+JcC<$Jc>`Mr;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+mJm+brr;osrr;os!ri6#rVufr!WN/ts8;p!rr<&urrE-"r;cZnr;cHhq#L<lrW)iqq>gBlr;cHh
+q>gEmr;c`pq>gHnr;c`pr;ZitrW)rt!<E/u!;lfp!:g*g!<3#t!<)rr!;QTm!;ulq!;lcs!<;ut
+JcC<$Jc>`Mr;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+mJm+brr;osrr;os!ri6#rVufr!WN/ts8;p!rr<&urrE-"r;cZnr;cHhq#L<lrW)iqq>gBlr;cHh
+q>gEmr;c`pq>gHnr;c`pr;ZitrW)rt!<E/u!;lfp!:g*g!<3#t!<)rr!;QTm!;ulq!;lcs!<;ut
+JcC<$Jc>`Mr;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+ci3tFJcC<$JcC<$O8o4[m/MS~>
+ci3tFJcC<$JcC<$O8o4[m/MS~>
+ci3tFJcC<$JcC<$O8o4[m/MS~>
+ci3tFJcC<$JcC<$O8o4[m/MS~>
+ci3tFJcC<$JcC<$O8o4[m/MS~>
+ci3tFJcC<$JcC<$O8o4[m/MS~>
+d/O(GJcC<$JcC<$NrT%X')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+d/O(GJcC<$JcC<$NrT%X')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+d/O(GJcC<$JcC<$NrT%X')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+ec5OIJcC<$JcC<$NW9"Ym/MS~>
+ec5OIJcC<$JcC<$NW9"Ym/MS~>
+ec5OIJcC<$JcC<$NW9"Ym/MS~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+iW&oX_#O?5JcCu7rrD$Xr;_EKJcF=$rrDEcJ,~>
+iW&oX_#O?5JcCu7rrD$Xr;_EKJcF=$rrDEcJ,~>
+iW&oX_#O?5JcCu7rrD$Xr;_EKJcF=$rrDEcJ,~>
+m/Qh\rr2ruo`"mkbPqPBJcGZKm/I%cfDbgNiVrlXq>UEphZ!QUmJd.diVrlXm/R"a!WN/ts8;p"
+rrE*!quFP4!!%TMqu?Tp')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+m/Qh\rr2ruo`"mkbPqPBJcGZKm/I%cfDbgNiVrlXq>UEphZ!QUmJd.diVrlXm/R"a!WN/ts8;p"
+rrE*!quFP4!!%TMqu?Tp')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+m/Qh\rr2ruo`"mkbPqPBJcGZKm/I%cfDbgNiVrlXq>UEphZ!QUmJd.diVrlXm/R"a!WN/ts8;p"
+rrE*!quFP4!!%TMqu?Tp')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+m/I%crr2rurr2rurr2ruo`"mkbPqPBJcG`L!!)Bc!!(XN!!)!X!!)ip!!(mU!!)Ed!!)!X!!)He
+rrE#trrE&urrE#trrE#t!!'b5!!%TMqu?Zrm/MS~>
+m/I%crr2rurr2rurr2ruo`"mkbPqPBJcG`L!!)Bc!!(XN!!)!X!!)ip!!(mU!!)Ed!!)!X!!)He
+rrE#trrE&urrE#trrE#t!!'b5!!%TMqu?Zrm/MS~>
+m/I%crr2rurr2rurr2ruo`"mkbPqPBJcG`L!!)Bc!!(XN!!)!X!!)ip!!(mU!!)Ed!!)!X!!)He
+rrE#trrE&urrE#trrE#t!!'b5!!%TMqu?Zrm/MS~>
+m/I%crr2rurr2rurr2ru^&J'4JcGcM!W`6#_Z'T9iVrlXq>UEphZ!QUmJd.diVrlXmf*7equ6Wr
+rr2ruqu6WrrVlitJcE4ZrrDEcJ,~>
+m/I%crr2rurr2rurr2ru^&J'4JcGcM!W`6#_Z'T9iVrlXq>UEphZ!QUmJd.diVrlXmf*7equ6Wr
+rr2ruqu6WrrVlitJcE4ZrrDEcJ,~>
+m/I%crr2rurr2rurr2ru^&J'4JcGcM!W`6#_Z'T9iVrlXq>UEphZ!QUmJd.diVrlXmf*7equ6Wr
+rr2ruqu6WrrVlitJcE4ZrrDEcJ,~>
+m/I%crr2rurr2rurr3!!s8;rps8E#os8;ourrDZjrVururW)iqr;cWm!!)ipr;c]or;c]or;Zlu
+!;ulq!:p0i!!`H'!<<'!!;ulq!;ulr!<3#t!<)rr!;c`o!!3*"nG`OirrDusrW)uurW)lrrW)co
+r;cfrrr<9'!!*'!!!)Tiq>gHnr;c?eq>gKo!<E/u!;lfp!:Bdd!;ZZn!;lfm!;ulq!;c`o!!3*"
+rVu]ooD\djp\t3np&>!lmf37drr;rtrVufrr;Z`r!<<#uqu?Tp!WN/ts8E#os8;rqs8N'!s8;q]
+s8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+m/I%crr2rurr2rurr3!!s8;rps8E#os8;ourrDZjrVururW)iqr;cWm!!)ipr;c]or;c]or;Zlu
+!;ulq!:p0i!!`H'!<<'!!;ulq!;ulr!<3#t!<)rr!;c`o!!3*"nG`OirrDusrW)uurW)lrrW)co
+r;cfrrr<9'!!*'!!!)Tiq>gHnr;c?eq>gKo!<E/u!;lfp!:Bdd!;ZZn!;lfm!;ulq!;c`o!!3*"
+rVu]ooD\djp\t3np&>!lmf37drr;rtrVufrr;Z`r!<<#uqu?Tp!WN/ts8E#os8;rqs8N'!s8;q]
+s8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+m/I%crr2rurr2rurr3!!s8;rps8E#os8;ourrDZjrVururW)iqr;cWm!!)ipr;c]or;c]or;Zlu
+!;ulq!:p0i!!`H'!<<'!!;ulq!;ulr!<3#t!<)rr!;c`o!!3*"nG`OirrDusrW)uurW)lrrW)co
+r;cfrrr<9'!!*'!!!)Tiq>gHnr;c?eq>gKo!<E/u!;lfp!:Bdd!;ZZn!;lfm!;ulq!;c`o!!3*"
+rVu]ooD\djp\t3np&>!lmf37drr;rtrVufrr;Z`r!<<#uqu?Tp!WN/ts8E#os8;rqs8N'!s8;q]
+s8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+kl1V_qZ$QqrVlitqYpNqqYpNqrVultnc/Uhrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlit
+r;Q`srVultrVlitrVlito)J^is8W*!s8N'!rr2rurVlitr;Q`sr;Q`srVlitrVlitr;Q`srVult
+nc&Rhrr2rur;Q`srVlitq>UEpqYpNqrVlitrVults8W*!s8N'!nc&Rhq>UEprVlitn,E@fq>^Hp
+rVlitrVlitrVlitmf*7eqYpNqrVlitqYpNqq>UEprVlitr;Q`srVultqu6Wrn,E@fp\t3np&>!l
+mJd.dr;Q`srVlitrVlitqu?Zrrr2rurVlitrVultqYpNqqYpNqrVlitr;ZcsrVlitPlLa`m/MS~>
+kl1V_qZ$QqrVlitqYpNqqYpNqrVultnc/Uhrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlit
+r;Q`srVultrVlitrVlito)J^is8W*!s8N'!rr2rurVlitr;Q`sr;Q`srVlitrVlitr;Q`srVult
+nc&Rhrr2rur;Q`srVlitq>UEpqYpNqrVlitrVults8W*!s8N'!nc&Rhq>UEprVlitn,E@fq>^Hp
+rVlitrVlitrVlitmf*7eqYpNqrVlitqYpNqq>UEprVlitr;Q`srVultqu6Wrn,E@fp\t3np&>!l
+mJd.dr;Q`srVlitrVlitqu?Zrrr2rurVlitrVultqYpNqqYpNqrVlitr;ZcsrVlitPlLa`m/MS~>
+kl1V_qZ$QqrVlitqYpNqqYpNqrVultnc/Uhrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlit
+r;Q`srVultrVlitrVlito)J^is8W*!s8N'!rr2rurVlitr;Q`sr;Q`srVlitrVlitr;Q`srVult
+nc&Rhrr2rur;Q`srVlitq>UEpqYpNqrVlitrVults8W*!s8N'!nc&Rhq>UEprVlitn,E@fq>^Hp
+rVlitrVlitrVlitmf*7eqYpNqrVlitqYpNqq>UEprVlitr;Q`srVultqu6Wrn,E@fp\t3np&>!l
+mJd.dr;Q`srVlitrVlitqu?Zrrr2rurVlitrVultqYpNqqYpNqrVlitr;ZcsrVlitPlLa`m/MS~>
+kl1V_qYpNqr;Q`sqYpNqqYpNqr;Q`snc&Rhq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`s
+rr2ruqu6WroD\djrr2rurr3'#s8N)rrr<&srr<&urr<&trr<&rrr<&trr<&srr<&hrr<&urr<&r
+rrW9$rrDio!!)or!!)or!!*#u!!*#u!!*#u!!)Qh!!)lq!!)or!!)Ng!!)ip!!)rs!!*#u!!)or
+!!)Kf!!)]l!!)lq!!)lq!!)or!!)ut!!)rs!!)or!!)Kf!!)cn!!)]l!!)Bc!!*#u!!)ut!!)or
+!!)rs!!)fo!!)rs!!)lq!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqqYpNqr;Q`snc&Rhq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`s
+rr2ruqu6WroD\djrr2rurr3'#s8N)rrr<&srr<&urr<&trr<&rrr<&trr<&srr<&hrr<&urr<&r
+rrW9$rrDio!!)or!!)or!!*#u!!*#u!!*#u!!)Qh!!)lq!!)or!!)Ng!!)ip!!)rs!!*#u!!)or
+!!)Kf!!)]l!!)lq!!)lq!!)or!!)ut!!)rs!!)or!!)Kf!!)cn!!)]l!!)Bc!!*#u!!)ut!!)or
+!!)rs!!)fo!!)rs!!)lq!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqqYpNqr;Q`snc&Rhq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`s
+rr2ruqu6WroD\djrr2rurr3'#s8N)rrr<&srr<&urr<&trr<&rrr<&trr<&srr<&hrr<&urr<&r
+rrW9$rrDio!!)or!!)or!!*#u!!*#u!!*#u!!)Qh!!)lq!!)or!!)Ng!!)ip!!)rs!!*#u!!)or
+!!)Kf!!)]l!!)lq!!)lq!!)or!!)ut!!)rs!!)or!!)Kf!!)cn!!)]l!!)Bc!!*#u!!)ut!!)or
+!!)rs!!)fo!!)rs!!)lq!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqq>^Eomf*7eq>^6jqYpNqqu?HlrVu`pqu?Wqqu?HloD\djrr2rurr3'#
+s8N)rrr<&srr<&urr<&ts7lZms8E#err<&srr<&rs8N)nrr<&rrr<&rrr<&urr<&urr<&urr<&h
+rr<&qrr<&rrr<&grr<&prr<&srr<&us7lZ`rr<&qs8)fmrr<&qs7lZms8E#nrr<&frr<&ss8;ou
+rrD`l!!)Bc!!*#u!!)utq#L?m!!)cnrW)]m!!)or!!)or!!)ut!!)rs!!&8`r;[K1!!*$!!<3$!
+rr<'!!!*$!!<7Q~>
+kl1V_qYpNqr;Q`sqYpNqq>^Eomf*7eq>^6jqYpNqqu?HlrVu`pqu?Wqqu?HloD\djrr2rurr3'#
+s8N)rrr<&srr<&urr<&ts7lZms8E#err<&srr<&rs8N)nrr<&rrr<&rrr<&urr<&urr<&urr<&h
+rr<&qrr<&rrr<&grr<&prr<&srr<&us7lZ`rr<&qs8)fmrr<&qs7lZms8E#nrr<&frr<&ss8;ou
+rrD`l!!)Bc!!*#u!!)utq#L?m!!)cnrW)]m!!)or!!)or!!)ut!!)rs!!&8`r;[K1!!*$!!<3$!
+rr<'!!!*$!!<7Q~>
+kl1V_qYpNqr;Q`sqYpNqq>^Eomf*7eq>^6jqYpNqqu?HlrVu`pqu?Wqqu?HloD\djrr2rurr3'#
+s8N)rrr<&srr<&urr<&ts7lZms8E#err<&srr<&rs8N)nrr<&rrr<&rrr<&urr<&urr<&urr<&h
+rr<&qrr<&rrr<&grr<&prr<&srr<&us7lZ`rr<&qs8)fmrr<&qs7lZms8E#nrr<&frr<&ss8;ou
+rrD`l!!)Bc!!*#u!!)utq#L?m!!)cnrW)]m!!)or!!)or!!)ut!!)rs!!&8`r;[K1!!*$!!<3$!
+rr<'!!!*$!!<7Q~>
+kl1V_qYpNqr;Q`sqYpNqpAb-mnG`Igq>UEpoD\djqu6Wrp\t3nr;Q`sq#C?orVlitm/I%crr2ru
+rr3'#s8N)rrr<&rrrN3#!;uis!:p0i!:g*c!;lfr!;HKn!;lcr!;lcr!<2uu!<2uu!<2uu!:g'h
+!;c]q!;lcr!:^!g!;ZWp!;uis!<2uu!9jF_!;lcr!;uis!;c]q!;c]q!:p0i!;c]q!:Tpf!;c]t
+!<<'!p&>!lr;Q`snc&XjrrDus!!)]l!!)ZkrrDlp!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqpAb-mnG`Igq>UEpoD\djqu6Wrp\t3nr;Q`sq#C?orVlitm/I%crr2ru
+rr3'#s8N)rrr<&rrrN3#!;uis!:p0i!:g*c!;lfr!;HKn!;lcr!;lcr!<2uu!<2uu!<2uu!:g'h
+!;c]q!;lcr!:^!g!;ZWp!;uis!<2uu!9jF_!;lcr!;uis!;c]q!;c]q!:p0i!;c]q!:Tpf!;c]t
+!<<'!p&>!lr;Q`snc&XjrrDus!!)]l!!)ZkrrDlp!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqpAb-mnG`Igq>UEpoD\djqu6Wrp\t3nr;Q`sq#C?orVlitm/I%crr2ru
+rr3'#s8N)rrr<&rrrN3#!;uis!:p0i!:g*c!;lfr!;HKn!;lcr!;lcr!<2uu!<2uu!<2uu!:g'h
+!;c]q!;lcr!:^!g!;ZWp!;uis!<2uu!9jF_!;lcr!;uis!;c]q!;c]q!:p0i!;c]q!:Tpf!;c]t
+!<<'!p&>!lr;Q`snc&XjrrDus!!)]l!!)ZkrrDlp!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqqYpNqr;Q`snc&Rhq>UEpoD\djqu6Wrp\t3nr;Q`sr;Q`sr;Q`srr2ru
+m/I%crr2rurr3'#s8N)rrr<&rrrN3#!;uis!;?Em!;uis!;$3j!;c]q!<)p"!<<'!q#:<oqu6Wr
+qu6Wrrr2rurr2rurr2runc&RhqYpNqqu6WrnG`Igq>UEpr;Q`srr2rukl1V_qu6Wrr;Q`sqYpNq
+qYpNqpAY*mr;Q`squ6Wrmf*7equ6Wrrr2ruqu6WrrVlitr;Q`snc&XjrrDus!!)]l!!)fo!!)rs
+!!)lq!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqqYpNqr;Q`snc&Rhq>UEpoD\djqu6Wrp\t3nr;Q`sr;Q`sr;Q`srr2ru
+m/I%crr2rurr3'#s8N)rrr<&rrrN3#!;uis!;?Em!;uis!;$3j!;c]q!<)p"!<<'!q#:<oqu6Wr
+qu6Wrrr2rurr2rurr2runc&RhqYpNqqu6WrnG`Igq>UEpr;Q`srr2rukl1V_qu6Wrr;Q`sqYpNq
+qYpNqpAY*mr;Q`squ6Wrmf*7equ6Wrrr2ruqu6WrrVlitr;Q`snc&XjrrDus!!)]l!!)fo!!)rs
+!!)lq!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqqYpNqr;Q`snc&Rhq>UEpoD\djqu6Wrp\t3nr;Q`sr;Q`sr;Q`srr2ru
+m/I%crr2rurr3'#s8N)rrr<&rrrN3#!;uis!;?Em!;uis!;$3j!;c]q!<)p"!<<'!q#:<oqu6Wr
+qu6Wrrr2rurr2rurr2runc&RhqYpNqqu6WrnG`Igq>UEpr;Q`srr2rukl1V_qu6Wrr;Q`sqYpNq
+qYpNqpAY*mr;Q`squ6Wrmf*7equ6Wrrr2ruqu6WrrVlitr;Q`snc&XjrrDus!!)]l!!)fo!!)rs
+!!)lq!!)or!!)or!!)ut!!)rs!!&8`rrDEcJ,~>
+kl1V_qYpNqr;Q`sqYpNqqZ$QqrVlitnc&Rhq#:<orVultqYpNqqYpNqrVultrr2rurVultr;Zcs
+rVlitrVlitrVultoD\djrr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVultrVlitoD\djqYpNq
+rr2rurVlitq>UEpqYpNqrVlitrVlitrr2rurr2runc&RhrVlitrr2rurVlitn,E@frVlitrr2ru
+r;Q`srVlitrVultn,E@fqu6WrrVultqYpNqrVlitrr2rurVultrVultrVlitqu6WrrVlitoDegj
+rVlitrVultrVlitr;Q`sr;Q`snG`IgqYpNqrVultr;Q`sq#C?orVlitqYpNqqYpNqrVlitr;Q`s
+r;Q`squ?ZrSH&Nf')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+kl1V_qYpNqr;Q`sqYpNqqZ$QqrVlitnc&Rhq#:<orVultqYpNqqYpNqrVultrr2rurVultr;Zcs
+rVlitrVlitrVultoD\djrr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVultrVlitoD\djqYpNq
+rr2rurVlitq>UEpqYpNqrVlitrVlitrr2rurr2runc&RhrVlitrr2rurVlitn,E@frVlitrr2ru
+r;Q`srVlitrVultn,E@fqu6WrrVultqYpNqrVlitrr2rurVultrVultrVlitqu6WrrVlitoDegj
+rVlitrVultrVlitr;Q`sr;Q`snG`IgqYpNqrVultr;Q`sq#C?orVlitqYpNqqYpNqrVlitr;Q`s
+r;Q`squ?ZrSH&Nf')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+kl1V_qYpNqr;Q`sqYpNqqZ$QqrVlitnc&Rhq#:<orVultqYpNqqYpNqrVultrr2rurVultr;Zcs
+rVlitrVlitrVultoD\djrr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVultrVlitoD\djqYpNq
+rr2rurVlitq>UEpqYpNqrVlitrVlitrr2rurr2runc&RhrVlitrr2rurVlitn,E@frVlitrr2ru
+r;Q`srVlitrVultn,E@fqu6WrrVultqYpNqrVlitrr2rurVultrVultrVlitqu6WrrVlitoDegj
+rVlitrVultrVlitr;Q`sr;Q`snG`IgqYpNqrVultr;Q`sq#C?orVlitqYpNqqYpNqrVlitr;Q`s
+r;Q`squ?ZrSH&Nf')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+lMpb^rVuisrr;rtrr;fprVllus8;rgs7u`ms8;rps7u`ns8;rps8;ots8E#trrE-"r;c`pr;cEg
+rW)uurrE*!rrE&ur;cWm!!)ipr;c`p!<E/u!;$6h!<3#s!!*&u!<<)u!<)ro!;ulq!<)rs!<<*!
+!<<*!!:g*f!;ulq!:Bgb!<3#t!<3#t!<)rr!:^$b!<)rr!!*&u!;lfp!;ulq!;lcs!<;utq>^Bn
+nGiFeqZ$KorVuWmnG`Igq>^Bnr;ZTnr;Qcts8;rqs7u`ns8;rqs8E#ts8E#rs8N(hs8N)cs*t~>
+lMpb^rVuisrr;rtrr;fprVllus8;rgs7u`ms8;rps7u`ns8;rps8;ots8E#trrE-"r;c`pr;cEg
+rW)uurrE*!rrE&ur;cWm!!)ipr;c`p!<E/u!;$6h!<3#s!!*&u!<<)u!<)ro!;ulq!<)rs!<<*!
+!<<*!!:g*f!;ulq!:Bgb!<3#t!<3#t!<)rr!:^$b!<)rr!!*&u!;lfp!;ulq!;lcs!<;utq>^Bn
+nGiFeqZ$KorVuWmnG`Igq>^Bnr;ZTnr;Qcts8;rqs7u`ns8;rqs8E#ts8E#rs8N(hs8N)cs*t~>
+lMpb^rVuisrr;rtrr;fprVllus8;rgs7u`ms8;rps7u`ns8;rps8;ots8E#trrE-"r;c`pr;cEg
+rW)uurrE*!rrE&ur;cWm!!)ipr;c`p!<E/u!;$6h!<3#s!!*&u!<<)u!<)ro!;ulq!<)rs!<<*!
+!<<*!!:g*f!;ulq!:Bgb!<3#t!<3#t!<)rr!:^$b!<)rr!!*&u!;lfp!;ulq!;lcs!<;utq>^Bn
+nGiFeqZ$KorVuWmnG`Igq>^Bnr;ZTnr;Qcts8;rqs7u`ns8;rqs8E#ts8E#rs8N(hs8N)cs*t~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+i;``UqZ$KoZiC%*JcC<$ci="FJcCi3rrDEcJ,~>
+i;``UqZ$KoZiC%*JcC<$ci="FJcCi3rrDEcJ,~>
+i;``UqZ$KoZiC%*JcC<$ci="FJcCi3rrDEcJ,~>
+li6n`p\t3np\t3nZMsn)g&D$PWrE&!JcF'r!!%TMOT5=\m/MS~>
+li6n`p\t3np\t3nZMsn)g&D$PWrE&!JcF'r!!%TMOT5=\m/MS~>
+li6n`p\t3np\t3nZMsn)g&D$PWrE&!JcF'r!!%TMOT5=\m/MS~>
+kl1V_p\t3np\t3nZMsn)g&D$PWrE&!JcF'r!!%TMOT57Z')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+kl1V_p\t3np\t3nZMsn)g&D$PWrE&!JcF'r!!%TMOT57Z')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+kl1V_p\t3np\t3nZMsn)g&D$PWrE&!JcF'r!!%TMOT57Z')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+l2LebrrDio!!)cn!!'>)!!%TMJcF$q!!%TMOT5=\m/MS~>
+l2LebrrDio!!)cn!!'>)!!%TMJcF$q!!%TMOT5=\m/MS~>
+l2LebrrDio!!)cn!!'>)!!%TMJcF$q!!%TMOT5=\m/MS~>
+l2LebrrDio!!)cn!!)NgrrE#trrE&urr<'!r;cfrrrE#trrDusr;Zlu!;ulq!;c`o!!3*"oDegj
+!<;utrVuis!<<#uqu?Wqq>^Bnr;Z`r!<<#uo)J[hrr;rtrVufrr;Z`r!<<#uqu?Tp!WN/ts8E#o
+s8;rqs8N'!s8;rps8;ourrDZjrW)rtrW)osr;ccqrVururW)iqr;cBfrVururW)iqr;cfrrr<9'
+!!*'!!!)rsr;ccqrW)rtrW)osr;c]or;Zlu!.k03s8N)cs*t~>
+l2LebrrDio!!)cn!!)NgrrE#trrE&urr<'!r;cfrrrE#trrDusr;Zlu!;ulq!;c`o!!3*"oDegj
+!<;utrVuis!<<#uqu?Wqq>^Bnr;Z`r!<<#uo)J[hrr;rtrVufrr;Z`r!<<#uqu?Tp!WN/ts8E#o
+s8;rqs8N'!s8;rps8;ourrDZjrW)rtrW)osr;ccqrVururW)iqr;cBfrVururW)iqr;cfrrr<9'
+!!*'!!!)rsr;ccqrW)rtrW)osr;c]or;Zlu!.k03s8N)cs*t~>
+l2LebrrDio!!)cn!!)NgrrE#trrE&urr<'!r;cfrrrE#trrDusr;Zlu!;ulq!;c`o!!3*"oDegj
+!<;utrVuis!<<#uqu?Wqq>^Bnr;Z`r!<<#uo)J[hrr;rtrVufrr;Z`r!<<#uqu?Tp!WN/ts8E#o
+s8;rqs8N'!s8;rps8;ourrDZjrW)rtrW)osr;ccqrVururW)iqr;cBfrVururW)iqr;cfrrr<9'
+!!*'!!!)rsr;ccqrW)rtrW)osr;c]or;Zlu!.k03s8N)cs*t~>
+lMgharr2ruq>UEpp\t3nn,E@fr;Q`srVultrVlitrVlitr;Q`srVlitrVultrVlitrVlitr;Q`s
+rVulto)J^irVlitr;Zcsrr2ruqYpNqqYpNqrVlitqu?Zrrr2ruo)A[ir;Q`srVlitrVlitqu?Zr
+rr2rurVlitrVultqYpNqqYpNqrVlitr;ZcsrVlitrVlitrVulto)A[ir;Q`srVlitrVlitqu?Zr
+rr2rurVlitrVlitnGiLgrr2rurVlitrVlitrVults8W*!s8N'!rr2rurVlitr;Q`sr;Q`srVlit
+rVlitr;Q`srVultJcCi3r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+lMgharr2ruq>UEpp\t3nn,E@fr;Q`srVultrVlitrVlitr;Q`srVlitrVultrVlitrVlitr;Q`s
+rVulto)J^irVlitr;Zcsrr2ruqYpNqqYpNqrVlitqu?Zrrr2ruo)A[ir;Q`srVlitrVlitqu?Zr
+rr2rurVlitrVultqYpNqqYpNqrVlitr;ZcsrVlitrVlitrVulto)A[ir;Q`srVlitrVlitqu?Zr
+rr2rurVlitrVlitnGiLgrr2rurVlitrVlitrVults8W*!s8N'!rr2rurVlitr;Q`sr;Q`srVlit
+rVlitr;Q`srVultJcCi3r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+lMgharr2ruq>UEpp\t3nn,E@fr;Q`srVultrVlitrVlitr;Q`srVlitrVultrVlitrVlitr;Q`s
+rVulto)J^irVlitr;Zcsrr2ruqYpNqqYpNqrVlitqu?Zrrr2ruo)A[ir;Q`srVlitrVlitqu?Zr
+rr2rurVlitrVultqYpNqqYpNqrVlitr;ZcsrVlitrVlitrVulto)A[ir;Q`srVlitrVlitqu?Zr
+rr2rurVlitrVlitnGiLgrr2rurVlitrVlitrVults8W*!s8N'!rr2rurVlitr;Q`sr;Q`srVlit
+rVlitr;Q`srVultJcCi3r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+lMgharr2ruq>UEpp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`srVlitr;Q`srr2ruqu6Wrrr2ru
+qu6Wro)A[iqu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sm/I%crr2rurVlitqu6Wrr;Q`sq#:<or;Q`s
+qYpNqqu6Wrqu6WrrVlitr;Q`srVlitr;Q`so)Amos8N*!rrE&u!!)or!!)rs!!)ip!!)or!!)Qh
+!!)ip!!)or!!*#u!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)ot!;lcr!<2uu!;lcr!.k03s8N)c
+s*t~>
+lMgharr2ruq>UEpp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`srVlitr;Q`srr2ruqu6Wrrr2ru
+qu6Wro)A[iqu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sm/I%crr2rurVlitqu6Wrr;Q`sq#:<or;Q`s
+qYpNqqu6Wrqu6WrrVlitr;Q`srVlitr;Q`so)Amos8N*!rrE&u!!)or!!)rs!!)ip!!)or!!)Qh
+!!)ip!!)or!!*#u!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)ot!;lcr!<2uu!;lcr!.k03s8N)c
+s*t~>
+lMgharr2ruq>UEpp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`srVlitr;Q`srr2ruqu6Wrrr2ru
+qu6Wro)A[iqu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sm/I%crr2rurVlitqu6Wrr;Q`sq#:<or;Q`s
+qYpNqqu6Wrqu6WrrVlitr;Q`srVlitr;Q`so)Amos8N*!rrE&u!!)or!!)rs!!)ip!!)or!!)Qh
+!!)ip!!)or!!*#u!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)ot!;lcr!<2uu!;lcr!.k03s8N)c
+s*t~>
+li-qbr;Q`sqYpNqp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`sr;Z`rqu?Hlrr2ruqu6Wro)A[i
+qu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sm/I%crr2rurVuZnr;Q`sp](3mp\t3nqu6Wrqu6WrrVlit
+r;Q`sr;Z`rn,ERls8N*!rrE&uq#L?m!!)ipq#Ksb!!)ipq#LEo!!*#u!!*#u!s&B$!;lcr!;uis
+!<2uu!<)rn!<2uu!;lcr!.k03s8N)cs*t~>
+li-qbr;Q`sqYpNqp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`sr;Z`rqu?Hlrr2ruqu6Wro)A[i
+qu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sm/I%crr2rurVuZnr;Q`sp](3mp\t3nqu6Wrqu6WrrVlit
+r;Q`sr;Z`rn,ERls8N*!rrE&uq#L?m!!)ipq#Ksb!!)ipq#LEo!!*#u!!*#u!s&B$!;lcr!;uis
+!<2uu!<)rn!<2uu!;lcr!.k03s8N)cs*t~>
+li-qbr;Q`sqYpNqp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`sr;Z`rqu?Hlrr2ruqu6Wro)A[i
+qu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sm/I%crr2rurVuZnr;Q`sp](3mp\t3nqu6Wrqu6WrrVlit
+r;Q`sr;Z`rn,ERls8N*!rrE&uq#L?m!!)ipq#Ksb!!)ipq#LEo!!*#u!!*#u!s&B$!;lcr!;uis
+!<2uu!<)rn!<2uu!;lcr!.k03s8N)cs*t~>
+li6e]qYpNqp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`sq>^HprVlitp\t3nqu6Wro)A[iqu6Wr
+rVlitp&>!lqu6Wrqu6Wrr;Q`sli."drrDus!!)]l!!)ZkrrDlp!!)or!!)or!!)ut!!)rs!!)ip
+rrDTh"p"Z'rrE'!rr2rup&>!lq>UEplMghaq>UEpp\t3nrr2rurr3'#s8N)rrr<&rrrN3#!;uis
+!;HKn!;lcr!.k03s8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+li6e]qYpNqp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`sq>^HprVlitp\t3nqu6Wro)A[iqu6Wr
+rVlitp&>!lqu6Wrqu6Wrr;Q`sli."drrDus!!)]l!!)ZkrrDlp!!)or!!)or!!)ut!!)rs!!)ip
+rrDTh"p"Z'rrE'!rr2rup&>!lq>UEplMghaq>UEpp\t3nrr2rurr3'#s8N)rrr<&rrrN3#!;uis
+!;HKn!;lcr!.k03s8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+li6e]qYpNqp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`sq>^HprVlitp\t3nqu6Wro)A[iqu6Wr
+rVlitp&>!lqu6Wrqu6Wrr;Q`sli."drrDus!!)]l!!)ZkrrDlp!!)or!!)or!!)ut!!)rs!!)ip
+rrDTh"p"Z'rrE'!rr2rup&>!lq>UEplMghaq>UEpp\t3nrr2rurr3'#s8N)rrr<&rrrN3#!;uis
+!;HKn!;lcr!.k03s8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+m/I%cqYpNqqu6Wrp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`srVlitr;Q`srr2rup\t3nqu6Wr
+o)A[iqu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sli."drrDus!!)]l!!)fo!!)rs!!)lq!!)or!!)or
+!!)ut!!)rs!!)ut!!)rs!!)Ti"p"Z'rrE'!rr2rup&>!lq>UEplMghaq>UEpp\t3nrr2rurr3'#
+s8N)rrr<&rrrN3#!;uis!;HKn!;lcr!.k03s8N)cs*t~>
+m/I%cqYpNqqu6Wrp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`srVlitr;Q`srr2rup\t3nqu6Wr
+o)A[iqu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sli."drrDus!!)]l!!)fo!!)rs!!)lq!!)or!!)or
+!!)ut!!)rs!!)ut!!)rs!!)Ti"p"Z'rrE'!rr2rup&>!lq>UEplMghaq>UEpp\t3nrr2rurr3'#
+s8N)rrr<&rrrN3#!;uis!;HKn!;lcr!.k03s8N)cs*t~>
+m/I%cqYpNqqu6Wrp\t3nn,E@fr;Q`srVlitr;Q`srVlitr;Q`srVlitr;Q`srr2rup\t3nqu6Wr
+o)A[iqu6WrrVlitp&>!lqu6Wrqu6Wrr;Q`sli."drrDus!!)]l!!)fo!!)rs!!)lq!!)or!!)or
+!!)ut!!)rs!!)ut!!)rs!!)Ti"p"Z'rrE'!rr2rup&>!lq>UEplMghaq>UEpp\t3nrr2rurr3'#
+s8N)rrr<&rrrN3#!;uis!;HKn!;lcr!.k03s8N)cs*t~>
+m/I%cqYpNqqu6Wrp\t3nn,E@frVultrVlitr;Q`srVlitrVultrVultrVlitrVlitrVultrVlit
+rVulto)J^irVlitr;Q`sp&>!lqYpNqrVlitqu6WrlMghaqYpNqrVultr;Q`sq#C?orVlitqYpNq
+qYpNqrVlitr;Q`sr;Q`srVultrVlitnc&Rhrr2rur;Q`srVultr;Q`sq#:<orVultnc&Rhq#:<o
+rVultrr2rurr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVlitrVultqu?ZrJcD,;rrDEcJ,~>
+m/I%cqYpNqqu6Wrp\t3nn,E@frVultrVlitr;Q`srVlitrVultrVultrVlitrVlitrVultrVlit
+rVulto)J^irVlitr;Q`sp&>!lqYpNqrVlitqu6WrlMghaqYpNqrVultr;Q`sq#C?orVlitqYpNq
+qYpNqrVlitr;Q`sr;Q`srVultrVlitnc&Rhrr2rur;Q`srVultr;Q`sq#:<orVultnc&Rhq#:<o
+rVultrr2rurr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVlitrVultqu?ZrJcD,;rrDEcJ,~>
+m/I%cqYpNqqu6Wrp\t3nn,E@frVultrVlitr;Q`srVlitrVultrVultrVlitrVlitrVultrVlit
+rVulto)J^irVlitr;Q`sp&>!lqYpNqrVlitqu6WrlMghaqYpNqrVultr;Q`sq#C?orVlitqYpNq
+qYpNqrVlitr;Q`sr;Q`srVultrVlitnc&Rhrr2rur;Q`srVultr;Q`sq#:<orVultnc&Rhq#:<o
+rVultrr2rurr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVlitrVultqu?ZrJcD,;rrDEcJ,~>
+mJm+brr;oss8VoqrVu]onc/Of"TJH%s8W&urr;rtrVufr!ri6#rr3!!s8;rps8;ros8;p!rr<&j
+rrE-"r;cfrq>gHnq>gHnr;ccqq>fs`!!)ipr;ccqq>gHn!<E/u!;uln!;ulq!;ulr!<3#t!<3!!
+!<;utnG`Igrr2ruqu?Tpr;ZTnqu?Tpnc/Fcqu?TprVuiss8W*!s8W*!rr;osq#:<oq>^BnqZ$Ko
+!ri6#r;ZcsJcD,;r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+mJm+brr;oss8VoqrVu]onc/Of"TJH%s8W&urr;rtrVufr!ri6#rr3!!s8;rps8;ros8;p!rr<&j
+rrE-"r;cfrq>gHnq>gHnr;ccqq>fs`!!)ipr;ccqq>gHn!<E/u!;uln!;ulq!;ulr!<3#t!<3!!
+!<;utnG`Igrr2ruqu?Tpr;ZTnqu?Tpnc/Fcqu?TprVuiss8W*!s8W*!rr;osq#:<oq>^BnqZ$Ko
+!ri6#r;ZcsJcD,;r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+mJm+brr;oss8VoqrVu]onc/Of"TJH%s8W&urr;rtrVufr!ri6#rr3!!s8;rps8;ros8;p!rr<&j
+rrE-"r;cfrq>gHnq>gHnr;ccqq>fs`!!)ipr;ccqq>gHn!<E/u!;uln!;ulq!;ulr!<3#t!<3!!
+!<;utnG`Igrr2ruqu?Tpr;ZTnqu?Tpnc/Fcqu?TprVuiss8W*!s8W*!rr;osq#:<oq>^BnqZ$Ko
+!ri6#r;ZcsJcD,;r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcG<@!!%TMJcC<$JcG*:rrDEcJ,~>
+JcG<@!!%TMJcC<$JcG*:rrDEcJ,~>
+JcG<@!!%TMJcC<$JcG*:rrDEcJ,~>
+JcG<@!!%TMJcC<$JcG*:rrDEcJ,~>
+JcG<@!!%TMJcC<$JcG*:rrDEcJ,~>
+JcG<@!!%TMJcC<$JcG*:rrDEcJ,~>
+JcG<@!!%TMJcC<$JcG*:r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcG<@!!%TMJcC<$JcG*:r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcG<@!!%TMJcC<$JcG*:r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcG?Ar;_EKJcC<$JcG0<rrDEcJ,~>
+JcG?Ar;_EKJcC<$JcG0<rrDEcJ,~>
+JcG?Ar;_EKJcC<$JcG0<rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+V>pJol2Ub`_>jN8_#O?5huE]Va8c/>_#O?5`;fi;WrN"thuE]V_#OE7m/MS~>
+V>pJol2Ub`_>jN8_#O?5huE]Va8c/>_#O?5`;fi;WrN"thuE]V_#OE7m/MS~>
+V>pJol2Ub`_>jN8_#O?5huE]Va8c/>_#O?5`;fi;WrN"thuE]V_#OE7m/MS~>
+mJm.cr;Z`rkPkM^i;WcWmJd.dq>UEp_#FB7l2L_`f)G^MhZ!QUn,E@fir8uYq>UEpo`"mkbPqPB
+_uB]:e,KCJf)G^MhZ!QUnGiFe!WN0!s8;rps7cTls8E!!rrDfnr;[K1!!*$!!<3$!rr<'!!!*$!
+!<7Q~>
+mJm.cr;Z`rkPkM^i;WcWmJd.dq>UEp_#FB7l2L_`f)G^MhZ!QUn,E@fir8uYq>UEpo`"mkbPqPB
+_uB]:e,KCJf)G^MhZ!QUnGiFe!WN0!s8;rps7cTls8E!!rrDfnr;[K1!!*$!!<3$!rr<'!!!*$!
+!<7Q~>
+mJm.cr;Z`rkPkM^i;WcWmJd.dq>UEp_#FB7l2L_`f)G^MhZ!QUn,E@fir8uYq>UEpo`"mkbPqPB
+_uB]:e,KCJf)G^MhZ!QUnGiFe!WN0!s8;rps7cTls8E!!rrDfnr;[K1!!*$!!<3$!rr<'!!!*$!
+!<7Q~>
+m/R(cr;Zcsk5PD]iVrlXm/I%cq>UEp_#FB7l2L_`f)G^MhZ!QUn,E@fir8uYq>UEpo`"mkbPqPB
+_uB]:e,KCJf)G^MhZ!QUo)J^irVultqu6Wrqu6Wrrr2rurr2rurVlitrr;uup](6nm/MS~>
+m/R(cr;Zcsk5PD]iVrlXm/I%cq>UEp_#FB7l2L_`f)G^MhZ!QUn,E@fir8uYq>UEpo`"mkbPqPB
+_uB]:e,KCJf)G^MhZ!QUo)J^irVultqu6Wrqu6Wrrr2rurr2rurVlitrr;uup](6nm/MS~>
+m/R(cr;Zcsk5PD]iVrlXm/I%cq>UEp_#FB7l2L_`f)G^MhZ!QUn,E@fir8uYq>UEpo`"mkbPqPB
+_uB]:e,KCJf)G^MhZ!QUo)J^irVultqu6Wrqu6Wrrr2rurr2rurVlitrr;uup](6nm/MS~>
+m/I+errE&u!W`6#k5PD]iVrlXm/I%cq>UEp_#FB7^&J'4hZ!QUci3tFq>UEp^&J'4_uB]:VuH_s
+hZ!QUo)A[iqu6Wrr;QfurrDus!!*#u!!*#u!!*#u!!)rs!!)cnrrDEcJ,~>
+m/I+errE&u!W`6#k5PD]iVrlXm/I%cq>UEp_#FB7^&J'4hZ!QUci3tFq>UEp^&J'4_uB]:VuH_s
+hZ!QUo)A[iqu6Wrr;QfurrDus!!*#u!!*#u!!*#u!!)rs!!)cnrrDEcJ,~>
+m/I+errE&u!W`6#k5PD]iVrlXm/I%cq>UEp_#FB7^&J'4hZ!QUci3tFq>UEp^&J'4_uB]:VuH_s
+hZ!QUo)A[iqu6Wrr;QfurrDus!!*#u!!*#u!!*#u!!)rs!!)cnrrDEcJ,~>
+m/I+errE&u!W`6#rVufrqZ$Ko!WN/us7u`cs8;rps7u`ds7u`orrE-"r;c`pr;cBfrW)rtrW)os
+r;ccqrVururW)lr!W`9#r;cBfrW)iqrr<'!r;cfrrW)rtrW)osr;cWm!!)orrW)rtrW)osr;c]o
+r;Zlu!:g*g!;lfr!!*&t!:g*c!<)ou!<;utqu?Wqq>^Bn!WN/ks8Duus8E#qs8;rmrr<&ps8;ro
+s8;ros8;ourrDusr;c?e!<E/u!;lfp!;c`o!!3*"nc/Rgqu?Zr!<;utrVuisrr;rtrVufrq#:<o
+qu?Wqrr;rtrVufrqZ$Ko!WN/krr<&krrN3#!;uis!<2uu!<2uu!<2uu!:g*f!##;3!<3$!rr<'!
+!!*$!!<3$!s*t~>
+m/I+errE&u!W`6#rVufrqZ$Ko!WN/us7u`cs8;rps7u`ds7u`orrE-"r;c`pr;cBfrW)rtrW)os
+r;ccqrVururW)lr!W`9#r;cBfrW)iqrr<'!r;cfrrW)rtrW)osr;cWm!!)orrW)rtrW)osr;c]o
+r;Zlu!:g*g!;lfr!!*&t!:g*c!<)ou!<;utqu?Wqq>^Bn!WN/ks8Duus8E#qs8;rmrr<&ps8;ro
+s8;ros8;ourrDusr;c?e!<E/u!;lfp!;c`o!!3*"nc/Rgqu?Zr!<;utrVuisrr;rtrVufrq#:<o
+qu?Wqrr;rtrVufrqZ$Ko!WN/krr<&krrN3#!;uis!<2uu!<2uu!<2uu!:g*f!##;3!<3$!rr<'!
+!!*$!!<3$!s*t~>
+m/I+errE&u!W`6#rVufrqZ$Ko!WN/us7u`cs8;rps7u`ds7u`orrE-"r;c`pr;cBfrW)rtrW)os
+r;ccqrVururW)lr!W`9#r;cBfrW)iqrr<'!r;cfrrW)rtrW)osr;cWm!!)orrW)rtrW)osr;c]o
+r;Zlu!:g*g!;lfr!!*&t!:g*c!<)ou!<;utqu?Wqq>^Bn!WN/ks8Duus8E#qs8;rmrr<&ps8;ro
+s8;ros8;ourrDusr;c?e!<E/u!;lfp!;c`o!!3*"nc/Rgqu?Zr!<;utrVuisrr;rtrVufrq#:<o
+qu?Wqrr;rtrVufrqZ$Ko!WN/krr<&krrN3#!;uis!<2uu!<2uu!<2uu!:g*f!##;3!<3$!rr<'!
+!!*$!!<3$!s*t~>
+m/I=ks8N*!!<<'!rr2rurVlitr;Q`srVultqu6Wrmf*7erVlitqYpNqm/I%cq>^HprVlitrVlit
+rVlitnc&Rhr;Q`srVlitrVlitqu?Zrrr2rurVlitrr2rumJd.dqZ$QqrVlitrVlitr;Q`srVlit
+rVlitq>UEpqYpNqr;Q`srVlitrVlitr;Q`srVultn,E@fqZ$QqrVlitnG`Igq>^HprVlitqYpNq
+qYpNqrVultnc/Uhrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlitr;Q`srVultrVlitrVlit
+nc/UhrVlitrVlitrVlitr;Q`srVultn,E@fqZ$QqrVlitrVlitr;Q`srVlitrVlitq>UEpqYpNq
+r;Q`srVlitrVlitr;Q`srVultoD\djp&>!lrr2ruq>UEpq>UEpo)J^im/MS~>
+m/I=ks8N*!!<<'!rr2rurVlitr;Q`srVultqu6Wrmf*7erVlitqYpNqm/I%cq>^HprVlitrVlit
+rVlitnc&Rhr;Q`srVlitrVlitqu?Zrrr2rurVlitrr2rumJd.dqZ$QqrVlitrVlitr;Q`srVlit
+rVlitq>UEpqYpNqr;Q`srVlitrVlitr;Q`srVultn,E@fqZ$QqrVlitnG`Igq>^HprVlitqYpNq
+qYpNqrVultnc/Uhrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlitr;Q`srVultrVlitrVlit
+nc/UhrVlitrVlitrVlitr;Q`srVultn,E@fqZ$QqrVlitrVlitr;Q`srVlitrVlitq>UEpqYpNq
+r;Q`srVlitrVlitr;Q`srVultoD\djp&>!lrr2ruq>UEpq>UEpo)J^im/MS~>
+m/I=ks8N*!!<<'!rr2rurVlitr;Q`srVultqu6Wrmf*7erVlitqYpNqm/I%cq>^HprVlitrVlit
+rVlitnc&Rhr;Q`srVlitrVlitqu?Zrrr2rurVlitrr2rumJd.dqZ$QqrVlitrVlitr;Q`srVlit
+rVlitq>UEpqYpNqr;Q`srVlitrVlitr;Q`srVultn,E@fqZ$QqrVlitnG`Igq>^HprVlitqYpNq
+qYpNqrVultnc/Uhrr2rurVlitrVlitq>UEpqYpNqrVlitr;Q`srVlitr;Q`srVultrVlitrVlit
+nc/UhrVlitrVlitrVlitr;Q`srVultn,E@fqZ$QqrVlitrVlitr;Q`srVlitrVlitq>UEpqYpNq
+r;Q`srVlitrVlitr;Q`srVultoD\djp&>!lrr2ruq>UEpq>UEpo)J^im/MS~>
+m/IFns8N*!!<<'!s8N)rrr<&trr<&srr<&rrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&r
+rr<&irrrK'rrE*!!<2uu!;lcr!;uis!;QQr!<<'!m/I%cqYpNqr;Q`sr;Q`srr2rurVlitqu6Wr
+qYpNqq>UEprr2rurVlitqu6Wrrr2ruqu6Wrn,E@fqYpNqr;Q`snG`Igq>UEpr;Q`sqYpNqqYpNq
+r;Q`snc&Rhq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`srr2ruqu6Wro)A[ir;Q`sq#:<o
+r;Q`sr;Q`sn,E@fqYpNqr;Q`sr;Q`srr2rurVlitqu6WrqYpNqq>UEprr2rurVlitqu6Wrrr2ru
+qu6WroD\djp&>!lrr2ruq>UEpq#C9mpAb-mm/MS~>
+m/IFns8N*!!<<'!s8N)rrr<&trr<&srr<&rrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&r
+rr<&irrrK'rrE*!!<2uu!;lcr!;uis!;QQr!<<'!m/I%cqYpNqr;Q`sr;Q`srr2rurVlitqu6Wr
+qYpNqq>UEprr2rurVlitqu6Wrrr2ruqu6Wrn,E@fqYpNqr;Q`snG`Igq>UEpr;Q`sqYpNqqYpNq
+r;Q`snc&Rhq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`srr2ruqu6Wro)A[ir;Q`sq#:<o
+r;Q`sr;Q`sn,E@fqYpNqr;Q`sr;Q`srr2rurVlitqu6WrqYpNqq>UEprr2rurVlitqu6Wrrr2ru
+qu6WroD\djp&>!lrr2ruq>UEpq#C9mpAb-mm/MS~>
+m/IFns8N*!!<<'!s8N)rrr<&trr<&srr<&rrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&r
+rr<&irrrK'rrE*!!<2uu!;lcr!;uis!;QQr!<<'!m/I%cqYpNqr;Q`sr;Q`srr2rurVlitqu6Wr
+qYpNqq>UEprr2rurVlitqu6Wrrr2ruqu6Wrn,E@fqYpNqr;Q`snG`Igq>UEpr;Q`sqYpNqqYpNq
+r;Q`snc&Rhq>UEpqu6WrqYpNqqu6Wrqu6Wrq#:<or;Q`sr;Q`srr2ruqu6Wro)A[ir;Q`sq#:<o
+r;Q`sr;Q`sn,E@fqYpNqr;Q`sr;Q`srr2rurVlitqu6WrqYpNqq>UEprr2rurVlitqu6Wrrr2ru
+qu6WroD\djp&>!lrr2ruq>UEpq#C9mpAb-mm/MS~>
+m/I%crr2rurr3'#s8N)rrr<&ss8E#nrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&us7lZcrrrK'
+rrE*!!<2uu!;lcr!;uis!;QTn!:0Xb!;c]q!;uis!;uis!<2uu!<)ot!;lcr!;c]q!;ZWp!<2uu
+!<)rn!<2uu!;lcr!:Tpf!;c]q!;uis!:^!g!;ZWp!;uis!;c]q!;ZZo!:Kje!;ZZj!;c]q!;lfl
+!<)rp!;lfq!;lfl!:p-i!;uis!<)rp!;lfq!:9^c!;c]q!;uis!;uis!<2uu!<)ot!;lcr!;c]q
+!;ZWp!<2uu!<)rn!<2uu!;lcr!;$3j!;?Em!;uis!;c]q!;-9k!;HNl!##;3!<3$!rr<'!!!*$!
+!<3$!s*t~>
+m/I%crr2rurr3'#s8N)rrr<&ss8E#nrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&us7lZcrrrK'
+rrE*!!<2uu!;lcr!;uis!;QTn!:0Xb!;c]q!;uis!;uis!<2uu!<)ot!;lcr!;c]q!;ZWp!<2uu
+!<)rn!<2uu!;lcr!:Tpf!;c]q!;uis!:^!g!;ZWp!;uis!;c]q!;ZZo!:Kje!;ZZj!;c]q!;lfl
+!<)rp!;lfq!;lfl!:p-i!;uis!<)rp!;lfq!:9^c!;c]q!;uis!;uis!<2uu!<)ot!;lcr!;c]q
+!;ZWp!<2uu!<)rn!<2uu!;lcr!;$3j!;?Em!;uis!;c]q!;-9k!;HNl!##;3!<3$!rr<'!!!*$!
+!<3$!s*t~>
+m/I%crr2rurr3'#s8N)rrr<&ss8E#nrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&us7lZcrrrK'
+rrE*!!<2uu!;lcr!;uis!;QTn!:0Xb!;c]q!;uis!;uis!<2uu!<)ot!;lcr!;c]q!;ZWp!<2uu
+!<)rn!<2uu!;lcr!:Tpf!;c]q!;uis!:^!g!;ZWp!;uis!;c]q!;ZZo!:Kje!;ZZj!;c]q!;lfl
+!<)rp!;lfq!;lfl!:p-i!;uis!<)rp!;lfq!:9^c!;c]q!;uis!;uis!<2uu!<)ot!;lcr!;c]q
+!;ZWp!<2uu!<)rn!<2uu!;lcr!;$3j!;?Em!;uis!;c]q!;-9k!;HNl!##;3!<3$!rr<'!!!*$!
+!<3$!s*t~>
+m/I%crr2rurr3'#s8N)rrr<&ps8N)qrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&brrrK'
+!<3'!!<2uu!;lcr!;uis!;QQr!<<'!m/I%cqYpNqr;Q`squ6]trrDus!!)or!!)lq!!)fo!W`6#
+r;Q`sp\t3nqu6Wrn,E@fqYpNqr;Q`snG`Igq>UEpr;Q`sqYpNqpAb-mnG`Igq>UEpoD\djqu6Wr
+p\t3nr;Q`sq#C?orVlitli-qbr;Q`srr2rur;Q`sq#C?omf*7eqYpNqr;Q`squ6]trrDus!!)or
+!!)lq!!)fo!W`6#r;Q`sp\t3nqu6WroD\djpAashqYpNqoD\djq#C?om/MS~>
+m/I%crr2rurr3'#s8N)rrr<&ps8N)qrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&brrrK'
+!<3'!!<2uu!;lcr!;uis!;QQr!<<'!m/I%cqYpNqr;Q`squ6]trrDus!!)or!!)lq!!)fo!W`6#
+r;Q`sp\t3nqu6Wrn,E@fqYpNqr;Q`snG`Igq>UEpr;Q`sqYpNqpAb-mnG`Igq>UEpoD\djqu6Wr
+p\t3nr;Q`sq#C?orVlitli-qbr;Q`srr2rur;Q`sq#C?omf*7eqYpNqr;Q`squ6]trrDus!!)or
+!!)lq!!)fo!W`6#r;Q`sp\t3nqu6WroD\djpAashqYpNqoD\djq#C?om/MS~>
+m/I%crr2rurr3'#s8N)rrr<&ps8N)qrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&brrrK'
+!<3'!!<2uu!;lcr!;uis!;QQr!<<'!m/I%cqYpNqr;Q`squ6]trrDus!!)or!!)lq!!)fo!W`6#
+r;Q`sp\t3nqu6Wrn,E@fqYpNqr;Q`snG`Igq>UEpr;Q`sqYpNqpAb-mnG`Igq>UEpoD\djqu6Wr
+p\t3nr;Q`sq#C?orVlitli-qbr;Q`srr2rur;Q`sq#C?omf*7eqYpNqr;Q`squ6]trrDus!!)or
+!!)lq!!)fo!W`6#r;Q`sp\t3nqu6WroD\djpAashqYpNqoD\djq#C?om/MS~>
+m/I%cqYpWts8N)rrr<&trr<&srr<&rrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&brrrK'
+!<3'!!<2uu!;lcr!;uis!;QQo!<2uu!:Bdd!;c]q!;uis!;lct!<3&srr<&rrr<&qrr<&orrN3#
+!;uis!;HKn!;lcr!:Tpf!;c]q!;uis!:^!g!;ZWp!;uis!;c]q!;c]q!;uis!:g'h!;ZWp!;$3j
+!;lcr!;HKn!;uis!;uis!;uis!<2uu!:0Xb!;uis!<2uu!;uis!;uis!;uis!:Tpf!;c]q!;uis
+!;lct!<3&srr<&rrr<&qrr<&orrN3#!;uis!;HKn!;lcr!:p-i!;lcu!<<'!qYpNqqu6WrqYpNq
+qu6Wrq#C?om/MS~>
+m/I%cqYpWts8N)rrr<&trr<&srr<&rrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&brrrK'
+!<3'!!<2uu!;lcr!;uis!;QQo!<2uu!:Bdd!;c]q!;uis!;lct!<3&srr<&rrr<&qrr<&orrN3#
+!;uis!;HKn!;lcr!:Tpf!;c]q!;uis!:^!g!;ZWp!;uis!;c]q!;c]q!;uis!:g'h!;ZWp!;$3j
+!;lcr!;HKn!;uis!;uis!;uis!<2uu!:0Xb!;uis!<2uu!;uis!;uis!;uis!:Tpf!;c]q!;uis
+!;lct!<3&srr<&rrr<&qrr<&orrN3#!;uis!;HKn!;lcr!:p-i!;lcu!<<'!qYpNqqu6WrqYpNq
+qu6Wrq#C?om/MS~>
+m/I%cqYpWts8N)rrr<&trr<&srr<&rrr<&frr<&rrr<&rrr<&crr<&prr<&srr<&urr<&brrrK'
+!<3'!!<2uu!;lcr!;uis!;QQo!<2uu!:Bdd!;c]q!;uis!;lct!<3&srr<&rrr<&qrr<&orrN3#
+!;uis!;HKn!;lcr!:Tpf!;c]q!;uis!:^!g!;ZWp!;uis!;c]q!;c]q!;uis!:g'h!;ZWp!;$3j
+!;lcr!;HKn!;uis!;uis!;uis!<2uu!:0Xb!;uis!<2uu!;uis!;uis!;uis!:Tpf!;c]q!;uis
+!;lct!<3&srr<&rrr<&qrr<&orrN3#!;uis!;HKn!;lcr!:p-i!;lcu!<<'!qYpNqqu6WrqYpNq
+qu6Wrq#C?om/MS~>
+m/I%cqYpNqrr2rurVlitr;ZcsrVlitqu6WrrVlitoD\djrVlitqYpNqm/I%crVlitrr2rur;Q`s
+rVlitrVultnc&Rhrr2rur;Q`srVlitqu6Wrq#:<orVlitmf*7eqYpNqr;Q`sqYpNqqYpNqrVlit
+q>UEpp\t3nqYpNqrVultrVlitrVultn,E@fqYpNqr;Q`snG`IgrVlitrr2rur;Q`sqYpNqqZ$Qq
+rVlitnc&Rhq#:<orVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVulto)A[ir;Q`s
+rr2rurVultr;ZcsrVlitn,E@fqYpNqr;Q`sqYpNqqYpNqrVlitq>UEpp\t3nqYpNqrVultrVlit
+rVulto)J^irVlitrr2ruqYpNqqu6WrqZ$QqrVlitqZ$Qq!<;ut')qq3rr<'!!!*$!!<3$!rr<'!
+J,~>
+m/I%cqYpNqrr2rurVlitr;ZcsrVlitqu6WrrVlitoD\djrVlitqYpNqm/I%crVlitrr2rur;Q`s
+rVlitrVultnc&Rhrr2rur;Q`srVlitqu6Wrq#:<orVlitmf*7eqYpNqr;Q`sqYpNqqYpNqrVlit
+q>UEpp\t3nqYpNqrVultrVlitrVultn,E@fqYpNqr;Q`snG`IgrVlitrr2rur;Q`sqYpNqqZ$Qq
+rVlitnc&Rhq#:<orVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVulto)A[ir;Q`s
+rr2rurVultr;ZcsrVlitn,E@fqYpNqr;Q`sqYpNqqYpNqrVlitq>UEpp\t3nqYpNqrVultrVlit
+rVulto)J^irVlitrr2ruqYpNqqu6WrqZ$QqrVlitqZ$Qq!<;ut')qq3rr<'!!!*$!!<3$!rr<'!
+J,~>
+m/I%cqYpNqrr2rurVlitr;ZcsrVlitqu6WrrVlitoD\djrVlitqYpNqm/I%crVlitrr2rur;Q`s
+rVlitrVultnc&Rhrr2rur;Q`srVlitqu6Wrq#:<orVlitmf*7eqYpNqr;Q`sqYpNqqYpNqrVlit
+q>UEpp\t3nqYpNqrVultrVlitrVultn,E@fqYpNqr;Q`snG`IgrVlitrr2rur;Q`sqYpNqqZ$Qq
+rVlitnc&Rhq#:<orVultqYpNqqYpNqrVultrr2rurVultr;ZcsrVlitrVlitrVulto)A[ir;Q`s
+rr2rurVultr;ZcsrVlitn,E@fqYpNqr;Q`sqYpNqqYpNqrVlitq>UEpp\t3nqYpNqrVultrVlit
+rVulto)J^irVlitrr2ruqYpNqqu6WrqZ$QqrVlitqZ$Qq!<;ut')qq3rr<'!!!*$!!<3$!rr<'!
+J,~>
+mJm+brr;osrr;osqu6Zss8;rns8;rfs8;rps7u`as8;rss8E#ts8E#ss8;rdrr<&urr<&rs8;rq
+s7u`os8N)us8;rhs7u`ps8E#ts8E#qrr<&ps8;rps7u`lrr<&ps8;ros8;p!rr<&js7u`ps8E#t
+s8E#fs8;rss8E#ts8E#ts7u`orrE-"r;cEgq>gEmr;c`pq>gHnr;c`pr;ZitrW)rt!<E/u!;lfp
+!:g*g!<3#t!<3#s!!*&u!<3!!!<;utnc/Fcrr;rtrr;rtqu6Wrq>^Bnqu?KmqYpNqq>^BnqZ$Ko
+!ri6#nc/Ofrr;osrr;osrr;lrr;Qcts8;rns8N'#rr<&cs*t~>
+mJm+brr;osrr;osqu6Zss8;rns8;rfs8;rps7u`as8;rss8E#ts8E#ss8;rdrr<&urr<&rs8;rq
+s7u`os8N)us8;rhs7u`ps8E#ts8E#qrr<&ps8;rps7u`lrr<&ps8;ros8;p!rr<&js7u`ps8E#t
+s8E#fs8;rss8E#ts8E#ts7u`orrE-"r;cEgq>gEmr;c`pq>gHnr;c`pr;ZitrW)rt!<E/u!;lfp
+!:g*g!<3#t!<3#s!!*&u!<3!!!<;utnc/Fcrr;rtrr;rtqu6Wrq>^Bnqu?KmqYpNqq>^BnqZ$Ko
+!ri6#nc/Ofrr;osrr;osrr;lrr;Qcts8;rns8N'#rr<&cs*t~>
+mJm+brr;osrr;osqu6Zss8;rns8;rfs8;rps7u`as8;rss8E#ts8E#ss8;rdrr<&urr<&rs8;rq
+s7u`os8N)us8;rhs7u`ps8E#ts8E#qrr<&ps8;rps7u`lrr<&ps8;ros8;p!rr<&js7u`ps8E#t
+s8E#fs8;rss8E#ts8E#ts7u`orrE-"r;cEgq>gEmr;c`pq>gHnr;c`pr;ZitrW)rt!<E/u!;lfp
+!:g*g!<3#t!<3#s!!*&u!<3!!!<;utnc/Fcrr;rtrr;rtqu6Wrq>^Bnqu?KmqYpNqq>^BnqZ$Ko
+!ri6#nc/Ofrr;osrr;osrr;lrr;Qcts8;rns8N'#rr<&cs*t~>
+JcC<$JcC<$JcF[.rrE*!rrDEcJ,~>
+JcC<$JcC<$JcF[.rrE*!rrDEcJ,~>
+JcC<$JcC<$JcF[.rrE*!rrDEcJ,~>
+JcC<$JcC<$JcF[.rrE*!r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcF[.rrE*!r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcF[.rrE*!r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcF^/rrE&urrDEcJ,~>
+JcC<$JcC<$JcF^/rrE&urrDEcJ,~>
+JcC<$JcC<$JcF^/rrE&urrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+bQ%SBX8i2"iW&iVqu?ZrX8i2"`rH&=h#I<QJcC<$f)PaMm/MS~>
+bQ%SBX8i2"iW&iVqu?ZrX8i2"`rH&=h#I<QJcC<$f)PaMm/MS~>
+bQ%SBX8i2"iW&iVqu?ZrX8i2"`rH&=h#I<QJcC<$f)PaMm/MS~>
+b5VGAo`"mkbPqPBq#:<oq>UEpm/R"ap\t3nqYpNqhu<ZVn,N4aq>UEpn,E@flMghah>[HTg&D$P
+g&M!Nm/I%cfDbgNiVrlXJcFg2rrDEcJ,~>
+b5VGAo`"mkbPqPBq#:<oq>UEpm/R"ap\t3nqYpNqhu<ZVn,N4aq>UEpn,E@flMghah>[HTg&D$P
+g&M!Nm/I%cfDbgNiVrlXJcFg2rrDEcJ,~>
+b5VGAo`"mkbPqPBq#:<oq>UEpm/R"ap\t3nqYpNqhu<ZVn,N4aq>UEpn,E@flMghah>[HTg&D$P
+g&M!Nm/I%cfDbgNiVrlXJcFg2rrDEcJ,~>
+b5VGAo`"mkbPqPBq#:<oq>UEpl2L_`p\t3nqYpNqhu<ZVmf*7er;Q`sqYpNqn,E@flMghah>[HT
+g&D$Pf)G^Mm/I%cfDbgNiVrlXJcFg2r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+b5VGAo`"mkbPqPBq#:<oq>UEpl2L_`p\t3nqYpNqhu<ZVmf*7er;Q`sqYpNqn,E@flMghah>[HT
+g&D$Pf)G^Mm/I%cfDbgNiVrlXJcFg2r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+b5VGAo`"mkbPqPBq#:<oq>UEpl2L_`p\t3nqYpNqhu<ZVmf*7er;Q`sqYpNqn,E@flMghah>[HT
+g&D$Pf)G^Mm/I%cfDbgNiVrlXJcFg2r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+b5VGAZi:"*q>UEplMgncrrDio!!)lq!!(pV!!)He!!)rs!!)3^!!)<a!!(jT!!(^P!!(XN!W`6#
+_Z'T9iVrlXJcFg2rrDEcJ,~>
+b5VGAZi:"*q>UEplMgncrrDio!!)lq!!(pV!!)He!!)rs!!)3^!!)<a!!(jT!!(^P!!(XN!W`6#
+_Z'T9iVrlXJcFg2rrDEcJ,~>
+b5VGAZi:"*q>UEplMgncrrDio!!)lq!!(pV!!)He!!)rs!!)3^!!)<a!!(jT!!(^P!!(XN!W`6#
+_Z'T9iVrlXJcFg2rrDEcJ,~>
+m/R%brr;rtrVufrr;Z`r!<<#ur;Qfus8W#tr;Z`rqu?Zr!<;utqu?Tp!ri6#o`+mjrr;rtrVuis
+qZ$BlrVllus8;rdrrN3#!;QQo!;c]r!<;utqu?Tpr;Z`r!<<#ur;ZTno)A[ir;Q`sr;Z`rq>^Bn
+!WN/urrE-"r;cBfq>gHnr;c<dr;Zlu!;ulq!;ulr!<3#t!<)rr!;QQo!;ZZn!;uls!!*&t!:Tph
+!<3&ss8E#us8E#rs8E#os8;rrs8N''rr<'!rr<&is7u`ns8;ros8;ourrE#tq>gHnr;Zlu!.k1A
+s8N)cs*t~>
+m/R%brr;rtrVufrr;Z`r!<<#ur;Qfus8W#tr;Z`rqu?Zr!<;utqu?Tp!ri6#o`+mjrr;rtrVuis
+qZ$BlrVllus8;rdrrN3#!;QQo!;c]r!<;utqu?Tpr;Z`r!<<#ur;ZTno)A[ir;Q`sr;Z`rq>^Bn
+!WN/urrE-"r;cBfq>gHnr;c<dr;Zlu!;ulq!;ulr!<3#t!<)rr!;QQo!;ZZn!;uls!!*&t!:Tph
+!<3&ss8E#us8E#rs8E#os8;rrs8N''rr<'!rr<&is7u`ns8;ros8;ourrE#tq>gHnr;Zlu!.k1A
+s8N)cs*t~>
+m/R%brr;rtrVufrr;Z`r!<<#ur;Qfus8W#tr;Z`rqu?Zr!<;utqu?Tp!ri6#o`+mjrr;rtrVuis
+qZ$BlrVllus8;rdrrN3#!;QQo!;c]r!<;utqu?Tpr;Z`r!<<#ur;ZTno)A[ir;Q`sr;Z`rq>^Bn
+!WN/urrE-"r;cBfq>gHnr;c<dr;Zlu!;ulq!;ulr!<3#t!<)rr!;QQo!;ZZn!;uls!!*&t!:Tph
+!<3&ss8E#us8E#rs8E#os8;rrs8N''rr<'!rr<&is7u`ns8;ros8;ourrE#tq>gHnr;Zlu!.k1A
+s8N)cs*t~>
+li-qbr;Q`srVlitrVlitqu?Zrrr2rurVlitrr2ruq#:<oqZ$QqrVlitrVlitrVulto)A[ir;Q`s
+qYpNqq#:<oq>^HprVlitnc&Rhrr2ruq>UEpqZ$QqrVlitrVlitrVlitqu?Zrrr2ruqu6Wrmf*7e
+rVlitq>UEpqYpNqrVultrVultrVlitnG`Igq>UEprVlitnc&RhrVultrVlitrVlitr;Q`sr;Q`s
+rVlitrVlitq>UEpqYpNqrVlitr;ZcsrVlitnc&Rhrr2rur;Q`srVlitq>UEpqYpNqrVlitrVult
+s8W*!s8N'!nc&Rhq>UEprVlitr;Q`srVultqu6Wrq>UEprVultJcG?Ar;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+li-qbr;Q`srVlitrVlitqu?Zrrr2rurVlitrr2ruq#:<oqZ$QqrVlitrVlitrVulto)A[ir;Q`s
+qYpNqq#:<oq>^HprVlitnc&Rhrr2ruq>UEpqZ$QqrVlitrVlitrVlitqu?Zrrr2ruqu6Wrmf*7e
+rVlitq>UEpqYpNqrVultrVultrVlitnG`Igq>UEprVlitnc&RhrVultrVlitrVlitr;Q`sr;Q`s
+rVlitrVlitq>UEpqYpNqrVlitr;ZcsrVlitnc&Rhrr2rur;Q`srVlitq>UEpqYpNqrVlitrVult
+s8W*!s8N'!nc&Rhq>UEprVlitr;Q`srVultqu6Wrq>UEprVultJcG?Ar;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+li-qbr;Q`srVlitrVlitqu?Zrrr2rurVlitrr2ruq#:<oqZ$QqrVlitrVlitrVulto)A[ir;Q`s
+qYpNqq#:<oq>^HprVlitnc&Rhrr2ruq>UEpqZ$QqrVlitrVlitrVlitqu?Zrrr2ruqu6Wrmf*7e
+rVlitq>UEpqYpNqrVultrVultrVlitnG`Igq>UEprVlitnc&RhrVultrVlitrVlitr;Q`sr;Q`s
+rVlitrVlitq>UEpqYpNqrVlitr;ZcsrVlitnc&Rhrr2rur;Q`srVlitq>UEpqYpNqrVlitrVult
+s8W*!s8N'!nc&Rhq>UEprVlitr;Q`srVultqu6Wrq>UEprVultJcG?Ar;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+li..hs8N*!rrE&u!!)or!!)rs!!)fo!s&B$!;HKn!;c]q!;uis!<2uu!;lcr!:p-o!<<'!s8N)q
+rr<&orr<&prr<&srr<&hrr<&urr<&prr<&qrr<&rrrW9$rrDrr!!)rs!!)`m!!)HequHNl!!)or
+!!)or!!)ut!!)rs!!)Ng!!)lq!!)or!!)Wj!!)or!!*#u!!)or!!)rs!!*#u!!)ut!!)or!!)lq
+!!)or!!)or!!)ut!!)or!!)Ti!!*#u!!)or!s&B$!;QQo!;lcr!;lcr!<2uu!<2uu!<2uu!:g'h
+!;c]q!;lcr!<)ot!;uis!;lcr!;ZWp!;uis!.k1As8N)cs*t~>
+li..hs8N*!rrE&u!!)or!!)rs!!)fo!s&B$!;HKn!;c]q!;uis!<2uu!;lcr!:p-o!<<'!s8N)q
+rr<&orr<&prr<&srr<&hrr<&urr<&prr<&qrr<&rrrW9$rrDrr!!)rs!!)`m!!)HequHNl!!)or
+!!)or!!)ut!!)rs!!)Ng!!)lq!!)or!!)Wj!!)or!!*#u!!)or!!)rs!!*#u!!)ut!!)or!!)lq
+!!)or!!)or!!)ut!!)or!!)Ti!!*#u!!)or!s&B$!;QQo!;lcr!;lcr!<2uu!<2uu!<2uu!:g'h
+!;c]q!;lcr!<)ot!;uis!;lcr!;ZWp!;uis!.k1As8N)cs*t~>
+li..hs8N*!rrE&u!!)or!!)rs!!)fo!s&B$!;HKn!;c]q!;uis!<2uu!;lcr!:p-o!<<'!s8N)q
+rr<&orr<&prr<&srr<&hrr<&urr<&prr<&qrr<&rrrW9$rrDrr!!)rs!!)`m!!)HequHNl!!)or
+!!)or!!)ut!!)rs!!)Ng!!)lq!!)or!!)Wj!!)or!!*#u!!)or!!)rs!!*#u!!)ut!!)or!!)lq
+!!)or!!)or!!)ut!!)or!!)Ti!!*#u!!)or!s&B$!;QQo!;lcr!;lcr!<2uu!<2uu!<2uu!:g'h
+!;c]q!;lcr!<)ot!;uis!;lcr!;ZWp!;uis!.k1As8N)cs*t~>
+li..hs8N*!rrE&u!!)or!!)rs!!)forW)Zl!!)lq!!)rs!!*#u!!)or!!)Ti"p"]'!<<'!qYpNq
+q#:<oq>UEpr;Q`so)A[ir;Q`sqYpNqqYpNqqu6]ts8Vlpr;Q`spAY*mmf*7erVlitq>UEpqu6Wr
+pAY*mr;Q`snG`IgqYpNqqu6WroD\djqu6Wrrr;cor;Q`srr2rurVuZnqYpNqqu6Wrqu6WrrVlit
+qu6WroD\djr;Q`squ?Zrp\t3nqu6Wrqu6Wrrr2rurr2rurr2runc&RhqZ$?kr;Z`rq#:<oq#C<n
+JcG6>rrDEcJ,~>
+li..hs8N*!rrE&u!!)or!!)rs!!)forW)Zl!!)lq!!)rs!!*#u!!)or!!)Ti"p"]'!<<'!qYpNq
+q#:<oq>UEpr;Q`so)A[ir;Q`sqYpNqqYpNqqu6]ts8Vlpr;Q`spAY*mmf*7erVlitq>UEpqu6Wr
+pAY*mr;Q`snG`IgqYpNqqu6WroD\djqu6Wrrr;cor;Q`srr2rurVuZnqYpNqqu6Wrqu6WrrVlit
+qu6WroD\djr;Q`squ?Zrp\t3nqu6Wrqu6Wrrr2rurr2rurr2runc&RhqZ$?kr;Z`rq#:<oq#C<n
+JcG6>rrDEcJ,~>
+li..hs8N*!rrE&u!!)or!!)rs!!)forW)Zl!!)lq!!)rs!!*#u!!)or!!)Ti"p"]'!<<'!qYpNq
+q#:<oq>UEpr;Q`so)A[ir;Q`sqYpNqqYpNqqu6]ts8Vlpr;Q`spAY*mmf*7erVlitq>UEpqu6Wr
+pAY*mr;Q`snG`IgqYpNqqu6WroD\djqu6Wrrr;cor;Q`srr2rurVuZnqYpNqqu6Wrqu6WrrVlit
+qu6WroD\djr;Q`squ?Zrp\t3nqu6Wrqu6Wrrr2rurr2rurr2runc&RhqZ$?kr;Z`rq#:<oq#C<n
+JcG6>rrDEcJ,~>
+li..hrrE'!rrE&u!!)or!!)rs!!)fo!s&B$!;HKn!;c]q!;uis!<2uu!;lcr!:p-o!<3'!!<3&q
+rr<&orr<&prr<&srr<&is7u`lrr<&qrr<&rrrW9$rrD`l!!)`m!!)He!!)ut!!)ip!!)or!!)`m
+!!)rs!!)Ng!!)lq!!)or!!)Wj!!)or!!*#u!!)Zk!W`6#r;Q`soD\djqu6Wrqu6WrrVlitqu6Wr
+oDeXequ?Zrp\t3nqu6Wrqu6Wrrr2rurr2rurr2runc&RhqYpNqo)J^iqYpNqp&G$lJcG<@r;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li..hrrE'!rrE&u!!)or!!)rs!!)fo!s&B$!;HKn!;c]q!;uis!<2uu!;lcr!:p-o!<3'!!<3&q
+rr<&orr<&prr<&srr<&is7u`lrr<&qrr<&rrrW9$rrD`l!!)`m!!)He!!)ut!!)ip!!)or!!)`m
+!!)rs!!)Ng!!)lq!!)or!!)Wj!!)or!!*#u!!)Zk!W`6#r;Q`soD\djqu6Wrqu6WrrVlitqu6Wr
+oDeXequ?Zrp\t3nqu6Wrqu6Wrrr2rurr2rurr2runc&RhqYpNqo)J^iqYpNqp&G$lJcG<@r;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li..hrrE'!rrE&u!!)or!!)rs!!)fo!s&B$!;HKn!;c]q!;uis!<2uu!;lcr!:p-o!<3'!!<3&q
+rr<&orr<&prr<&srr<&is7u`lrr<&qrr<&rrrW9$rrD`l!!)`m!!)He!!)ut!!)ip!!)or!!)`m
+!!)rs!!)Ng!!)lq!!)or!!)Wj!!)or!!*#u!!)Zk!W`6#r;Q`soD\djqu6Wrqu6WrrVlitqu6Wr
+oDeXequ?Zrp\t3nqu6Wrqu6Wrrr2rurr2rurr2runc&RhqYpNqo)J^iqYpNqp&G$lJcG<@r;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li..hrrE'!rrE&u!!)or!!)rs!!)fo!!*#u!!)fo!!)lq!!)rs!!*#u!!)or!!)Ti"p"Z'rrE'!
+qYpNqq#:<oq>UEpr;Q`soD\djqYpNqqu6WrqYpNqqu6`us8N)lrr<&mrr<&err<&srr<&qrr<&r
+rr<&mrr<&srr<&grr<&qrr<&rrr<&jrr<&rrr<&urr<&krrN3#!;uis!;$3j!;lcr!;lcr!<)ot
+!;lcr!;-9k!;c]q!<)p"!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2runc&RhqYpNqpAY*mr;Q`s
+qu6Wrq>UEpr;Q`sJcG?ArrDEcJ,~>
+li..hrrE'!rrE&u!!)or!!)rs!!)fo!!*#u!!)fo!!)lq!!)rs!!*#u!!)or!!)Ti"p"Z'rrE'!
+qYpNqq#:<oq>UEpr;Q`soD\djqYpNqqu6WrqYpNqqu6`us8N)lrr<&mrr<&err<&srr<&qrr<&r
+rr<&mrr<&srr<&grr<&qrr<&rrr<&jrr<&rrr<&urr<&krrN3#!;uis!;$3j!;lcr!;lcr!<)ot
+!;lcr!;-9k!;c]q!<)p"!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2runc&RhqYpNqpAY*mr;Q`s
+qu6Wrq>UEpr;Q`sJcG?ArrDEcJ,~>
+li..hrrE'!rrE&u!!)or!!)rs!!)fo!!*#u!!)fo!!)lq!!)rs!!*#u!!)or!!)Ti"p"Z'rrE'!
+qYpNqq#:<oq>UEpr;Q`soD\djqYpNqqu6WrqYpNqqu6`us8N)lrr<&mrr<&err<&srr<&qrr<&r
+rr<&mrr<&srr<&grr<&qrr<&rrr<&jrr<&rrr<&urr<&krrN3#!;uis!;$3j!;lcr!;lcr!<)ot
+!;lcr!;-9k!;c]q!<)p"!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2runc&RhqYpNqpAY*mr;Q`s
+qu6Wrq>UEpr;Q`sJcG?ArrDEcJ,~>
+lMgharr2rur;Q`srVlitqu6Wrq#:<orVlitq>UEpqYpNqr;Q`srVlitrVultnc&Rhrr2ruq>UEp
+q#:<orVlitrr2rur;Q`soD\djqYpNqqu6WrqZ$QqrVlitrVlitrVultr;Q`spAY*mrVlitoD\dj
+r;Q`sqYpNqqYpNqrVultrVlitr;Q`snG`IgrVlitrr2rurVlitnc&RhrVultrVlitrVultqYpNq
+qYpNqrVultqYpNqqYpNqrVlitr;ZcsrVlitoD\djqYpNqrr2rurVlitq>UEpqYpNqrVlitrVlit
+rr2rurr2runc&RhrVlitrr2rurVultrVultrVlitqu6WrrVlitrr;uurVlitqu?ZrJcGWIrrDEc
+J,~>
+lMgharr2rur;Q`srVlitqu6Wrq#:<orVlitq>UEpqYpNqr;Q`srVlitrVultnc&Rhrr2ruq>UEp
+q#:<orVlitrr2rur;Q`soD\djqYpNqqu6WrqZ$QqrVlitrVlitrVultr;Q`spAY*mrVlitoD\dj
+r;Q`sqYpNqqYpNqrVultrVlitr;Q`snG`IgrVlitrr2rurVlitnc&RhrVultrVlitrVultqYpNq
+qYpNqrVultqYpNqqYpNqrVlitr;ZcsrVlitoD\djqYpNqrr2rurVlitq>UEpqYpNqrVlitrVlit
+rr2rurr2runc&RhrVlitrr2rurVultrVultrVlitqu6WrrVlitrr;uurVlitqu?ZrJcGWIrrDEc
+J,~>
+lMgharr2rur;Q`srVlitqu6Wrq#:<orVlitq>UEpqYpNqr;Q`srVlitrVultnc&Rhrr2ruq>UEp
+q#:<orVlitrr2rur;Q`soD\djqYpNqqu6WrqZ$QqrVlitrVlitrVultr;Q`spAY*mrVlitoD\dj
+r;Q`sqYpNqqYpNqrVultrVlitr;Q`snG`IgrVlitrr2rurVlitnc&RhrVultrVlitrVultqYpNq
+qYpNqrVultqYpNqqYpNqrVlitr;ZcsrVlitoD\djqYpNqrr2rurVlitq>UEpqYpNqrVlitrVlit
+rr2rurr2runc&RhrVlitrr2rurVultrVultrVlitqu6WrrVlitrr;uurVlitqu?ZrJcGWIrrDEc
+J,~>
+lMgharr2ruqu?Tpr;ZTnrVultrr;osrr;fprr;rtrr;rtrVufr!WN/irr<&urr<&ss7u`ls8;rs
+s8E#ts8E#ks8;rss8;rts7u`ps8N'!s8;rps8;rqs7u`ks8;rhs8;rrs8N*!s7u`ns8;rqs8E#t
+s8E#fs8;rqs8;rds8;p!rr<&ts8;rmrr<&ps8;rps7u`ns8;rprrE-"r;cHhr;cisr;ZitrW)uu
+rW)osq>gHnr;cfrrW)uurrE*!rrDThr;ccqr;c`p!<E/u!;ZZn!<)ou!<;utqZ$QqJcGWIr;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+lMgharr2ruqu?Tpr;ZTnrVultrr;osrr;fprr;rtrr;rtrVufr!WN/irr<&urr<&ss7u`ls8;rs
+s8E#ts8E#ks8;rss8;rts7u`ps8N'!s8;rps8;rqs7u`ks8;rhs8;rrs8N*!s7u`ns8;rqs8E#t
+s8E#fs8;rqs8;rds8;p!rr<&ts8;rmrr<&ps8;rps7u`ns8;rprrE-"r;cHhr;cisr;ZitrW)uu
+rW)osq>gHnr;cfrrW)uurrE*!rrDThr;ccqr;c`p!<E/u!;ZZn!<)ou!<;utqZ$QqJcGWIr;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+lMgharr2ruqu?Tpr;ZTnrVultrr;osrr;fprr;rtrr;rtrVufr!WN/irr<&urr<&ss7u`ls8;rs
+s8E#ts8E#ks8;rss8;rts7u`ps8N'!s8;rps8;rqs7u`ks8;rhs8;rrs8N*!s7u`ns8;rqs8E#t
+s8E#fs8;rqs8;rds8;p!rr<&ts8;rmrr<&ps8;rps7u`ns8;rprrE-"r;cHhr;cisr;ZitrW)uu
+rW)osq>gHnr;cfrrW)uurrE*!rrDThr;ccqr;c`p!<E/u!;ZZn!<)ou!<;utqZ$QqJcGWIr;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+U]1;oJcC<$eGfLKJcC<$l2Ub`m/MS~>
+U]1;oJcC<$eGfLKJcC<$l2Ub`m/MS~>
+U]1;oJcC<$eGfLKJcC<$l2Ub`m/MS~>
+U]1;oJcC<$eGfLKJcC<$l2Ub`m/MS~>
+U]1;oJcC<$eGfLKJcC<$l2Ub`m/MS~>
+U]1;oJcC<$eGfLKJcC<$l2Ub`m/MS~>
+V#LDpJcC<$e,KCJJcC<$l2U\^')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+V#LDpJcC<$e,KCJJcC<$l2U\^')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+V#LDpJcC<$e,KCJJcC<$l2U\^')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+WW2krJcC<$e,T@HJcC<$li6tbm/MS~>
+WW2krJcC<$e,T@HJcC<$li6tbm/MS~>
+WW2krJcC<$e,T@HJcC<$li6tbm/MS~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+_#OE7JcGQGrr@WMJcG$8r;_EKr;aq=rrDEcJ,~>
+_#OE7JcGQGrr@WMJcG$8r;_EKr;aq=rrDEcJ,~>
+_#OE7JcGQGrr@WMJcG$8r;_EKr;aq=rrDEcJ,~>
+m/R%bs8W#th>[HTJcGNF!!)3^r;c3a!!%TMoD\djq#:<o[/U++p\t3nq#:<of)G^MiVrlXi;WcW
+aT)2=')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+m/R%bs8W#th>[HTJcGNF!!)3^r;c3a!!%TMoD\djq#:<o[/U++p\t3nq#:<of)G^MiVrlXi;WcW
+aT)2=')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+m/R%bs8W#th>[HTJcGNF!!)3^r;c3a!!%TMoD\djq#:<o[/U++p\t3nq#:<of)G^MiVrlXi;WcW
+aT)2=')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+li6tbrVlith#@?SJcGNF!!)*[!!)Bc!!%TMoD\djq#:<o[/U++p\t3nq#:<of)G^MiVrlXi;WcW
+aT)8?m/MS~>
+li6tbrVlith#@?SJcGNF!!)*[!!)Bc!!%TMoD\djq#:<o[/U++p\t3nq#:<of)G^MiVrlXi;WcW
+aT)8?m/MS~>
+li6tbrVlith#@?SJcGNF!!)*[!!)Bc!!%TMoD\djq#:<o[/U++p\t3nq#:<of)G^MiVrlXi;WcW
+aT)8?m/MS~>
+li."drrE&u!!(gS!!%TMq#:<ojo5A^rr@WMeGfLK[/U++mJd.df)G^MiVrlXi;WcWaT)8?m/MS~>
+li."drrE&u!!(gS!!%TMq#:<ojo5A^rr@WMeGfLK[/U++mJd.df)G^MiVrlXi;WcWaT)8?m/MS~>
+li."drrE&u!!(gS!!%TMq#:<ojo5A^rr@WMeGfLK[/U++mJd.df)G^MiVrlXi;WcWaT)8?m/MS~>
+li."drrE&u!!)rsr;ccqrW)rtrW)osr;c`p!<E/u!:p0h!<3#t!<)rr!;c`o!!3*"oDedi!<<#u
+qu?TprVult#6+Z's8N'!r;Z]qr;Z`rrr;rtrVufrqZ$Ko!WN/]rrN3#!;ulr!<<)u!;ulr!;ZZn
+!<)rt!!`H'!<<'!!;$6j!!*&t!;lfp!;ulr!<3#t!;-<k!<)rt!;ulq!!3*"r;Z]qqZ$Ko!WN/i
+s8E#ps7u`ns8;ourrDThr;ccqrW)rtrW)uurr<'!r;c9c!!)iprW)fpq>gHnr;ccqrVururW)iq
+r;c`pq>gHnr;c?eq>gHnr;c]or;cWm!!)ipr;Zlu!7q2K!##;3!<3$!rr<'!!!*$!!<3$!s*t~>
+li."drrE&u!!)rsr;ccqrW)rtrW)osr;c`p!<E/u!:p0h!<3#t!<)rr!;c`o!!3*"oDedi!<<#u
+qu?TprVult#6+Z's8N'!r;Z]qr;Z`rrr;rtrVufrqZ$Ko!WN/]rrN3#!;ulr!<<)u!;ulr!;ZZn
+!<)rt!!`H'!<<'!!;$6j!!*&t!;lfp!;ulr!<3#t!;-<k!<)rt!;ulq!!3*"r;Z]qqZ$Ko!WN/i
+s8E#ps7u`ns8;ourrDThr;ccqrW)rtrW)uurr<'!r;c9c!!)iprW)fpq>gHnr;ccqrVururW)iq
+r;c`pq>gHnr;c?eq>gHnr;c]or;cWm!!)ipr;Zlu!7q2K!##;3!<3$!rr<'!!!*$!!<3$!s*t~>
+li."drrE&u!!)rsr;ccqrW)rtrW)osr;c`p!<E/u!:p0h!<3#t!<)rr!;c`o!!3*"oDedi!<<#u
+qu?TprVult#6+Z's8N'!r;Z]qr;Z`rrr;rtrVufrqZ$Ko!WN/]rrN3#!;ulr!<<)u!;ulr!;ZZn
+!<)rt!!`H'!<<'!!;$6j!!*&t!;lfp!;ulr!<3#t!;-<k!<)rt!;ulq!!3*"r;Z]qqZ$Ko!WN/i
+s8E#ps7u`ns8;ourrDThr;ccqrW)rtrW)uurr<'!r;c9c!!)iprW)fpq>gHnr;ccqrVururW)iq
+r;c`pq>gHnr;c?eq>gHnr;c]or;cWm!!)ipr;Zlu!7q2K!##;3!<3$!rr<'!!!*$!!<3$!s*t~>
+li..hs8N*!rrE#t!!)ut!!)rs!!)rs!!)ut!!)ut!!)rsrrE#t!!)Ti!!)rs!!)ut!!)ut!!)rs
+!!)utrrDThrrE&u!!)ut!!)ut!!)utrrE*!rrE*!!!*#u!!)ut!!)rs!!)rs!!)ut!!)ut!!)rs
+!!)utrrD3]!!*#u!!)rs!!)ut!!)ip!!)lq!!)ut!!)utrrE*!rrE*!!!)WjrrE#t!!)ut!!)ut
+!!)rs!!)rs!!)Ti!!)rs!!)ut!!)utrrE#t!!)ut!!)rs!!)utrrDNf!!)fo!!)ip!!)utrrDWi
+!!)ut!!)rs!!)rs!!)utrrE#t!!)Kf!!)cn!!)fo!!)ip!!)ut!!)orrrE&u!!)ut!!)ut!!)lq
+!!)ip!!)ut!!)Kf!!)ip!!)ut!!)rs!!)ut!!)ip!!)lq!!)utrrCXMrrDEcJ,~>
+li..hs8N*!rrE#t!!)ut!!)rs!!)rs!!)ut!!)ut!!)rsrrE#t!!)Ti!!)rs!!)ut!!)ut!!)rs
+!!)utrrDThrrE&u!!)ut!!)ut!!)utrrE*!rrE*!!!*#u!!)ut!!)rs!!)rs!!)ut!!)ut!!)rs
+!!)utrrD3]!!*#u!!)rs!!)ut!!)ip!!)lq!!)ut!!)utrrE*!rrE*!!!)WjrrE#t!!)ut!!)ut
+!!)rs!!)rs!!)Ti!!)rs!!)ut!!)utrrE#t!!)ut!!)rs!!)utrrDNf!!)fo!!)ip!!)utrrDWi
+!!)ut!!)rs!!)rs!!)utrrE#t!!)Kf!!)cn!!)fo!!)ip!!)ut!!)orrrE&u!!)ut!!)ut!!)lq
+!!)ip!!)ut!!)Kf!!)ip!!)ut!!)rs!!)ut!!)ip!!)lq!!)utrrCXMrrDEcJ,~>
+li..hs8N*!rrE#t!!)ut!!)rs!!)rs!!)ut!!)ut!!)rsrrE#t!!)Ti!!)rs!!)ut!!)ut!!)rs
+!!)utrrDThrrE&u!!)ut!!)ut!!)utrrE*!rrE*!!!*#u!!)ut!!)rs!!)rs!!)ut!!)ut!!)rs
+!!)utrrD3]!!*#u!!)rs!!)ut!!)ip!!)lq!!)ut!!)utrrE*!rrE*!!!)WjrrE#t!!)ut!!)ut
+!!)rs!!)rs!!)Ti!!)rs!!)ut!!)utrrE#t!!)ut!!)rs!!)utrrDNf!!)fo!!)ip!!)utrrDWi
+!!)ut!!)rs!!)rs!!)utrrE#t!!)Kf!!)cn!!)fo!!)ip!!)ut!!)orrrE&u!!)ut!!)ut!!)lq
+!!)ip!!)ut!!)Kf!!)ip!!)ut!!)rs!!)ut!!)ip!!)lq!!)utrrCXMrrDEcJ,~>
+li..hs8N*!rrE&u!!)or!!)ut"p"]'!<<'!rr2ruqu6WrrVlitqu6WroD]!ps8N*!rrDio!!)rs
+!!)rs!!)Qh!!)ip!!)or!!*#u!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)ot!;lcr!<2uu!;lcr
+!9X:]!<2uu!;lcu!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2ruoD\djr;Q`srr2ruqu6WrrVm'%
+s8N*!rrDWi!!)rs!!)ut!!)rs!!*#u!!)or!!)ut!!)rs!!)Kf!!)fo!!)ip!!)rs!!)Wj!!)or
+!!)ut"p"]'!<<'!rVlitr;Q`sn,E@fp\t3nq#:<oqYpNqqu6Wrr;Q`soD\djqYpNqqYpNqqu6Wr
+nG`IgqYpNqqu6Wrrr2ruqu6WrqYpNqqYpNqr;Q`sf)PaMm/MS~>
+li..hs8N*!rrE&u!!)or!!)ut"p"]'!<<'!rr2ruqu6WrrVlitqu6WroD]!ps8N*!rrDio!!)rs
+!!)rs!!)Qh!!)ip!!)or!!*#u!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)ot!;lcr!<2uu!;lcr
+!9X:]!<2uu!;lcu!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2ruoD\djr;Q`srr2ruqu6WrrVm'%
+s8N*!rrDWi!!)rs!!)ut!!)rs!!*#u!!)or!!)ut!!)rs!!)Kf!!)fo!!)ip!!)rs!!)Wj!!)or
+!!)ut"p"]'!<<'!rVlitr;Q`sn,E@fp\t3nq#:<oqYpNqqu6Wrr;Q`soD\djqYpNqqYpNqqu6Wr
+nG`IgqYpNqqu6Wrrr2ruqu6WrqYpNqqYpNqr;Q`sf)PaMm/MS~>
+li..hs8N*!rrE&u!!)or!!)ut"p"]'!<<'!rr2ruqu6WrrVlitqu6WroD]!ps8N*!rrDio!!)rs
+!!)rs!!)Qh!!)ip!!)or!!*#u!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)ot!;lcr!<2uu!;lcr
+!9X:]!<2uu!;lcu!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2ruoD\djr;Q`srr2ruqu6WrrVm'%
+s8N*!rrDWi!!)rs!!)ut!!)rs!!*#u!!)or!!)ut!!)rs!!)Kf!!)fo!!)ip!!)rs!!)Wj!!)or
+!!)ut"p"]'!<<'!rVlitr;Q`sn,E@fp\t3nq#:<oqYpNqqu6Wrr;Q`soD\djqYpNqqYpNqqu6Wr
+nG`IgqYpNqqu6Wrrr2ruqu6WrqYpNqqYpNqr;Q`sf)PaMm/MS~>
+li-qbrr3$"rrE&u!!)or!!)ut"p"]'!<<'!rr;corVlitqu6WroD]!ps8N*!rrE#tqZ-NnrW)Bd
+!!)ipq#LEo!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)rn!<2uu!;lcr!9a@^!;uis!;lfr!;HKn
+!;lcr!;lcr!<2uu!<2uu!<2uu!;$3j!;uis!<2uu!;lcr!<)p%!<<'!s8N)irr<&srr<&ss8E#q
+s7lZms8E#brr<&orr<&os8E#frr<&rrr<&trrrK'rrE*!!<)ot!;uis!:Tpf!;HKn!;QQo!;c`k
+!;uis!;QTk!;c]q!;c`k!:^!g!;c]q!;lcr!<2uu!;lcr!;c]q!;ZZo!7UuH!##;3!<3$!rr<'!
+!!*$!!<3$!s*t~>
+li-qbrr3$"rrE&u!!)or!!)ut"p"]'!<<'!rr;corVlitqu6WroD]!ps8N*!rrE#tqZ-NnrW)Bd
+!!)ipq#LEo!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)rn!<2uu!;lcr!9a@^!;uis!;lfr!;HKn
+!;lcr!;lcr!<2uu!<2uu!<2uu!;$3j!;uis!<2uu!;lcr!<)p%!<<'!s8N)irr<&srr<&ss8E#q
+s7lZms8E#brr<&orr<&os8E#frr<&rrr<&trrrK'rrE*!!<)ot!;uis!:Tpf!;HKn!;QQo!;c`k
+!;uis!;QTk!;c]q!;c`k!:^!g!;c]q!;lcr!<2uu!;lcr!;c]q!;ZZo!7UuH!##;3!<3$!rr<'!
+!!*$!!<3$!s*t~>
+li-qbrr3$"rrE&u!!)or!!)ut"p"]'!<<'!rr;corVlitqu6WroD]!ps8N*!rrE#tqZ-NnrW)Bd
+!!)ipq#LEo!!*#u!!*#u!s&B$!;lcr!;uis!<2uu!<)rn!<2uu!;lcr!9a@^!;uis!;lfr!;HKn
+!;lcr!;lcr!<2uu!<2uu!<2uu!;$3j!;uis!<2uu!;lcr!<)p%!<<'!s8N)irr<&srr<&ss8E#q
+s7lZms8E#brr<&orr<&os8E#frr<&rrr<&trrrK'rrE*!!<)ot!;uis!:Tpf!;HKn!;QQo!;c`k
+!;uis!;QTk!;c]q!;c`k!:^!g!;c]q!;lcr!<2uu!;lcr!;c]q!;ZZo!7UuH!##;3!<3$!rr<'!
+!!*$!!<3$!s*t~>
+li-qbrr3$"rrE&u!!)or!!)ut"p"Z'rrE'!rr2rupAY*mqu6WroD]!prrE'!rrE&u!!)rs!!)fo
+rrDQg!!)ip!!)cn!!*#u!!*#u!s&B$!;lcr!;lct!<3&srr<&nrr<&rrr<&^s7u`ms8N)nrr<&r
+rr<&rrr<&urr<&urr<&urr<&jrr<&srr<&urr<&rrr<&trrrK'!<3'!!:p-i!;uis!;ZZp!<)ot
+!:p0i!:Kje!;QQo!;6Bl!:p-i!;lcr!<)p%!<3'!!<3&trr<&srr<&frr<&nrr<&orr<&qrr<&l
+rr<&prr<&srr<&qrr<&qrr<&`rr<&qrr<&rrr<&urr<&rrr<&qrr<&ms8N)Ls8N)cs*t~>
+li-qbrr3$"rrE&u!!)or!!)ut"p"Z'rrE'!rr2rupAY*mqu6WroD]!prrE'!rrE&u!!)rs!!)fo
+rrDQg!!)ip!!)cn!!*#u!!*#u!s&B$!;lcr!;lct!<3&srr<&nrr<&rrr<&^s7u`ms8N)nrr<&r
+rr<&rrr<&urr<&urr<&urr<&jrr<&srr<&urr<&rrr<&trrrK'!<3'!!:p-i!;uis!;ZZp!<)ot
+!:p0i!:Kje!;QQo!;6Bl!:p-i!;lcr!<)p%!<3'!!<3&trr<&srr<&frr<&nrr<&orr<&qrr<&l
+rr<&prr<&srr<&qrr<&qrr<&`rr<&qrr<&rrr<&urr<&rrr<&qrr<&ms8N)Ls8N)cs*t~>
+li-qbrr3$"rrE&u!!)or!!)ut"p"Z'rrE'!rr2rupAY*mqu6WroD]!prrE'!rrE&u!!)rs!!)fo
+rrDQg!!)ip!!)cn!!*#u!!*#u!s&B$!;lcr!;lct!<3&srr<&nrr<&rrr<&^s7u`ms8N)nrr<&r
+rr<&rrr<&urr<&urr<&urr<&jrr<&srr<&urr<&rrr<&trrrK'!<3'!!:p-i!;uis!;ZZp!<)ot
+!:p0i!:Kje!;QQo!;6Bl!:p-i!;lcr!<)p%!<3'!!<3&trr<&srr<&frr<&nrr<&orr<&qrr<&l
+rr<&prr<&srr<&qrr<&qrr<&`rr<&qrr<&rrr<&urr<&rrr<&qrr<&ms8N)Ls8N)cs*t~>
+li-qbrVultrr2ruqu6WrrVm'%rrE'!rrE&u!!)`m!!)or!!)Wj"p"Z'rrE'!rr2rur;Q`sr;Q`s
+r;Q`snc&Rhq>UEpp\t3nrr2rurr3'#s8N)rrr<&rrrN3#!;uis!;HKn!;lcr!9jF_!;c]q!<)p"
+!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2ruoD\djr;Q`srr2ruqu6WrrVm'%rrE'!rrDWi!!)rs
+!!)ut!!)rs!!*#u!!)`m!!)rs!!)Kf!!)fo!!)ip!!)rs!!)Wj!!)or!!)ut"p"Z'rrE'!rVlit
+r;Q`sn,E@fp\t3nq#:<oqYpNqp&>!lq>UEpr;Q`sqYpNqqYpNql2L_`qYpNqqu6Wrrr2ruqu6Wr
+qYpNqqYpNqr;Q`sf)PaMm/MS~>
+li-qbrVultrr2ruqu6WrrVm'%rrE'!rrE&u!!)`m!!)or!!)Wj"p"Z'rrE'!rr2rur;Q`sr;Q`s
+r;Q`snc&Rhq>UEpp\t3nrr2rurr3'#s8N)rrr<&rrrN3#!;uis!;HKn!;lcr!9jF_!;c]q!<)p"
+!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2ruoD\djr;Q`srr2ruqu6WrrVm'%rrE'!rrDWi!!)rs
+!!)ut!!)rs!!*#u!!)`m!!)rs!!)Kf!!)fo!!)ip!!)rs!!)Wj!!)or!!)ut"p"Z'rrE'!rVlit
+r;Q`sn,E@fp\t3nq#:<oqYpNqp&>!lq>UEpr;Q`sqYpNqqYpNql2L_`qYpNqqu6Wrrr2ruqu6Wr
+qYpNqqYpNqr;Q`sf)PaMm/MS~>
+li-qbrVultrr2ruqu6WrrVm'%rrE'!rrE&u!!)`m!!)or!!)Wj"p"Z'rrE'!rr2rur;Q`sr;Q`s
+r;Q`snc&Rhq>UEpp\t3nrr2rurr3'#s8N)rrr<&rrrN3#!;uis!;HKn!;lcr!9jF_!;c]q!<)p"
+!<<'!q#:<oqu6Wrqu6Wrrr2rurr2rurr2ruoD\djr;Q`srr2ruqu6WrrVm'%rrE'!rrDWi!!)rs
+!!)ut!!)rs!!*#u!!)`m!!)rs!!)Kf!!)fo!!)ip!!)rs!!)Wj!!)or!!)ut"p"Z'rrE'!rVlit
+r;Q`sn,E@fp\t3nq#:<oqYpNqp&>!lq>UEpr;Q`sqYpNqqYpNql2L_`qYpNqqu6Wrrr2ruqu6Wr
+qYpNqqYpNqr;Q`sf)PaMm/MS~>
+li-qbrVultrVlitrVlitqu6Wrrr2rur;Q`srVultrVultrVlitnc&Rhrr2rurVlitrVultr;Zcs
+rVlitnc&Rhq#:<orVultrr2rurr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVlitrVultqu?Zr
+nG`IgqYpNqrr2rurVlitq>UEpqYpNqrVlitrVlitrr2rurr2ruoD\djr;Q`srVlitrVlitqu6Wr
+rr2runc&RhrVultrVultrVlitrVlitrVultrVultrVlitn,E@fq#:<orVlitrr;uurVlito)A[i
+rVlitqu6Wrrr2rur;Q`sr;Q`sn,E@fp\t3nq#:<orVlitrr2rurVultr;Q`sq>UEprVultqYpNq
+rVlitrr2rurVultnG`IgrVlitrr2rurVlitr;Q`srVlitq>UEpqZ$QqrVlitqu?ZrhZ*NS')qq3
+rr<'!!!*$!!<3$!rr<'!J,~>
+li-qbrVultrVlitrVlitqu6Wrrr2rur;Q`srVultrVultrVlitnc&Rhrr2rurVlitrVultr;Zcs
+rVlitnc&Rhq#:<orVultrr2rurr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVlitrVultqu?Zr
+nG`IgqYpNqrr2rurVlitq>UEpqYpNqrVlitrVlitrr2rurr2ruoD\djr;Q`srVlitrVlitqu6Wr
+rr2runc&RhrVultrVultrVlitrVlitrVultrVultrVlitn,E@fq#:<orVlitrr;uurVlito)A[i
+rVlitqu6Wrrr2rur;Q`sr;Q`sn,E@fp\t3nq#:<orVlitrr2rurVultr;Q`sq>UEprVultqYpNq
+rVlitrr2rurVultnG`IgrVlitrr2rurVlitr;Q`srVlitq>UEpqZ$QqrVlitqu?ZrhZ*NS')qq3
+rr<'!!!*$!!<3$!rr<'!J,~>
+li-qbrVultrVlitrVlitqu6Wrrr2rur;Q`srVultrVultrVlitnc&Rhrr2rurVlitrVultr;Zcs
+rVlitnc&Rhq#:<orVultrr2rurr2rurr2rurr2rurVlitq>UEpqYpNqrVultrVlitrVultqu?Zr
+nG`IgqYpNqrr2rurVlitq>UEpqYpNqrVlitrVlitrr2rurr2ruoD\djr;Q`srVlitrVlitqu6Wr
+rr2runc&RhrVultrVultrVlitrVlitrVultrVultrVlitn,E@fq#:<orVlitrr;uurVlito)A[i
+rVlitqu6Wrrr2rur;Q`sr;Q`sn,E@fp\t3nq#:<orVlitrr2rurVultr;Q`sq>UEprVultqYpNq
+rVlitrr2rurVultnG`IgrVlitrr2rurVlitr;Q`srVlitq>UEpqZ$QqrVlitqu?ZrhZ*NS')qq3
+rr<'!!!*$!!<3$!rr<'!J,~>
+m/R"arr2rur;Z]qqYpNqrr2ruqu?Tpr;Zcs!<;utnG`Igrr2rur;Z]q!<<#urr3!!s8;rgs7u`m
+s8;rrs8E#us8N*!s8N)us8;rmrr<&ps8;ros8;p!rr<&ss8N)hs8;rss8;ots8E#us8E#ss7u`n
+s8;rrs8E#us8N*!s8N)ls8E#ts8E#ss8;rorr<&urr<&gs8;p!rr<&urrE-"r;c`pr;c`p!<E/u
+!:g*c!;c`o!<)ou!<;utnGiFeqYpNqrr2rurVuisrr;rtoDeXerVu]oqZ$Kor;Z]qr;ZTnr;Z]q
+!<<#uqu?Tpr;Z]qmJm+br;Z]qqZ$Koqu?KmrVllus8;ros8N)Us8N)cs*t~>
+m/R"arr2rur;Z]qqYpNqrr2ruqu?Tpr;Zcs!<;utnG`Igrr2rur;Z]q!<<#urr3!!s8;rgs7u`m
+s8;rrs8E#us8N*!s8N)us8;rmrr<&ps8;ros8;p!rr<&ss8N)hs8;rss8;ots8E#us8E#ss7u`n
+s8;rrs8E#us8N*!s8N)ls8E#ts8E#ss8;rorr<&urr<&gs8;p!rr<&urrE-"r;c`pr;c`p!<E/u
+!:g*c!;c`o!<)ou!<;utnGiFeqYpNqrr2rurVuisrr;rtoDeXerVu]oqZ$Kor;Z]qr;ZTnr;Z]q
+!<<#uqu?Tpr;Z]qmJm+br;Z]qqZ$Koqu?KmrVllus8;ros8N)Us8N)cs*t~>
+m/R"arr2rur;Z]qqYpNqrr2ruqu?Tpr;Zcs!<;utnG`Igrr2rur;Z]q!<<#urr3!!s8;rgs7u`m
+s8;rrs8E#us8N*!s8N)us8;rmrr<&ps8;ros8;p!rr<&ss8N)hs8;rss8;ots8E#us8E#ss7u`n
+s8;rrs8E#us8N*!s8N)ls8E#ts8E#ss8;rorr<&urr<&gs8;p!rr<&urrE-"r;c`pr;c`p!<E/u
+!:g*c!;c`o!<)ou!<;utnGiFeqYpNqrr2rurVuisrr;rtoDeXerVu]oqZ$Kor;Z]qr;ZTnr;Z]q
+!<<#uqu?Tpr;Z]qmJm+br;Z]qqZ$Koqu?KmrVllus8;ros8N)Us8N)cs*t~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+iW&oXh#IBSh>dKTJcG?Ar;_EKd/X+GJcCi3r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+iW&oXh#IBSh>dKTJcG?Ar;_EKd/X+GJcCi3r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+iW&oXh#IBSh>dKTJcG?Ar;_EKd/X+GJcCi3r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+m/Qh\rr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3rrDEcJ,~>
+m/Qh\rr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3rrDEcJ,~>
+m/Qh\rr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3rrDEcJ,~>
+m/I%crr2rurr2rurr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3rrDEcJ,~>
+m/I%crr2rurr2rurr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3rrDEcJ,~>
+m/I%crr2rurr2rurr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3rrDEcJ,~>
+m/I%crr2rurr2rurr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3r;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+m/I%crr2rurr2rurr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3r;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+m/I%crr2rurr2rurr2rug]%6RnG`Igmf*7eJcG6>!!%TMci3tFJcCi3r;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+m/I%crr2rurr2rurr3!!s8;rps8;rds8;ourrDusr;c`pq>gHnr;c`p!<E/u!;lfp!;c`o!!3*"
+r;Z]qqZ$Ko!WN/is8;rqs8Duus8E#qs8;rfs8N'!s8;rps8;rbrr<&ps8;rqs8N'!s8;rps8;p!
+rr<&ts8;rqs8Duus8E#fs8;ourrDusr;cfrrr<9'!!*'!!!*#urr<'!r;cfrrVururW)iqr;c]o
+r;Zlu!;ulq!!3*"r;Z]qqZ$Ko!WN.Ns,d9\!:9`9~>
+m/I%crr2rurr2rurr3!!s8;rps8;rds8;ourrDusr;c`pq>gHnr;c`p!<E/u!;lfp!;c`o!!3*"
+r;Z]qqZ$Ko!WN/is8;rqs8Duus8E#qs8;rfs8N'!s8;rps8;rbrr<&ps8;rqs8N'!s8;rps8;p!
+rr<&ts8;rqs8Duus8E#fs8;ourrDusr;cfrrr<9'!!*'!!!*#urr<'!r;cfrrVururW)iqr;c]o
+r;Zlu!;ulq!!3*"r;Z]qqZ$Ko!WN.Ns,d9\!:9`9~>
+m/I%crr2rurr2rurr3!!s8;rps8;rds8;ourrDusr;c`pq>gHnr;c`p!<E/u!;lfp!;c`o!!3*"
+r;Z]qqZ$Ko!WN/is8;rqs8Duus8E#qs8;rfs8N'!s8;rps8;rbrr<&ps8;rqs8N'!s8;rps8;p!
+rr<&ts8;rqs8Duus8E#fs8;ourrDusr;cfrrr<9'!!*'!!!*#urr<'!r;cfrrVururW)iqr;c]o
+r;Zlu!;ulq!!3*"r;Z]qqZ$Ko!WN.Ns,d9\!:9`9~>
+kl1V_qZ$QqrVlitrVlitrVlitnc&RhrVultrVlitrVlitqYpNqq>UEprVlitr;ZcsrVlitrVlit
+rVlitr;Q`srVultrVlitrVlitr;Q`srVulto)A[irVlitqu?Zrrr2rurVlitrVlitnc/UhrVlit
+rVlitrVlitmf*7eqYpNqrVlitr;ZcsrVlitrVlitrVultrVlitrVlitqu?Zrrr2ruo)A[irVult
+rVlitrVlitrVults8W*!s8N'!rr;uurVlitr;Zcsrr2rurVlitrVlitr;Q`srVultrVlitrVult
+rVlitrVlitr;Q`srVultJcCi3rrDEcJ,~>
+kl1V_qZ$QqrVlitrVlitrVlitnc&RhrVultrVlitrVlitqYpNqq>UEprVlitr;ZcsrVlitrVlit
+rVlitr;Q`srVultrVlitrVlitr;Q`srVulto)A[irVlitqu?Zrrr2rurVlitrVlitnc/UhrVlit
+rVlitrVlitmf*7eqYpNqrVlitr;ZcsrVlitrVlitrVultrVlitrVlitqu?Zrrr2ruo)A[irVult
+rVlitrVlitrVults8W*!s8N'!rr;uurVlitr;Zcsrr2rurVlitrVlitr;Q`srVultrVlitrVult
+rVlitrVlitr;Q`srVultJcCi3rrDEcJ,~>
+kl1V_qZ$QqrVlitrVlitrVlitnc&RhrVultrVlitrVlitqYpNqq>UEprVlitr;ZcsrVlitrVlit
+rVlitr;Q`srVultrVlitrVlitr;Q`srVulto)A[irVlitqu?Zrrr2rurVlitrVlitnc/UhrVlit
+rVlitrVlitmf*7eqYpNqrVlitr;ZcsrVlitrVlitrVultrVlitrVlitqu?Zrrr2ruo)A[irVult
+rVlitrVlitrVults8W*!s8N'!rr;uurVlitr;Zcsrr2rurVlitrVlitr;Q`srVultrVlitrVult
+rVlitrVlitr;Q`srVultJcCi3rrDEcJ,~>
+kl1V_qYpNqr;Q`srr2ruqu6WroD\djqu6Wrq#:<oqYpNqo`"mkr;Q`squ6Wrq>UEpr;Q`sr;Q`s
+rr2ruqu6WrrVlitr;Q`smJd.dqu6Wrq>UEpqu6Wro)A[ir;Q`srr2ruqu6Wrn,E@fqu6Wrqu6Wr
+rVlitr;Q`srr2ruqu6Wrrr2ruqu6Wrr;Q`smf*7equ6Wrrr2ruqu6Wrrr2rurr2rurr2rurr2ru
+qu6WrrVlitq>UEpqu6WrrVlitr;Q`srVlitr;Q`srr2ruqu6Wrrr2ruqu6WrJcCi3r;[K1!!*$!
+!<3$!rr<'!!!*$!!<7Q~>
+kl1V_qYpNqr;Q`srr2ruqu6WroD\djqu6Wrq#:<oqYpNqo`"mkr;Q`squ6Wrq>UEpr;Q`sr;Q`s
+rr2ruqu6WrrVlitr;Q`smJd.dqu6Wrq>UEpqu6Wro)A[ir;Q`srr2ruqu6Wrn,E@fqu6Wrqu6Wr
+rVlitr;Q`srr2ruqu6Wrrr2ruqu6Wrr;Q`smf*7equ6Wrrr2ruqu6Wrrr2rurr2rurr2rurr2ru
+qu6WrrVlitq>UEpqu6WrrVlitr;Q`srVlitr;Q`srr2ruqu6Wrrr2ruqu6WrJcCi3r;[K1!!*$!
+!<3$!rr<'!!!*$!!<7Q~>
+kl1V_qYpNqr;Q`srr2ruqu6WroD\djqu6Wrq#:<oqYpNqo`"mkr;Q`squ6Wrq>UEpr;Q`sr;Q`s
+rr2ruqu6WrrVlitr;Q`smJd.dqu6Wrq>UEpqu6Wro)A[ir;Q`srr2ruqu6Wrn,E@fqu6Wrqu6Wr
+rVlitr;Q`srr2ruqu6Wrrr2ruqu6Wrr;Q`smf*7equ6Wrrr2ruqu6Wrrr2rurr2rurr2rurr2ru
+qu6WrrVlitq>UEpqu6WrrVlitr;Q`srVlitr;Q`srr2ruqu6Wrrr2ruqu6WrJcCi3r;[K1!!*$!
+!<3$!rr<'!!!*$!!<7Q~>
+kl1V_qYpNqr;Q`srr;cooD\djqu6WrrVu`pqYpNqq>^<lr;Q`squ6Wrrr;iqqu?Wqqu?Hlr;Z`r
+n,N7bqu6Wrq>^6jo)A[ir;Q`srr2ruqu6Wrn,E@fqu6Wrqu6WrrVlitr;Q`srr2ruqu6Wrrr;co
+r;Q`smf*7ep\t3nqu6Wrrr2rurr2rurr2rurr2ruqu6WrrVlitq>^6jr;Z`rq>^Eoqu?Hlrr2ru
+qu6WrJcCi3rrDEcJ,~>
+kl1V_qYpNqr;Q`srr;cooD\djqu6WrrVu`pqYpNqq>^<lr;Q`squ6Wrrr;iqqu?Wqqu?Hlr;Z`r
+n,N7bqu6Wrq>^6jo)A[ir;Q`srr2ruqu6Wrn,E@fqu6Wrqu6WrrVlitr;Q`srr2ruqu6Wrrr;co
+r;Q`smf*7ep\t3nqu6Wrrr2rurr2rurr2rurr2ruqu6WrrVlitq>^6jr;Z`rq>^Eoqu?Hlrr2ru
+qu6WrJcCi3rrDEcJ,~>
+kl1V_qYpNqr;Q`srr;cooD\djqu6WrrVu`pqYpNqq>^<lr;Q`squ6Wrrr;iqqu?Wqqu?Hlr;Z`r
+n,N7bqu6Wrq>^6jo)A[ir;Q`srr2ruqu6Wrn,E@fqu6Wrqu6WrrVlitr;Q`srr2ruqu6Wrrr;co
+r;Q`smf*7ep\t3nqu6Wrrr2rurr2rurr2rurr2ruqu6WrrVlitq>^6jr;Z`rq>^Eoqu?Hlrr2ru
+qu6WrJcCi3rrDEcJ,~>
+kl1V_qYpNqr;Q`srr2rum/I%cqu6Wrrr2rur;Q`sqYpNqqYpNqr;Q`sr;Q`squ6`us8N)srr<&o
+s8N)trr<&is8N)irr<&srr<&rrr<&prr<&brr<&srr<&urr<&rrr<&frr<&rrr<&rrr<&trr<&s
+rr<&urr<&rrr<&urr<&lrr<&err<&nrr<&rrr<&urr<&urr<&urr<&urr<&rrr<&trr<&prr<&i
+s8N)os8N)trr<&nrr<&rrr<%Ms,d9\!:9`9~>
+kl1V_qYpNqr;Q`srr2rum/I%cqu6Wrrr2rur;Q`sqYpNqqYpNqr;Q`sr;Q`squ6`us8N)srr<&o
+s8N)trr<&is8N)irr<&srr<&rrr<&prr<&brr<&srr<&urr<&rrr<&frr<&rrr<&rrr<&trr<&s
+rr<&urr<&rrr<&urr<&lrr<&err<&nrr<&rrr<&urr<&urr<&urr<&urr<&rrr<&trr<&prr<&i
+s8N)os8N)trr<&nrr<&rrr<%Ms,d9\!:9`9~>
+kl1V_qYpNqr;Q`srr2rum/I%cqu6Wrrr2rur;Q`sqYpNqqYpNqr;Q`sr;Q`squ6`us8N)srr<&o
+s8N)trr<&is8N)irr<&srr<&rrr<&prr<&brr<&srr<&urr<&rrr<&frr<&rrr<&rrr<&trr<&s
+rr<&urr<&rrr<&urr<&lrr<&err<&nrr<&rrr<&urr<&urr<&urr<&urr<&rrr<&trr<&prr<&i
+s8N)os8N)trr<&nrr<&rrr<%Ms,d9\!:9`9~>
+kl1V_qYpNqr;Q`srr2rum/I%cqu6Wrrr2rur;Q`sqYpNqqYpNqr;Q`sr;Q`squ6`us8N)srr<&s
+rr<&srr<&urr<&mrr<&srr<&jrr<&srr<&rrr<&prr<&brr<&srr<&urr<&rrr<&frr<&rrr<&r
+rr<&trr<&srr<&urr<&rrr<&urr<&lrr<&err<&nrr<&rrr<&urr<&urr<&urr<&urr<&rrr<&t
+rr<&prr<&mrr<&srr<&trr<&srr<&urr<&nrr<&rrr<%Ms,d9Z!##;3!<3$!rr<'!!!*$!!<3$!
+s*t~>
+kl1V_qYpNqr;Q`srr2rum/I%cqu6Wrrr2rur;Q`sqYpNqqYpNqr;Q`sr;Q`squ6`us8N)srr<&s
+rr<&srr<&urr<&mrr<&srr<&jrr<&srr<&rrr<&prr<&brr<&srr<&urr<&rrr<&frr<&rrr<&r
+rr<&trr<&srr<&urr<&rrr<&urr<&lrr<&err<&nrr<&rrr<&urr<&urr<&urr<&urr<&rrr<&t
+rr<&prr<&mrr<&srr<&trr<&srr<&urr<&nrr<&rrr<%Ms,d9Z!##;3!<3$!rr<'!!!*$!!<3$!
+s*t~>
+kl1V_qYpNqr;Q`srr2rum/I%cqu6Wrrr2rur;Q`sqYpNqqYpNqr;Q`sr;Q`squ6`us8N)srr<&s
+rr<&srr<&urr<&mrr<&srr<&jrr<&srr<&rrr<&prr<&brr<&srr<&urr<&rrr<&frr<&rrr<&r
+rr<&trr<&srr<&urr<&rrr<&urr<&lrr<&err<&nrr<&rrr<&urr<&urr<&urr<&urr<&rrr<&t
+rr<&prr<&mrr<&srr<&trr<&srr<&urr<&nrr<&rrr<%Ms,d9Z!##;3!<3$!rr<'!!!*$!!<3$!
+s*t~>
+kl1V_qYpNqr;Q`srVlitrVulto)A[irVultrr2rurVultqYpNqrVls"s8N)ts8N)ss8N)trr<&u
+rr<&ts8N)ss8N)trr<&trr<&ts8N)ts8N)trr<&jrr<&ts8N)rrr<&orr<&ts8N)irr<&srr<&t
+rr<&trr<&err<&qrr<&trr<&srr<&srr<&trr<&ts8N)trr<&ts8N)srr<&drr<&ts8N)trr<&t
+rr<&trr<&urr<&urr<&us8N)trr<&srr<&orr<&ts8N)ts8N)trr<&ts8N)trr<&trr<&ts8N)t
+rr<&ts8N)rs8N(Ms-Wid!:9`9~>
+kl1V_qYpNqr;Q`srVlitrVulto)A[irVultrr2rurVultqYpNqrVls"s8N)ts8N)ss8N)trr<&u
+rr<&ts8N)ss8N)trr<&trr<&ts8N)ts8N)trr<&jrr<&ts8N)rrr<&orr<&ts8N)irr<&srr<&t
+rr<&trr<&err<&qrr<&trr<&srr<&srr<&trr<&ts8N)trr<&ts8N)srr<&drr<&ts8N)trr<&t
+rr<&trr<&urr<&urr<&us8N)trr<&srr<&orr<&ts8N)ts8N)trr<&ts8N)trr<&trr<&ts8N)t
+rr<&ts8N)rs8N(Ms-Wid!:9`9~>
+kl1V_qYpNqr;Q`srVlitrVulto)A[irVultrr2rurVultqYpNqrVls"s8N)ts8N)ss8N)trr<&u
+rr<&ts8N)ss8N)trr<&trr<&ts8N)ts8N)trr<&jrr<&ts8N)rrr<&orr<&ts8N)irr<&srr<&t
+rr<&trr<&err<&qrr<&trr<&srr<&srr<&trr<&ts8N)trr<&ts8N)srr<&drr<&ts8N)trr<&t
+rr<&trr<&urr<&urr<&us8N)trr<&srr<&orr<&ts8N)ts8N)trr<&ts8N)trr<&trr<&ts8N)t
+rr<&ts8N)rs8N(Ms-Wid!:9`9~>
+lMpb^rVuisrr;rtrVufrn,N=d!ri6#rr;os!<<#uqu?TprVufr!<<#us8W*!!<;utr;Z]q!<<#u
+rr3!!s8;rps8;rprrE-"r;cBfr;ZitrW)uuq>gEmr;cBfrW)rtrW)osr;c?eq>gHnr;ccqrW)rt
+rW)osr;Zlu!;ulq!;uln!:^$e!;c`o!<)rs!<<*!!<<*!!<<'"!<;utrVu]oqu?Tpqu6Zss8;rq
+rrE-"r;c`pr;c]or;Zp!!!)rsrr@WMR/d0dm/MS~>
+lMpb^rVuisrr;rtrVufrn,N=d!ri6#rr;os!<<#uqu?TprVufr!<<#us8W*!!<;utr;Z]q!<<#u
+rr3!!s8;rps8;rprrE-"r;cBfr;ZitrW)uuq>gEmr;cBfrW)rtrW)osr;c?eq>gHnr;ccqrW)rt
+rW)osr;Zlu!;ulq!;uln!:^$e!;c`o!<)rs!<<*!!<<*!!<<'"!<;utrVu]oqu?Tpqu6Zss8;rq
+rrE-"r;c`pr;c]or;Zp!!!)rsrr@WMR/d0dm/MS~>
+lMpb^rVuisrr;rtrVufrn,N=d!ri6#rr;os!<<#uqu?TprVufr!<<#us8W*!!<;utr;Z]q!<<#u
+rr3!!s8;rps8;rprrE-"r;cBfr;ZitrW)uuq>gEmr;cBfrW)rtrW)osr;c?eq>gHnr;ccqrW)rt
+rW)osr;Zlu!;ulq!;uln!:^$e!;c`o!<)rs!<<*!!<<*!!<<'"!<;utrVu]oqu?Tpqu6Zss8;rq
+rrE-"r;c`pr;c]or;Zp!!!)rsrr@WMR/d0dm/MS~>
+JcC<$h>[HT]Dhj2JcC<$aT)2=')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcC<$h>[HT]Dhj2JcC<$aT)2=')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcC<$h>[HT]Dhj2JcC<$aT)2=')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcC<$h>[HT]Dhj2JcC<$aT)8?m/MS~>
+JcC<$h>[HT]Dhj2JcC<$aT)8?m/MS~>
+JcC<$h>[HT]Dhj2JcC<$aT)8?m/MS~>
+JcC<$hZ!QU])Ma1JcC<$aT)8?m/MS~>
+JcC<$hZ!QU])Ma1JcC<$aT)8?m/MS~>
+JcC<$hZ!QU])Ma1JcC<$aT)8?m/MS~>
+JcC<$j8]#W])V^/JcC<$b5_D?')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcC<$j8]#W])V^/JcC<$b5_D?')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcC<$j8]#W])V^/JcC<$b5_D?')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+ec5RJbl@\Cq>^BnJcC<$Jc>fO!!%TMdf9=Im/MS~>
+ec5RJbl@\Cq>^BnJcC<$Jc>fO!!%TMdf9=Im/MS~>
+ec5RJbl@\Cq>^BnJcC<$Jc>fO!!%TMdf9=Im/MS~>
+mJm+brr;osnc&RhcN!nE!WN/rrr<&trr<&^s7u`Jrr<&Ps8;rarr<&Ns8;ourrC%<!!'G,!!)!X
+!!)6_!!%TMdf9=Im/MS~>
+mJm+brr;osnc&RhcN!nE!WN/rrr<&trr<&^s7u`Jrr<&Ps8;rarr<&Ns8;ourrC%<!!'G,!!)!X
+!!)6_!!%TMdf9=Im/MS~>
+mJm+brr;osnc&RhcN!nE!WN/rrr<&trr<&^s7u`Jrr<&Ps8;rarr<&Ns8;ourrC%<!!'G,!!)!X
+!!)6_!!%TMdf9=Im/MS~>
+m/I%cqYpNqnG`IgbPqPBo`"mkkPkM^r;Q`sg&D$Pf)G^Mm/I%cg&M'PrVult`W#o<[Jp4,iVrlX
+kl1V_JcF0ur;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+m/I%cqYpNqnG`IgbPqPBo`"mkkPkM^r;Q`sg&D$Pf)G^Mm/I%cg&M'PrVult`W#o<[Jp4,iVrlX
+kl1V_JcF0ur;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+m/I%cqYpNqnG`IgbPqPBo`"mkkPkM^r;Q`sg&D$Pf)G^Mm/I%cg&M'PrVult`W#o<[Jp4,iVrlX
+kl1V_JcF0ur;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+m/I%cqYpNqnG`IgbPqPBo`"mkkPkM^qu6WrYQ"Y(rrC";!!)or!!("<!!'G,!!)!X!!)6_!!%TM
+df9=Im/MS~>
+m/I%cqYpNqnG`IgbPqPBo`"mkkPkM^qu6WrYQ"Y(rrC";!!)or!!("<!!'G,!!)!X!!)6_!!%TM
+df9=Im/MS~>
+m/I%cqYpNqnG`IgbPqPBo`"mkkPkM^qu6WrYQ"Y(rrC";!!)or!!("<!!'G,!!)!X!!)6_!!%TM
+df9=Im/MS~>
+li-qbr;Q`sr;Z]qq#:<oqu?ZrrVults8W*!#6+Z's8N'!r;Z]qmJd.dp&>!lq>^HpnG`Igqu6]t
+s8W&u!<<#uqu?Tpr;Z`rrr;rtrVuisqu?Zr!<;utqu?Tp!ri6#nc&XjrrDusrW)uurW)lrrW)co
+r;cfrrr<9'!!*'!!!)Wj!!)]lr;ccqrVururW)osrVururW)iqr;c]or;Zlu!<)ro!;$6i!<3#t
+!<)rr!;c`o!!3*"nc/Of!WN/us7u`ns8;rqs8Duus8E#rs7u`ns8;ros8;ourr@WMdf9=Im/MS~>
+li-qbr;Q`sr;Z]qq#:<oqu?ZrrVults8W*!#6+Z's8N'!r;Z]qmJd.dp&>!lq>^HpnG`Igqu6]t
+s8W&u!<<#uqu?Tpr;Z`rrr;rtrVuisqu?Zr!<;utqu?Tp!ri6#nc&XjrrDusrW)uurW)lrrW)co
+r;cfrrr<9'!!*'!!!)Wj!!)]lr;ccqrVururW)osrVururW)iqr;c]or;Zlu!<)ro!;$6i!<3#t
+!<)rr!;c`o!!3*"nc/Of!WN/us7u`ns8;rqs8Duus8E#rs7u`ns8;ros8;ourr@WMdf9=Im/MS~>
+li-qbr;Q`sr;Z]qq#:<oqu?ZrrVults8W*!#6+Z's8N'!r;Z]qmJd.dp&>!lq>^HpnG`Igqu6]t
+s8W&u!<<#uqu?Tpr;Z`rrr;rtrVuisqu?Zr!<;utqu?Tp!ri6#nc&XjrrDusrW)uurW)lrrW)co
+r;cfrrr<9'!!*'!!!)Wj!!)]lr;ccqrVururW)osrVururW)iqr;c]or;Zlu!<)ro!;$6i!<3#t
+!<)rr!;c`o!!3*"nc/Of!WN/us7u`ns8;rqs8Duus8E#rs7u`ns8;ros8;ourr@WMdf9=Im/MS~>
+li-qbr;Q`srVlitrVlitq>UEpqYpNqr;Q`srr;uus8W*!s8N'!rr2rurVlitmf*7eq#C<nq#C?o
+nG`Igqu6WrrVultrr2rurVlitrVlitr;Q`sr;Q`sqYpNqqZ$QqrVlitrVlitrVultnc&Rhrr2ru
+r;Q`srVlitq>UEpqYpNqrVlitrVults8W*!s8N'!o`"mkpAY*mrVlitqu?Zrrr2rur;Zcsrr2ru
+rVlitrVlitr;Q`srVultqu6Wrmf*7er;Q`srVlitrVlitr;Q`srVulto)A[irVultqu6Wrq>UEp
+rVlitqu?Zrrr2ruqu6Wrq>UEprVlitr;Q`srVultJcF0ur;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li-qbr;Q`srVlitrVlitq>UEpqYpNqr;Q`srr;uus8W*!s8N'!rr2rurVlitmf*7eq#C<nq#C?o
+nG`Igqu6WrrVultrr2rurVlitrVlitr;Q`sr;Q`sqYpNqqZ$QqrVlitrVlitrVultnc&Rhrr2ru
+r;Q`srVlitq>UEpqYpNqrVlitrVults8W*!s8N'!o`"mkpAY*mrVlitqu?Zrrr2rur;Zcsrr2ru
+rVlitrVlitr;Q`srVultqu6Wrmf*7er;Q`srVlitrVlitr;Q`srVulto)A[irVultqu6Wrq>UEp
+rVlitqu?Zrrr2ruqu6Wrq>UEprVlitr;Q`srVultJcF0ur;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+li-qbr;Q`srVlitrVlitq>UEpqYpNqr;Q`srr;uus8W*!s8N'!rr2rurVlitmf*7eq#C<nq#C?o
+nG`Igqu6WrrVultrr2rurVlitrVlitr;Q`sr;Q`sqYpNqqZ$QqrVlitrVlitrVultnc&Rhrr2ru
+r;Q`srVlitq>UEpqYpNqrVlitrVults8W*!s8N'!o`"mkpAY*mrVlitqu?Zrrr2rur;Zcsrr2ru
+rVlitrVlitr;Q`srVultqu6Wrmf*7er;Q`srVlitrVlitr;Q`srVulto)A[irVultqu6Wrq>UEp
+rVlitqu?Zrrr2ruqu6Wrq>UEprVlitr;Q`srVultJcF0ur;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+lMgharr2rurVlitqu6WrqYpNqqYpNqr;Q`srr2rurr2rurr3'#s8N)rrr<&frr<&lrr<&]rr<&s
+rr<&srr<&prr<&rrr<&srr<&urr<&prr<&qrr<&srr<&urr<&rrr<&hrr<&urr<&rrrW9$rrDio
+!!)or!!)or!!*#u!!*#u!!*#u!!)Zk!!)cn!!)or!!)rs!!)cn!!)ip!!)or!!*#u!!)or!!)or
+!!)He"p"]'!<<'!q#:<or;Q`sr;Q`so)A[ir;Q`squ6Wro`"mkqu6WrpAY*mqYpNqqu6Wrrr2ru
+qu6WrJcF0urrDEcJ,~>
+lMgharr2rurVlitqu6WrqYpNqqYpNqr;Q`srr2rurr2rurr3'#s8N)rrr<&frr<&lrr<&]rr<&s
+rr<&srr<&prr<&rrr<&srr<&urr<&prr<&qrr<&srr<&urr<&rrr<&hrr<&urr<&rrrW9$rrDio
+!!)or!!)or!!*#u!!*#u!!*#u!!)Zk!!)cn!!)or!!)rs!!)cn!!)ip!!)or!!*#u!!)or!!)or
+!!)He"p"]'!<<'!q#:<or;Q`sr;Q`so)A[ir;Q`squ6Wro`"mkqu6WrpAY*mqYpNqqu6Wrrr2ru
+qu6WrJcF0urrDEcJ,~>
+lMgharr2rurVlitqu6WrqYpNqqYpNqr;Q`srr2rurr2rurr3'#s8N)rrr<&frr<&lrr<&]rr<&s
+rr<&srr<&prr<&rrr<&srr<&urr<&prr<&qrr<&srr<&urr<&rrr<&hrr<&urr<&rrrW9$rrDio
+!!)or!!)or!!*#u!!*#u!!*#u!!)Zk!!)cn!!)or!!)rs!!)cn!!)ip!!)or!!*#u!!)or!!)or
+!!)He"p"]'!<<'!q#:<or;Q`sr;Q`so)A[ir;Q`squ6Wro`"mkqu6WrpAY*mqYpNqqu6Wrrr2ru
+qu6WrJcF0urrDEcJ,~>
+lMgharr2rurVlitqu6WrqYpNqqYpNqr;Q`srr2rurr2rurr3$"s8Vlpn,E@fo`"mkkPtDZqu6Wr
+q>UEpqu6Wrr;Q`srr2ruq>UEpqYpNqr;Q`srr2ruqu6Wro)A[ir;Q`squ?Zrp\t3nqu6Wrqu6Wr
+rr2rurr2rurr2ruo`"mkp\t3nqu6Wrr;Q`sp\t3nq>^6jrr2ruo`"mkmf*Iks8N*!rrE#tqZ-Nn
+rW)BdrW)`n!!)ipqZ-Nn!!)`m!!)lqq#LEo!!)or!!%TMdf9=Im/MS~>
+lMgharr2rurVlitqu6WrqYpNqqYpNqr;Q`srr2rurr2rurr3$"s8Vlpn,E@fo`"mkkPtDZqu6Wr
+q>UEpqu6Wrr;Q`srr2ruq>UEpqYpNqr;Q`srr2ruqu6Wro)A[ir;Q`squ?Zrp\t3nqu6Wrqu6Wr
+rr2rurr2rurr2ruo`"mkp\t3nqu6Wrr;Q`sp\t3nq>^6jrr2ruo`"mkmf*Iks8N*!rrE#tqZ-Nn
+rW)BdrW)`n!!)ipqZ-Nn!!)`m!!)lqq#LEo!!)or!!%TMdf9=Im/MS~>
+lMgharr2rurVlitqu6WrqYpNqqYpNqr;Q`srr2rurr2rurr3$"s8Vlpn,E@fo`"mkkPtDZqu6Wr
+q>UEpqu6Wrr;Q`srr2ruq>UEpqYpNqr;Q`srr2ruqu6Wro)A[ir;Q`squ?Zrp\t3nqu6Wrqu6Wr
+rr2rurr2rurr2ruo`"mkp\t3nqu6Wrr;Q`sp\t3nq>^6jrr2ruo`"mkmf*Iks8N*!rrE#tqZ-Nn
+rW)BdrW)`n!!)ipqZ-Nn!!)`m!!)lqq#LEo!!)or!!%TMdf9=Im/MS~>
+l2LebrrDus!!)or!!)lq!!)lq!!)rs!!*#u!!*#u!!*#u!s&B$!9jF_!;-9k!9a@^!;?Em!;ZWp
+!;lcr!;lct!<3&orr<&qrr<&srr<&urr<&rrr<&is7u`ms8N)nrr<&rrr<&rrr<&urr<&urr<&u
+rr<&krr<&nrr<&rrr<&srr<&nrr<&prr<&nrr<&krr<&errrK'!<3'!!<2uu!;uis!;QTo!:Bgd
+!;c]q!;c]q!;uis!;lcr!;?Em!;c]q!;HKn!;lcr!.k0us8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+l2LebrrDus!!)or!!)lq!!)lq!!)rs!!*#u!!*#u!!*#u!s&B$!9jF_!;-9k!9a@^!;?Em!;ZWp
+!;lcr!;lct!<3&orr<&qrr<&srr<&urr<&rrr<&is7u`ms8N)nrr<&rrr<&rrr<&urr<&urr<&u
+rr<&krr<&nrr<&rrr<&srr<&nrr<&prr<&nrr<&krr<&errrK'!<3'!!<2uu!;uis!;QTo!:Bgd
+!;c]q!;c]q!;uis!;lcr!;?Em!;c]q!;HKn!;lcr!.k0us8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+l2LebrrDus!!)or!!)lq!!)lq!!)rs!!*#u!!*#u!!*#u!s&B$!9jF_!;-9k!9a@^!;?Em!;ZWp
+!;lcr!;lct!<3&orr<&qrr<&srr<&urr<&rrr<&is7u`ms8N)nrr<&rrr<&rrr<&urr<&urr<&u
+rr<&krr<&nrr<&rrr<&srr<&nrr<&prr<&nrr<&krr<&errrK'!<3'!!<2uu!;uis!;QTo!:Bgd
+!;c]q!;c]q!;uis!;lcr!;?Em!;c]q!;HKn!;lcr!.k0us8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+l2LebrrDus!!)or!!)lq!!)lq!!)rs!!*#u!!*#u!!*#u!s&B$!9jF_!;-9k!9a@^!;?Em!;ZWp
+!;lcr!;lct!<3&orr<&qrr<&srr<&urr<&rrr<&jrr<&qrr<&trrW9$rrDio!!)or!!)or!!*#u
+!!*#u!!*#u!!)Wj!!)or!s&B$!;lcr!;uis!;HKn!;ZWp!;HKn!;-9k!:Kjk!<3'!!<3&urr<&s
+rr<&srr<&srr<&irr<&srr<&rrr<&qrr<&srr<&rrr<&mrr<&qrr<&nrr<&rrr<%Ms3grI!:9`9~>
+l2LebrrDus!!)or!!)lq!!)lq!!)rs!!*#u!!*#u!!*#u!s&B$!9jF_!;-9k!9a@^!;?Em!;ZWp
+!;lcr!;lct!<3&orr<&qrr<&srr<&urr<&rrr<&jrr<&qrr<&trrW9$rrDio!!)or!!)or!!*#u
+!!*#u!!*#u!!)Wj!!)or!s&B$!;lcr!;uis!;HKn!;ZWp!;HKn!;-9k!:Kjk!<3'!!<3&urr<&s
+rr<&srr<&srr<&irr<&srr<&rrr<&qrr<&srr<&rrr<&mrr<&qrr<&nrr<&rrr<%Ms3grI!:9`9~>
+l2LebrrDus!!)or!!)lq!!)lq!!)rs!!*#u!!*#u!!*#u!s&B$!9jF_!;-9k!9a@^!;?Em!;ZWp
+!;lcr!;lct!<3&orr<&qrr<&srr<&urr<&rrr<&jrr<&qrr<&trrW9$rrDio!!)or!!)or!!*#u
+!!*#u!!*#u!!)Wj!!)or!s&B$!;lcr!;uis!;HKn!;ZWp!;HKn!;-9k!:Kjk!<3'!!<3&urr<&s
+rr<&srr<&srr<&irr<&srr<&rrr<&qrr<&srr<&rrr<&mrr<&qrr<&nrr<&rrr<%Ms3grI!:9`9~>
+kl1V_qYpNqrVlitq>UEpqYpNqrVultrr2rurr2rurr2rurr2rurVultn,E@fqYpNqrVlitq>^Hp
+nG`IgpAY*mq#:<orVlitq>UEpp\t3nqYpNqr;Q`srVlitrVultoD\djqYpNqrr2rurVlitq>UEp
+qYpNqrVlitrVlitrr2rurr2ruoDegjrVlitrVlitrVlitqu6Wrp\t3nq#:<orVultrVlitrVult
+qu6WrrVlito)A[irr2rurVlitrVultr;ZcsrVlito)J^irVlitqu6WrrVls"s8N)ts8N)rrr<&m
+rr<&trr<&urr<&ts8N)trr<&ts8N(Ms3grI!:9`9~>
+kl1V_qYpNqrVlitq>UEpqYpNqrVultrr2rurr2rurr2rurr2rurVultn,E@fqYpNqrVlitq>^Hp
+nG`IgpAY*mq#:<orVlitq>UEpp\t3nqYpNqr;Q`srVlitrVultoD\djqYpNqrr2rurVlitq>UEp
+qYpNqrVlitrVlitrr2rurr2ruoDegjrVlitrVlitrVlitqu6Wrp\t3nq#:<orVultrVlitrVult
+qu6WrrVlito)A[irr2rurVlitrVultr;ZcsrVlito)J^irVlitqu6WrrVls"s8N)ts8N)rrr<&m
+rr<&trr<&urr<&ts8N)trr<&ts8N(Ms3grI!:9`9~>
+kl1V_qYpNqrVlitq>UEpqYpNqrVultrr2rurr2rurr2rurr2rurVultn,E@fqYpNqrVlitq>^Hp
+nG`IgpAY*mq#:<orVlitq>UEpp\t3nqYpNqr;Q`srVlitrVultoD\djqYpNqrr2rurVlitq>UEp
+qYpNqrVlitrVlitrr2rurr2ruoDegjrVlitrVlitrVlitqu6Wrp\t3nq#:<orVultrVlitrVult
+qu6WrrVlito)A[irr2rurVlitrVultr;ZcsrVlito)J^irVlitqu6WrrVls"s8N)ts8N)rrr<&m
+rr<&trr<&urr<&ts8N)trr<&ts8N(Ms3grI!:9`9~>
+kl1V_q>^Bnqu?Kmr;Z]q"9/?$s8E#us8N*!s8N)us8;res7u`ns8;rms8N)hs82los7u`ms8;rm
+rr<&qs7u`ps8E#ts8E#ss8;ourrD]kr;cisr;ZitrW)uurW)osq>gHnr;cfrrW)uurrE*!rrDWi
+r;c`pr;ccqq>gKoq>gEmr;c]or;cWmr;cBf!!*#u!!)rsr;ZitrW)rt!<E/u!:g'i!<;utq>^Bn
+rVufr!<<#us8Voqq>^Bnr;Z]qqZ$Ko!ri6#JcF4!r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+kl1V_q>^Bnqu?Kmr;Z]q"9/?$s8E#us8N*!s8N)us8;res7u`ns8;rms8N)hs82los7u`ms8;rm
+rr<&qs7u`ps8E#ts8E#ss8;ourrD]kr;cisr;ZitrW)uurW)osq>gHnr;cfrrW)uurrE*!rrDWi
+r;c`pr;ccqq>gKoq>gEmr;c]or;cWmr;cBf!!*#u!!)rsr;ZitrW)rt!<E/u!:g'i!<;utq>^Bn
+rVufr!<<#us8Voqq>^Bnr;Z]qqZ$Ko!ri6#JcF4!r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+kl1V_q>^Bnqu?Kmr;Z]q"9/?$s8E#us8N*!s8N)us8;res7u`ns8;rms8N)hs82los7u`ms8;rm
+rr<&qs7u`ps8E#ts8E#ss8;ourrD]kr;cisr;ZitrW)uurW)osq>gHnr;cfrrW)uurrE*!rrDWi
+r;c`pr;ccqq>gKoq>gEmr;c]or;cWmr;cBf!!*#u!!)rsr;ZitrW)rt!<E/u!:g'i!<;utq>^Bn
+rVufr!<<#us8Voqq>^Bnr;Z]qqZ$Ko!ri6#JcF4!r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcDbM!!%TMJcC<$[/^.+m/MS~>
+JcDbM!!%TMJcC<$[/^.+m/MS~>
+JcDbM!!%TMJcC<$[/^.+m/MS~>
+JcDbM!!%TMJcC<$[/^.+m/MS~>
+JcDbM!!%TMJcC<$[/^.+m/MS~>
+JcDbM!!%TMJcC<$[/^.+m/MS~>
+JcDeN!!%TMJcC<$ZiBt(')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcDeN!!%TMJcC<$ZiBt(')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcDeN!!%TMJcC<$ZiBt(')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+JcDtSquD<JJcC<$ZN'q)m/MS~>
+JcDtSquD<JJcC<$ZN'q)m/MS~>
+JcDtSquD<JJcC<$ZN'q)m/MS~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+f)PaMkl:S]oDeah\c;[0p](0lJcC<$JcCi3rrDEcJ,~>
+f)PaMkl:S]oDeah\c;[0p](0lJcC<$JcCi3rrDEcJ,~>
+f)PaMkl:S]oDeah\c;[0p](0lJcC<$JcCi3rrDEcJ,~>
+mJm.cr;Z`ro`"mkl2L_`p\t3np\t3n\GlO/o`"mkmJd.dJcC<$JcDSHr;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+mJm.cr;Z`ro`"mkl2L_`p\t3np\t3n\GlO/o`"mkmJd.dJcC<$JcDSHr;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+mJm.cr;Z`ro`"mkl2L_`p\t3np\t3n\GlO/o`"mkmJd.dJcC<$JcDSHr;[K1!!*$!!<3$!rr<'!
+!!*$!!<7Q~>
+m/R(cr;ZcsoD\djlMghapAY*mp\t3n\GlO/o`"mkmJd.dJcC<$JcDSHrrDEcJ,~>
+m/R(cr;ZcsoD\djlMghapAY*mp\t3n\GlO/o`"mkmJd.dJcC<$JcDSHrrDEcJ,~>
+m/R(cr;ZcsoD\djlMghapAY*mp\t3n\GlO/o`"mkmJd.dJcC<$JcDSHrrDEcJ,~>
+m/I+errE&u!W`6#oD\djlMghali-qb\GlO/o`"mkmJd.dJcC<$JcDSHrrDEcJ,~>
+m/I+errE&u!W`6#oD\djlMghali-qb\GlO/o`"mkmJd.dJcC<$JcDSHrrDEcJ,~>
+m/I+errE&u!W`6#oD\djlMghali-qb\GlO/o`"mkmJd.dJcC<$JcDSHrrDEcJ,~>
+m/I+errE&u!W`6#rVufrqu6]ts8W#tr;Z]qqu?Kmr;Z`rp\t3nq>^Bnnc/Uh!<;utqu?TprVult
+#6+Z's8N'!rr;uu!<;utr;Qcts8;rnrr<&ps8;rps7u_Hs+13$s/H%s!##;3!<3$!rr<'!!!*$!
+!<3$!s*t~>
+m/I+errE&u!W`6#rVufrqu6]ts8W#tr;Z]qqu?Kmr;Z`rp\t3nq>^Bnnc/Uh!<;utqu?TprVult
+#6+Z's8N'!rr;uu!<;utr;Qcts8;rnrr<&ps8;rps7u_Hs+13$s/H%s!##;3!<3$!rr<'!!!*$!
+!<3$!s*t~>
+m/I+errE&u!W`6#rVufrqu6]ts8W#tr;Z]qqu?Kmr;Z`rp\t3nq>^Bnnc/Uh!<;utqu?TprVult
+#6+Z's8N'!rr;uu!<;utr;Qcts8;rnrr<&ps8;rps7u_Hs+13$s/H%s!##;3!<3$!rr<'!!!*$!
+!<3$!s*t~>
+m/I=ks8N*!!<<'!rr2rurVlitr;Q`srr2ruqu6WrrVlitqYpNqpAY*mp\t3nqYpNqrVlitnc/Uh
+rVlitrVlitrVlitrVults8W*!s8N'!rr;uurVlitrVultrVlitqYpNqqYpNqrVlitqYpNqJcC<$
+JcDSHrrDEcJ,~>
+m/I=ks8N*!!<<'!rr2rurVlitr;Q`srr2ruqu6WrrVlitqYpNqpAY*mp\t3nqYpNqrVlitnc/Uh
+rVlitrVlitrVlitrVults8W*!s8N'!rr;uurVlitrVultrVlitqYpNqqYpNqrVlitqYpNqJcC<$
+JcDSHrrDEcJ,~>
+m/I=ks8N*!!<<'!rr2rurVlitr;Q`srr2ruqu6WrrVlitqYpNqpAY*mp\t3nqYpNqrVlitnc/Uh
+rVlitrVlitrVlitrVults8W*!s8N'!rr;uurVlitrVultrVlitqYpNqqYpNqrVlitqYpNqJcC<$
+JcDSHrrDEcJ,~>
+m/I=ks8N*!!<<'!q>UEpr;Qj!s8N)rrr<&rrr<&rrr<&mrr<&nrr<&rrr<&rrr<&irr<&rrr<&p
+rr<&trr<&urr<&urr<&urr<&rrr<&urr<&srr<&qrr<&rrr<&rrr<&rrr<%Ms+13$s/#bq!:9`9~>
+m/I=ks8N*!!<<'!q>UEpr;Qj!s8N)rrr<&rrr<&rrr<&mrr<&nrr<&rrr<&rrr<&irr<&rrr<&p
+rr<&trr<&urr<&urr<&urr<&rrr<&urr<&srr<&qrr<&rrr<&rrr<&rrr<%Ms+13$s/#bq!:9`9~>
+m/I=ks8N*!!<<'!q>UEpr;Qj!s8N)rrr<&rrr<&rrr<&mrr<&nrr<&rrr<&rrr<&irr<&rrr<&p
+rr<&trr<&urr<&urr<&urr<&rrr<&urr<&srr<&qrr<&rrr<&rrr<&rrr<%Ms+13$s/#bq!:9`9~>
+m/I%crr2rurr2rurr;iqr;Z`rqZ$?kqu6WrpAY*mp\t3nqu?Hlo)A[iqu6Wrrr;iqrVlitrr2ru
+rr2rurr2ruqu6Wrrr2rur;Q`sqYpNqqu?Hlqu6WrJcC<$JcDSHr;[K1!!*$!!<3$!rr<'!!!*$!
+!<7Q~>
+m/I%crr2rurr2rurr;iqr;Z`rqZ$?kqu6WrpAY*mp\t3nqu?Hlo)A[iqu6Wrrr;iqrVlitrr2ru
+rr2rurr2ruqu6Wrrr2rur;Q`sqYpNqqu?Hlqu6WrJcC<$JcDSHr;[K1!!*$!!<3$!rr<'!!!*$!
+!<7Q~>
+m/I%crr2rurr2rurr;iqr;Z`rqZ$?kqu6WrpAY*mp\t3nqu?Hlo)A[iqu6Wrrr;iqrVlitrr2ru
+rr2rurr2ruqu6Wrrr2rur;Q`sqYpNqqu?Hlqu6WrJcC<$JcDSHr;[K1!!*$!!<3$!rr<'!!!*$!
+!<7Q~>
+m/I%crr2rurr3'#s8N)srr<&srrW9$rrDrr!!)Zk!!)`m!!)cn!!)or!!)?b!!)or!s&B$!;uis
+!<)ot!<2uu!<2uu!<2uu!;lcr!<2uu!;uis!;c]q!;lcr!;-9k!.k0$s+13Hs8N)cs*t~>
+m/I%crr2rurr3'#s8N)srr<&srrW9$rrDrr!!)Zk!!)`m!!)cn!!)or!!)?b!!)or!s&B$!;uis
+!<)ot!<2uu!<2uu!<2uu!;lcr!<2uu!;uis!;c]q!;lcr!;-9k!.k0$s+13Hs8N)cs*t~>
+m/I%crr2rurr3'#s8N)srr<&srrW9$rrDrr!!)Zk!!)`m!!)cn!!)or!!)?b!!)or!s&B$!;uis
+!<)ot!<2uu!<2uu!<2uu!;lcr!<2uu!;uis!;c]q!;lcr!;-9k!.k0$s+13Hs8N)cs*t~>
+m/I%cqYpWts8N)srr<&srr<&urr<&srr<&krr<&mrr<&nrr<&rrr<&brr<&rrrW9$rrDus!!)ut
+!!*#u!!*#u!!*#u!!)or!!*#u!!)rs!!)lq!!)or!!)Zk!!%TMJcC<$V>pPqm/MS~>
+m/I%cqYpWts8N)srr<&srr<&urr<&srr<&krr<&mrr<&nrr<&rrr<&brr<&rrrW9$rrDus!!)ut
+!!*#u!!*#u!!*#u!!)or!!*#u!!)rs!!)lq!!)or!!)Zk!!%TMJcC<$V>pPqm/MS~>
+m/I%cqYpWts8N)srr<&srr<&urr<&srr<&krr<&mrr<&nrr<&rrr<&brr<&rrrW9$rrDus!!)ut
+!!*#u!!*#u!!*#u!!)or!!*#u!!)rs!!)lq!!)or!!)Zk!!%TMJcC<$V>pPqm/MS~>
+m/I%cqYpWts8N)ts8N)srr<&trr<&srr<&ts8N)rrr<&mrr<&nrr<&qrr<&ts8N)rs8N)qs8N)t
+rr<&urr<&ts8N)trr<&urr<&urr<&us8N)trr<&trr<&srr<&qrr<&qrr<&ts8N)rrr<&trr<%M
+s+13$s/Q+t!##;3!<3$!rr<'!!!*$!!<3$!s*t~>
+m/I%cqYpWts8N)ts8N)srr<&trr<&srr<&ts8N)rrr<&mrr<&nrr<&qrr<&ts8N)rs8N)qs8N)t
+rr<&urr<&ts8N)trr<&urr<&urr<&us8N)trr<&trr<&srr<&qrr<&qrr<&ts8N)rrr<&trr<%M
+s+13$s/Q+t!##;3!<3$!rr<'!!!*$!!<3$!s*t~>
+m/I%cqYpWts8N)ts8N)srr<&trr<&srr<&ts8N)rrr<&mrr<&nrr<&qrr<&ts8N)rs8N)qs8N)t
+rr<&urr<&ts8N)trr<&urr<&urr<&us8N)trr<&trr<&srr<&qrr<&qrr<&ts8N)rrr<&trr<%M
+s+13$s/Q+t!##;3!<3$!rr<'!!!*$!!<3$!s*t~>
+mJm+brr;oss8W#t!<<#us8W*!rr;osrVufrqu?KmrVu]orVu]or;Z]qq>^HpqYpQrs8;rqs8;ot
+s8Duus8E#us8N*!s8N*!rrE-"r;cfrrW)rtrW)rtq>gHnr;cWmr;_EKJcC<$WW2tum/MS~>
+mJm+brr;oss8W#t!<<#us8W*!rr;osrVufrqu?KmrVu]orVu]or;Z]qq>^HpqYpQrs8;rqs8;ot
+s8Duus8E#us8N*!s8N*!rrE-"r;cfrrW)rtrW)rtq>gHnr;cWmr;_EKJcC<$WW2tum/MS~>
+mJm+brr;oss8W#t!<<#us8W*!rr;osrVufrqu?KmrVu]orVu]or;Z]qq>^HpqYpQrs8;rqs8;ot
+s8Duus8E#us8N*!s8N*!rrE-"r;cfrrW)rtrW)rtq>gHnr;cWmr;_EKJcC<$WW2tum/MS~>
+M#RGTiVrlXJcC<$JcC<$p](6nm/MS~>
+M#RGTiVrlXJcC<$JcC<$p](6nm/MS~>
+M#RGTiVrlXJcC<$JcC<$p](6nm/MS~>
+M#RGTiVrlXJcC<$JcC<$p](0l')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+M#RGTiVrlXJcC<$JcC<$p](0l')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+M#RGTiVrlXJcC<$JcC<$p](0l')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+M#RGTiVrlXJcC<$JcC<$p](6nm/MS~>
+M#RGTiVrlXJcC<$JcC<$p](6nm/MS~>
+M#RGTiVrlXJcC<$JcC<$p](6nm/MS~>
+M?!MSjT#/YJcC<$JcC<$q>^Hpm/MS~>
+M?!MSjT#/YJcC<$JcC<$q>^Hpm/MS~>
+M?!MSjT#/YJcC<$JcC<$q>^Hpm/MS~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*rrDEcJ,~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC<$JcC<$JcFO*r;[K1!!*$!!<3$!rr<'!!!*$!!<7Q~>
+JcC`0rW)corW)corrDcmrr@WMJcC<$p&G$lm/MS~>
+JcC`0rW)corW)corrDcmrr@WMJcC<$p&G$lm/MS~>
+JcC`0rW)corW)corrDcmrr@WMJcC<$p&G$lm/MS~>
+bl@VArr;os!<;iprr;fpqZ$Np!WN/us7u`ms8E#rs8E#us8;rRs8;rArr<&drr<&urr<&rrr<&u
+rr<&ss8N'"rrDfn!W`6#JcC<$JcGECrrDEcJ,~>
+bl@VArr;os!<;iprr;fpqZ$Np!WN/us7u`ms8E#rs8E#us8;rRs8;rArr<&drr<&urr<&rrr<&u
+rr<&ss8N'"rrDfn!W`6#JcC<$JcGECrrDEcJ,~>
+bl@VArr;os!<;iprr;fpqZ$Np!WN/us7u`ms8E#rs8E#us8;rRs8;rArr<&drr<&urr<&rrr<&u
+rr<&ss8N'"rrDfn!W`6#JcC<$JcGECrrDEcJ,~>
+bPqPBqYpNqrr2rur;Q`srVlitr;Q`sr;Q`srr;uuqYpNqqZ$Qqrr;uurVultrVlitg&D$Pbl7YC
+mf*7er;Q`srVlitr;Q`sqYpNqp\t9prr@WMJcC<$p&Fsj')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+bPqPBqYpNqrr2rur;Q`srVlitr;Q`sr;Q`srr;uuqYpNqqZ$Qqrr;uurVultrVlitg&D$Pbl7YC
+mf*7er;Q`srVlitr;Q`sqYpNqp\t9prr@WMJcC<$p&Fsj')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+bPqPBqYpNqrr2rur;Q`srVlitr;Q`sr;Q`srr;uuqYpNqqZ$Qqrr;uurVultrVlitg&D$Pbl7YC
+mf*7er;Q`srVlitr;Q`sqYpNqp\t9prr@WMJcC<$p&Fsj')qq3rr<'!!!*$!!<3$!rr<'!J,~>
+bPqPBqYpNqrr2rur;Q`srVlitr;Q`srVlitr;Q`sqYpNqqYpNqr;Q`srVlp!rrE&u!!(aQ!W`6#
+c2RbDmf*7er;Q`srVlitr;Q`sqYpNqq#:Ers8N(Ms+13$s7QEl!:9`9~>
+bPqPBqYpNqrr2rur;Q`srVlitr;Q`srVlitr;Q`sqYpNqqYpNqr;Q`srVlp!rrE&u!!(aQ!W`6#
+c2RbDmf*7er;Q`srVlitr;Q`sqYpNqq#:Ers8N(Ms+13$s7QEl!:9`9~>
+bPqPBqYpNqrr2rur;Q`srVlitr;Q`srVlitr;Q`sqYpNqqYpNqr;Q`srVlp!rrE&u!!(aQ!W`6#
+c2RbDmf*7er;Q`srVlitr;Q`sqYpNqq#:Ers8N(Ms+13$s7QEl!:9`9~>
+b5VGAr;Q`srVlitr;Q`srVlitr;Q`srVlito`"mkqu6WrqYpNqrr3$"rrE&u!!(aQ!W`6#r;Zcs
+rVultr;Z]q#6+Z's8N'!rVultr;Z]q!WN/us7u`^rr<&trr<&srr<&qrr<&orrW9$rr@WMJcC<$
+p&G$lm/MS~>
+b5VGAr;Q`srVlitr;Q`srVlitr;Q`srVlito`"mkqu6WrqYpNqrr3$"rrE&u!!(aQ!W`6#r;Zcs
+rVultr;Z]q#6+Z's8N'!rVultr;Z]q!WN/us7u`^rr<&trr<&srr<&qrr<&orrW9$rr@WMJcC<$
+p&G$lm/MS~>
+b5VGAr;Q`srVlitr;Q`srVlitr;Q`srVlito`"mkqu6WrqYpNqrr3$"rrE&u!!(aQ!W`6#r;Zcs
+rVultr;Z]q#6+Z's8N'!rVultr;Z]q!WN/us7u`^rr<&trr<&srr<&qrr<&orrW9$rr@WMJcC<$
+p&G$lm/MS~>
+b5VGAr;Q`srVls"s8N)qrr<&trr<&rrr<&lrr<&rrr<&qrr<&urrrK'rrE*!!;$6c!:p-i!<2uu
+!;uis!;uis!<)ot!<)rt!<)ot!;uis!<)ot!<)rt!;lcr!9sL`!;uis!;uis!;c]q!;ZWp!<2uu
+!.k0$s+14Cs8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+b5VGAr;Q`srVls"s8N)qrr<&trr<&rrr<&lrr<&rrr<&qrr<&urrrK'rrE*!!;$6c!:p-i!<2uu
+!;uis!;uis!<)ot!<)rt!<)ot!;uis!<)ot!<)rt!;lcr!9sL`!;uis!;uis!;c]q!;ZWp!<2uu
+!.k0$s+14Cs8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+b5VGAr;Q`srVls"s8N)qrr<&trr<&rrr<&lrr<&rrr<&qrr<&urrrK'rrE*!!;$6c!:p-i!<2uu
+!;uis!;uis!<)ot!<)rt!<)ot!;uis!<)ot!<)rt!;lcr!9sL`!;uis!;uis!;c]q!;ZWp!<2uu
+!.k0$s+14Cs8;p1rr<'!!!*$!!<3$!rr<'!!!*%L~>
+ao;>@rr2rur;Z]qqZ$Hnq>^Bnq>UEpqu6WrqYpNqrr30&s8N*!rrCgR!!*#u!!)rs!!)rs!!*#u
+!!)or!!)ut!!)rs!!)ut!!)rs!!)or!!)<a!!)or!!)rs!!)lq!!)ip!!*#u!!%TMJcC<$p&G$l
+m/MS~>
+ao;>@rr2rur;Z]qqZ$Hnq>^Bnq>UEpqu6WrqYpNqrr30&s8N*!rrCgR!!*#u!!)rs!!)rs!!*#u
+!!)or!!)ut!!)rs!!)ut!!)rs!!)or!!)<a!!)or!!)rs!!)lq!!)ip!!*#u!!%TMJcC<$p&G$l
+m/MS~>
+ao;>@rr2rur;Z]qqZ$Hnq>^Bnq>UEpqu6WrqYpNqrr30&s8N*!rrCgR!!*#u!!)rs!!)rs!!*#u
+!!)or!!)ut!!)rs!!)ut!!)rs!!)or!!)<a!!)or!!)rs!!)lq!!)ip!!*#u!!%TMJcC<$p&G$l
+m/MS~>
+ao;>@rr2rur;Qj!s8N)qrr<&trr<&mrr<&qrr<&rrr<&qrr<&urr<&urrN3#!8RSS!;uis!<)ot
+!;uis!<2uu!;lcr!<)ot!;uis!;ulr!;QQo!:0Xb!;c]q!;uis!;c]q!;c]q!<)ot!.k0$s+14C
+s8N)cs*t~>
+ao;>@rr2rur;Qj!s8N)qrr<&trr<&mrr<&qrr<&rrr<&qrr<&urr<&urrN3#!8RSS!;uis!<)ot
+!;uis!<2uu!;lcr!<)ot!;uis!;ulr!;QQo!:0Xb!;c]q!;uis!;c]q!;c]q!<)ot!.k0$s+14C
+s8N)cs*t~>
+ao;>@rr2rur;Qj!s8N)qrr<&trr<&mrr<&qrr<&rrr<&qrr<&urr<&urrN3#!8RSS!;uis!<)ot
+!;uis!<2uu!;lcr!<)ot!;uis!;ulr!;QQo!:0Xb!;c]q!;uis!;c]q!;c]q!<)ot!.k0$s+14C
+s8N)cs*t~>
+aSu;ArrDrr!!)rs!!)ut!!)ut!!)]l!!)or!!)or!!)lq!!*#u!!*#u!W`6#oDeRcoDeXerVlit
+r;Q`srr2ruqu6WrrVlitr;Q`sq>^HpqYpNqm/I%cq>UEpr;Q`sqYpNqqZ$BlJcC<$JcGHDr;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+aSu;ArrDrr!!)rs!!)ut!!)ut!!)]l!!)or!!)or!!)lq!!*#u!!*#u!W`6#oDeRcoDeXerVlit
+r;Q`srr2ruqu6WrrVlitr;Q`sq>^HpqYpNqm/I%cq>UEpr;Q`sqYpNqqZ$BlJcC<$JcGHDr;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+aSu;ArrDrr!!)rs!!)ut!!)ut!!)]l!!)or!!)or!!)lq!!*#u!!*#u!W`6#oDeRcoDeXerVlit
+r;Q`srr2ruqu6WrrVlitr;Q`sq>^HpqYpNqm/I%cq>UEpr;Q`sqYpNqqZ$BlJcC<$JcGHDr;[K1
+!!*$!!<3$!rr<'!!!*$!!<7Q~>
+aSu;ArrDrr!!)rs!!)ut!!)rs!!)ut!!)or!!)or!!)lq!!)rs!!)ut!!)utrrCmT!!)lq!!*#u
+!!)rs!!*#u!!)or!!)ut!!)rs!!)ut!!)rs!!)or!!)Ed!!)fo!!)rs!!)lq!!)]l!!%TMJcC<$
+p&G$lm/MS~>
+aSu;ArrDrr!!)rs!!)ut!!)rs!!)ut!!)or!!)or!!)lq!!)rs!!)ut!!)utrrCmT!!)lq!!*#u
+!!)rs!!*#u!!)or!!)ut!!)rs!!)ut!!)rs!!)or!!)Ed!!)fo!!)rs!!)lq!!)]l!!%TMJcC<$
+p&G$lm/MS~>
+aSu;ArrDrr!!)rs!!)ut!!)rs!!)ut!!)or!!)or!!)lq!!)rs!!)ut!!)utrrCmT!!)lq!!*#u
+!!)rs!!*#u!!)or!!)ut!!)rs!!)ut!!)rs!!)or!!)Ed!!)fo!!)rs!!)lq!!)]l!!%TMJcC<$
+p&G$lm/MS~>
+a8Z,>qYpNqr;Q`srVlitr;Q`srVultrVlitqYpNqqZ$Qqrr;uurVlitrVulth>[HTqYpNqrr2ru
+rVultrVlitrVultrVlitrVultrVultrVlitqu6WrrVlitoD\djr;Q`sr;Q`srr2ruq>UEpp&>!l
+JcC<$JcGECl2Z>~>
+a8Z,>qYpNqr;Q`srVlitr;Q`srVultrVlitqYpNqqZ$Qqrr;uurVlitrVulth>[HTqYpNqrr2ru
+rVultrVlitrVultrVlitrVultrVultrVlitqu6WrrVlitoD\djr;Q`sr;Q`srr2ruq>UEpp&>!l
+JcC<$JcGECl2Z>~>
+a8Z,>qYpNqr;Q`srVlitr;Q`srVultrVlitqYpNqqZ$Qqrr;uurVlitrVulth>[HTqYpNqrr2ru
+rVultrVlitrVultrVlitrVultrVultrVlitqu6WrrVlitoD\djr;Q`sr;Q`srr2ruq>UEpp&>!l
+JcC<$JcGECl2Z>~>
+a8Z,>qu?Hlrr;osrVults8N*"s8;rqs7u`ms8E#rs8;rsrr<&Us8;rss8;rss8;p!rr<&ts8;ou
+rrDusr;Zp!!!*#u!<E/u!;ZZn!;$6d!;lfq!;lfm!;c`o!.k0$s+14Ds69T7~>
+a8Z,>qu?Hlrr;osrVults8N*"s8;rqs7u`ms8E#rs8;rsrr<&Us8;rss8;rss8;p!rr<&ts8;ou
+rrDusr;Zp!!!*#u!<E/u!;ZZn!;$6d!;lfq!;lfm!;c`o!.k0$s+14Ds69T7~>
+a8Z,>qu?Hlrr;osrVults8N*"s8;rqs7u`ms8E#rs8;rsrr<&Us8;rss8;rss8;p!rr<&ts8;ou
+rrDusr;Zp!!!*#u!<E/u!;ZZn!;$6d!;lfq!;lfm!;c`o!.k0$s+14Ds69T7~>
+JcEOc!!%TMJcC<$T)\fj'`S15!<3'!!<3'!!<3'!!<3'!!<7Q~>
+JcEOc!!%TMJcC<$T)\fj'`S15!<3'!!<3'!!<3'!!<3'!!<7Q~>
+JcEOc!!%TMJcC<$T)\fj'`S15!<3'!!<3'!!<3'!!<3'!!<7Q~>
+JcEOc!!%TMJcC<$T)\ci'E8(4!<3'!!<3'!!<3'!!<3'!!.Y~>
+JcEOc!!%TMJcC<$T)\ci'E8(4!<3'!!<3'!!<3'!!<3'!!.Y~>
+JcEOc!!%TMJcC<$T)\ci'E8(4!<3'!!<3'!!<3'!!<3'!!.Y~>
+JcERd!!%TMJcC<$ScA]i!WN/is8N'!s*t~>
+JcERd!!%TMJcC<$ScA]i!WN/is8N'!s*t~>
+JcERd!!%TMJcC<$ScA]i!WN/is8N'!s*t~>
+JcEaiquD<JJcC<$SH&Qgrr3N0rrE'!rrE'!rrE'!rrE'!J,~>
+JcEaiquD<JJcC<$SH&Qgrr3N0rrE'!rrE'!rrE'!rrE'!J,~>
+JcEaiquD<JJcC<$SH&Qgrr3N0rrE'!rrE'!rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rr<W1!<3'!!<3'!!<3'!!<3'!rVuruJ,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rW)rt!s&?$s82j%rrE'!rrE'!J,~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rW)rt!!)QhJ,~>
+JcC<$JcC<$JcFO*rW)rt!!)QhJ,~>
+JcC<$JcC<$JcFO*rW)rt!!)QhJ,~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rW)rt!!)Wj!I4Wp~>
+JcC<$JcC<$JcFO*rW)rt!!)Wj!I4Wp~>
+JcC<$JcC<$JcFO*rW)rt!!)Wj!I4Wp~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;6?nGV&lF~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;6?nGV&lF~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;6?nGV&lF~>
+JcC<$JcC<$JcFO*rW)rt!!)]l"*Q6Ns*t~>
+JcC<$JcC<$JcFO*rW)rt!!)]l"*Q6Ns*t~>
+JcC<$JcC<$JcFO*rW)rt!!)]l"*Q6Ns*t~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;HKrFtDGKs*t~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;HKrFtDGKs*t~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;HKrFtDGKs*t~>
+JcC<$JcC<$JcFO*rW)rt!!)cn"`Q$Js*4Qo~>
+JcC<$JcC<$JcFO*rW)rt!!)cn"`Q$Js*4Qo~>
+JcC<$JcC<$JcFO*rW)rt!!)cn"`Q$Js*4Qo~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;ZX!CFe3?GV&lF~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;ZX!CFe3?GV&lF~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;ZX!CFe3?GV&lF~>
+JcC<$JcC<$JcFO*rW)rt!!)ip#AYjFs)TaHs*t~>
+JcC<$JcC<$JcFO*rW)rt!!)ip#AYjFs)TaHs*t~>
+JcC<$JcC<$JcFO*rW)rt!!)ip#AYjFs)TaHs*t~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;ld%CFe3?F"?&Gs*t~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;ld%CFe3?F"?&Gs*t~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!;ld%CFe3?F"?&Gs*t~>
+JcC<$JcC<$JcFO*rW)rt!!)or$"YXBs)T^Gs)\3j~>
+JcC<$JcC<$JcFO*rW)rt!!)or$"YXBs)T^Gs)\3j~>
+JcC<$JcC<$JcFO*rW)rt!!)or$"YXBs)T^Gs)\3j~>
+JcC<$JcC<$JcFO*rr<'!quH]q$?I`Qs)T^Gs)T^jJ,~>
+JcC<$JcC<$JcFO*rr<'!quH]q$?I`Qs)T^Gs)T^jJ,~>
+JcC<$JcC<$JcFO*rr<'!quH]q$?I`Qs)T^Gs)T^jJ,~>
+JcC<$JcC<$JcFO*rW!'#!<3&trsNluh#DFGh#DFGh#Dm~>
+JcC<$JcC<$JcFO*rW!'#!<3&trsNluh#DFGh#DFGh#Dm~>
+JcC<$JcC<$JcFO*rW!'#!<3&trsNluh#DFGh#DFGh#Dm~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+JcC<$JcC<$JcFO*rr<6&!<3'!!:p/?~>
+%%EndData
+showpage
+%%Trailer
+end
+%%EOF
diff --git a/changelog b/changelog
index add2de2..af78717 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,122 @@
+20140727 tpd src/axiom-website/patches.html 20140727.02.tpd.patch
+20140727 tpd src/axiom-website/download.html update table, add MACOSX
+20140727 tpd src/axiom-website/releasenotes.html add august release notes
+20140727 tpd books/ps/v71aug2014.eps add the august 2014 image
+20140727 tpd books/bookvol7.1 add August 2014 to What's New page
+20140727 tpd books/bookvol13 add OCAML gcd code
+20150727 tpd src/axiom-website/documentation.html add Volume 8.1
+20140727 tpd Makefile VERSION:="Axiom (August 2014)"
+20140727 tpd en.wikipedia.org/wiki/Axiom_(computer_algebra_system) update
+20140727 tpd en.wikipedia.org/wiki/List_of_computer_algebra_systems update
+20140727 tpd zips/gcl-2.4.1.h.386-linux.defs.patch deleted
+20140727 tpd zips/gcl-2.4.1.h.386-linux.h.patch deleted
+20140727 tpd zips/gcl-2.4.1.unixport.init_gcl.lsp.patch deleted
+20140727 tpd zips/gcl-2.4.1.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.5.2.cmpnew.cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.5.2.cmpnew.cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.5.2.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.5.2.h.linux.h.patch deleted
+20140727 tpd zips/gcl-2.5.2.o.cmpaux.c.patch deleted
+20140727 tpd zips/gcl-2.5.2.o.main.c.patch deleted
+20140727 tpd zips/gcl-2.5.2.o.package.d.patch deleted
+20140727 tpd zips/gcl-2.5.2.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.5.2.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.5.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.5.h.linux.h.patch deleted
+20140727 tpd zips/gcl-2.5.o.xdrfuns.c.patch deleted
+20140727 tpd zips/gcl-2.5.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.5.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.1.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.1.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.1.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.1.o.main.c.patch deleted
+20140727 tpd zips/gcl-2.6.1.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.1.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.10.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.10.lsp.gcl_top.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.10.o.read.d.patch deleted
+20140727 tpd zips/gcl-2.6.10.tgz deleted
+20140727 tpd zips/gcl-2.6.10.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.2.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.2.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.2.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.2.o.main.c.patch deleted
+20140727 tpd zips/gcl-2.6.2.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.2.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.2a.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.2a.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.2a.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.2a.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.2a.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.3.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.3.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.3.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.3.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.3.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.5.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.5.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.5.cmpnew.gcl_cmpmain.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.5.h.386-linux.h.patch deleted
+20140727 tpd zips/gcl-2.6.5.h.gmp_wrappers.h.patch deleted
+20140727 tpd zips/gcl-2.6.5.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.5.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.5.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.5w.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.5w.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.5w.h.gmp_wrappers.h.patch deleted
+20140727 tpd zips/gcl-2.6.5w.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.5w.h.mingw.defs.patch deleted
+20140727 tpd zips/gcl-2.6.5w.o.alloc.c.patch deleted
+20140727 tpd zips/gcl-2.6.5w.o.mingfile.c.patch deleted
+20140727 tpd zips/gcl-2.6.5w.o.unixfsys.c.patch deleted
+20140727 tpd zips/gcl-2.6.5w.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.5w.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.6.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.6.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.6.cmpnew.gcl_cmpmain.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.6.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.6.h.linux.h.patch deleted
+20140727 tpd zips/gcl-2.6.6.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.6.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.7.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.7.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.7.configure.in.patch deleted
+20140727 tpd zips/gcl-2.6.7.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.7.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.7.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.7pre.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.7pre.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.7pre.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.7pre.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.7pre.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.cmpnew.gcl_cmpcall.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.configure.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.configure.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.h.powerpc-macosx.defs.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.8pre2.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.8pre2.configure.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre2.configure.patch deleted
+20140727 tpd zips/gcl-2.6.8pre2.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.8pre2.tgz deleted
+20140727 tpd zips/gcl-2.6.8pre2.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre2.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.cmpnew.gcl_cmpflet.lsp.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.configure.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.configure.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.o.read.d.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.tgz deleted
+20140727 tpd zips/gcl-2.6.8pre3.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre3.unixport.makefile.patch deleted
+20140727 tpd zips/gcl-2.6.8pre4.h.linux.defs.patch deleted
+20140727 tpd zips/gcl-2.6.8pre4.o.read.d.patch deleted
+20140727 tpd zips/gcl-2.6.8pre4.tgz deleted
+20140727 tpd zips/gcl-2.6.8pre4.unixport.init_gcl.lsp.in.patch deleted
+20140727 tpd zips/gcl-2.6.8pre4.unixport.makefile.patch deleted
 20140727 tpd src/axiom-website/patches.html 20140727.01.tpd.patch
 20140727 tpd Makefile rename tangle.c to tanglec.c
 20140727 tpd books/extract rename tangle.c to tanglec.c
diff --git a/patch b/patch
index d19918e..800bcad 100644
--- a/patch
+++ b/patch
@@ -1,4 +1,466 @@
-Makefiles, tanglec move tangle.c to tanglec.c to avoid gcl
+August 2014 release notes
+
+This release moves Axiom to the latest GCL version.
+All unused prior versions were removed.
+
+Most of the work involved in this release has involved CATS,
+working with Albert Rich to develop Axiom tests.
+
+Noweb was removed. Axiom now uses its own literate tools.
+
+The databases are no longer compressed.
+
+Volume 13: Proving Axiom Correct was started
+
+Makefile.pamphlet
+   VERSION = August 2014
+   TESTSET defaults to regresstests
+   fix missing dvipdfm
+   remove noweb
+
+book/
+   new directory containing axiom-developer emails
+   reduce and categorize emails for history
+   create timeline of people joining/leaving
+
+books/
+   axiom.sty
+      document
+      remove all other sources
+      add additional macros
+   axbook.tgz
+      fix sinCosExpandRules
+   dvipdfm.def
+      added
+   tanglec.c
+      new C function to handle chunks
+   tangle.lisp
+      add fastxhtml extraction from bookvol11
+   extract (rename from document)
+      support new chunk syntax
+   ps/
+      move .ps to .eps 
+      add new images
+
+books/Makefile
+   handle bookheader.tex
+   fix broken sed regular expression
+   add bookvol13 (Proving Axiom Correct)
+
+books/bookheader.tex
+   user underline, colored links
+   standardize headers, table of contents
+
+books/bookvol0 (Jenks)
+   add condata for MAGCDOC
+   add graphics, fix typos, add text
+
+books/bookvol1 (tutorial)
+   use bookheader.tex
+   fix typos
+
+books/bookvol2 (users guide)
+   use bookheader.tex
+   add category theory chapter
+   remove noweb
+
+books/bookvol3 (programmers guide)
+   use bookheader.tex
+   remove noweb
+
+books/bookvol4 (developers guide)
+   use bookheader.tex
+   section on changing GCL versions
+   document makeHelpFiles
+   remove autoload files
+   remove noweb
+   add HACKPI section
+
+books/bookvol5 (interpreter)
+   use bookheader.tex
+   fix GETL for GCL
+   add Attributes as Categories
+   add Comparable
+   add LeftOreRing
+   add U32Matrix support macros
+   add bc-matrix code
+   add support code for U8Vector
+   add support code for U32Vector
+   add support code for U8Matrix
+   add support code for U16Matrix
+   add U32VectorPolyunomialOperations
+   expose FiniteFieldFactorization
+   expose MAGCDOC
+   expose MatrixManipulation
+   rename functionp to canFuncall?
+   incremental rewrite of br-con.lisp
+   merge ht-util.lisp
+
+books/bookvol6 (commands)
+   use bookheader.tex
+
+books/bookvol7 (hyperdoc)
+   apply Camm's patches
+   remove bibliography
+   standardize the table of contents
+   update credits
+   use bookheader.tex
+
+books/bookvol7.1 (hyperdoc pages)
+   standardize the table of contents
+   update What's New Page
+   update credits
+   use bookheader.tex
+
+books/bookvol8 (graphics)
+   apply Camm's patches
+   convert bookvol8 from noweb to chunks
+   remove crc test cases
+   standardize the table of contents
+   update credits
+   use bookheader.tex
+   remove noweb
+
+books/bookvol8.1 (graphics gallery)
+   add CRC standard test cases, section 2.3-2.9
+
+books/bookvol9 (compiler)
+   use bookheader.tex
+   functionp -> canFuncall?
+
+books/bookvol10 (algebra implementation)
+   absorb src/algebra/Makefile
+   use bookheader.tex
+
+books/bookvol10.1 (algebra theory)
+   add interval arithmetic
+   add section on interpolation formulas
+   use bookheader.tex
+
+books/bookvol10.2 (categories)
+   AGG bug fixed 40355
+   CLAGG bug fixed 40021
+   MONAD bug fix 40350, add 7236
+   ORDSET bug fix 40346
+   PTRANFN bug fixed 40357
+   REAL bug fix 40345
+   add Attributes as Categories
+   add Comparable
+   add LeftOreRing
+   add MAGCDOC
+   add enumerate to FINITE
+   add matrix initializer function
+   fix failing test cases
+   fix help documentation and regression tests
+   use bookheader.tex
+   write help documentation for all categories
+   FiniteSetAggregate subset? fixed
+   BinaryTreeCategory remove finiteAggregate, bug fix 7255
+
+books/bookvol10.3 (domains)
+   AFFSP bug fix 30230, 20495; introduce 60076
+   BLAS1 bug fixed 40304
+   CHAR bug fix 40022
+   DFLOAT bug fix 20073, add 20570
+   DFLOAT bug fixed 40019
+   FPS bug fixed 40013
+   INBFF bug fixed 20465, add 20571
+   INTRVL bug fix 20480, 30143
+   ITAYLOR bug fix 20542 pretend
+   LIST bug fix 20063, add, add 20569
+   MLIFT bug fix 20001, add 20568
+   OPTPROB bug fix 40347
+   RNUMP removed bug fix 30047
+   SINT bug fix 20057 pretend
+   SMTS bug fix 20383, 50005, add 20567
+   SYMBOL bug fix 20056 pretend
+   add U16Matrix
+   add U16Vector
+   add U32Matrix
+   add U8Matrix
+   add U8Vector
+   add information to SingleInteger
+   SEXOF bug fix 20501
+   fix failing test cases
+   fix help documentation and regression tests
+   move EFULS EFUPXS from package to domain
+   update U32Vector domain
+   use bookheader.tex
+   write help documentation for all domains
+
+books/bookvol10.4 (packages)
+   ATTREG bug fix 40362
+   ELTAB bug fix 40360
+   FSPECF bug fix 7235, 40077
+   GRAY bug fixed 20467
+   MAPPKG1 bug fix 40351
+   MSYSCMD bug fix 40359
+   SOLVERAD bug fix 40043
+   SREGSET bug fix 50001
+   add FiniteFieldFactorization
+   add MatrixManipulation, add Raoul Bourquin
+   add U32VectorPolynomialOperations
+   apply Waldek's changes to imposelc in PGCD
+   comment out bad code in GUESS
+   document htrigs function in TRMANIP
+   expand hyperbolic identities
+   bug fix "bad reduction" in multivariate poly gcd
+   bug fix ++X function example in gcd
+   bug fix OUT.spad warning (bug 329)
+   bug fix failing test cases
+   bug fix help documentation and regression tests
+   move EFULS EFUPXS from package to domain
+   use bookheader.tex
+   write help documentation
+   add reportInstantiations to API package
+
+books/bookvol10.5 (numerics)
+   add netlib cephes function covers
+   use bookheader.tex
+
+books/bookvol11 (browser)
+   use bookheader.tex
+   remove noweb
+
+books/bookvol12 (crystal)
+   remove noweb
+
+books/bookvol13 (proving axiom correct)
+   created
+
+books/bookvolbib (bibliography)
+   add references and abstracts
+   add subsection Ore Rings 
+   add subsection Partial Fraction Decomposition
+   add subsection Integration
+   add subsection Expression Simplification
+   add subsection Differential Equations
+   add subsection Advanced Documentation
+   add subsection Numerics
+   add subsection Interval Arithmetic
+   add subsection Proving Axiom Correct
+   add subsection Category Theory
+   add subsection Polynomial GCD
+   add subsection Exponenetial Integral
+   add subsection Special Functions
+   add subsection Numerical Algorithms
+   add subsection Solving Systems of Equations
+
+buglist
+   MLIFT fix 20001, add 20568
+   AGG fixed 40355
+   ATTREG fix 40362
+   BLAS1 fixed 40304
+   CHAR fix 40022
+   CLAGG fixed 40021
+   DFLOAT fix 20073, add 20570
+   DFLOAT fixed 40019
+   ELTAB fix 40360
+   FPS fixed 40013
+   FSPECF fix 7235, 40077
+   GRAY fixed 20467
+   INBFF fixed 20465, add 20571
+   INTRVL fix 20480, 30143
+   ITAYLOR fix 20542 pretend
+   LIST fix 20063, add, add 20569
+   MAPPKG1 fix 40351
+   MONAD fix 40350, add 7236
+   MSYSCMD fix 40359
+   OPTPROB fix 40347
+   ORDSET fix 40346
+   PTRANFN fixed 40357
+   REAL fix 40345
+   SINT fix 20057 pretend
+   SMTS fix 20383, 50005, add 20567
+   SOLVERAD fix 40043
+   SREGSET fix 50001
+   SYMBOL fix 20056 pretend
+   fix bug 7072/19 D(0^z, z) closed
+   fix bug 7248: differentiation fix bug in D(1,z)
+   fix bug 7249: radicalSolve(z^7=1, z)
+   fix bug 7249: radicalSolve(z^7=1, z) update
+   fix bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float
+   fix bug 7252: argument(-%i)
+   fix bug 7253: There are no library operations named 'when'
+   fix bug 7254: f==n+->sum(sum(1/i,i=1..j),j=1..n) complains
+   fix bug 7256: acot(-1) values differ
+   fix bug 7257: normalize(subst(asin(z),z=-1)) division by zero
+   fix bug 7258: acosh(0.0) invalid argument to acosh
+   fix bug 20501, SEXOF pretend, 30047 RNUMP
+   fix bug 30230, 20495; introduce 60076
+   fix bug 7236
+   fix bug 329, add todo 330
+   remove dead items
+   remove error message for deleted files
+   add 7142 exp^log(x) Cannot take first of an empty list update
+   add 7233: fill! operation from U8Vector does not show up
+   add 7242/7243
+   add 7244, 7245
+   add bug 7241, fix the integration routines
+   add bugs found in tests
+   add kamke4, kamke6 missing bug
+   add todo 335: add packages to )d op gcd
+   add 7232
+   wish 1011: sum(1/(k+a), k=1..n) by Gosper's method
+
+Wikipedia
+   en.wikipedia.org/wiki/Axiom_(computer_algebra_system) update date
+   en.wikipedia.org/wiki/List_of_computer_algebra_systems update date
+
+faq
+   remove noweb
+   fix mailing list links
+
+readme
+   add Edi Meier
+   add Edi Meier
+   add Jia Zhao Cong
+   add Raoul Bourquin
+   update credits
+
+src/Makefile
+   clean up src/algebra properly
+   convert bookvol8 from noweb to chunks
+   fix {OUT} bug
+   handle special case files for bookvol11
+   rename tangle.c to tanglec.c
+   pamphlet extract src using chunk syntax
+   pamphlet modified, noweb removed
+
+src/algebra/Makefile
+   add Comparable
+   add FINITE-
+   add LeftOreRing
+   add MatrixManipulation
+   add U16Matrix
+   add U32Matrix
+   add U32VectorPolynomialOperations
+   add U8Matrix
+   add fastxhtml extraction call
+   add machinearithmetic.input
+   compile FiniteFieldFactorization
+   compile MAGCDOC
+   fix failing test cases
+   set up regression tests
+   update graph info for OUT
+   modified, noweb removed
+
+src/algebra/libdb.text
+   add Attributes as Categories
+
+src/axiom-website/
+   AxiomConference.pdf added
+   axiom.sty
+   CATS/
+      charlwood.input added
+      rich* added
+      kamke*.txt added
+   books/
+      add 8.1, 10.5, bibliography
+      add bookvol13
+   community/
+      fix mailing list links
+   documentation.html
+      add AxiomConference.pdf
+      add Bottorff quote
+      add Knuth quote, cleanup
+      add Lamport quote
+      add McNamara quote
+      add Stroustrop quote
+      add W.T. Gowers quote
+   download.html
+      add binaries
+      add texlive-fonts-extra
+   patches.html
+      add patches
+   releasenotes.html
+       update for August 2014
+
+src/booklets
+   Makefile cleanup
+
+src/clef
+   Makefile rename tangle to tanglec
+   edible.c modified, noweb removed
+
+src/doc
+   export endpaper as pdf
+   remove axiom.bib
+   rename tangle to tanglec
+   use books/axiom.sty
+   remove noweb
+   booklet.c fix mailing list, remove noweb
+   msgs/
+      s2-us.msgs remove .as extension from compiler msg
+
+src/etc
+   Makefile remove noweb
+   asq.c remove noweb
+
+src/input/
+   Makefile add input tests for 
+      charlwood, cherry, functioncode, machinarithmetic,
+      pgcd, polygamma, rich*, romanpolynomials, rsa, segletes
+      exptest, subset, tree, trigtests
+   Makefile remove noweb
+   add many tests
+
+src/interp
+   Makefile
+      remove noweb
+      remove autoload of ht-util
+      remove bc-matrix
+    bc-matrix.lisp removed
+    br-con.lisp move to bookvol5
+    debugsys cleanup
+    g-timer.lisp RNUMP removed
+    g-util.lisp functionp -> canFuncall?
+    g-util.lisp remove functions
+    ht-util.lisp deleted, merged with bookvol5
+    i-coerce.lisp functionp -> canFuncall?
+    i-funsel.lisp remove functions
+    i-spec2.lisp. functionp -> canFuncall?
+    interp-proclaims.lisp functionp -> canFuncall?
+    regress.lisp improve diff output
+    sys-pkg.lisp RNUMP removed
+    temp.text deleted
+    util.lisp functionp -> canFuncall?
+    util.lisp remove autoload of ht-util
+    util.lisp remove autoload trigger functions
+    util.lisp remove bc-matrix autoload triggers
+    util.lisp remove compression
+    vmlisp.lisp RNUMP removed
+
+src/scripts
+   Makefile remove noweb
+   boxhead removed
+   boxtail removed
+   boxup removed
+   document -> books/extract
+   showdvi removed
+   tex/
+      axiom.sty removed
+
+src/share
+   Makefile remove noweb
+   algebra/compress removed
+   algebra/browse, category, dependents, interp, operations, users
+      add Attributes as Categories
+      add LeftOreRing
+      enumerate to FINITE
+      no compression
+      updated
+   doc/
+      hypertex/pages/util.ht deleted, unused
+
+src/sman
+   Makefile cleanup
+
+zips/
+   axiom.vim.tgz vim syntax file added
+   gcl-cgywin.tgz added
+   noweb-2.10a.tgz deleted, noweb removed
+   noweb.* deleted, noweb removed
+   all unused patches and versions of gcl deleted
+
 
-GCL compiles tangle.lisp and steps on tangle.c so we renamed the C
-version to tanglec and changed it everywhere.
diff --git a/src/axiom-website/documentation.html b/src/axiom-website/documentation.html
index 803ee81..81baf0a 100644
--- a/src/axiom-website/documentation.html
+++ b/src/axiom-website/documentation.html
@@ -564,6 +564,12 @@ other month when the system is distributed. The current volume set is:
  </li>
  This is the source and explanation of the X11 graphics subsystem.
  <br/>
+ <ul>
+ <li>
+  <a href="bookvol8.1.pdf"><b>Volume 8.1: Axiom Gallery</b></a>
+ </li>
+ A gallery of Axiom images.
+ </ul>
  <li>
   <a href="bookvol9.pdf"><b>Volume 9: Axiom Compiler</b></a>
  </li>
@@ -608,6 +614,11 @@ other month when the system is distributed. The current volume set is:
  This is the design documents and internals for the crystal interface.
  <br/>
  <li>
+  <a href="bookvol13.pdf"><b>Volume 13: Proving Axiom Correct</b></a>
+ </li>
+ This is the work on proving Axiom correct.
+ <br/>
+ <li>
   <a href="bookvolbib.pdf"><b>Axiom Bibliography</b></a>
  </li>
  This contains all the literature references to, and from, Axiom.
diff --git a/src/axiom-website/download.html b/src/axiom-website/download.html
index 2f9557d..5232991 100644
--- a/src/axiom-website/download.html
+++ b/src/axiom-website/download.html
@@ -156,11 +156,6 @@
      </td>
      <td align="center">
       <font face="Helvetica, Arial, sans-serif">
-       Sept 2011&nbsp;&nbsp;&nbsp;&nbsp;
-      </font>
-     </td>
-     <td align="center">
-      <font face="Helvetica, Arial, sans-serif">
        Nov 2011&nbsp;&nbsp;&nbsp;&nbsp;
       </font>
      </td>
@@ -179,6 +174,11 @@
        May 2012&nbsp;&nbsp;&nbsp;&nbsp;
       </font>
      </td>
+     <td align="center">
+      <font face="Helvetica, Arial, sans-serif">
+       Aug 2014&nbsp;&nbsp;&nbsp;&nbsp;
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -187,11 +187,6 @@
        debian
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -213,6 +208,11 @@
       <a href="downloads/axiom-may2012-src.tgz">src</a>
       </font>
      </td>
+     <td align="center"><!-- August 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -221,11 +221,6 @@
        fedora
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -248,6 +243,11 @@
       <a href="downloads/axiom-fedora-may2012-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
    </tr>
 
     <tr>
@@ -256,11 +256,6 @@
        opensuse
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -283,6 +278,11 @@
       <a href="downloads/axiom-opensuse-may2012-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -291,12 +291,6 @@
        ubuntu
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      <a href="downloads/axiom-ubuntu-sept2011-bin.tgz">bin</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -321,6 +315,12 @@
       <a href="downloads/axiom-ubuntu-may2012-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      <a href="downloads/axiom-ubuntu-aug2014-bin.tgz">bin</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -329,11 +329,6 @@
        ubuntu64
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -355,6 +350,11 @@
       <a href="downloads/axiom-may2012-src.tgz">src</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -363,11 +363,6 @@
        vector
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -388,6 +383,11 @@
       <a href="downloads/axiom-may2012-src.tgz">src</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -396,11 +396,6 @@
        slackware
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -421,6 +416,11 @@
       <a href="downloads/axiom-may2012-src.tgz">src</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -429,11 +429,6 @@
        mandriva
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      <a href="downloads/axiom-sept2011-src.tgz">src</a>
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       <a href="downloads/axiom-nov2011-src.tgz">src</a>
@@ -456,6 +451,11 @@
       <a href="downloads/axiom-mandriva-may2012-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
     <tr>
@@ -464,10 +464,6 @@
        centos
       </font>
      </td>
-     <td align="center"><!-- Sept 2011 -->
-      <font face="Helvetica, Arial, sans-serif" size="+1">
-      </font>
-     </td>
      <td align="center"><!-- Nov 2011 -->
       <font face="Helvetica, Arial, sans-serif" size="+1">
       </font>
@@ -490,6 +486,40 @@
       <a href="downloads/axiom-centos-may2012-bin.tgz">bin</a>
       </font>
      </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
+    </tr>
+
+    <tr>
+     <td align="left">
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+       MACOSX
+      </font>
+     </td>
+     <td align="center"><!-- Nov 2011 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center"><!-- Jan 2012 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center"><!-- Mar 2012 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center"><!-- May 2012 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      </font>
+     </td>
+     <td align="center"><!-- Aug 2014 -->
+      <font face="Helvetica, Arial, sans-serif" size="+1">
+      <a href="downloads/axiom-aug2014-src.tgz">src</a>
+      </font>
+     </td>
     </tr>
 
    </tbody>
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 7215b83..7b36e1b 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -3774,7 +3774,7 @@ books/bookvol0 fix appendix E<br/>
 <h3>March 2012 Release</h3>
 <a href="releasenotes.html#20120331">March 2012 Release Notes</a>
 <br/><a href="#20120127">Jump to previous release</a>
-<br/><a href="20120531">Jump to next release</a>
+<br/><a href="#20120531">Jump to next release</a>
 <br/>
 <br/>
 <a href="patches/20120127.01.tpd.patch">20120127.01.tpd.patch</a>
@@ -3860,7 +3860,7 @@ src/algebra/Makefile fix clique1, clique2<br/>
 <h3>May 2012 Release</h3>
 <a href="releasenotes.html#20120531">May 2012 Release Notes</a>
 <br/><a href="#20120331">Jump to previous release</a>
-<br/><a href="#latest">Jump to next release</a>
+<br/><a href="#20120701">Jump to next release</a>
 <br/>
 <br/>
 <a href="patches/20120402.01.tpd.patch">20120402.01.tpd.patch</a>
@@ -3930,644 +3930,652 @@ books/bookvol10.5 BLAS1 zaxpy</br/>
 <a href="patches/20120610.01.tpd.patch">20120610.01.tpd.patch</a>
 src/input/simplify.input.pamphlet add missing file
 <br/>  <hr>
-<a name="latest"/>
-<h3>July 2012 Release</h3>
+<a name="20140727"/>
+<h3>August 2014 Release</h3>
 <br/><a href="#20120531">Jump to previous release</a>
-<br/><a href="#20071123">Jump to top release</a>
+<br/><a href="#latest">Jump to next release</a>
 <br/>
 <br/>
-In process, not yet released<br/><br/>
 <a href="patches/20120612.01.tpd.patch">20120612.01.tpd.patch</a>
 src/axiom-website/download.html add binaries<br/>
 <a href="patches/20120615.01.tpd.patch">20120615.01.tpd.patch</a>
 Makefile.pamphlet add mint stanza<br/>
 <a href="patches/20120815.01.tpd.patch">20120815.01.tpd.patch</a>
-src/axiom-website/documentation.html
+src/axiom-website/documentation.html<br/>
 <a href="patches/20130105.01.tpd.patch">20130105.01.tpd.patch</a>
-src/input/cherry.input added
+src/input/cherry.input added<br/>
 <a href="patches/20130110.01.tpd.patch">20130110.01.tpd.patch</a>
-books/bookvolbib add Koutschan
+books/bookvolbib add Koutschan<br/>
 <a href="patches/20130122.01.tpd.patch">20130122.01.tpd.patch</a>
-src/input/trigtests.input added
+src/input/trigtests.input added<br/>
 <a href="patches/20130123.01.tpd.patch">20130123.01.tpd.patch</a>
-src/input/tree.regress added
+src/input/tree.regress added<br/>
 <a href="patches/20130123.02.tpd.patch">20130123.02.tpd.patch</a>
-src/doc/endpaper fixed format
+src/doc/endpaper fixed format<br/>
 <a href="patches/20130123.03.tpd.patch">20130123.03.tpd.patch</a>
-src/Makefile clean up src/algebra properly
+src/Makefile clean up src/algebra properly<br/>
 <a href="patches/20130124.01.tpd.patch">20130124.01.tpd.patch</a>
-books/bookvol10.4 document htrigs function in TRMANIP
+books/bookvol10.4 document htrigs function in TRMANIP<br/>
 <a href="patches/20130124.02.tpd.patch">20130124.02.tpd.patch</a>
-books/bookvol10.4 expand hyperbolic identities
+books/bookvol10.4 expand hyperbolic identities<br/>
 <a href="patches/20130124.03.tpd.patch">20130124.03.tpd.patch</a>
-src/input/trigtests.input test new hyperbolic identities
+src/input/trigtests.input test new hyperbolic identities<br/>
 <a href="patches/20130124.04.tpd.patch">20130124.04.tpd.patch</a>
-books/Makefile, bookvol3, bookvol12 remove noweb
+books/Makefile, bookvol3, bookvol12 remove noweb<br/>
 <a href="patches/20130124.05.tpd.patch">20130124.05.tpd.patch</a>
-books/Makefile, bookvol2 remove noweb
+books/Makefile, bookvol2 remove noweb<br/>
 <a href="patches/20130124.06.tpd.patch">20130124.06.tpd.patch</a>
-books/Makefile, bookvol4 remove noweb
+books/Makefile, bookvol4 remove noweb<br/>
 <a href="patches/20130214.01.tpd.patch">20130214.01.tpd.patch</a>
-buglist add bug 7232
+buglist add bug 7232<br/>
 <a href="patches/20130214.02.tpd.patch">20130214.02.tpd.patch</a>
-src/input/rsa.input added
+src/input/rsa.input added<br/>
 <a href="patches/20130216.01.gdr.patch">20130216.01.gdr.patch</a>
-books/bookvol10.2 add matrix initializer function
+books/bookvol10.2 add matrix initializer function<br/>
 <a href="patches/20130216.02.tpd.patch">20130216.02.tpd.patch</a>
-books/bookvol10.2 add MAGCDOC
+books/bookvol10.2 add MAGCDOC<br/>
 <a href="patches/20130221.01.tpd.patch">20130221.01.tpd.patch</a>
-books/bookvol10.3 update U32Vector domain, add machinearithmetic
+books/bookvol10.3 update U32Vector domain, add machinearithmetic<br/>
 <a href="patches/20130223.01.tpd.patch">20130223.01.tpd.patch</a>
-books/bookvol5 fix exposure for MAGCDOC category
+books/bookvol5 fix exposure for MAGCDOC category<br/>
 <a href="patches/20130223.02.tpd.patch">20130223.02.tpd.patch</a>
-books/bookvol10.3 add U16Vector
+books/bookvol10.3 add U16Vector<br/>
 <a href="patches/20130223.03.tpd.patch">20130223.03.tpd.patch</a>
-books/bookvol10.3 add U8Vector
+books/bookvol10.3 add U8Vector<br/>
 <a href="patches/20130223.04.tpd.patch">20130223.04.tpd.patch</a>
-buglist add 7233: fill! operation from U8Vector does not show up
+buglist add 7233: fill! operation from U8Vector does not show up<br/>
 <a href="patches/20130225.01.tpd.patch">20130225.01.tpd.patch</a>
-books/bookvol10.3 add U32Matrix
+books/bookvol10.3 add U32Matrix<br/>
 <a href="patches/20130226.01.tpd.patch">20130226.01.tpd.patch</a>
-books/bookvol10.4 comment out bad code in GUESS
+books/bookvol10.4 comment out bad code in GUESS<br/>
 <a href="patches/20130226.02.tpd.patch">20130226.02.tpd.patch</a>
-books/bookvol10.3 add U16Matrix
+books/bookvol10.3 add U16Matrix<br/>
 <a href="patches/20130227.01.tpd.patch">20130227.01.tpd.patch</a>
-books/bookvol10.3 add U8Matrix
+books/bookvol10.3 add U8Matrix<br/>
 <a href="patches/20130227.02.tpd.patch">20130227.02.tpd.patch</a>
-books/bookvol10.4 add U32VectorPolynomialOperations
+books/bookvol10.4 add U32VectorPolynomialOperations<br/>
 <a href="patches/20130228.01.tpd.patch">20130228.01.tpd.patch</a>
-books/bookvolbib add references
+books/bookvolbib add references<br/>
 <a href="patches/20130228.02.tpd.patch">20130228.02.tpd.patch</a>
-books/bookvol10.2 write help documentation for all categories
+books/bookvol10.2 write help documentation for all categories<br/>
 <a href="patches/20130229.01.tpd.patch">20130229.01.tpd.patch</a>
-books/bookvolbib add references
+books/bookvolbib add references<br/>
 <a href="patches/20130301.01.tpd.patch">20130301.01.tpd.patch</a>
-books/bookvol10.3 write help documentation for all domains
+books/bookvol10.3 write help documentation for all domains<br/>
 <a href="patches/20130305.01.tpd.patch">20130305.01.tpd.patch</a>
-books/bookvolbib add references
+books/bookvolbib add references<br/>
 <a href="patches/20130305.02.tpd.patch">20130305.02.tpd.patch</a>
-books/bookvol10.4 write help documentation
+books/bookvol10.4 write help documentation<br/>
 <a href="patches/20130306.01.tpd.patch">20130306.01.tpd.patch</a>
-books/bookvol4 fix mixing end verbatim
+books/bookvol4 fix mixing end verbatim<br/>
 <a href="patches/20130306.02.tpd.patch">20130306.02.tpd.patch</a>
-books/bookvol4 replace " with ``
+books/bookvol4 replace " with ``<br/>
 <a href="patches/20130307.01.tpd.patch">20130307.01.tpd.patch</a>
-books/bookvol10.* fix help documentation and regression tests
+books/bookvol10.* fix help documentation and regression tests<br/>
 <a href="patches/20130307.02.tpd.patch">20130307.02.tpd.patch</a>
-books/bookvol4 clean up latex, document makeHelpFiles
+books/bookvol4 clean up latex, document makeHelpFiles<br/>
 <a href="patches/20130313.01.tpd.patch">20130313.01.tpd.patch</a>
-buglist complete console review and classify
+buglist complete console review and classify<br/>
 <a href="patches/20130313.02.tpd.patch">20130313.02.tpd.patch</a>
-books/bookvol5 fix references
+books/bookvol5 fix references<br/>
 <a href="patches/20130313.03.tpd.patch">20130313.03.tpd.patch</a>
-books/bookvol10.3 AFFSP fix 30230, 20495; introduce 60076
+books/bookvol10.3 AFFSP fix 30230, 20495; introduce 60076<br/>
 <a href="patches/20130313.04.tpd.patch">20130313.04.tpd.patch</a>
-books/bookvol10.3 INTRVL fix 20480, 30143
+books/bookvol10.3 INTRVL fix 20480, 30143<br/>
 <a href="patches/20130313.05.tpd.patch">20130313.05.tpd.patch</a>
-books/bookvol10.3 RNUMP removed
+books/bookvol10.3 RNUMP removed<br/>
 <a href="patches/20130313.06.tpd.patch">20130313.06.tpd.patch</a>
-books/bookvol10.3 fix 20501, SEXOF pretend
+books/bookvol10.3 fix 20501, SEXOF pretend<br/>
 <a href="patches/20130313.07.tpd.patch">20130313.07.tpd.patch</a>
-books/bookvol10.4 FSPECF fix 7235, 40077
+books/bookvol10.4 FSPECF fix 7235, 40077<br/>
 <a href="patches/20130314.01.tpd.patch">20130314.01.tpd.patch</a>
-books/bookvol10.4 GRAY fixed 20467
+books/bookvol10.4 GRAY fixed 20467<br/>
 <a href="patches/20130314.02.tpd.patch">20130314.02.tpd.patch</a>
-readme add Jia Zhao Cong
+readme add Jia Zhao Cong<br/>
 <a href="patches/20130314.03.tpd.patch">20130314.03.tpd.patch</a>
-changlog. fix jzc email address
+changlog. fix jzc email address<br/>
 <a href="patches/20130314.04.jzc.patch">20130314.04.jzc.patch</a>
-books/bookvol0, books/bookvol1 fix typo
+books/bookvol0, books/bookvol1 fix typo<br/>
 <a href="patches/20130314.05.tpd.patch">20130314.05.tpd.patch</a>
-books/bookvol5 treeshake interpreter code
+books/bookvol5 treeshake interpreter code<br/>
 <a href="patches/20130314.06.tpd.patch">20130314.06.tpd.patch</a>
-books/bookvol10.3 ITAYLOR fix 20542 pretend
+books/bookvol10.3 ITAYLOR fix 20542 pretend<br/>
 <a href="patches/20130314.07.tpd.patch">20130314.07.tpd.patch</a>
-books/bookvol10.3 SYMBOL fix 20056 pretend
+books/bookvol10.3 SYMBOL fix 20056 pretend<br/>
 <a href="patches/20130314.08.tpd.patch">20130314.08.tpd.patch</a>
-books/bookvol10.3 SINT fix 20057 pretend
+books/bookvol10.3 SINT fix 20057 pretend<br/>
 <a href="patches/20130314.09.tpd.patch">20130314.09.tpd.patch</a>
-books/bookvol10.3 SMTS fix 20383, 50005, add 20567
+books/bookvol10.3 SMTS fix 20383, 50005, add 20567<br/>
 <a href="patches/20130314.10.tpd.patch">20130314.10.tpd.patch</a>
-books/bookvol10.3 MLIFT fix 20001, add 20568
+books/bookvol10.3 MLIFT fix 20001, add 20568<br/>
 <a href="patches/20130314.11.tpd.patch">20130314.11.tpd.patch</a>
-books/bookvol2 Axiom and Category Theory chapter
+books/bookvol2 Axiom and Category Theory chapter<br/>
 <a href="patches/20130315.01.tpd.patch">20130315.01.tpd.patch</a>
-books/bookvol10.3 LIST fix 20063, add, add 20569
+books/bookvol10.3 LIST fix 20063, add, add 20569<br/>
 <a href="patches/20130315.02.tpd.patch">20130315.02.tpd.patch</a>
-books/bookvol10.3 DFLOAT fix 20073, add 20570
+books/bookvol10.3 DFLOAT fix 20073, add 20570<br/>
 <a href="patches/20130315.03.tpd.patch">20130315.03.tpd.patch</a>
-books/bookvol10.3 INBFF fixed 20465, add 20571
+books/bookvol10.3 INBFF fixed 20465, add 20571<br/>
 <a href="patches/20130315.04.tpd.patch">20130315.04.tpd.patch</a>
-books/bookvol10.3 BLAS1 fixed 40304
+books/bookvol10.3 BLAS1 fixed 40304<br/>
 <a href="patches/20130315.05.tpd.patch">20130315.05.tpd.patch</a>
-books/bookvol10.3 FPS fixed 40013
+books/bookvol10.3 FPS fixed 40013<br/>
 <a href="patches/20130315.06.tpd.patch">20130315.06.tpd.patch</a>
-changlog. fix jzc email address
+changlog. fix jzc email address<br/>
 <a href="patches/20130315.07.jzc.patch">20130315.07.jzc.patch</a>
-books/bookvol0 add linebreak on p988
+books/bookvol0 add linebreak on p988<br/>
 <a href="patches/20130315.08.tpd.patch">20130315.08.tpd.patch</a>
-books/bookvol10.3 DFLOAT fixed 40019
+books/bookvol10.3 DFLOAT fixed 40019<br/>
 <a href="patches/20130315.09.tpd.patch">20130315.09.tpd.patch</a>
-books/bookvol10.2 CLAGG fixed 40021
+books/bookvol10.2 CLAGG fixed 40021<br/>
 <a href="patches/20130316.01.tpd.patch">20130316.01.tpd.patch</a>
-books/bookvol10.3 CHAR fix 40022
+books/bookvol10.3 CHAR fix 40022<br/>
 <a href="patches/20130316.02.tpd.patch">20130316.02.tpd.patch</a>
-books/bookvol10.4 SOLVERAD fix 40043
+books/bookvol10.4 SOLVERAD fix 40043<br/>
 <a href="patches/20130316.03.tpd.patch">20130316.03.tpd.patch</a>
-books/bookvol2 category theory notes
+books/bookvol2 category theory notes<br/>
 <a href="patches/20130316.04.tpd.patch">20130316.04.tpd.patch</a>
-books/bookvol10.4 ATTREG fix 40362
+books/bookvol10.4 ATTREG fix 40362<br/>
 <a href="patches/20130316.05.tpd.patch">20130316.05.tpd.patch</a>
-books/bookvol10.4 SREGSET fix 50001
+books/bookvol10.4 SREGSET fix 50001<br/>
 <a href="patches/20130316.06.tpd.patch">20130316.06.tpd.patch</a>
-books/bookvol10.4 ELTAB fix 40360
+books/bookvol10.4 ELTAB fix 40360<br/>
 <a href="patches/20130316.07.tpd.patch">20130316.07.tpd.patch</a>
-books/bookvol10.4 MSYSCMD fix 40359
+books/bookvol10.4 MSYSCMD fix 40359<br/>
 <a href="patches/20130316.08.tpd.patch">20130316.08.tpd.patch</a>
-books/bookvol10.4 PTRANFN fixed 40357
+books/bookvol10.4 PTRANFN fixed 40357<br/>
 <a href="patches/20130317.01.tpd.patch">20130317.01.tpd.patch</a>
-books/bookvol10.2 AGG fixed 40355
+books/bookvol10.2 AGG fixed 40355<br/>
 <a href="patches/20130317.02.tpd.patch">20130317.02.tpd.patch</a>
-books/bookvol10.4 MAPPKG1 fix 40351
+books/bookvol10.4 MAPPKG1 fix 40351<br/>
 <a href="patches/20130317.03.tpd.patch">20130317.03.tpd.patch</a>
-books/bookvol10.4 MONAD fix 40350, add 7236
+books/bookvol10.4 MONAD fix 40350, add 7236<br/>
 <a href="patches/20130317.04.tpd.patch">20130317.04.tpd.patch</a>
-books/bookvol10.3 OPTPROB fix 40347
+books/bookvol10.3 OPTPROB fix 40347<br/>
 <a href="patches/20130317.05.tpd.patch">20130317.05.tpd.patch</a>
-books/bookvol10.2 ORDSET fix 40346
+books/bookvol10.2 ORDSET fix 40346<br/>
 <a href="patches/20130317.06.tpd.patch">20130317.06.tpd.patch</a>
-books/bookvol10.2 REAL fix 40345
+books/bookvol10.2 REAL fix 40345<br/>
 <a href="patches/20130317.07.tpd.patch">20130317.07.tpd.patch</a>
-books/bookvol10.2 fix multiple typos
+books/bookvol10.2 fix multiple typos<br/>
 <a href="patches/20130318.01.rxb.patch">20130318.01.rxb.patch</a>
-books/bookvol10.4 add MatrixManipulation
+books/bookvol10.4 add MatrixManipulation<br/>
 <a href="patches/20130318.02.tpd.patch">20130318.02.tpd.patch</a>
-books/bookvol10.2, bookvol10.3 fix typos
+books/bookvol10.2, bookvol10.3 fix typos<br/>
 <a href="patches/20130319.01.tpd.patch">20130319.01.tpd.patch</a>
-fix broken tests
+fix broken tests<br/>
 <a href="patches/20130319.02.tpd.patch">20130319.02.tpd.patch</a>
-regression test cleaup
+regression test cleaup<br/>
 <a href="patches/20130320.01.tpd.patch">20130320.01.tpd.patch</a>
-regression test cleaup
+regression test cleaup<br/>
 <a href="patches/20130321.01.tpd.patch">20130321.01.tpd.patch</a>
-books/bookvol10.4 add FiniteFieldFactorization
+books/bookvol10.4 add FiniteFieldFactorization<br/>
 <a href="patches/20130323.01.tpd.patch">20130323.01.tpd.patch</a>
-books/bookvolbib add references
+books/bookvolbib add references<br/>
 <a href="patches/20130324.01.jxb.patch">20130324.01.jxb.patch</a>
-src/input/romanpolynomials.input create POLY(ROMAN)
+src/input/romanpolynomials.input create POLY(ROMAN)<br/>
 <a href="patches/20130324.02.tpd.patch">20130324.02.tpd.patch</a>
-books/bookvolbib add references
+books/bookvolbib add references<br/>
 <a href="patches/20130326.01.tpd.patch">20130326.01.tpd.patch</a>
-src/input/* fix failing tests, move EFULS, EFUPXS from package to domain
+src/input/* fix failing tests, move EFULS, EFUPXS from package to domain<br/>
 <a href="patches/20130327.01.tpd.patch">20130327.01.tpd.patch</a>
-src/input/functioncode.input added
+src/input/functioncode.input added<br/>
 <a href="patches/20130329.01.tpd.patch">20130329.01.tpd.patch</a>
-books/bookvol0 add graphics, fix typos, add text
+books/bookvol0 add graphics, fix typos, add text<br/>
 <a href="patches/20130329.02.tpd.patch">20130329.02.tpd.patch</a>
-books/bookvol0 fix typo
+books/bookvol0 fix typo<br/>
 <a href="patches/20130330.01.tpd.patch">20130330.01.tpd.patch</a>
-books/bookvol* update credit list
+books/bookvol* update credit list<br/>
 <a href="patches/20130330.02.tpd.patch">20130330.02.tpd.patch</a>
-books/bookvol0 fix typo
+books/bookvol0 fix typo<br/>
 <a href="patches/20130331.01.tpd.patch">20130331.01.tpd.patch</a>
-src/input/richalgebraic100-199.input fix failures
+src/input/richalgebraic100-199.input fix failures<br/>
 <a href="patches/20130331.02.tpd.patch">20130331.02.tpd.patch</a>
-books/bookvol10.4 fix OUT.spad warning (bug 329)
+books/bookvol10.4 fix OUT.spad warning (bug 329)<br/>
 <a href="patches/20130411.01.tpd.patch">20130411.01.tpd.patch</a>
-src/interp/Makefile, books/bookvol5 remove bc-matrix.lisp
+src/interp/Makefile, books/bookvol5 remove bc-matrix.lisp<br/>
 <a href="patches/20130414.01.tpd.patch">20130414.01.tpd.patch</a>
-src/axiom-website/documentation.html add quote
+src/axiom-website/documentation.html add quote<br/>
 <a href="patches/20130418.01.jzc.patch">20130418.01.jzc.patch</a>
-books/bookvol0 fix Jenks book format issues
+books/bookvol0 fix Jenks book format issues<br/>
 <a href="patches/20130422.01.tpd.patch">20130422.01.tpd.patch</a>
-books/bookvol10.2 add enumerate to FINITE
+books/bookvol10.2 add enumerate to FINITE<br/>
 <a href="patches/20130423.01.tpd.patch">20130423.01.tpd.patch</a>
-books/bookvol10.2 add Comparable
+books/bookvol10.2 add Comparable<br/>
 <a href="patches/20130423.02.tpd.patch">20130423.02.tpd.patch</a>
-Makefile make clean removes all cruft
+Makefile make clean removes all cruft<br/>
 <a href="patches/20130426.01.tpd.patch">20130426.01.tpd.patch</a>
-books/bookvol10.2 add Attributes as Categories
+books/bookvol10.2 add Attributes as Categories<br/>
 <a href="patches/20130428.01.exm.patch">20130428.01.exm.patch</a>
-src/axiom-website/community.html fix mailing list links
+src/axiom-website/community.html fix mailing list links<br/>
 <a href="patches/20130428.02.tpd.patch">20130428.02.tpd.patch</a>
-books/bookheader.tex standardize the book headers
+books/bookheader.tex standardize the book headers<br/>
 <a href="patches/20130428.03.tpd.patch">20130428.03.tpd.patch</a>
-books/bookvol* use bookheader.tex
+books/bookvol* use bookheader.tex<br/>
 <a href="patches/20130428.04.tpd.patch">20130428.04.tpd.patch</a>
-src/input/cherry.input annotate the integration routines
+src/input/cherry.input annotate the integration routines<br/>
 <a href="patches/20130429.01.tpd.patch">20130429.01.tpd.patch</a>
-books/bookvol8 convert bookvol8 from noweb to chunks
+books/bookvol8 convert bookvol8 from noweb to chunks<br/>
 <a href="patches/20130429.02.tpd.patch">20130429.02.tpd.patch</a>
-books/bookvol{1,7.1,8} use bookheader.tex
+books/bookvol{1,7.1,8} use bookheader.tex<br/>
 <a href="patches/20130430.01.tpd.patch">20130430.01.tpd.patch</a>
-books/bookvol11 use latex chunking, remove Makefile
+books/bookvol11 use latex chunking, remove Makefile<br/>
 <a href="patches/20130501.01.tpd.patch">20130501.01.tpd.patch</a>
-books/bookvol10 use bookheader.tex on remaining books
+books/bookvol10 use bookheader.tex on remaining books<br/>
 <a href="patches/20130508.01.exm.patch">20130508.01.exm.patch</a>
-src/axiom-website/books.html add 8.1, 10.5, bibliography
+src/axiom-website/books.html add 8.1, 10.5, bibliography<br/>
 <a href="patches/20130508.02.exm.patch">20130508.02.exm.patch</a>
-books/axbook.tgz fix sinCosExpandRules
+books/axbook.tgz fix sinCosExpandRules<br/>
 <a href="patches/20130511.01.tpd.patch">20130511.01.tpd.patch</a>
-src/doc/axiom.bib removed
+src/doc/axiom.bib removed<br/>
 <a href="patches/20130511.02.tpd.patch">20130511.02.tpd.patch</a>
-buglist remove dead items
+buglist remove dead items<br/>
 <a href="patches/20130512.01.tpd.patch">20130512.01.tpd.patch</a>
-src/share/doc/hypertex/pages/util.ht deleted, unused
+src/share/doc/hypertex/pages/util.ht deleted, unused<br/>
 <a href="patches/20130513.01.tpd.patch">20130513.01.tpd.patch</a>
-books/bookvol5 merge ht-util.lisp
+books/bookvol5 merge ht-util.lisp<br/>
 <a href="patches/20130522.01.tpd.patch">20130522.01.tpd.patch</a>
-src/Makefile fix {OUT} bug
+src/Makefile fix {OUT} bug<br/>
 <a href="patches/20130522.02.tpd.patch">20130522.02.tpd.patch</a>
-buglist remove error message for deleted files
+buglist remove error message for deleted files<br/>
 <a href="patches/20130526.01.tpd.patch">20130526.01.tpd.patch</a>
-books/bookvol10.* fix failing test cases
+books/bookvol10.* fix failing test cases<br/>
 <a href="patches/20130526.02.tpd.patch">20130526.02.tpd.patch</a>
-src/interp/regress.lisp improve diff output
+src/interp/regress.lisp improve diff output<br/>
 <a href="patches/20130526.03.tpd.patch">20130526.03.tpd.patch</a>
-books/bookvol5 incremental rewrite of br-con.lisp
+books/bookvol5 incremental rewrite of br-con.lisp<br/>
 <a href="patches/20130528.01.tpd.patch">20130528.01.tpd.patch</a>
-books/bookvol* standardize the table of contents
+books/bookvol* standardize the table of contents<br/>
 <a href="patches/20130529.01.jzc.patch">20130529.01.jzc.patch</a>
-books/bookvol{0,1,2,4} fix typos
+books/bookvol{0,1,2,4} fix typos<br/>
 <a href="patches/20130531.01.tpd.patch">20130531.01.tpd.patch</a>
-books/bookvol5 rewrite code from br-con
+books/bookvol5 rewrite code from br-con<br/>
 <a href="patches/20130607.01.tpd.patch">20130607.01.tpd.patch</a>
-books/bookvol8.1 add crc test cases
+books/bookvol8.1 add crc test cases<br/>
 <a href="patches/20130607.02.tpd.patch">20130607.02.tpd.patch</a>
-books/bookvol{0,1,2,4} fix typos
+books/bookvol{0,1,2,4} fix typos<br/>
 <a href="patches/20130607.03.tpd.patch">20130607.03.tpd.patch</a>
-books/bookvol5 move functions from br-con.lisp
-books/Makefile fix broken sed regular expression
+books/bookvol5 move functions from br-con.lisp<br/>
 <a href="patches/20130608.01.tpd.patch">20130608.01.tpd.patch</a>
-books/bookvol8.1 add new crc test graphs
+books/bookvol8.1 add new crc test graphs<br/>
 <a href="patches/20130609.01.tpd.patch">20130609.01.tpd.patch</a>
-books/bookvol8.1 add crc test section 2.3
+books/bookvol8.1 add crc test section 2.3<br/>
 <a href="patches/20130609.02.tpd.patch">20130609.02.tpd.patch</a>
-books/bookvol8.1 add crc test section 2.4
+books/bookvol8.1 add crc test section 2.4<br/>
 <a href="patches/20130609.03.tpd.patch">20130609.03.tpd.patch</a>
-books/bookvol8.1 add crc test section 2.5, 2.6, 2.7
+books/bookvol8.1 add crc test section 2.5, 2.6, 2.7<br/>
 <a href="patches/20130613.01.tpd.patch">20130613.01.tpd.patch</a>
-books/bookvol8.1 add crc test section 2.8, 2.9
+books/bookvol8.1 add crc test section 2.8, 2.9<br/>
 <a href="patches/20130613.02.tpd.patch">20130613.02.tpd.patch</a>
-books/bookvol5 move code from br-con.lisp
+books/bookvol5 move code from br-con.lisp<br/>
 <a href="patches/20130618.01.tpd.patch">20130618.01.tpd.patch</a>
-books/bookvol5 move code from br-con.lisp
+books/bookvol5 move code from br-con.lisp<br/>
 <a href="patches/20130621.01.tpd.patch">20130621.01.tpd.patch</a>
-books/bookvol5 move code from br-con.lisp
+books/bookvol5 move code from br-con.lisp<br/>
 <a href="patches/20130622.01.tpd.patch">20130622.01.tpd.patch</a>
-books/bookvol5 move code from br-con.lisp
+books/bookvol5 move code from br-con.lisp<br/>
 <a href="patches/20130623.01.tpd.patch">20130623.01.tpd.patch</a>
-books/bookvol5 move code from br-con.lisp
+books/bookvol5 move code from br-con.lisp<br/>
 <a href="patches/20130625.01.tpd.patch">20130625.01.tpd.patch</a>
-Makefiles cleanup
+Makefiles cleanup<br/>
 <a href="patches/20130625.02.tpd.patch">20130625.02.tpd.patch</a>
-books/bookvol5 move code from br-con.lisp
+books/bookvol5 move code from br-con.lisp<br/>
 <a href="patches/20130630.01.tpd.patch">20130630.01.tpd.patch</a>
-src/interp/Makefile make cleanup
+src/interp/Makefile make cleanup<br/>
 <a href="patches/20130701.01.tpd.patch">20130701.01.tpd.patch</a>
-src/interp/Makefile make cleanup
+src/interp/Makefile make cleanup<br/>
 <a href="patches/20130702.01.tpd.patch">20130702.01.tpd.patch</a>
-books/bookvolbib add Griesmer ref, sort items
+books/bookvolbib add Griesmer ref, sort items<br/>
 <a href="patches/20130714.01.tpd.patch">20130714.01.tpd.patch</a>
-add rich integral set to CATS test suite
+add rich integral set to CATS test suite<br/>
 <a href="patches/20130714.02.tpd.patch">20130714.02.tpd.patch</a>
-src/input/charlwood.input added
+src/input/charlwood.input added<br/>
 <a href="patches/20130715.01.tpd.patch">20130715.01.tpd.patch</a>
-CATS updated with txt, charlwood
+CATS updated with txt, charlwood<br/>
 <a href="patches/20130718.01.tpd.patch">20130718.01.tpd.patch</a>
-src/input/rich1a, rich1b
+src/input/rich1a, rich1b<br/>
 <a href="patches/20130719.01.tpd.patch">20130719.01.tpd.patch</a>
-src/axiom-website/CATS/index.html, rich1a, rich1b
+src/axiom-website/CATS/index.html, rich1a, rich1b<br/>
 <a href="patches/20130720.01.tpd.patch">20130720.01.tpd.patch</a>
-src/input/rich2.input
+src/input/rich2.input<br/>
 <a href="patches/20130721.01.tpd.patch">20130721.01.tpd.patch</a>
-src/axiom-website/CATS/index.html, rich2.input
+src/axiom-website/CATS/index.html, rich2.input<br/>
 <a href="patches/20130722.01.tpd.patch">20130722.01.tpd.patch</a>
-src/axiom-website/CATS/rich1a statistics update
+src/axiom-website/CATS/rich1a statistics update<br/>
 <a href="patches/20130723.01.tpd.patch">20130723.01.tpd.patch</a>
-src/axiom-website/CATS/rich1b statistics update
+src/axiom-website/CATS/rich1b statistics update<br/>
 <a href="patches/20130725.01.tpd.patch">20130725.01.tpd.patch</a>
-src/axiom-website/CATS/rich2, rich3a
+src/axiom-website/CATS/rich2, rich3a<br/>
 <a href="patches/20130726.01.tpd.patch">20130726.01.tpd.patch</a>
-src/axiom-website/CATS/rich3b
+src/axiom-website/CATS/rich3b<br/>
 <a href="patches/20130727.01.tpd.patch">20130727.01.tpd.patch</a>
-src/axiom-website/CATS/rich3c
+src/axiom-website/CATS/rich3c<br/>
 <a href="patches/20130804.01.tpd.patch">20130804.01.tpd.patch</a>
-src/axiom-website/CATS/rich4*, src/input/rich4*
+src/axiom-website/CATS/rich4*, src/input/rich4*<br/>
 <a href="patches/20130811.01.tpd.patch">20130811.01.tpd.patch</a>
-src/axiom-website/CATS/rich5,6*, src/input/rich5,6*
+src/axiom-website/CATS/rich5,6*, src/input/rich5,6*<br/>
 <a href="patches/20130827.01.tpd.patch">20130827.01.tpd.patch</a>
-src/axiom-website/CATS/rich*, richder*, src/input/rich*
+src/axiom-website/CATS/rich*, richder*, src/input/rich*<br/>
 <a href="patches/20131112.01.tpd.patch">20131112.01.tpd.patch</a>
-src/axiom-website/CATS/rich*, richder*, src/input/rich*
+src/axiom-website/CATS/rich*, richder*, src/input/rich*<br/>
 <a href="patches/20131115.01.tpd.patch">20131115.01.tpd.patch</a>
-src/interp/Makefile typo fix, bookvol5 enlarge memory
+src/interp/Makefile typo fix, bookvol5 enlarge memory<br/>
 <a href="patches/20131116.01.tpd.patch">20131116.01.tpd.patch</a>
-books/tangle.lisp make gcl code read-time conditional
+books/tangle.lisp make gcl code read-time conditional<br/>
 <a href="patches/20131120.01.fxs.patch">20131120.01.fxs.patch</a>
-zips/axiom.vim.tgz vim syntax file added
+zips/axiom.vim.tgz vim syntax file added<br/>
 <a href="patches/20131129.01.tpd.patch">20131129.01.tpd.patch</a>
-Makefile change TESTSET default to regresstests
+Makefile change TESTSET default to regresstests<br/>
 <a href="patches/20140417.01.tpd.patch">20140417.01.tpd.patch</a>
-add AxiomConference.pdf
+add AxiomConference.pdf<br/>
 <a href="patches/20140418.01.tpd.patch">20140418.01.tpd.patch</a>
-book/* all of the axiom emails to date
+book/* all of the axiom emails to date<br/>
 <a href="patches/20140418.02.tpd.patch">20140418.02.tpd.patch</a>
-book/2002*.txt, 2003-01..06.txt modified
+book/2002*.txt, 2003-01..06.txt modified<br/>
 <a href="patches/20140418.03.tpd.patch">20140418.03.tpd.patch</a>
-book/2003-07.txt regularize
+book/2003-07.txt regularize<br/>
 <a href="patches/20140418.04.tpd.patch">20140418.04.tpd.patch</a>
-book/2003-08.txt regularize
+book/2003-08.txt regularize<br/>
 <a href="patches/20140419.01.tpd.patch">20140419.01.tpd.patch</a>
-book/2003-09.txt regularize, remove, reorder CC lines
+book/2003-09.txt regularize, remove, reorder CC lines<br/>
 <a href="patches/20140420.01.tpd.patch">20140420.01.tpd.patch</a>
-book/2003-10.txt regularize
+book/2003-10.txt regularize<br/>
 <a href="patches/20140420.02.tpd.patch">20140420.02.tpd.patch</a>
-book/2003-11.txt regularize
+book/2003-11.txt regularize<br/>
 <a href="patches/20140420.03.tpd.patch">20140420.03.tpd.patch</a>
-book/2003-12.txt regularize
+book/2003-12.txt regularize<br/>
 <a href="patches/20140421.01.tpd.patch">20140421.01.tpd.patch</a>
-book/2004-01.txt regularize
+book/2004-01.txt regularize<br/>
 <a href="patches/20140422.01.tpd.patch">20140422.01.tpd.patch</a>
-book/2004-02.txt regularize
+book/2004-02.txt regularize<br/>
 <a href="patches/20140422.02.tpd.patch">20140422.02.tpd.patch</a>
-book/2004-03.txt regularize
+book/2004-03.txt regularize<br/>
 <a href="patches/20140422.03.tpd.patch">20140422.03.tpd.patch</a>
-book/2004-04.txt regularize
+book/2004-04.txt regularize<br/>
 <a href="patches/20140422.04.tpd.patch">20140422.04.tpd.patch</a>
-book/2004-05.txt regularize
+book/2004-05.txt regularize<br/>
 <a href="patches/20140423.01.tpd.patch">20140423.01.tpd.patch</a>
-book/2004-06.txt regularize
+book/2004-06.txt regularize<br/>
 <a href="patches/20140423.02.tpd.patch">20140423.02.tpd.patch</a>
-book/2004-07.txt regularize
+book/2004-07.txt regularize<br/>
 <a href="patches/20140423.03.tpd.patch">20140423.03.tpd.patch</a>
-book/2004-08.txt regularize
+book/2004-08.txt regularize<br/>
 <a href="patches/20140423.04.tpd.patch">20140423.04.tpd.patch</a>
-book/2004-09.txt regularize
+book/2004-09.txt regularize<br/>
 <a href="patches/20140423.05.tpd.patch">20140423.05.tpd.patch</a>
-book/2004-10.txt regularize
+book/2004-10.txt regularize<br/>
 <a href="patches/20140424.01.tpd.patch">20140424.01.tpd.patch</a>
-book/2004-11.txt regularize
+book/2004-11.txt regularize<br/>
 <a href="patches/20140424.02.tpd.patch">20140424.02.tpd.patch</a>
-book/2002-10.txt, book/2002-11.txt, book/2002-12.txt use real names
+book/2002-10.txt, book/2002-11.txt, book/2002-12.txt use real names<br/>
 <a href="patches/20140426.01.tpd.patch">20140426.01.tpd.patch</a>
-book/*.txt use real names
+book/*.txt use real names<br/>
 <a href="patches/20140427.01.tpd.patch">20140427.01.tpd.patch</a>
-src/axiom-website/documentation.html add Knuth quote, cleanup
+src/axiom-website/documentation.html add Knuth quote, cleanup<br/>
 <a href="patches/20140427.02.tpd.patch">20140427.02.tpd.patch</a>
-src/axiom-website/documentation.html whos -> whose. yaknow, life.
+src/axiom-website/documentation.html whos -> whose. yaknow, life.<br/>
 <a href="patches/20140430.01.tpd.patch">20140430.01.tpd.patch</a>
-book/*.txt add all edited versions of email logs
+book/*.txt add all edited versions of email logs<br/>
 <a href="patches/20140503.01.tpd.patch">20140503.01.tpd.patch</a>
-book/*.txt cleanup
+book/*.txt cleanup<br/>
 <a href="patches/20140506.01.tpd.patch">20140506.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140507.01.tpd.patch">20140507.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140507.02.tpd.patch">20140507.02.tpd.patch</a>
-src/axiom-website/documentation.html add Bottorff quote
+src/axiom-website/documentation.html add Bottorff quote<br/>
 <a href="patches/20140508.01.tpd.patch">20140508.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140509.01.tpd.patch">20140509.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140509.02.tpd.patch">20140509.02.tpd.patch</a>
-books/bookvolbib.pamphlet
+books/bookvolbib.pamphlet<br/>
 <a href="patches/20140509.03.tpd.patch">20140509.03.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140511.01.tpd.patch">20140511.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140511.02.tpd.patch">20140511.02.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140514.01.tpd.patch">20140514.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140515.01.tpd.patch">20140515.01.tpd.patch</a>
-bookvol4 add operationalist details
+bookvol4 add operationalist details<br/>
 <a href="patches/20140516.01.tpd.patch">20140516.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140520.01.tpd.patch">20140520.01.tpd.patch</a>
-books/bookvolbib.pamphlet 
+books/bookvolbib.pamphlet <br/>
 <a href="patches/20140520.02.tpd.patch">20140520.02.tpd.patch</a>
-src/axiom-website/documentation.html
+src/axiom-website/documentation.html<br/>
 <a href="patches/20140523.01.tpd.patch">20140523.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140524.01.tpd.patch">20140524.01.tpd.patch</a>
-books/bookvolbib.pamphlet add gruntz, knuth refs
+books/bookvolbib.pamphlet add gruntz, knuth refs<br/>
 <a href="patches/20140524.02.tpd.patch">20140524.02.tpd.patch</a>
-src/input/Makefile add inputform
+src/input/Makefile add inputform<br/>
 <a href="patches/20140525.01.tpd.patch">20140525.01.tpd.patch</a>
-src/input/page.input removed
+src/input/page.input removed<br/>
 <a href="patches/20140530.01.tpd.patch">20140530.01.tpd.patch</a>
-books/bookvolbib add Sit06
+books/bookvolbib add Sit06<br/>
 <a href="patches/20140530.02.tpd.patch">20140530.02.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140602.01.tpd.patch">20140602.01.tpd.patch</a>
-books/bookvol10.4 apply Waldek's changes to imposelc in PGCD
+books/bookvol10.4 apply Waldek's changes to imposelc in PGCD<br/>
 <a href="patches/20140603.01.tpd.patch">20140603.01.tpd.patch</a>
-buglist, add todo 335: add packages to )d op gcd
+buglist, add todo 335: add packages to )d op gcd<br/>
 <a href="patches/20140603.02.tpd.patch">20140603.02.tpd.patch</a>
-books/bookvolbib add published references from/to Axiom
+books/bookvolbib add published references from/to Axiom<br/>
 <a href="patches/20140603.03.tpd.patch">20140603.03.tpd.patch</a>
-books/bookvol10.4 fix "bad reduction" in multivariate poly gcd
+books/bookvol10.4 fix "bad reduction" in multivariate poly gcd<br/>
 <a href="patches/20140603.04.tpd.patch">20140603.04.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140603.05.tpd.patch">20140603.05.tpd.patch</a>
-src/axiom-website/documentation.html add Stroustrop quote
+src/axiom-website/documentation.html add Stroustrop quote<br/>
 <a href="patches/20140603.06.jzc.patch">20140603.06.jzc.patch</a>
-books/bookvolbib fix typo in Rain14 reference from 20 to 30
+books/bookvolbib fix typo in Rain14 reference from 20 to 30<br/>
 <a href="patches/20140603.07.tpd.patch">20140603.07.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140604.01.tpd.patch">20140604.01.tpd.patch</a>
-books/dvipdfm.def added to fix missing file in latex builds
+books/dvipdfm.def added to fix missing file in latex builds<br/>
 <a href="patches/20140605.01.tpd.patch">20140605.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140605.02.tpd.patch">20140605.02.tpd.patch</a>
-books/bookvolbib add Special Topics / Polynomial GCD
+books/bookvolbib add Special Topics / Polynomial GCD<br/>
 <a href="patches/20140605.03.tpd.patch">20140605.03.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140605.04.tpd.patch">20140605.04.tpd.patch</a>
-src/axiom-website/documentation.html add Leslie Lamport quote
+src/axiom-website/documentation.html add Leslie Lamport quote<br/>
 <a href="patches/20140606.01.tpd.patch">20140606.01.tpd.patch</a>
-Makefile copy books/changepage.sty to ${MNT}/${SYS}/doc
+Makefile copy books/changepage.sty to ${MNT}/${SYS}/doc<br/>
 <a href="patches/20140606.02.tpd.patch">20140606.02.tpd.patch</a>
-books/Makefile remove style and def files from final distro
+books/Makefile remove style and def files from final distro<br/>
 <a href="patches/20140606.03.tpd.patch">20140606.03.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140606.04.tpd.patch">20140606.04.tpd.patch</a>
-books/bookvolbib add special functions / exponential integral
+books/bookvolbib add special functions / exponential integral<br/>
 <a href="patches/20140607.01.tpd.patch">20140607.01.tpd.patch</a>
-books/bookvolbib add abstract for Segletes 98, fix duplicate
+books/bookvolbib add abstract for Segletes 98, fix duplicate<br/>
 <a href="patches/20140607.02.tpd.patch">20140607.02.tpd.patch</a>
-src/input/segletes.input implement 6, 8, 10, 12 Ei functions
+src/input/segletes.input implement 6, 8, 10, 12 Ei functions<br/>
 <a href="patches/20140608.01.tpd.patch">20140608.01.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140608.02.tpd.patch">20140608.02.tpd.patch</a>
-bug 7247: subset? uses wrong length test, should use <=
+bug 7247: subset? uses wrong length test, should use <=<br/>
 <a href="patches/20140608.03.tpd.patch">20140608.03.tpd.patch</a>
-src/input/subset.input implement 6, 8, 10, 12 Ei functions
+src/input/subset.input implement 6, 8, 10, 12 Ei functions<br/>
 <a href="patches/20140608.04.tpd.patch">20140608.04.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140609.01.tpd.patch">20140609.01.tpd.patch</a>
-books/bookvol10.4 fix ++X function example in gcd
+books/bookvol10.4 fix ++X function example in gcd<br/>
 <a href="patches/20140610.01.tpd.patch">20140610.01.tpd.patch</a>
-books/bookvolbib add reference Yapp07
+books/bookvolbib add reference Yapp07<br/>
 <a href="patches/20140610.02.tpd.patch">20140610.02.tpd.patch</a>
-src/doc/msgs/s2-us.msgs remove .as extension from compiler msg
+src/doc/msgs/s2-us.msgs remove .as extension from compiler msg<br/>
 <a href="patches/20140610.03.tpd.patch">20140610.03.tpd.patch</a>
-book/*.txt email cleanup
+book/*.txt email cleanup<br/>
 <a href="patches/20140610.04.tpd.patch">20140610.04.tpd.patch</a>
-books/bookvol10.4,bookvol5 add reportInstantiations to API package
+books/bookvol10.4,bookvol5 add reportInstantiations to API package<br/>
 <a href="patches/20140610.05.tpd.patch">20140610.05.tpd.patch</a>
-books/bookvolbib add Le96a
+books/bookvolbib add Le96a<br/>
 <a href="patches/20140612.01.tpd.patch">20140612.01.tpd.patch</a>
-books/bookvolbib add Proving Axiom Correct section, Bert04
+books/bookvolbib add Proving Axiom Correct section, Bert04<br/>
 <a href="patches/20140613.01.tpd.patch">20140613.01.tpd.patch</a>
-books/ProvingAxiomCorrect created
+books/ProvingAxiomCorrect created<br/>
 <a href="patches/20140613.02.tpd.patch">20140613.02.tpd.patch</a>
-books/ProvingAxiomCorrect state the problem
+books/ProvingAxiomCorrect state the problem<br/>
 <a href="patches/20140613.03.tpd.patch">20140613.03.tpd.patch</a>
-books/bookvol4,vol10.3 What is the purpose of the HACKPI domain?
+books/bookvol4,vol10.3 What is the purpose of the HACKPI domain?<br/>
 <a href="patches/20140613.04.tpd.patch">20140613.04.tpd.patch</a>
-buglist 7142 exp^log(x) Cannot take first of an empty list update
+buglist 7142 exp^log(x) Cannot take first of an empty list update<br/>
 <a href="patches/20140613.05.tpd.patch">20140613.05.tpd.patch</a>
-buglist 7142 exp^log(x) Cannot take first of an empty list update
+buglist 7142 exp^log(x) Cannot take first of an empty list update<br/>
 <a href="patches/20140613.06.tpd.patch">20140613.06.tpd.patch</a>
-buglist 7142 exp^log(x) Cannot take first of an empty list update
+buglist 7142 exp^log(x) Cannot take first of an empty list update<br/>
 <a href="patches/20140613.07.tpd.patch">20140613.07.tpd.patch</a>
-buglist 7142 exp^log(x) Cannot take first of an empty list update
+buglist 7142 exp^log(x) Cannot take first of an empty list update<br/>
 <a href="patches/20140613.08.tpd.patch">20140613.08.tpd.patch</a>
-buglist bug 7248: differentiation bug in D(1,z)
+buglist bug 7248: differentiation bug in D(1,z)<br/>
 <a href="patches/20140613.09.tpd.patch">20140613.09.tpd.patch</a>
-buglist bug 7249: radicalSolve(z^7=1, z)
+buglist bug 7249: radicalSolve(z^7=1, z)<br/>
 <a href="patches/20140613.10.tpd.patch">20140613.10.tpd.patch</a>
-buglist bug 7072/19 D(0^z, z) closed
+buglist bug 7072/19 D(0^z, z) closed<br/>
 <a href="patches/20140613.11.tpd.patch">20140613.11.tpd.patch</a>
-buglist bug 7250: print(typeOf(1)::OutputForm) Value Stack Overflow
+buglist bug 7250: print(typeOf(1)::OutputForm) Value Stack Overflow<br/>
 <a href="patches/20140613.12.tpd.patch">20140613.12.tpd.patch</a>
-buglist bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float
+buglist bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float<br/>
 <a href="patches/20140613.13.tpd.patch">20140613.13.tpd.patch</a>
-buglist bug 7249: radicalSolve(z^7=1, z) update
+buglist bug 7249: radicalSolve(z^7=1, z) update<br/>
 <a href="patches/20140614.01.tpd.patch">20140614.01.tpd.patch</a>
-buglist bug 7252: argument(-%i)
+buglist bug 7252: argument(-%i)<br/>
 <a href="patches/20140614.02.tpd.patch">20140614.02.tpd.patch</a>
-buglist bug 7253: There are no library operations named 'when'
+buglist bug 7253: There are no library operations named 'when'<br/>
 <a href="patches/20140614.03.tpd.patch">20140614.03.tpd.patch</a>
-buglist bug 7254: f==n+->sum(sum(1/i,i=1..j),j=1..n) complains
+buglist bug 7254: f==n+->sum(sum(1/i,i=1..j),j=1..n) complains<br/>
 <a href="patches/20140614.04.tpd.patch">20140614.04.tpd.patch</a>
-books/bookvol13 Proving Axiom Correct
+books/bookvol13 Proving Axiom Correct<br/>
 <a href="patches/20140614.05.tpd.patch">20140614.05.tpd.patch</a>
-Fixup broken build issues
+Fixup broken build issues<br/>
 <a href="patches/20140614.06.tpd.patch">20140614.06.tpd.patch</a>
-books/bookvol4 rescale Baker's architecture image
+books/bookvol4 rescale Baker's architecture image<br/>
 <a href="patches/20140615.01.tpd.patch">20140615.01.tpd.patch</a>
-bookvol10.2 bug 7255: BinaryTreeCategory remove finiteAggregate
+bookvol10.2 bug 7255: BinaryTreeCategory remove finiteAggregate<br/>
 <a href="patches/20140615.02.tpd.patch">20140615.02.tpd.patch</a>
-books/bookvol4, ps/v4architecture.eps add Baker's graphic
+books/bookvol4, ps/v4architecture.eps add Baker's graphic<br/>
 <a href="patches/20140615.03.tpd.patch">20140615.03.tpd.patch</a>
-books/bookvol13.pamphlet, ps/v13llvmtoacl2.eps file rename
+books/bookvol13.pamphlet, ps/v13llvmtoacl2.eps file rename<br/>
 <a href="patches/20140615.04.tpd.patch">20140615.04.tpd.patch</a>
-buglist bug 7256: acot(-1) values differ
+buglist bug 7256: acot(-1) values differ<br/>
 <a href="patches/20140615.05.tpd.patch">20140615.05.tpd.patch</a>
-buglist bug 7257: normalize(subst(asin(z),z=-1)) division by zero
+buglist bug 7257: normalize(subst(asin(z),z=-1)) division by zero<br/>
 <a href="patches/20140615.06.tpd.patch">20140615.06.tpd.patch</a>
-buglist bug 7258: acosh(0.0) invalid argument to acosh
+buglist bug 7258: acosh(0.0) invalid argument to acosh<br/>
 <a href="patches/20140615.07.tpd.patch">20140615.07.tpd.patch</a>
-buglist wish 1011: sum(1/(k+a), k=1..n) by Gosper's method
+buglist wish 1011: sum(1/(k+a), k=1..n) by Gosper's method<br/>
 <a href="patches/20140616.01.tpd.patch">20140616.01.tpd.patch</a>
-src/input/polygamma.input add a polygamma example
+src/input/polygamma.input add a polygamma example<br/>
 <a href="patches/20140617.01.tpd.patch">20140617.01.tpd.patch</a>
-books/bookvol10.1, bookvolbib add interval arithmetic
+books/bookvol10.1, bookvolbib add interval arithmetic<br/>
 <a href="patches/20140618.01.tpd.patch">20140618.01.tpd.patch</a>
-src/input/exptest.input test worst case exponential values
+src/input/exptest.input test worst case exponential values<br/>
 <a href="patches/20140618.02.tpd.patch">20140618.02.tpd.patch</a>
-books/axiom.sty master copy, commented
+books/axiom.sty master copy, commented<br/>
 <a href="patches/20140618.03.tpd.patch">20140618.03.tpd.patch</a>
-books/Makefile remove debugging message
+books/Makefile remove debugging message<br/>
 <a href="patches/20140619.01.tpd.patch">20140619.01.tpd.patch</a>
-book/*.txt axiom-developer email cleanup
+book/*.txt axiom-developer email cleanup<br/>
 <a href="patches/20140623.01.tpd.patch">20140623.01.tpd.patch</a>
-book/*.txt cleanup complete, book/timeline of join/leave complete
+book/*.txt cleanup complete, book/timeline of join/leave complete<br/>
 <a href="patches/20140623.02.tpd.patch">20140623.02.tpd.patch</a>
-books/bookvolbib.pamphlet add Baez09
+books/bookvolbib.pamphlet add Baez09<br/>
 <a href="patches/20140623.03.tpd.patch">20140623.03.tpd.patch</a>
-src/axiom-website/download.html add texlive-fonts-extra
+src/axiom-website/download.html add texlive-fonts-extra<br/>
 <a href="patches/20140623.04.tpd.patch">20140623.04.tpd.patch</a>
-src/scripts/boxhead, boxtail, boxup, showdvi removed
+src/scripts/boxhead, boxtail, boxup, showdvi removed<br/>
 <a href="patches/20140623.05.tpd.patch">20140623.05.tpd.patch</a>
-Makefile, books/tangle.c set up a native tangle function
+Makefile, books/tangle.c set up a native tangle function<br/>
 <a href="patches/20140625.01.tpd.patch">20140625.01.tpd.patch</a>
-Makefile books/Makefile.pamphlet books/tangle.c books/extract
+Makefile books/Makefile.pamphlet books/tangle.c books/extract<br/>
 <a href="patches/20140625.02.tpd.patch">20140625.02.tpd.patch</a>
-Makefile.pamphlet src/Makefile.pamphlet use chunk syntax
+Makefile.pamphlet src/Makefile.pamphlet use chunk syntax<br/>
 <a href="patches/20140628.01.tpd.patch">20140628.01.tpd.patch</a>
-zips/noweb-2.10a.tgz deleted, noweb removed
+zips/noweb-2.10a.tgz deleted, noweb removed<br/>
 <a href="patches/20140628.02.tpd.patch">20140628.02.tpd.patch</a>
-src/input/dbtest.input remove failing input file
+src/input/dbtest.input remove failing input file<br/>
 <a href="patches/20140629.01.c1m.patch">20140629.01.c1m.patch</a>
-functionp -> canFuncall?
+functionp -> canFuncall?<br/>
 <a href="patches/20140629.02.tpd.patch">20140629.02.tpd.patch</a>
-books/bookvolbib add Vict11, Vict12 to Advanced Documentation
+books/bookvolbib add Vict11, Vict12 to Advanced Documentation<br/>
 <a href="patches/20140629.03.tpd.patch">20140629.03.tpd.patch</a>
-src/axiom-website/documentation.html add McNamara quote
+src/axiom-website/documentation.html add McNamara quote<br/>
 <a href="patches/20140629.04.tpd.patch">20140629.04.tpd.patch</a>
-Makefile default to notests for users
+Makefile default to notests for users<br/>
 <a href="patches/20140629.05.tpd.patch">20140629.05.tpd.patch</a>
-books/bookvol10.3 add information to SingleInteger
+books/bookvol10.3 add information to SingleInteger<br/>
 <a href="patches/20140629.06.tpd.patch">20140629.06.tpd.patch</a>
-books/tangle.c improve the debugging output (DEBUG==3)
+books/tangle.c improve the debugging output (DEBUG==3)<br/>
 <a href="patches/20140630.01.tpd.patch">20140630.01.tpd.patch</a>
-src/input/wangeez.input Paul Wang's EEZ test polynmials
+src/input/wangeez.input Paul Wang's EEZ test polynmials<br/>
 <a href="patches/20140630.02.tpd.patch">20140630.02.tpd.patch</a>
-books/bookvolbib.pamphlet add special sections, abstracts
+books/bookvolbib.pamphlet add special sections, abstracts<br/>
 <a href="patches/20140703.01.tpd.patch">20140703.01.tpd.patch</a>
-src/axiom-website/documentation.html add W.T. Gowers quote
+src/axiom-website/documentation.html add W.T. Gowers quote<br/>
 <a href="patches/20140703.02.tpd.patch">20140703.02.tpd.patch</a>
-books/bookvolbib add Numerical Algorithms section, add Yang14
+books/bookvolbib add Numerical Algorithms section, add Yang14<br/>
 <a href="patches/20140703.03.tpd.patch">20140703.03.tpd.patch</a>
-src/axiom-website/documentation.html add Lamport quote
+src/axiom-website/documentation.html add Lamport quote<br/>
 <a href="patches/20140703.04.tpd.patch">20140703.04.tpd.patch</a>
-books/bookvolbib add Lamport book "Specifying Systems"
+books/bookvolbib add Lamport book "Specifying Systems"<br/>
 <a href="patches/20140706.01.tpd.patch">20140706.01.tpd.patch</a>
-books/bookvolbib add references Meij91, Mohr94
+books/bookvolbib add references Meij91, Mohr94<br/>
 <a href="patches/20140707.01.tpd.patch">20140707.01.tpd.patch</a>
-books/bookvolbib add many new references
+books/bookvolbib add many new references<br/>
 <a href="patches/20140707.02.tpd.patch">20140707.02.tpd.patch</a>
-books/bookvolbib add Mohr98, Jeff99
+books/bookvolbib add Mohr98, Jeff99<br/>
 <a href="patches/20140708.01.tpd.patch">20140708.01.tpd.patch</a>
-src/algebra/Makefile add LeftOreRing
+src/algebra/Makefile add LeftOreRing<br/>
 <a href="patches/20140708.02.tpd.patch">20140708.02.tpd.patch</a>
-books/ps/v102leftorering.eps add missing image file
+books/ps/v102leftorering.eps add missing image file<br/>
 <a href="patches/20140710.01.tpd.patch">20140710.01.tpd.patch</a>
-Makefile remove leftover pdf files on clean
+Makefile remove leftover pdf files on clean<br/>
 <a href="patches/20140710.02.tpd.patch">20140710.02.tpd.patch</a>
-books/bookvol4 add a section on changing GCL2 versions
+books/bookvol4 add a section on changing GCL2 versions<br/>
 <a href="patches/20140710.03.tpd.patch">20140710.03.tpd.patch</a>
-zips/gcl-2.6.10.tgz add the latest gcl and all of its patches
+zips/gcl-2.6.10.tgz add the latest gcl and all of its patches<br/>
 <a href="patches/20140710.04.tpd.patch">20140710.04.tpd.patch</a>
-books/bookvol5 GCL 2.6.10 assoc sematics change requires GETL fix
+books/bookvol5 GCL 2.6.10 assoc sematics change requires GETL fix<br/>
 <a href="patches/20140712.01.tpd.patch">20140712.01.tpd.patch</a>
-books/bookvol5  remove compression
+books/bookvol5  remove compression<br/>
 <a href="patches/20140713.01.tpd.patch">20140713.01.tpd.patch</a>
-books/bookvol10 absorb src/algebra/Makefile
+books/bookvol10 absorb src/algebra/Makefile<br/>
 <a href="patches/20140715.01.tpd.patch">20140715.01.tpd.patch</a>
-books/bookvolbib add Hoeij04
+books/bookvolbib add Hoeij04<br/>
 <a href="patches/20140718.01.tpd.patch">20140718.01.tpd.patch</a>
-books/bookvolbib add Jeff97
+books/bookvolbib add Jeff97<br/>
 <a href="patches/20140719.01.tpd.patch">20140719.01.tpd.patch</a>
-books/bookvol10.1, bookvolbib, bookheader.tex clean up mistakes
+books/bookvol10.1, bookvolbib, bookheader.tex clean up mistakes<br/>
 <a href="patches/20140720.01.tpd.patch">20140720.01.tpd.patch</a>
-books/bookvol7, bookvol8 apply Camm's patches
+books/bookvol7, bookvol8 apply Camm's patches<br/>
 <a href="patches/20140722.01.tpd.patch">20140722.01.tpd.patch</a>
-books/bookvol10.1 add section on interpolation formulas
+books/bookvol10.1 add section on interpolation formulas<br/>
 <a href="patches/20140723.01.tpd.patch">20140723.01.tpd.patch</a>
-books/bookvol10.1 expand section on interpolation formulas
+books/bookvol10.1 expand section on interpolation formulas<br/>
 <a href="patches/20140724.01.tpd.patch">20140724.01.tpd.patch</a>
-books/bookvol13, bookvolbib add Mason86 for proving Axiom
+books/bookvol13, bookvolbib add Mason86 for proving Axiom<br/>
 <a href="patches/20140724.02.tpd.patch">20140724.02.tpd.patch</a>
-books/bookvol13, bookvolbib add Daly10 for proving Axiom
+books/bookvol13, bookvolbib add Daly10 for proving Axiom<br/>
 <a href="patches/20140726.01.tpd.patch">20140726.01.tpd.patch</a>
-Makefile, lsp/Makefile, zips/gcl-cygwin.tgz use the latest gcl
+Makefile, lsp/Makefile, zips/gcl-cygwin.tgz use the latest gcl<br/>
 <a href="patches/20140727.01.tpd.patch">20140727.01.tpd.patch</a>
 books/tangle.c -> books/tanglec.c
+<a href="patches/20140727.02.tpd.patch">20140727.02.tpd.patch</a>
+August 2014 release<br/>
+<br/>  <hr>
+<a name="latest"/>
+<h3>Latest Release</h3>
+<br/><a href="#20140727">Jump to previous release</a>
+<br/><a href="#20071123">Jump to top release</a>
+<br/>
+<br/>
+In process, not yet released<br/><br/>
  </body>
 </html>
 
diff --git a/src/axiom-website/releasenotes.html b/src/axiom-website/releasenotes.html
index c7a1d38..ca84073 100644
--- a/src/axiom-website/releasenotes.html
+++ b/src/axiom-website/releasenotes.html
@@ -146,11 +146,485 @@
 </div><!-- end #sidebar -->
 
 <br/><hr></br>
+<a name="20140727"/>
+<h3>August, 2014 Release Notes </h3>
+<a href="patches.html#20120531>patch list</a>
+<br/><a href="#20120531">Jump to next older release</a>
+<br/><!--a href="#2012">Jump to newer release</a-->
+<pre>
+August 2014 release notes
+
+This release moves Axiom to the latest GCL version.
+All unused prior versions were removed.
+
+Most of the work involved in this release has involved CATS,
+working with Albert Rich to develop Axiom tests.
+
+Noweb was removed. Axiom now uses its own literate tools.
+
+The databases are no longer compressed.
+
+Volume 13: Proving Axiom Correct was started
+
+Makefile.pamphlet
+   VERSION = August 2014
+   TESTSET defaults to regresstests
+   fix missing dvipdfm
+   remove noweb
+
+book/
+   new directory containing axiom-developer emails
+   reduce and categorize emails for history
+   create timeline of people joining/leaving
+
+books/
+   axiom.sty
+      document
+      remove all other sources
+      add additional macros
+   axbook.tgz
+      fix sinCosExpandRules
+   dvipdfm.def
+      added
+   tanglec.c
+      new C function to handle chunks
+   tangle.lisp
+      add fastxhtml extraction from bookvol11
+   extract (rename from document)
+      support new chunk syntax
+   ps/
+      move .ps to .eps 
+      add new images
+
+books/Makefile
+   handle bookheader.tex
+   fix broken sed regular expression
+   add bookvol13 (Proving Axiom Correct)
+
+books/bookheader.tex
+   user underline, colored links
+   standardize headers, table of contents
+
+books/bookvol0 (Jenks)
+   add condata for MAGCDOC
+   add graphics, fix typos, add text
+
+books/bookvol1 (tutorial)
+   use bookheader.tex
+   fix typos
+
+books/bookvol2 (users guide)
+   use bookheader.tex
+   add category theory chapter
+   remove noweb
+
+books/bookvol3 (programmers guide)
+   use bookheader.tex
+   remove noweb
+
+books/bookvol4 (developers guide)
+   use bookheader.tex
+   section on changing GCL versions
+   document makeHelpFiles
+   remove autoload files
+   remove noweb
+   add HACKPI section
+
+books/bookvol5 (interpreter)
+   use bookheader.tex
+   fix GETL for GCL
+   add Attributes as Categories
+   add Comparable
+   add LeftOreRing
+   add U32Matrix support macros
+   add bc-matrix code
+   add support code for U8Vector
+   add support code for U32Vector
+   add support code for U8Matrix
+   add support code for U16Matrix
+   add U32VectorPolyunomialOperations
+   expose FiniteFieldFactorization
+   expose MAGCDOC
+   expose MatrixManipulation
+   rename functionp to canFuncall?
+   incremental rewrite of br-con.lisp
+   merge ht-util.lisp
+
+books/bookvol6 (commands)
+   use bookheader.tex
+
+books/bookvol7 (hyperdoc)
+   apply Camm's patches
+   remove bibliography
+   standardize the table of contents
+   update credits
+   use bookheader.tex
+
+books/bookvol7.1 (hyperdoc pages)
+   standardize the table of contents
+   update What's New Page
+   update credits
+   use bookheader.tex
+
+books/bookvol8 (graphics)
+   apply Camm's patches
+   convert bookvol8 from noweb to chunks
+   remove crc test cases
+   standardize the table of contents
+   update credits
+   use bookheader.tex
+   remove noweb
+
+books/bookvol8.1 (graphics gallery)
+   add CRC standard test cases, section 2.3-2.9
+
+books/bookvol9 (compiler)
+   use bookheader.tex
+   functionp -> canFuncall?
+
+books/bookvol10 (algebra implementation)
+   absorb src/algebra/Makefile
+   use bookheader.tex
+
+books/bookvol10.1 (algebra theory)
+   add interval arithmetic
+   add section on interpolation formulas
+   use bookheader.tex
+
+books/bookvol10.2 (categories)
+   AGG bug fixed 40355
+   CLAGG bug fixed 40021
+   MONAD bug fix 40350, add 7236
+   ORDSET bug fix 40346
+   PTRANFN bug fixed 40357
+   REAL bug fix 40345
+   add Attributes as Categories
+   add Comparable
+   add LeftOreRing
+   add MAGCDOC
+   add enumerate to FINITE
+   add matrix initializer function
+   fix failing test cases
+   fix help documentation and regression tests
+   use bookheader.tex
+   write help documentation for all categories
+   FiniteSetAggregate subset? fixed
+   BinaryTreeCategory remove finiteAggregate, bug fix 7255
+
+books/bookvol10.3 (domains)
+   AFFSP bug fix 30230, 20495; introduce 60076
+   BLAS1 bug fixed 40304
+   CHAR bug fix 40022
+   DFLOAT bug fix 20073, add 20570
+   DFLOAT bug fixed 40019
+   FPS bug fixed 40013
+   INBFF bug fixed 20465, add 20571
+   INTRVL bug fix 20480, 30143
+   ITAYLOR bug fix 20542 pretend
+   LIST bug fix 20063, add, add 20569
+   MLIFT bug fix 20001, add 20568
+   OPTPROB bug fix 40347
+   RNUMP removed bug fix 30047
+   SINT bug fix 20057 pretend
+   SMTS bug fix 20383, 50005, add 20567
+   SYMBOL bug fix 20056 pretend
+   add U16Matrix
+   add U16Vector
+   add U32Matrix
+   add U8Matrix
+   add U8Vector
+   add information to SingleInteger
+   SEXOF bug fix 20501
+   fix failing test cases
+   fix help documentation and regression tests
+   move EFULS EFUPXS from package to domain
+   update U32Vector domain
+   use bookheader.tex
+   write help documentation for all domains
+
+books/bookvol10.4 (packages)
+   ATTREG bug fix 40362
+   ELTAB bug fix 40360
+   FSPECF bug fix 7235, 40077
+   GRAY bug fixed 20467
+   MAPPKG1 bug fix 40351
+   MSYSCMD bug fix 40359
+   SOLVERAD bug fix 40043
+   SREGSET bug fix 50001
+   add FiniteFieldFactorization
+   add MatrixManipulation, add Raoul Bourquin
+   add U32VectorPolynomialOperations
+   apply Waldek's changes to imposelc in PGCD
+   comment out bad code in GUESS
+   document htrigs function in TRMANIP
+   expand hyperbolic identities
+   bug fix "bad reduction" in multivariate poly gcd
+   bug fix ++X function example in gcd
+   bug fix OUT.spad warning (bug 329)
+   bug fix failing test cases
+   bug fix help documentation and regression tests
+   move EFULS EFUPXS from package to domain
+   use bookheader.tex
+   write help documentation
+   add reportInstantiations to API package
+
+books/bookvol10.5 (numerics)
+   add netlib cephes function covers
+   use bookheader.tex
+
+books/bookvol11 (browser)
+   use bookheader.tex
+   remove noweb
+
+books/bookvol12 (crystal)
+   remove noweb
+
+books/bookvol13 (proving axiom correct)
+   created
+
+books/bookvolbib (bibliography)
+   add references and abstracts
+   add subsection Ore Rings 
+   add subsection Partial Fraction Decomposition
+   add subsection Integration
+   add subsection Expression Simplification
+   add subsection Differential Equations
+   add subsection Advanced Documentation
+   add subsection Numerics
+   add subsection Interval Arithmetic
+   add subsection Proving Axiom Correct
+   add subsection Category Theory
+   add subsection Polynomial GCD
+   add subsection Exponenetial Integral
+   add subsection Special Functions
+   add subsection Numerical Algorithms
+   add subsection Solving Systems of Equations
+
+buglist
+   MLIFT fix 20001, add 20568
+   AGG fixed 40355
+   ATTREG fix 40362
+   BLAS1 fixed 40304
+   CHAR fix 40022
+   CLAGG fixed 40021
+   DFLOAT fix 20073, add 20570
+   DFLOAT fixed 40019
+   ELTAB fix 40360
+   FPS fixed 40013
+   FSPECF fix 7235, 40077
+   GRAY fixed 20467
+   INBFF fixed 20465, add 20571
+   INTRVL fix 20480, 30143
+   ITAYLOR fix 20542 pretend
+   LIST fix 20063, add, add 20569
+   MAPPKG1 fix 40351
+   MONAD fix 40350, add 7236
+   MSYSCMD fix 40359
+   OPTPROB fix 40347
+   ORDSET fix 40346
+   PTRANFN fixed 40357
+   REAL fix 40345
+   SINT fix 20057 pretend
+   SMTS fix 20383, 50005, add 20567
+   SOLVERAD fix 40043
+   SREGSET fix 50001
+   SYMBOL fix 20056 pretend
+   fix bug 7072/19 D(0^z, z) closed
+   fix bug 7248: differentiation fix bug in D(1,z)
+   fix bug 7249: radicalSolve(z^7=1, z)
+   fix bug 7249: radicalSolve(z^7=1, z) update
+   fix bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float
+   fix bug 7252: argument(-%i)
+   fix bug 7253: There are no library operations named 'when'
+   fix bug 7254: f==n+->sum(sum(1/i,i=1..j),j=1..n) complains
+   fix bug 7256: acot(-1) values differ
+   fix bug 7257: normalize(subst(asin(z),z=-1)) division by zero
+   fix bug 7258: acosh(0.0) invalid argument to acosh
+   fix bug 20501, SEXOF pretend, 30047 RNUMP
+   fix bug 30230, 20495; introduce 60076
+   fix bug 7236
+   fix bug 329, add todo 330
+   remove dead items
+   remove error message for deleted files
+   add 7142 exp^log(x) Cannot take first of an empty list update
+   add 7233: fill! operation from U8Vector does not show up
+   add 7242/7243
+   add 7244, 7245
+   add bug 7241, fix the integration routines
+   add bugs found in tests
+   add kamke4, kamke6 missing bug
+   add todo 335: add packages to )d op gcd
+   add 7232
+   wish 1011: sum(1/(k+a), k=1..n) by Gosper's method
+
+Wikipedia
+   en.wikipedia.org/wiki/Axiom_(computer_algebra_system) update date
+   en.wikipedia.org/wiki/List_of_computer_algebra_systems update date
+
+faq
+   remove noweb
+   fix mailing list links
+
+readme
+   add Edi Meier
+   add Edi Meier
+   add Jia Zhao Cong
+   add Raoul Bourquin
+   update credits
+
+src/Makefile
+   clean up src/algebra properly
+   convert bookvol8 from noweb to chunks
+   fix {OUT} bug
+   handle special case files for bookvol11
+   rename tangle.c to tanglec.c
+   pamphlet extract src using chunk syntax
+   pamphlet modified, noweb removed
+
+src/algebra/Makefile
+   add Comparable
+   add FINITE-
+   add LeftOreRing
+   add MatrixManipulation
+   add U16Matrix
+   add U32Matrix
+   add U32VectorPolynomialOperations
+   add U8Matrix
+   add fastxhtml extraction call
+   add machinearithmetic.input
+   compile FiniteFieldFactorization
+   compile MAGCDOC
+   fix failing test cases
+   set up regression tests
+   update graph info for OUT
+   modified, noweb removed
+
+src/algebra/libdb.text
+   add Attributes as Categories
+
+src/axiom-website/
+   AxiomConference.pdf added
+   axiom.sty
+   CATS/
+      charlwood.input added
+      rich* added
+      kamke*.txt added
+   books/
+      add 8.1, 10.5, bibliography
+      add bookvol13
+   community/
+      fix mailing list links
+   documentation.html
+      add AxiomConference.pdf
+      add Bottorff quote
+      add Knuth quote, cleanup
+      add Lamport quote
+      add McNamara quote
+      add Stroustrop quote
+      add W.T. Gowers quote
+   download.html
+      add binaries
+      add texlive-fonts-extra
+   patches.html
+      add patches
+   releasenotes.html
+       update for August 2014
+
+src/booklets
+   Makefile cleanup
+
+src/clef
+   Makefile rename tangle to tanglec
+   edible.c modified, noweb removed
+
+src/doc
+   export endpaper as pdf
+   remove axiom.bib
+   rename tangle to tanglec
+   use books/axiom.sty
+   remove noweb
+   booklet.c fix mailing list, remove noweb
+   msgs/
+      s2-us.msgs remove .as extension from compiler msg
+
+src/etc
+   Makefile remove noweb
+   asq.c remove noweb
+
+src/input/
+   Makefile add input tests for 
+      charlwood, cherry, functioncode, machinarithmetic,
+      pgcd, polygamma, rich*, romanpolynomials, rsa, segletes
+      exptest, subset, tree, trigtests
+   Makefile remove noweb
+   add many tests
+
+src/interp
+   Makefile
+      remove noweb
+      remove autoload of ht-util
+      remove bc-matrix
+    bc-matrix.lisp removed
+    br-con.lisp move to bookvol5
+    debugsys cleanup
+    g-timer.lisp RNUMP removed
+    g-util.lisp functionp -> canFuncall?
+    g-util.lisp remove functions
+    ht-util.lisp deleted, merged with bookvol5
+    i-coerce.lisp functionp -> canFuncall?
+    i-funsel.lisp remove functions
+    i-spec2.lisp. functionp -> canFuncall?
+    interp-proclaims.lisp functionp -> canFuncall?
+    regress.lisp improve diff output
+    sys-pkg.lisp RNUMP removed
+    temp.text deleted
+    util.lisp functionp -> canFuncall?
+    util.lisp remove autoload of ht-util
+    util.lisp remove autoload trigger functions
+    util.lisp remove bc-matrix autoload triggers
+    util.lisp remove compression
+    vmlisp.lisp RNUMP removed
+
+src/scripts
+   Makefile remove noweb
+   boxhead removed
+   boxtail removed
+   boxup removed
+   document -> books/extract
+   showdvi removed
+   tex/
+      axiom.sty removed
+
+src/share
+   Makefile remove noweb
+   algebra/compress removed
+   algebra/browse, category, dependents, interp, operations, users
+      add Attributes as Categories
+      add LeftOreRing
+      enumerate to FINITE
+      no compression
+      updated
+   doc/
+      hypertex/pages/util.ht deleted, unused
+
+src/sman
+   Makefile cleanup
+
+zips/
+   axiom.vim.tgz vim syntax file added
+   gcl-cgywin.tgz added
+   noweb-2.10a.tgz deleted, noweb removed
+   noweb.* deleted, noweb removed
+   all unused patches and versions of gcl deleted
+
+</pre>
+
+<br/><hr></br>
 <a name="20120531"/>
 <h3>May, 2012 Release Notes </h3>
 <a href="patches.html#20120531>patch list</a>
 <br/><a href="#20120331">Jump to next older release</a>
-<br/><!--a href="#2012">Jump to newer release</a-->
+<br/><a href="#20140727">Jump to newer release</a-->
 <pre>
 May 2012 release notes
 
diff --git a/zips/gcl-2.4.1.h.386-linux.defs.patch b/zips/gcl-2.4.1.h.386-linux.defs.patch
deleted file mode 100644
index 9fa969c..0000000
--- a/zips/gcl-2.4.1.h.386-linux.defs.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- 386-linux.defs	Mon Jan  7 12:02:38 2002
-+++ 386-linux.defs.tpd	Mon Dec 23 22:33:44 2002
-@@ -8,6 +8,8 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+
- LBINDIR=/usr/local/bin
- 
- OFLAG	=  -O 
diff --git a/zips/gcl-2.4.1.h.386-linux.h.patch b/zips/gcl-2.4.1.h.386-linux.h.patch
deleted file mode 100644
index c2b8645..0000000
--- a/zips/gcl-2.4.1.h.386-linux.h.patch
+++ /dev/null
@@ -1,14 +0,0 @@
---- 386-linux.h	Mon Jan  7 11:44:35 2002
-+++ 386-linux.h.tpd	Mon Dec 23 23:51:53 2002
-@@ -147,8 +147,9 @@
- #endif
- #define PAGEWIDTH       12      /*  page width  */
- 
--
--#undef HAVE_XDR
-+/* we need XDR -- tpd */
-+/*#undef HAVE_XDR*/
-+#define HAVE_XDR
- 
- #ifdef IN_UNIXSAVE
- #include <linux/user.h> 
diff --git a/zips/gcl-2.4.1.unixport.init_gcl.lsp.patch b/zips/gcl-2.4.1.unixport.init_gcl.lsp.patch
deleted file mode 100644
index dcbbb84..0000000
--- a/zips/gcl-2.4.1.unixport.init_gcl.lsp.patch
+++ /dev/null
@@ -1,24 +0,0 @@
---- init_gcl.lsp	Fri May 11 01:56:54 2001
-+++ init_gcl.lsp.tpd	Wed Dec 11 23:09:55 2002
-@@ -72,12 +72,15 @@
-   (cond ((si::get-command-arg "-batch")
-          (setq si::*top-level-hook* 'bye))
-         ((si::get-command-arg "-f"))
--        (t  ;; if ANY header or license information is printed by the
--            ;; program, then the following License and Enhancement notice
--            ;; must be printed (see License).
--	 (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%" "DATE"
--		 "Licensed under GNU Library General Public License"
--		 "Contains Enhancements by W. Schelter")))
-+        ((si::get-command-arg "-toploop")
-+         (progn (load "toploop" :verbose nil) (toploop)))
-+        (t nil))
-+;;        (t  ;; if ANY header or license information is printed by the
-+;;            ;; program, then the following License and Enhancement notice
-+;;            ;; must be printed (see License).
-+;;	 (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%" "DATE"
-+;;		 "Licensed under GNU Library General Public License"
-+;;		 "Contains Enhancements by W. Schelter")))
-      (setq si::*ihs-top* 1)
-   (in-package 'system::user) (incf system::*ihs-top* 2)
-   (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.4.1.unixport.makefile.patch b/zips/gcl-2.4.1.unixport.makefile.patch
deleted file mode 100644
index ed4f89b..0000000
--- a/zips/gcl-2.4.1.unixport.makefile.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- makefile	Mon Jan  7 11:44:36 2002
-+++ makefile.tpd	Mon Dec 23 22:22:19 2002
-@@ -128,7 +128,7 @@
- 
- # end makedefs
- 
--LIBS1= $(LIBS) $(LIBSYSTEM) $(GCLIB)
-+LIBS1= $(LIBS) $(LIBSYSTEM) $(GCLIB) ${OBJ}/${SYS}/lib/libspad.a
- 
- OD=$(ODIR)/
- NEW_INIT=$(OD)new_init.o
diff --git a/zips/gcl-2.5.2.cmpnew.cmpcall.lsp.patch b/zips/gcl-2.5.2.cmpnew.cmpcall.lsp.patch
deleted file mode 100644
index 6893503..0000000
--- a/zips/gcl-2.5.2.cmpnew.cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- cmpcall.lsp	2003-02-26 17:21:35.000000000 -0500
-+++ cmpcall.lsp.tpd	2003-07-13 09:46:46.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20030713000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.5.2.cmpnew.cmpflet.lsp.patch b/zips/gcl-2.5.2.cmpnew.cmpflet.lsp.patch
deleted file mode 100644
index d1bf9d6..0000000
--- a/zips/gcl-2.5.2.cmpnew.cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- cmpflet.lsp	1999-12-06 17:43:56.000000000 -0500
-+++ cmpflet.lsp.tpd	2003-07-13 09:47:14.000000000 -0400
-@@ -308,8 +308,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20030713000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.5.2.h.linux.defs.patch b/zips/gcl-2.5.2.h.linux.defs.patch
deleted file mode 100644
index a591f57..0000000
--- a/zips/gcl-2.5.2.h.linux.defs.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- linux.defs~	Thu Sep 12 00:38:49 2002
-+++ linux.defs	Sat May  3 21:59:40 2003
-@@ -8,8 +8,12 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+
- LBINDIR=/usr/local/bin
- 
-+OFLAG = -O
-+
- #OFLAG	=  -g -Wall
- #OFLAG	=  -g -Wall -fomit-frame-pointer -Werror
- #LIBS	= -lm 
diff --git a/zips/gcl-2.5.2.h.linux.h.patch b/zips/gcl-2.5.2.h.linux.h.patch
deleted file mode 100644
index 7a7a35b..0000000
--- a/zips/gcl-2.5.2.h.linux.h.patch
+++ /dev/null
@@ -1,14 +0,0 @@
---- linux.h~	Sun Oct 27 15:23:53 2002
-+++ linux.h	Sat May  3 22:06:44 2003
-@@ -119,8 +119,9 @@
- #undef RUN_PROCESS
- 
- #define	IEEEFLOAT
--       
--#undef HAVE_XDR
-+
-+/* Axiom needs XDR */       
-+#define HAVE_XDR
- 
- #define USE_ULONG_
- 
diff --git a/zips/gcl-2.5.2.o.cmpaux.c.patch b/zips/gcl-2.5.2.o.cmpaux.c.patch
deleted file mode 100644
index 64627c0..0000000
--- a/zips/gcl-2.5.2.o.cmpaux.c.patch
+++ /dev/null
@@ -1,52 +0,0 @@
---- cmpaux.c~	Thu Feb 27 09:12:13 2003
-+++ cmpaux.c	Sat May  3 22:18:06 2003
-@@ -199,28 +199,28 @@
- 	return(i);
- }
- 
--/* static float */
--/* object_to_float(object x) */
--/* { */
--/* 	float f=0.0; */
-+float 
-+object_to_float(object x) 
-+{ 
-+ 	float f=0.0; 
- 
--/* 	switch (type_of(x)) { */
--/* 	case t_character: */
--/* 		f = char_code(x);  break; */
--/* 	case t_fixnum: */
--/* 		f = fix(x);  break; */
--/* 	case t_bignum: */
--/* 	case t_ratio: */
--/* 		f = number_to_double(x);  break; */
--/* 	case t_shortfloat: */
--/* 		f = sf(x);  break; */
--/* 	case t_longfloat: */
--/* 		f = lf(x);  break; */
--/* 	default: */
--/* 		FEerror("~S cannot be coerce to a C float.", 1, x); */
--/* 	} */
--/* 	return(f); */
--/* } */
-+ 	switch (type_of(x)) { 
-+ 	case t_character: 
-+ 		f = char_code(x);  break; 
-+ 	case t_fixnum: 
-+ 		f = fix(x);  break; 
-+	case t_bignum: 
-+ 	case t_ratio: 
-+ 		f = number_to_double(x);  break; 
-+ 	case t_shortfloat: 
-+ 		f = sf(x);  break; 
-+ 	case t_longfloat: 
-+ 		f = lf(x);  break; 
-+ 	default: 
-+ 		FEerror("~S cannot be coerce to a C float.", 1, x); 
-+ 	} 
-+ 	return(f); 
-+ } 
- 
- /* static double */
- /* object_to_double(object x) */
diff --git a/zips/gcl-2.5.2.o.main.c.patch b/zips/gcl-2.5.2.o.main.c.patch
deleted file mode 100644
index 6ae4002..0000000
--- a/zips/gcl-2.5.2.o.main.c.patch
+++ /dev/null
@@ -1,26 +0,0 @@
---- main.c	2003-03-01 17:37:37.000000000 -0500
-+++ main.c.tpd	2003-07-18 13:09:40.000000000 -0400
-@@ -235,7 +235,8 @@
- 
- #ifdef BSD
- #ifndef MAX_STACK_SIZE
--#define MAX_STACK_SIZE (1<<23) /* 8Mb */
-+/* 20030718001 tpd Axiom stacks large objects */
-+#define MAX_STACK_SIZE (1<<24) /* 16Mb */
- #endif
- #ifdef RLIMIT_STACK
- 	getrlimit(RLIMIT_STACK, &rl);
-@@ -626,11 +627,11 @@
- DEFUN_NEW("QUIT",object,fLquit,LISP
-        ,0,1,NONE,OI,OO,OO,OO,(fixnum exitc),"")
- {	return fLbye(exitc); }
-- 
-+/* 20030718000 tpd Axiom defines EXIT 
- DEFUN_NEW("EXIT",object,fLexit,LISP
-        ,0,1,NONE,OI,OO,OO,OO,(fixnum exitc),"")
- {	return fLbye(exitc); }
-- 
-+*/
- 
- /*  c_trace(void) */
- /*  { */
diff --git a/zips/gcl-2.5.2.o.package.d.patch b/zips/gcl-2.5.2.o.package.d.patch
deleted file mode 100644
index d4dda4e..0000000
--- a/zips/gcl-2.5.2.o.package.d.patch
+++ /dev/null
@@ -1,30 +0,0 @@
---- package.d~	Fri Feb 14 19:38:28 2003
-+++ package.d	Sat May  3 22:27:00 2003
-@@ -220,10 +220,14 @@
- 
- 	x = find_package(n);
- 	if (x == Cnil) {
-- 	   	FEpackage_error(n,"No such package");  
-- 		return Cnil; 
--/*  		x = make_package(n, ns, ul,isize,esize);  */
--/*  		goto L;  */
-+/* this changes the common lisp 2.0 defined behavior of in-package
-+   (throw an error if the package does not exist) so that it mirrors
-+   the 1.0 defined behavior (create the package if it does not exist).
-+   This patch is intended to be temporary. Axiom's common lisp code
-+   should be fixed and this patch removed before shipment -- tpd
-+*/
-+  		x = make_package(n, ns, ul,isize,esize);  
-+  		goto L;  
- 	}
- 	if (isize) rehash_pack(&(x->p.p_internal),
- 		&x->p.p_internal_size,isize);
-@@ -243,7 +247,7 @@
- 	}
- 	for (;  !endp(ul);  ul = ul->c.c_cdr)
- 		use_package(ul->c.c_car, x);
--/* L:  */
-+L:  
- 	sLApackageA->s.s_dbind = x;
- 	vs_reset;
- 	return(x);
diff --git a/zips/gcl-2.5.2.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.5.2.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index 00043a5..0000000
--- a/zips/gcl-2.5.2.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,24 +0,0 @@
---- init_gcl.lsp.in~	Sun Mar  2 10:23:17 2003
-+++ init_gcl.lsp.in	Sat May  3 22:13:38 2003
-@@ -77,13 +77,14 @@
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
- 	 ((si::get-command-arg "-f"))
--	 (t  ;; if ANY header or license information is printed by the
--	  ;; program, then the following License and Enhancement notice
--	  ;; must be printed (see License).
--	  (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%~%~a~%" "@LI-VERS@"
--		  "Licensed under GNU Library General Public License"
--		  "Dedicated to the memory of W. Schelter"
--		  "Use (help) to get some basic information on how to use GCL.")))
-+;;	 (t  ;; if ANY header or license information is printed by the
-+;;	  ;; program, then the following License and Enhancement notice
-+;;	  ;; must be printed (see License).
-+;;	  (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%~%~a~%" "@LI-VERS@"
-+;;	  "Licensed under GNU Library General Public License"
-+;;	  "Dedicated to the memory of W. Schelter"
-+;;	  "Use (help) to get some basic information on how to use GCL."))
-+   )
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.5.2.unixport.makefile.patch b/zips/gcl-2.5.2.unixport.makefile.patch
deleted file mode 100644
index bbe0533..0000000
--- a/zips/gcl-2.5.2.unixport.makefile.patch
+++ /dev/null
@@ -1,18 +0,0 @@
---- makefile~	Thu Mar 20 10:22:55 2003
-+++ makefile	Sat May  3 22:30:50 2003
-@@ -13,7 +13,7 @@
- PORTDIR = .
- 
- LD_LIBS_PRE=$(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a
- 
- libgclp.a: $(ODIR)/gcllib.a
- 	cp $< $@
-@@ -130,4 +130,4 @@
- 		$(LSPDIR)/auto_new.lsp foo *maxima* init_*.lsp lib*.a gmp* bfd* *.lsp.tmp
- 
- .INTERMEDIATE: init_ansi_gcl.lsp.tmp init_gcl.lsp.tmp raw_gcl raw_ansi_gcl
--.PRECIOUS: init_gcl.lsp init_ansi_gcl.lsp
-\ No newline at end of file
-+.PRECIOUS: init_gcl.lsp init_ansi_gcl.lsp
diff --git a/zips/gcl-2.5.h.linux.defs.patch b/zips/gcl-2.5.h.linux.defs.patch
deleted file mode 100644
index 5efb1d6..0000000
--- a/zips/gcl-2.5.h.linux.defs.patch
+++ /dev/null
@@ -1,10 +0,0 @@
---- linux.defs	Thu Sep 12 00:38:49 2002
-+++ linux.defs.tpd	Sat Mar  8 15:12:50 2003
-@@ -8,6 +8,7 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.5.h.linux.h.patch b/zips/gcl-2.5.h.linux.h.patch
deleted file mode 100644
index 3d0cbef..0000000
--- a/zips/gcl-2.5.h.linux.h.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.h	Sun Oct 27 15:23:53 2002
-+++ linux.h.tpd	Sat Mar  8 15:24:53 2003
-@@ -120,7 +120,9 @@
- 
- #define	IEEEFLOAT
-        
--#undef HAVE_XDR
-+/*#undef HAVE_XDR*/
-+/* we need XDR -- tpd */
-+#define HAVE_XDR
- 
- #define USE_ULONG_
- 
diff --git a/zips/gcl-2.5.o.xdrfuns.c.patch b/zips/gcl-2.5.o.xdrfuns.c.patch
deleted file mode 100644
index 99330e1..0000000
--- a/zips/gcl-2.5.o.xdrfuns.c.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- xdrfuns.c	Sat Jul 20 03:10:56 2002
-+++ xdrfuns.c.tpd	Mon Mar 10 09:52:17 2003
-@@ -35,7 +35,7 @@
-   xdrstdio_create(xdrs, f->sm.sm_fp,
- 		  (f->sm.sm_mode == smm_input ?  XDR_DECODE :
- 		   f->sm.sm_mode == smm_output ?  XDR_ENCODE :
--		   FEerror("stream not input or output",0)))
-+		   FEerror("stream not input or output",0),XDR_ENCODE))
- 		   ;
-   return ar;
- }
diff --git a/zips/gcl-2.5.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.5.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index e1ca5ce..0000000
--- a/zips/gcl-2.5.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,22 +0,0 @@
---- init_gcl.lsp.in	Sun Nov 10 22:43:06 2002
-+++ init_gcl.lsp.in.tpd	Sat Mar  8 15:37:52 2003
-@@ -81,12 +81,13 @@
-   (cond ((si::get-command-arg "-batch")
-          (setq si::*top-level-hook* 'bye))
-         ((si::get-command-arg "-f"))
--        (t  ;; if ANY header or license information is printed by the
--            ;; program, then the following License and Enhancement notice
--            ;; must be printed (see License).
--	 (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%" "DATE"
--		 "Licensed under GNU Library General Public License"
--		 "Contains Enhancements by W. Schelter")))
-+        (t nil))
-+;;        (t  ;; if ANY header or license information is printed by the
-+;;            ;; program, then the following License and Enhancement notice
-+;;            ;; must be printed (see License).
-+;;	 (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%" "DATE"
-+;;		 "Licensed under GNU Library General Public License"
-+;;		 "Contains Enhancements by W. Schelter")))
-      (setq si::*ihs-top* 1)
-   (in-package 'system::user) (incf system::*ihs-top* 2)
-   (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.5.unixport.makefile.patch b/zips/gcl-2.5.unixport.makefile.patch
deleted file mode 100644
index e2389e5..0000000
--- a/zips/gcl-2.5.unixport.makefile.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- makefile	Tue Oct 15 14:38:38 2002
-+++ makefile.tpd	Sat Mar  8 15:28:24 2003
-@@ -14,7 +14,7 @@
- 
- OLDDATE = "DATE"
- 
--LD_LIBS=$(addprefix -u ,$(PATCHED_SYMBOLS)) -lgcl $(LIBS) $(LIBC) -lgclp
-+LD_LIBS=$(addprefix -u ,$(PATCHED_SYMBOLS)) -lgcl $(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a
- 
- libgclp.a: $(ODIR)/gcllib.a
- 	cp $< $@
diff --git a/zips/gcl-2.6.1.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.1.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.1.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.1.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.1.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 3b7c486..0000000
--- a/zips/gcl-2.6.1.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2003-10-09 22:31:05.000000000 -0400
-+++ gcl_cmpflet.lsp.tpd	2003-10-22 23:39:09.000000000 -0400
-@@ -370,8 +370,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.1.h.linux.defs.patch b/zips/gcl-2.6.1.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.1.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.1.o.main.c.patch b/zips/gcl-2.6.1.o.main.c.patch
deleted file mode 100644
index f0e4b9e..0000000
--- a/zips/gcl-2.6.1.o.main.c.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- main.c	2003-09-13 22:30:45.000000000 -0400
-+++ main.c.tpd	2003-10-22 23:57:47.000000000 -0400
-@@ -241,7 +241,8 @@
- 
- #ifdef BSD
- #ifndef MAX_STACK_SIZE
--#define MAX_STACK_SIZE (1<<23) /* 8Mb */
-+/* 20031022000 tpd Axiom stacks large objects */
-+#define MAX_STACK_SIZE (1<<24) /* 16Mb */
- #endif
- #ifdef RLIMIT_STACK
- 	getrlimit(RLIMIT_STACK, &rl);
diff --git a/zips/gcl-2.6.1.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.1.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index d6782c9..0000000
--- a/zips/gcl-2.6.1.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,24 +0,0 @@
---- init_gcl.lsp.in	2003-09-13 22:30:45.000000000 -0400
-+++ init_gcl.lsp.in.tpd	2003-10-23 00:03:52.000000000 -0400
-@@ -77,13 +77,14 @@
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
- 	 ((si::get-command-arg "-f"))
--	 (t  ;; if ANY header or license information is printed by the
--	  ;; program, then the following License and Enhancement notice
--	  ;; must be printed (see License).
--	  (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%~%~a~%" "@LI-VERS@"
--		  "Licensed under GNU Library General Public License"
--		  "Dedicated to the memory of W. Schelter"
--		  "Use (help) to get some basic information on how to use GCL.")))
-+;;	 (t  ;; if ANY header or license information is printed by the
-+;;	  ;; program, then the following License and Enhancement notice
-+;;	  ;; must be printed (see License).
-+;;	  (format t "GCL (GNU Common Lisp)  ~A~%~a~%~a~%~%~a~%" "@LI-VERS@"
-+;;	  "Licensed under GNU Library General Public License"
-+;;	  "Dedicated to the memory of W. Schelter"
-+;;	  "Use (help) to get some basic information on how to use GCL."))
-+)
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.1.unixport.makefile.patch b/zips/gcl-2.6.1.unixport.makefile.patch
deleted file mode 100644
index 0151b27..0000000
--- a/zips/gcl-2.6.1.unixport.makefile.patch
+++ /dev/null
@@ -1,19 +0,0 @@
---- makefile	2003-09-24 11:48:46.000000000 -0400
-+++ makefile.tpd	2003-10-23 00:07:38.000000000 -0400
-@@ -13,7 +13,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a
- 
- libgclp.a: $(ODIR)/gcllib.a
- 	cp $< $@
-@@ -138,4 +139,4 @@
- 		gazonk*.lsp
- 
- .INTERMEDIATE: init_ansi_gcl.lsp.tmp init_gcl.lsp.tmp raw_gcl raw_ansi_gcl
--.PRECIOUS: init_gcl.lsp init_ansi_gcl.lsp
-\ No newline at end of file
-+.PRECIOUS: init_gcl.lsp init_ansi_gcl.lsp
diff --git a/zips/gcl-2.6.10.h.linux.defs.patch b/zips/gcl-2.6.10.h.linux.defs.patch
deleted file mode 100644
index d161426..0000000
--- a/zips/gcl-2.6.10.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2013-11-11 09:55:48.000000000 -0500
-+++ linux.defs.tpd	2014-07-02 06:58:01.811472500 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20120407000 tpd link Axiom's code per Camm's instruction
-+SYSTEM_OBJS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.10.lsp.gcl_top.lsp.patch b/zips/gcl-2.6.10.lsp.gcl_top.lsp.patch
deleted file mode 100644
index e88355b..0000000
--- a/zips/gcl-2.6.10.lsp.gcl_top.lsp.patch
+++ /dev/null
@@ -1,16 +0,0 @@
---- gcl_top.lsp	2013-11-11 09:55:48.000000000 -0500
-+++ gcl_top.lsp.tpd	2014-07-02 07:54:30.780280567 -0400
-@@ -97,9 +97,10 @@
- 	 ((probe-file "init.lsp") (load "init.lsp"))))
-       (and (functionp *top-level-hook*)(funcall   *top-level-hook*)))
- 
--    (when (boundp '*system-banner*)
--      (format t *system-banner*)
--      (format t "Temporary directory for compiler files set to ~a~%" *tmp-dir*))
-+    (setq *tmp-dir* (getenv "TMP"))
-+;    (when (boundp '*system-banner*)
-+;      (format t *system-banner*)
-+;      (format t "Temporary directory for compiler files set to ~a~%" *tmp-dir*))
- 
-     (loop
-       (setq +++ ++ ++ + + -)
diff --git a/zips/gcl-2.6.10.o.read.d.patch b/zips/gcl-2.6.10.o.read.d.patch
deleted file mode 100644
index d4bece1..0000000
--- a/zips/gcl-2.6.10.o.read.d.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- read.d	2013-11-11 09:55:48.000000000 -0500
-+++ read.d.tpd	2014-07-02 07:32:04.301598985 -0400
-@@ -2162,7 +2162,7 @@
- 	else if (strm == Ct)
- 		strm = symbol_value(sLAterminal_ioA);
- 	check_type_stream(&strm);
--	if (stream_at_end(strm)) {
-+	if (!listen_stream(strm)) {
- 		if (eof_errorp == Cnil)
- 			@(return eof_value)
- 		else
diff --git a/zips/gcl-2.6.10.tgz b/zips/gcl-2.6.10.tgz
deleted file mode 100644
index 14e0e2d..0000000
Binary files a/zips/gcl-2.6.10.tgz and /dev/null differ
diff --git a/zips/gcl-2.6.10.unixport.makefile.patch b/zips/gcl-2.6.10.unixport.makefile.patch
deleted file mode 100644
index 8e29c87..0000000
--- a/zips/gcl-2.6.10.unixport.makefile.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- makefile	2013-11-11 09:55:48.000000000 -0500
-+++ makefile.tpd	2014-07-02 07:40:38.480142656 -0400
-@@ -18,7 +18,7 @@
- 
- LD_FLAGS=$(LDFLAGS) $(FIRST_FILE)
- LD_LIBS_PRE=$(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.2.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.2.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.2.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.2.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.2.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 985a317..0000000
--- a/zips/gcl-2.6.2.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2004-02-21 15:51:24.000000000 -0500
-+++ gcl_cmpflet.lsp.tpd	2004-02-21 15:51:50.000000000 -0500
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.2.h.linux.defs.patch b/zips/gcl-2.6.2.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.2.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.2.o.main.c.patch b/zips/gcl-2.6.2.o.main.c.patch
deleted file mode 100644
index 5ac12da..0000000
--- a/zips/gcl-2.6.2.o.main.c.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- main.c	2004-02-21 15:48:20.000000000 -0500
-+++ main.c.tpd	2004-02-21 15:48:30.000000000 -0500
-@@ -246,7 +246,8 @@
- 
- #ifdef BSD
- #ifndef MAX_STACK_SIZE
--#define MAX_STACK_SIZE (1<<23) /* 8Mb */
-+/* 20031022000 tpd Axiom stacks large objects */
-+#define MAX_STACK_SIZE (1<<24) /* 16Mb */
- #endif
- #ifdef RLIMIT_STACK
- 	getrlimit(RLIMIT_STACK, &rl);
diff --git a/zips/gcl-2.6.2.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.2.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index 06fc458..0000000
--- a/zips/gcl-2.6.2.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	2004-02-21 12:17:00.000000000 -0500
-+++ init_gcl.lsp.in.tpd	2004-02-21 15:02:45.000000000 -0500
-@@ -89,8 +89,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.2.unixport.makefile.patch b/zips/gcl-2.6.2.unixport.makefile.patch
deleted file mode 100644
index b17aad4..0000000
--- a/zips/gcl-2.6.2.unixport.makefile.patch
+++ /dev/null
@@ -1,19 +0,0 @@
---- makefile	2004-02-21 12:17:00.000000000 -0500
-+++ makefile.tpd	2004-02-21 14:47:00.000000000 -0500
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
-@@ -154,4 +155,4 @@
- 		gazonk*.lsp
- 
- .INTERMEDIATE: init_ansi_gcl.lsp.tmp init_gcl.lsp.tmp raw_gcl raw_ansi_gcl
--.PRECIOUS: init_gcl.lsp init_ansi_gcl.lsp
-\ No newline at end of file
-+.PRECIOUS: init_gcl.lsp init_ansi_gcl.lsp
diff --git a/zips/gcl-2.6.2a.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.2a.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.2a.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.2a.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.2a.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 985a317..0000000
--- a/zips/gcl-2.6.2a.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2004-02-21 15:51:24.000000000 -0500
-+++ gcl_cmpflet.lsp.tpd	2004-02-21 15:51:50.000000000 -0500
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.2a.h.linux.defs.patch b/zips/gcl-2.6.2a.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.2a.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.2a.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.2a.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index fc5d6ab..0000000
--- a/zips/gcl-2.6.2a.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Wed Apr  7 23:12:55 2004
-+++ init_gcl.lsp.in.tpd	Wed Apr  7 23:13:25 2004
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.2a.unixport.makefile.patch b/zips/gcl-2.6.2a.unixport.makefile.patch
deleted file mode 100644
index d994adf..0000000
--- a/zips/gcl-2.6.2a.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Wed Apr  7 23:08:46 2004
-+++ makefile.tpd	Wed Apr  7 23:09:08 2004
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.3.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.3.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.3.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.3.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.3.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 985a317..0000000
--- a/zips/gcl-2.6.3.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2004-02-21 15:51:24.000000000 -0500
-+++ gcl_cmpflet.lsp.tpd	2004-02-21 15:51:50.000000000 -0500
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.3.h.linux.defs.patch b/zips/gcl-2.6.3.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.3.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.3.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.3.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index fc5d6ab..0000000
--- a/zips/gcl-2.6.3.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Wed Apr  7 23:12:55 2004
-+++ init_gcl.lsp.in.tpd	Wed Apr  7 23:13:25 2004
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.3.unixport.makefile.patch b/zips/gcl-2.6.3.unixport.makefile.patch
deleted file mode 100644
index d994adf..0000000
--- a/zips/gcl-2.6.3.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Wed Apr  7 23:08:46 2004
-+++ makefile.tpd	Wed Apr  7 23:09:08 2004
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.5.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.5.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.5.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.5.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.5.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 985a317..0000000
--- a/zips/gcl-2.6.5.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2004-02-21 15:51:24.000000000 -0500
-+++ gcl_cmpflet.lsp.tpd	2004-02-21 15:51:50.000000000 -0500
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.5.cmpnew.gcl_cmpmain.lsp.patch b/zips/gcl-2.6.5.cmpnew.gcl_cmpmain.lsp.patch
deleted file mode 100644
index d233e6c..0000000
--- a/zips/gcl-2.6.5.cmpnew.gcl_cmpmain.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- /usr/lib/gcl-2.6.5/cmpnew/gcl_cmpmain.lsp	2004-09-03 
-17:48:54.000000000 +0000
-+++ cmpnew/gcl_cmpmain.lsp	2005-01-13 14:29:32.000000000 +0000
-@@ -547,7 +547,7 @@
-     (setq na  (namestring
- 	       (make-pathname :name name :type 
-(pathname-type(first args)))))
-    #+(or dos winnt)
--      (format nil "~a -I~a ~a ~a -c -w ~a -o ~a"
-+      (format nil "~a -I~a ~a ~a -c -w ~s -o ~s"
- 	      *cc*
- 	      (concatenate 'string si::*system-directory* "../h")
- 	      (if (and (boundp '*c-debug*) *c-debug*) " -g " "")
diff --git a/zips/gcl-2.6.5.h.386-linux.h.patch b/zips/gcl-2.6.5.h.386-linux.h.patch
deleted file mode 100644
index 909b181..0000000
--- a/zips/gcl-2.6.5.h.386-linux.h.patch
+++ /dev/null
@@ -1,13 +0,0 @@
-#ifdef IN_SFASL
-#include <sys/mman.h>
-#define CLEAR_CACHE {\
-   void *p,*pe; \
-   p=(void *)((unsigned long)memory->cfd.cfd_start & ~(PAGESIZE-1)); \
-   pe=(void *)((unsigned long)(memory->cfd.cfd_start+memory->cfd.cfd_size) & ~(PAGESIZE-1)) + PAGESIZE-1; \
-   if (mprotect(p,pe-p,PROT_READ|PROT_WRITE|PROT_EXEC)) {\
-     fprintf(stderr,"%p %p\n",p,pe);\
-     perror("");\
-     FEerror("Cannot mprotect", 0);\
-   }\
-}
-#endif
diff --git a/zips/gcl-2.6.5.h.gmp_wrappers.h.patch b/zips/gcl-2.6.5.h.gmp_wrappers.h.patch
deleted file mode 100644
index 22f55cd..0000000
--- a/zips/gcl-2.6.5.h.gmp_wrappers.h.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- gmp_wrappers.h.bb	Fri Sep 17 13:38:59 2004
-+++ gmp_wrappers.h	Fri Sep 17 13:39:35 2004
-@@ -96,8 +96,8 @@
- 
- #define MEM_GMP_CALL(n_,rt_,a_,s_,b_...) \
-    GMP_EXTERN_INLINE Join(RF_,rt_) Join(m,a_)(Join(P,n_)(b_)) { \
--           Join(RD_,rt_);\
-            int j;\
-+	   Join(RD_,rt_);\
- 	   jmp_gmp=0;\
-            if ((j=setjmp(gmp_jmp)))\
-               GBC(j);\
diff --git a/zips/gcl-2.6.5.h.linux.defs.patch b/zips/gcl-2.6.5.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.5.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.5.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.5.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index fc5d6ab..0000000
--- a/zips/gcl-2.6.5.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Wed Apr  7 23:12:55 2004
-+++ init_gcl.lsp.in.tpd	Wed Apr  7 23:13:25 2004
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.5.unixport.makefile.patch b/zips/gcl-2.6.5.unixport.makefile.patch
deleted file mode 100644
index 0d3dbd2..0000000
--- a/zips/gcl-2.6.5.unixport.makefile.patch
+++ /dev/null
@@ -1,21 +0,0 @@
---- makefile	Tue Dec  7 18:46:09 2004
-+++ makefile.tpd	Tue Dec  7 18:47:13 2004
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
-@@ -28,7 +29,7 @@
- 	rm -rf gmp
- 	mkdir gmp
- 	a="$^" ; \
--	for i in $^ ; do \
-+	for i in $$a ; do \
- 		cp $$i gmp/$$(echo $$i | sed -e 's,\.\./,,1' -e 's,/,_,g') ; \
- 	done
- 	touch $@
diff --git a/zips/gcl-2.6.5w.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.5w.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.5w.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.5w.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.5w.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 985a317..0000000
--- a/zips/gcl-2.6.5w.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2004-02-21 15:51:24.000000000 -0500
-+++ gcl_cmpflet.lsp.tpd	2004-02-21 15:51:50.000000000 -0500
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl "L" (fun-cfun (car fd)) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.5w.h.gmp_wrappers.h.patch b/zips/gcl-2.6.5w.h.gmp_wrappers.h.patch
deleted file mode 100644
index 22f55cd..0000000
--- a/zips/gcl-2.6.5w.h.gmp_wrappers.h.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- gmp_wrappers.h.bb	Fri Sep 17 13:38:59 2004
-+++ gmp_wrappers.h	Fri Sep 17 13:39:35 2004
-@@ -96,8 +96,8 @@
- 
- #define MEM_GMP_CALL(n_,rt_,a_,s_,b_...) \
-    GMP_EXTERN_INLINE Join(RF_,rt_) Join(m,a_)(Join(P,n_)(b_)) { \
--           Join(RD_,rt_);\
-            int j;\
-+	   Join(RD_,rt_);\
- 	   jmp_gmp=0;\
-            if ((j=setjmp(gmp_jmp)))\
-               GBC(j);\
diff --git a/zips/gcl-2.6.5w.h.linux.defs.patch b/zips/gcl-2.6.5w.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.5w.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.5w.h.mingw.defs.patch b/zips/gcl-2.6.5w.h.mingw.defs.patch
deleted file mode 100644
index c7a012c..0000000
--- a/zips/gcl-2.6.5w.h.mingw.defs.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- mingw.defs	Wed Dec 15 01:46:02 2004
-+++ mingw.defs.new	Wed Dec 15 01:46:30 2004
-@@ -20,7 +20,7 @@
- FIRST_FILE   = $(ODIR)/firstfile.o
- LAST_FILE    = $(ODIR)/lastfile.o
- LIBFILES     = bcmp.o bzero.o bcopy.o
--EXTRAS       = ${ODIR}/mingwin.o ${ODIR}/mingfile.o
-+EXTRAS       = ${ODIR}/mingwin.o ${ODIR}/mingfile.o ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
- 
- # When using SFASL it is good to have (si::build-symbol-table)
- INITFORM     = (si::build-symbol-table)
diff --git a/zips/gcl-2.6.5w.o.alloc.c.patch b/zips/gcl-2.6.5w.o.alloc.c.patch
deleted file mode 100644
index c1a0b00..0000000
--- a/zips/gcl-2.6.5w.o.alloc.c.patch
+++ /dev/null
@@ -1,21 +0,0 @@
---- alloc.c	Wed Dec 15 01:37:29 2004
-+++ alloc.c.new	Wed Dec 15 01:39:06 2004
-@@ -1485,7 +1485,17 @@
- 	     	RECREATE_HEAP
- #endif
- 		;
--	   }
-+#ifdef       __MINGW32__
-+                /* If malloc() gets called by the C runtime before
-+                 * main starts and the shared memory is not yet
-+                 * initialised causing boofo.
-+                 * SET_REAL_MAXPAGE calls init_shared_memory().
-+                 * This problem arose with gcc 3.4.2 and new libs.
-+                 */
-+                SET_REAL_MAXPAGE
-+                ;
-+#endif
-+            }
- 	}
- 
- #endif	
diff --git a/zips/gcl-2.6.5w.o.mingfile.c.patch b/zips/gcl-2.6.5w.o.mingfile.c.patch
deleted file mode 100644
index 2e318a6..0000000
--- a/zips/gcl-2.6.5w.o.mingfile.c.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- mingfile.c	Wed Dec 15 01:49:32 2004
-+++ mingfile.c.new	Wed Dec 15 01:49:48 2004
-@@ -10,7 +10,7 @@
- 	object path;
- 	check_arg(1);
- 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
--	path = vs_base[0] = truename(coerce_to_pathname(vs_base[0]));
-+	path = vs_base[0] = coerce_to_pathname(vs_base[0]);
- 	
- 	if (vs_base[0]->pn.pn_name==Cnil && vs_base[0]->pn.pn_type==Cnil) {
- 		coerce_to_filename(vs_base[0], filename);
diff --git a/zips/gcl-2.6.5w.o.unixfsys.c.patch b/zips/gcl-2.6.5w.o.unixfsys.c.patch
deleted file mode 100644
index 2ad5df2..0000000
--- a/zips/gcl-2.6.5w.o.unixfsys.c.patch
+++ /dev/null
@@ -1,125 +0,0 @@
---- unixfsys.c	Wed Dec 15 01:53:18 2004
-+++ unixfsys.c.new	Wed Dec 15 01:53:35 2004
-@@ -31,6 +31,10 @@
- #include <pwd.h>
- #endif
- 
-+#ifdef __MINGW32__ 
-+#  include <windows.h> 
-+#endif 
-+
- #ifdef BSD
- #define HAVE_RENAME
- #endif
-@@ -211,6 +215,10 @@
- {
-   object namestring;
-   namestring = coerce_to_namestring(pathname);
-+  if ( pathname == Cnil ) { 
-+     FEerror ( "NIL argument.", 1, pathname ); 
-+  } 
-+    
- #ifndef NO_PWD_H  
-   if(namestring->st.st_self[0]=='~')
-     {char name[20];
-@@ -259,40 +267,67 @@
- 	char current_directory[MAXPATHLEN];
- 	char directory[MAXPATHLEN];
- 	static char *getwd(char *buffer);
-+#ifdef __MINGW32__ 
-+        DWORD current_directory_length =
-+            GetCurrentDirectory ( MAXPATHLEN, current_directory ); 
-+        if ( MAXPATHLEN < current_directory_length ) { 
-+           FEerror ( "truename got a current directory name larger than MAXPATHLEN", 1, "" ); 
-+        } 
-+        if ( 0 == current_directory_length ) { 
-+           FEerror ( "truename could not determine the current directory.", 1, "" ); 
-+        } 
-+#else 
-+        getwd(current_directory); 
-+#endif 
-+    
- 	coerce_to_filename(pathname, filename);
--
--
- 	
- 	for (p = filename, q = 0;  *p != '\0';  p++)
- 		if (*p == '/')
- 			q = p;
- 	if (q == filename) {
- 		q++;
--		getwd(current_directory);
- 		p = "/";
- 	} else if (q == 0) {
- 		q = filename;
--		p = getwd(current_directory);
-+		p = current_directory;
- 	} else
- #ifdef __MINGW32__
--	  if (q[-1]==':') {
--	    int current = (q++, q[0]);
--	    q[0]=0;
--	    getwd(current_directory);
--	    if (chdir(filename) < 0)
--	      FEerror("Cannot get the truename of ~S.", 1, pathname);
--	    p = getwd(directory);
--	    if (p[1]==':' && p[2]=='\\' && p[3]==0) p[2]=0;
--	    q[0]=current;
-+	   if ( ( q > filename ) && ( q[-1] == ':' ) ) {
-+	     int current = (q++, q[0]);
-+	     q[0]=0;
-+	     if (chdir(filename) < 0)
-+	       FEerror("Cannot get the truename of ~S.", 1, pathname);
-+             current_directory_length =
-+               GetCurrentDirectory ( MAXPATHLEN, directory );
-+             if ( MAXPATHLEN < current_directory_length ) { 
-+               FEerror ( "truename got a current directory name larger than MAXPATHLEN", 1, "" ); 
-+             } 
-+             if ( 0 == current_directory_length ) { 
-+               FEerror ( "truename could not determine the current directory.", 1, "" ); 
-+             } 
-+             p = directory; 
-+             if ( p[1]==':' && ( p[2]=='\\' || p[2]=='/' ) && p[3]==0 ) p[2]=0; 
-+	     q[0]=current;
-           }
- 	  else
- #endif	
- 	  {
- 		*q++ = '\0';
--		getwd(current_directory);
- 		if (chdir(filename) < 0)
- 		    FEerror("Cannot get the truename of ~S.", 1, pathname);
-+#ifdef __MINGW32__ 
-+                current_directory_length = GetCurrentDirectory ( MAXPATHLEN, directory ); 
-+                if ( MAXPATHLEN < current_directory_length ) { 
-+                    FEerror ( "truename got a current directory name larger than MAXPATHLEN", 1, "" ); 
-+                } 
-+                if ( 0 == current_directory_length ) { 
-+                    FEerror ( "truename could not determine the current directory.", 1, "" ); 
-+                } 
-+                p = directory; 
-+#else 
- 		p = getwd(directory);
-+#endif                
- 	}
- 	if (p[0] == '/' && p[1] == '\0') {
- 		if (strcmp(q, "..") == 0)
-@@ -327,6 +362,18 @@
- 	struct stat filestatus;
- 
- 	coerce_to_filename(file, filename);
-+
-+#ifdef __MINGW32__
-+        {
-+            char *p;
-+            for (p = filename;  *p != '\0';  p++);
-+            if ( (p > filename) &&
-+                 ( ( *(p-1) == '/' ) || ( *(p-1) == '\\' ) ) ) {
-+               *(p-1) = '\0'; 
-+            }
-+        }
-+#endif        
-+
- 	if (stat(filename, &filestatus) >= 0)
- 	  {
- #ifdef AIX
diff --git a/zips/gcl-2.6.5w.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.5w.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index fc5d6ab..0000000
--- a/zips/gcl-2.6.5w.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Wed Apr  7 23:12:55 2004
-+++ init_gcl.lsp.in.tpd	Wed Apr  7 23:13:25 2004
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.5w.unixport.makefile.patch b/zips/gcl-2.6.5w.unixport.makefile.patch
deleted file mode 100644
index 0d3dbd2..0000000
--- a/zips/gcl-2.6.5w.unixport.makefile.patch
+++ /dev/null
@@ -1,21 +0,0 @@
---- makefile	Tue Dec  7 18:46:09 2004
-+++ makefile.tpd	Tue Dec  7 18:47:13 2004
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
-@@ -28,7 +29,7 @@
- 	rm -rf gmp
- 	mkdir gmp
- 	a="$^" ; \
--	for i in $^ ; do \
-+	for i in $$a ; do \
- 		cp $$i gmp/$$(echo $$i | sed -e 's,\.\./,,1' -e 's,/,_,g') ; \
- 	done
- 	touch $@
diff --git a/zips/gcl-2.6.6.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.6.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index e9c38f3..0000000
--- a/zips/gcl-2.6.6.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	2003-09-13 22:30:33.000000000 -0400
-+++ gcl_cmpcall.lsp.tpd	2003-10-22 23:34:52.000000000 -0400
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.6.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.6.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index 39d337f..0000000
--- a/zips/gcl-2.6.6.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	2004-08-05 18:04:27.000000000 -0400
-+++ gcl_cmpflet.lsp.tpd	2005-03-18 22:53:05.000000000 -0500
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl (c-function-name "L" (fun-cfun (car fd)) (fun-name (car fd))) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.6.cmpnew.gcl_cmpmain.lsp.patch b/zips/gcl-2.6.6.cmpnew.gcl_cmpmain.lsp.patch
deleted file mode 100644
index d233e6c..0000000
--- a/zips/gcl-2.6.6.cmpnew.gcl_cmpmain.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- /usr/lib/gcl-2.6.5/cmpnew/gcl_cmpmain.lsp	2004-09-03 
-17:48:54.000000000 +0000
-+++ cmpnew/gcl_cmpmain.lsp	2005-01-13 14:29:32.000000000 +0000
-@@ -547,7 +547,7 @@
-     (setq na  (namestring
- 	       (make-pathname :name name :type 
-(pathname-type(first args)))))
-    #+(or dos winnt)
--      (format nil "~a -I~a ~a ~a -c -w ~a -o ~a"
-+      (format nil "~a -I~a ~a ~a -c -w ~s -o ~s"
- 	      *cc*
- 	      (concatenate 'string si::*system-directory* "../h")
- 	      (if (and (boundp '*c-debug*) *c-debug*) " -g " "")
diff --git a/zips/gcl-2.6.6.h.linux.defs.patch b/zips/gcl-2.6.6.h.linux.defs.patch
deleted file mode 100644
index 64a2fb9..0000000
--- a/zips/gcl-2.6.6.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	2002-09-12 00:38:49.000000000 -0400
-+++ linux.defs.tpd	2003-10-22 23:42:02.000000000 -0400
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.6.h.linux.h.patch b/zips/gcl-2.6.6.h.linux.h.patch
deleted file mode 100644
index 885ef73..0000000
--- a/zips/gcl-2.6.6.h.linux.h.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- linux.h	2004-05-03 17:35:58.000000000 -0400
-+++ linux.h.tpd	2005-03-05 14:45:54.000000000 -0500
-@@ -93,7 +93,8 @@
-     result = (current_mask & sigmask(m) ? signal_mask(m) : 0) \
-       | (current_mask & sigmask(n) ? signal_mask(n) : 0);
- 
--#undef RUN_PROCESS
-+/*Axiom needs run-process*/
-+/*#undef RUN_PROCESS*/
- 
- #define	IEEEFLOAT
-        
diff --git a/zips/gcl-2.6.6.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.6.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index fc5d6ab..0000000
--- a/zips/gcl-2.6.6.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Wed Apr  7 23:12:55 2004
-+++ init_gcl.lsp.in.tpd	Wed Apr  7 23:13:25 2004
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.6.unixport.makefile.patch b/zips/gcl-2.6.6.unixport.makefile.patch
deleted file mode 100644
index e72462e..0000000
--- a/zips/gcl-2.6.6.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Tue Dec  7 18:46:09 2004
-+++ makefile.tpd	Tue Dec  7 18:47:13 2004
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code.
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.7.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.7.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index 6b31cc5..0000000
--- a/zips/gcl-2.6.7.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	Sun Jul 24 12:54:28 2005
-+++ gcl_cmpcall.lsp.tpd	Sun Jul 24 12:58:36 2005
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.7.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.7.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index c2905ce..0000000
--- a/zips/gcl-2.6.7.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	Sun Jul 24 12:54:29 2005
-+++ gcl_cmpflet.lsp.tpd	Sun Jul 24 13:44:18 2005
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl (c-function-name "L" (fun-cfun (car fd)) (fun-name (car fd))) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.7.configure.in.patch b/zips/gcl-2.6.7.configure.in.patch
deleted file mode 100644
index fd4e8c1..0000000
--- a/zips/gcl-2.6.7.configure.in.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure.in	Sat Jan 15 14:17:17 2005
-+++ configure.in.tpd	Tue Jan 17 09:32:15 2006
-@@ -538,7 +538,7 @@
- 	# results, and the version is kept in special file).
-     
- 	if test -r /etc/.relid -a "X`uname -n`" = "X`uname -s`" ; then
--	    system=MP-RAS-`${AWK} '{print $3}' /etc/.relid'`
-+	    system=MP-RAS-`${AWK} '{print $3}' '/etc/.relid'`
- 	fi
- 	if test "`uname -s`" = "AIX" ; then
- 	    system=AIX-`uname -v`.`uname -r`
diff --git a/zips/gcl-2.6.7.h.linux.defs.patch b/zips/gcl-2.6.7.h.linux.defs.patch
deleted file mode 100644
index fdefaff..0000000
--- a/zips/gcl-2.6.7.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	Sun Jul 24 12:55:14 2005
-+++ linux.defs.tpd	Sun Jul 24 13:55:26 2005
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.7.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.7.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index 117bb7f..0000000
--- a/zips/gcl-2.6.7.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Sun Jul 24 12:55:39 2005
-+++ init_gcl.lsp.in.tpd	Sun Jul 24 14:04:35 2005
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.7.unixport.makefile.patch b/zips/gcl-2.6.7.unixport.makefile.patch
deleted file mode 100644
index 56ed9a4..0000000
--- a/zips/gcl-2.6.7.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Sun Jul 24 12:55:39 2005
-+++ makefile.tpd	Sun Jul 24 15:40:01 2005
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE) 
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.7pre.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.7pre.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index 6b31cc5..0000000
--- a/zips/gcl-2.6.7pre.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	Sun Jul 24 12:54:28 2005
-+++ gcl_cmpcall.lsp.tpd	Sun Jul 24 12:58:36 2005
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.7pre.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.7pre.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index c2905ce..0000000
--- a/zips/gcl-2.6.7pre.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	Sun Jul 24 12:54:29 2005
-+++ gcl_cmpflet.lsp.tpd	Sun Jul 24 13:44:18 2005
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl (c-function-name "L" (fun-cfun (car fd)) (fun-name (car fd))) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.7pre.h.linux.defs.patch b/zips/gcl-2.6.7pre.h.linux.defs.patch
deleted file mode 100644
index fdefaff..0000000
--- a/zips/gcl-2.6.7pre.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	Sun Jul 24 12:55:14 2005
-+++ linux.defs.tpd	Sun Jul 24 13:55:26 2005
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.7pre.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.7pre.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index 117bb7f..0000000
--- a/zips/gcl-2.6.7pre.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	Sun Jul 24 12:55:39 2005
-+++ init_gcl.lsp.in.tpd	Sun Jul 24 14:04:35 2005
-@@ -84,8 +84,8 @@
- 	 (bye (if (or compiler::*error-p* (equal result '(nil))) 1 0))))
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
--	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)))
-+	 ((si::get-command-arg "-f")))
-+;	 (t (format t si::*system-banner*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.7pre.unixport.makefile.patch b/zips/gcl-2.6.7pre.unixport.makefile.patch
deleted file mode 100644
index 56ed9a4..0000000
--- a/zips/gcl-2.6.7pre.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Sun Jul 24 12:55:39 2005
-+++ makefile.tpd	Sun Jul 24 15:40:01 2005
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE) 
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.8pre.cmpnew.gcl_cmpcall.lsp.patch b/zips/gcl-2.6.8pre.cmpnew.gcl_cmpcall.lsp.patch
deleted file mode 100644
index 6b31cc5..0000000
--- a/zips/gcl-2.6.8pre.cmpnew.gcl_cmpcall.lsp.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- gcl_cmpcall.lsp	Sun Jul 24 12:54:28 2005
-+++ gcl_cmpcall.lsp.tpd	Sun Jul 24 12:58:36 2005
-@@ -264,7 +264,9 @@
-             (wt-label *exit*))
-       (unwind-no-exit 'tail-recursion-mark)
-       (wt-nl "goto TTL;")
--      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname))
-+; 20031022000 tpd we don't need to know this
-+;      (cmpnote "Tail-recursive call of ~s was replaced by iteration." fname)
-+      )
- 
-      ;;; Open-codable function call.
-      ((and (listp args)
diff --git a/zips/gcl-2.6.8pre.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.8pre.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index c2905ce..0000000
--- a/zips/gcl-2.6.8pre.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	Sun Jul 24 12:54:29 2005
-+++ gcl_cmpflet.lsp.tpd	Sun Jul 24 13:44:18 2005
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl (c-function-name "L" (fun-cfun (car fd)) (fun-name (car fd))) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.8pre.configure.in.patch b/zips/gcl-2.6.8pre.configure.in.patch
deleted file mode 100644
index fd4e8c1..0000000
--- a/zips/gcl-2.6.8pre.configure.in.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure.in	Sat Jan 15 14:17:17 2005
-+++ configure.in.tpd	Tue Jan 17 09:32:15 2006
-@@ -538,7 +538,7 @@
- 	# results, and the version is kept in special file).
-     
- 	if test -r /etc/.relid -a "X`uname -n`" = "X`uname -s`" ; then
--	    system=MP-RAS-`${AWK} '{print $3}' /etc/.relid'`
-+	    system=MP-RAS-`${AWK} '{print $3}' '/etc/.relid'`
- 	fi
- 	if test "`uname -s`" = "AIX" ; then
- 	    system=AIX-`uname -v`.`uname -r`
diff --git a/zips/gcl-2.6.8pre.configure.patch b/zips/gcl-2.6.8pre.configure.patch
deleted file mode 100644
index 131a382..0000000
--- a/zips/gcl-2.6.8pre.configure.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure	Sat Jan 15 14:17:17 2005
-+++ configure.tpd	Sun Apr 16 23:12:48 2006
-@@ -6187,7 +6187,7 @@
- echo "configure:6188: checking emacs site lisp directory" >&5
- if [ "$EMACS_SITE_LISP" = "unknown" ] ; then
- 	if [ "$EMACS" != "" ] ; then
--		EMACS_SITE_LISP=`$EMACS -q -batch --no-site-file -l conftest.el 2>&1 | sed -e /Loading/d | sed -e /load/d `
-+		EMACS_SITE_LISP=`$EMACS -q -batch --no-site-file -l conftest.el 2>&1 | grep -v ^Warning: | sed -e /Loading/d | sed -e /load/d `
- 	else
- 		EMACS_SITE_LISP=""
- 	fi
diff --git a/zips/gcl-2.6.8pre.h.linux.defs.patch b/zips/gcl-2.6.8pre.h.linux.defs.patch
deleted file mode 100644
index fdefaff..0000000
--- a/zips/gcl-2.6.8pre.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	Sun Jul 24 12:55:14 2005
-+++ linux.defs.tpd	Sun Jul 24 13:55:26 2005
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.8pre.h.powerpc-macosx.defs.patch b/zips/gcl-2.6.8pre.h.powerpc-macosx.defs.patch
deleted file mode 100644
index f5cb47d..0000000
--- a/zips/gcl-2.6.8pre.h.powerpc-macosx.defs.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- powerpc-macosx.defs	2008-02-06 16:25:44.000000000 -0500
-+++ powerpc-macosx.defs.tpd	2008-02-06 16:23:27.000000000 -0500
-@@ -8,6 +8,9 @@
- # This is due to the requirements of the two level namespace.
- LIBS := `echo $(LIBS) | sed -e 's/-lncurses/ /'` /sw/lib/libintl.dylib
- 
-+# 20080206 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+
- # Set this for the linker to operate correctly.
- MACOSX_DEPLOYMENT_TARGET = 10.2
- 
diff --git a/zips/gcl-2.6.8pre.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.8pre.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index bf41aa8..0000000
--- a/zips/gcl-2.6.8pre.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,17 +0,0 @@
---- init_gcl.lsp.in	Mon Jan  9 12:24:57 2006
-+++ init_gcl.lsp.in.tpd	Mon Apr 17 20:40:05 2006
-@@ -85,12 +85,12 @@
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
- 	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)
-+	 (t (format nil si::*system-banner*)
- 	    (let* ((c (find-package "COMPILER"))
- 		   (tmp (and c (find-symbol "*TMP-DIR*" c))))
- 	      (when tmp
- 		(setf (symbol-value tmp) (funcall (find-symbol "GET-TEMP-DIR" c)))
--	(format t "Temporary directory for compiler files set to ~a~%" (symbol-value tmp))))))
-+	(format nil "Temporary directory for compiler files set to ~a~%" (symbol-value tmp))))))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.8pre.unixport.makefile.patch b/zips/gcl-2.6.8pre.unixport.makefile.patch
deleted file mode 100644
index 56ed9a4..0000000
--- a/zips/gcl-2.6.8pre.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Sun Jul 24 12:55:39 2005
-+++ makefile.tpd	Sun Jul 24 15:40:01 2005
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE) 
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.8pre2.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.8pre2.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index c2905ce..0000000
--- a/zips/gcl-2.6.8pre2.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	Sun Jul 24 12:54:29 2005
-+++ gcl_cmpflet.lsp.tpd	Sun Jul 24 13:44:18 2005
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl (c-function-name "L" (fun-cfun (car fd)) (fun-name (car fd))) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.8pre2.configure.in.patch b/zips/gcl-2.6.8pre2.configure.in.patch
deleted file mode 100644
index fd4e8c1..0000000
--- a/zips/gcl-2.6.8pre2.configure.in.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure.in	Sat Jan 15 14:17:17 2005
-+++ configure.in.tpd	Tue Jan 17 09:32:15 2006
-@@ -538,7 +538,7 @@
- 	# results, and the version is kept in special file).
-     
- 	if test -r /etc/.relid -a "X`uname -n`" = "X`uname -s`" ; then
--	    system=MP-RAS-`${AWK} '{print $3}' /etc/.relid'`
-+	    system=MP-RAS-`${AWK} '{print $3}' '/etc/.relid'`
- 	fi
- 	if test "`uname -s`" = "AIX" ; then
- 	    system=AIX-`uname -v`.`uname -r`
diff --git a/zips/gcl-2.6.8pre2.configure.patch b/zips/gcl-2.6.8pre2.configure.patch
deleted file mode 100644
index 131a382..0000000
--- a/zips/gcl-2.6.8pre2.configure.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure	Sat Jan 15 14:17:17 2005
-+++ configure.tpd	Sun Apr 16 23:12:48 2006
-@@ -6187,7 +6187,7 @@
- echo "configure:6188: checking emacs site lisp directory" >&5
- if [ "$EMACS_SITE_LISP" = "unknown" ] ; then
- 	if [ "$EMACS" != "" ] ; then
--		EMACS_SITE_LISP=`$EMACS -q -batch --no-site-file -l conftest.el 2>&1 | sed -e /Loading/d | sed -e /load/d `
-+		EMACS_SITE_LISP=`$EMACS -q -batch --no-site-file -l conftest.el 2>&1 | grep -v ^Warning: | sed -e /Loading/d | sed -e /load/d `
- 	else
- 		EMACS_SITE_LISP=""
- 	fi
diff --git a/zips/gcl-2.6.8pre2.h.linux.defs.patch b/zips/gcl-2.6.8pre2.h.linux.defs.patch
deleted file mode 100644
index fdefaff..0000000
--- a/zips/gcl-2.6.8pre2.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	Sun Jul 24 12:55:14 2005
-+++ linux.defs.tpd	Sun Jul 24 13:55:26 2005
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.8pre2.tgz b/zips/gcl-2.6.8pre2.tgz
deleted file mode 100644
index f3d399a..0000000
Binary files a/zips/gcl-2.6.8pre2.tgz and /dev/null differ
diff --git a/zips/gcl-2.6.8pre2.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.8pre2.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index bf41aa8..0000000
--- a/zips/gcl-2.6.8pre2.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,17 +0,0 @@
---- init_gcl.lsp.in	Mon Jan  9 12:24:57 2006
-+++ init_gcl.lsp.in.tpd	Mon Apr 17 20:40:05 2006
-@@ -85,12 +85,12 @@
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
- 	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)
-+	 (t (format nil si::*system-banner*)
- 	    (let* ((c (find-package "COMPILER"))
- 		   (tmp (and c (find-symbol "*TMP-DIR*" c))))
- 	      (when tmp
- 		(setf (symbol-value tmp) (funcall (find-symbol "GET-TEMP-DIR" c)))
--	(format t "Temporary directory for compiler files set to ~a~%" (symbol-value tmp))))))
-+	(format nil "Temporary directory for compiler files set to ~a~%" (symbol-value tmp))))))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.8pre2.unixport.makefile.patch b/zips/gcl-2.6.8pre2.unixport.makefile.patch
deleted file mode 100644
index 56ed9a4..0000000
--- a/zips/gcl-2.6.8pre2.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	Sun Jul 24 12:55:39 2005
-+++ makefile.tpd	Sun Jul 24 15:40:01 2005
-@@ -14,7 +14,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE) 
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.8pre3.cmpnew.gcl_cmpflet.lsp.patch b/zips/gcl-2.6.8pre3.cmpnew.gcl_cmpflet.lsp.patch
deleted file mode 100644
index c2905ce..0000000
--- a/zips/gcl-2.6.8pre3.cmpnew.gcl_cmpflet.lsp.patch
+++ /dev/null
@@ -1,15 +0,0 @@
---- gcl_cmpflet.lsp	Sun Jul 24 12:54:29 2005
-+++ gcl_cmpflet.lsp.tpd	Sun Jul 24 13:44:18 2005
-@@ -390,8 +390,10 @@
-           (wt-label *exit*))
-     (unwind-no-exit 'tail-recursion-mark)
-     (wt-nl "goto TTL;")
--    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
--             (fun-name (car fd))))
-+; 20031022000 tpd we don't need to know this
-+;    (cmpnote "Tail-recursive call of ~s was replaced by iteration."
-+;             (fun-name (car fd)))
-+    )
-    (t (push-args args)
-       (wt-nl (c-function-name "L" (fun-cfun (car fd)) (fun-name (car fd))) "(")
-       (dotimes** (n (fun-level (car fd))) (wt "base" n ","))
diff --git a/zips/gcl-2.6.8pre3.configure.in.patch b/zips/gcl-2.6.8pre3.configure.in.patch
deleted file mode 100644
index fd4e8c1..0000000
--- a/zips/gcl-2.6.8pre3.configure.in.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure.in	Sat Jan 15 14:17:17 2005
-+++ configure.in.tpd	Tue Jan 17 09:32:15 2006
-@@ -538,7 +538,7 @@
- 	# results, and the version is kept in special file).
-     
- 	if test -r /etc/.relid -a "X`uname -n`" = "X`uname -s`" ; then
--	    system=MP-RAS-`${AWK} '{print $3}' /etc/.relid'`
-+	    system=MP-RAS-`${AWK} '{print $3}' '/etc/.relid'`
- 	fi
- 	if test "`uname -s`" = "AIX" ; then
- 	    system=AIX-`uname -v`.`uname -r`
diff --git a/zips/gcl-2.6.8pre3.configure.patch b/zips/gcl-2.6.8pre3.configure.patch
deleted file mode 100644
index 131a382..0000000
--- a/zips/gcl-2.6.8pre3.configure.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- configure	Sat Jan 15 14:17:17 2005
-+++ configure.tpd	Sun Apr 16 23:12:48 2006
-@@ -6187,7 +6187,7 @@
- echo "configure:6188: checking emacs site lisp directory" >&5
- if [ "$EMACS_SITE_LISP" = "unknown" ] ; then
- 	if [ "$EMACS" != "" ] ; then
--		EMACS_SITE_LISP=`$EMACS -q -batch --no-site-file -l conftest.el 2>&1 | sed -e /Loading/d | sed -e /load/d `
-+		EMACS_SITE_LISP=`$EMACS -q -batch --no-site-file -l conftest.el 2>&1 | grep -v ^Warning: | sed -e /Loading/d | sed -e /load/d `
- 	else
- 		EMACS_SITE_LISP=""
- 	fi
diff --git a/zips/gcl-2.6.8pre3.h.linux.defs.patch b/zips/gcl-2.6.8pre3.h.linux.defs.patch
deleted file mode 100644
index fdefaff..0000000
--- a/zips/gcl-2.6.8pre3.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	Sun Jul 24 12:55:14 2005
-+++ linux.defs.tpd	Sun Jul 24 13:55:26 2005
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.8pre3.o.read.d.patch b/zips/gcl-2.6.8pre3.o.read.d.patch
deleted file mode 100644
index 2c14c82..0000000
--- a/zips/gcl-2.6.8pre3.o.read.d.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- read.tpd	2009-02-20 00:02:00.000000000 -0500
-+++ read.d	2009-02-20 00:02:52.000000000 -0500
-@@ -2272,7 +2272,7 @@
- 	else if (strm == Ct)
- 		strm = symbol_value(sLAterminal_ioA);
- 	check_type_stream(&strm);
--	if (stream_at_end(strm)) {
-+	if (!listen_stream(strm)) {
- 		if (eof_errorp == Cnil)
- 			@(return eof_value)
- 		else
diff --git a/zips/gcl-2.6.8pre3.tgz b/zips/gcl-2.6.8pre3.tgz
deleted file mode 100644
index b1437ad..0000000
Binary files a/zips/gcl-2.6.8pre3.tgz and /dev/null differ
diff --git a/zips/gcl-2.6.8pre3.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.8pre3.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index 553d963..0000000
--- a/zips/gcl-2.6.8pre3.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	2006-10-25 17:17:05.000000000 -0400
-+++ init_gcl.lsp.in.tpd	2008-11-21 13:35:59.000000000 -0500
-@@ -85,8 +85,8 @@
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
- 	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)
--	    (format t "Temporary directory for compiler files set to ~a~%" *tmp-dir*)))
-+	 (t (format nil si::*system-banner*)
-+	    (format nil "Temporary directory for compiler files set to ~a~%" *tmp-dir*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.8pre3.unixport.makefile.patch b/zips/gcl-2.6.8pre3.unixport.makefile.patch
deleted file mode 100644
index 4af04b1..0000000
--- a/zips/gcl-2.6.8pre3.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	2006-08-23 14:14:22.000000000 -0400
-+++ makefile.tpd	2008-11-21 13:31:06.000000000 -0500
-@@ -15,7 +15,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
diff --git a/zips/gcl-2.6.8pre4.h.linux.defs.patch b/zips/gcl-2.6.8pre4.h.linux.defs.patch
deleted file mode 100644
index fdefaff..0000000
--- a/zips/gcl-2.6.8pre4.h.linux.defs.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- linux.defs	Sun Jul 24 12:55:14 2005
-+++ linux.defs.tpd	Sun Jul 24 13:55:26 2005
-@@ -8,6 +8,10 @@
- 
- # Machine dependent makefile definitions for intel 386,486 running linux
- 
-+# 20031022000 tpd link Axiom's code into the image
-+EXTRAS = ${OBJ}/${SYS}/lib/cfuns-c.o ${OBJ}/${SYS}/lib/sockio-c.o
-+OFLAG = -O
-+
- LBINDIR=/usr/local/bin
- 
- #OFLAG	=  -g -Wall
diff --git a/zips/gcl-2.6.8pre4.o.read.d.patch b/zips/gcl-2.6.8pre4.o.read.d.patch
deleted file mode 100644
index 2c14c82..0000000
--- a/zips/gcl-2.6.8pre4.o.read.d.patch
+++ /dev/null
@@ -1,11 +0,0 @@
---- read.tpd	2009-02-20 00:02:00.000000000 -0500
-+++ read.d	2009-02-20 00:02:52.000000000 -0500
-@@ -2272,7 +2272,7 @@
- 	else if (strm == Ct)
- 		strm = symbol_value(sLAterminal_ioA);
- 	check_type_stream(&strm);
--	if (stream_at_end(strm)) {
-+	if (!listen_stream(strm)) {
- 		if (eof_errorp == Cnil)
- 			@(return eof_value)
- 		else
diff --git a/zips/gcl-2.6.8pre4.tgz b/zips/gcl-2.6.8pre4.tgz
deleted file mode 100644
index 65a3820..0000000
Binary files a/zips/gcl-2.6.8pre4.tgz and /dev/null differ
diff --git a/zips/gcl-2.6.8pre4.unixport.init_gcl.lsp.in.patch b/zips/gcl-2.6.8pre4.unixport.init_gcl.lsp.in.patch
deleted file mode 100644
index 553d963..0000000
--- a/zips/gcl-2.6.8pre4.unixport.init_gcl.lsp.in.patch
+++ /dev/null
@@ -1,13 +0,0 @@
---- init_gcl.lsp.in	2006-10-25 17:17:05.000000000 -0400
-+++ init_gcl.lsp.in.tpd	2008-11-21 13:35:59.000000000 -0500
-@@ -85,8 +85,8 @@
-    (cond ((si::get-command-arg "-batch")
- 	  (setq si::*top-level-hook* 'bye))
- 	 ((si::get-command-arg "-f"))
--	 (t (format t si::*system-banner*)
--	    (format t "Temporary directory for compiler files set to ~a~%" *tmp-dir*)))
-+	 (t (format nil si::*system-banner*)
-+	    (format nil "Temporary directory for compiler files set to ~a~%" *tmp-dir*)))
-    (setq si::*ihs-top* 1)
-    (in-package 'system::user) (incf system::*ihs-top* 2)
-    (funcall system::*old-top-level*))
diff --git a/zips/gcl-2.6.8pre4.unixport.makefile.patch b/zips/gcl-2.6.8pre4.unixport.makefile.patch
deleted file mode 100644
index 4af04b1..0000000
--- a/zips/gcl-2.6.8pre4.unixport.makefile.patch
+++ /dev/null
@@ -1,12 +0,0 @@
---- makefile	2006-08-23 14:14:22.000000000 -0400
-+++ makefile.tpd	2008-11-21 13:31:06.000000000 -0500
-@@ -15,7 +15,8 @@
- PORTDIR = $(shell pwd)
- 
- LD_LIBS_PRE=$(FIRST_FILE) $(addprefix -u ,$(PATCHED_SYMBOLS))
--LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp $(LAST_FILE)
-+# 20031022000 tpd link axiom's C library code
-+LD_LIBS_POST=$(LIBS) $(LIBC) -lgclp ${OBJ}/${SYS}/lib/libspad.a $(LAST_FILE)
- 
- ifeq ($(ARRS),)
- ARRS:=ar rs
